C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C
C     This file is part of the air quality modeling system Polyphemus.
C
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C
C     Polyphemus is free software; you can redistribute i and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C------------------------------------------------------------------------
 
      subroutine jacdchemdc(ns,nr,y,convers_factor,
     $                    convers_factor_jac,rk,JacC)
 
C------------------------------------------------------------------------
C
C     -- DESCRIPTION
C
C     This routine computes the Jacobian matrix for the gas-phase.
C     This routine is automatically generated by SPACK.
C     Mechanism: CB05_AEC            
C     Species: _ciCB05_AEC         
C
C------------------------------------------------------------------------
C
C     -- INPUT VARIABLES
C
C     Ns: chemical species number.
C     NR: reaction number.
C     Y: chemical concentrations.
C     RK: kinetic rates.
C     convers_factor: unity conversion factor of mug/m3 to molecules/cm3.
C     convers_factor_jac: Wmol(i)/Wmol(j) for JacC(i,j)
C
C     -- INPUT/OUTPUT VARIABLES
C
C     -- OUTPUT VARIABLES
C
C     JACC: Jacobian matrix.
C
C------------------------------------------------------------------------
C
C     -- REMARKS
C
C     The matrix JACC could be stored in a low-dimensional vector.
C
C------------------------------------------------------------------------
C
C     -- MODIFICATIONS
C
C------------------------------------------------------------------------
C
C     -- AUTHOR(S)
C
C     SPACK.
C
C------------------------------------------------------------------------
 
      implicit none
 
      integer i,j,nr,ns
      double precision dw(nr,ns),rk(nr),y(ns),JacC(ns,ns)
      double precision convers_factor(ns)
      double precision convers_factor_jac(ns,ns)
      double precision conc(ns)
 
      do j=1,ns
       do i=1,ns
        JacC(i,j)=0.d0
       enddo
      enddo
 
C     Conversion mug/m3 to molecules/cm3.
 
      do i = 1, ns
         conc(i) = y(i) * convers_factor(i)
      enddo
 
      call dratedc(ns,nr,rk,conc,dw)
 
      JacC( 60, 66) = JacC( 60, 66) + dw(  1, 66)
      JacC( 65, 66) = JacC( 65, 66) + dw(  1, 66)
      JacC( 66, 66) = JacC( 66, 66) - dw(  1, 66)
      JacC( 60, 60) = JacC( 60, 60) - dw(  2, 60)
      JacC( 62, 60) = JacC( 62, 60) + dw(  2, 60)
      JacC( 62, 62) = JacC( 62, 62) - dw(  3, 62)
      JacC( 62, 65) = JacC( 62, 65) - dw(  3, 65)
      JacC( 65, 62) = JacC( 65, 62) - dw(  3, 62)
      JacC( 65, 65) = JacC( 65, 65) - dw(  3, 65)
      JacC( 66, 62) = JacC( 66, 62) + dw(  3, 62)
      JacC( 66, 65) = JacC( 66, 65) + dw(  3, 65)
      JacC( 60, 60) = JacC( 60, 60) - dw(  4, 60)
      JacC( 60, 66) = JacC( 60, 66) - dw(  4, 66)
      JacC( 65, 60) = JacC( 65, 60) + dw(  4, 60)
      JacC( 65, 66) = JacC( 65, 66) + dw(  4, 66)
      JacC( 66, 60) = JacC( 66, 60) - dw(  4, 60)
      JacC( 66, 66) = JacC( 66, 66) - dw(  4, 66)
      JacC( 59, 60) = JacC( 59, 60) + dw(  5, 60)
      JacC( 59, 66) = JacC( 59, 66) + dw(  5, 66)
      JacC( 60, 60) = JacC( 60, 60) - dw(  5, 60)
      JacC( 60, 66) = JacC( 60, 66) - dw(  5, 66)
      JacC( 66, 60) = JacC( 66, 60) - dw(  5, 60)
      JacC( 66, 66) = JacC( 66, 66) - dw(  5, 66)
      JacC( 60, 60) = JacC( 60, 60) - dw(  6, 60)
      JacC( 60, 65) = JacC( 60, 65) - dw(  6, 65)
      JacC( 65, 60) = JacC( 65, 60) - dw(  6, 60)
      JacC( 65, 65) = JacC( 65, 65) - dw(  6, 65)
      JacC( 66, 60) = JacC( 66, 60) + dw(  6, 60)
      JacC( 66, 65) = JacC( 66, 65) + dw(  6, 65)
      JacC( 59, 66) = JacC( 59, 66) + dw(  7, 66)
      JacC( 59, 62) = JacC( 59, 62) + dw(  7, 62)
      JacC( 62, 66) = JacC( 62, 66) - dw(  7, 66)
      JacC( 62, 62) = JacC( 62, 62) - dw(  7, 62)
      JacC( 66, 66) = JacC( 66, 66) - dw(  7, 66)
      JacC( 66, 62) = JacC( 66, 62) - dw(  7, 62)
      JacC( 60, 62) = JacC( 60, 62) + dw(  8, 62)
      JacC( 62, 62) = JacC( 62, 62) - dw(  8, 62)
      JacC(  3, 62) = JacC(  3, 62) + dw(  9, 62)
      JacC( 62, 62) = JacC( 62, 62) - dw(  9, 62)
      JacC(  3,  3) = JacC(  3,  3) - dw( 10,  3)
      JacC( 60,  3) = JacC( 60,  3) + dw( 10,  3)
      JacC(  3,  3) = JacC(  3,  3) - dw( 11,  3)
      JacC( 58,  3) = JacC( 58,  3)+ 0.2000000000000000D+01*dw( 11,  3)
      JacC( 58, 62) = JacC( 58, 62) - dw( 12, 62)
      JacC( 58, 58) = JacC( 58, 58) - dw( 12, 58)
      JacC( 62, 62) = JacC( 62, 62) - dw( 12, 62)
      JacC( 62, 58) = JacC( 62, 58) - dw( 12, 58)
      JacC( 67, 62) = JacC( 67, 62) + dw( 12, 62)
      JacC( 67, 58) = JacC( 67, 58) + dw( 12, 58)
      JacC( 58, 62) = JacC( 58, 62) + dw( 13, 62)
      JacC( 58, 67) = JacC( 58, 67) + dw( 13, 67)
      JacC( 62, 62) = JacC( 62, 62) - dw( 13, 62)
      JacC( 62, 67) = JacC( 62, 67) - dw( 13, 67)
      JacC( 67, 62) = JacC( 67, 62) - dw( 13, 62)
      JacC( 67, 67) = JacC( 67, 67) - dw( 13, 67)
      JacC( 59, 59) = JacC( 59, 59) - dw( 14, 59)
      JacC( 60, 59) = JacC( 60, 59) + dw( 14, 59)
      JacC( 66, 59) = JacC( 66, 59) + dw( 14, 59)
      JacC( 59, 59) = JacC( 59, 59) - dw( 15, 59)
      JacC( 65, 59) = JacC( 65, 59) + dw( 15, 59)
      JacC( 59, 59) = JacC( 59, 59) - dw( 16, 59)
      JacC( 59, 65) = JacC( 59, 65) - dw( 16, 65)
      JacC( 65, 59) = JacC( 65, 59) - dw( 16, 59)
      JacC( 65, 65) = JacC( 65, 65) - dw( 16, 65)
      JacC( 66, 59) = JacC( 66, 59)+ 0.2000000000000000D+01*dw( 16, 59)
      JacC( 66, 65) = JacC( 66, 65)+ 0.2000000000000000D+01*dw( 16, 65)
      JacC( 59, 59) = JacC( 59, 59) - dw( 17, 59)
      JacC( 59, 66) = JacC( 59, 66) - dw( 17, 66)
      JacC( 65, 59) = JacC( 65, 59) + dw( 17, 59)
      JacC( 65, 66) = JacC( 65, 66) + dw( 17, 66)
      JacC( 15, 59) = JacC( 15, 59) + dw( 18, 59)
      JacC( 15, 66) = JacC( 15, 66) + dw( 18, 66)
      JacC( 59, 59) = JacC( 59, 59) - dw( 18, 59)
      JacC( 59, 66) = JacC( 59, 66) - dw( 18, 66)
      JacC( 66, 59) = JacC( 66, 59) - dw( 18, 59)
      JacC( 66, 66) = JacC( 66, 66) - dw( 18, 66)
      JacC( 15, 15) = JacC( 15, 15) - dw( 19, 15)
      JacC( 50, 15) = JacC( 50, 15)+ 0.2000000000000000D+01*dw( 19, 15)
      JacC( 15, 15) = JacC( 15, 15) - dw( 20, 15)
      JacC( 59, 15) = JacC( 59, 15) + dw( 20, 15)
      JacC( 66, 15) = JacC( 66, 15) + dw( 20, 15)
      JacC( 65, 65) = JacC( 65, 65)- 0.2000000000000000D+01*dw( 21, 65)
      JacC( 65, 65) = JacC( 65, 65)- 0.2000000000000000D+01*dw( 21, 65)
      JacC( 66, 65) = JacC( 66, 65)+ 0.2000000000000000D+01*dw( 21, 65)
      JacC( 66, 65) = JacC( 66, 65)+ 0.2000000000000000D+01*dw( 21, 65)
      JacC( 24, 65) = JacC( 24, 65)+ 0.2000000000000000D+01*dw( 22, 65)
      JacC( 24, 66) = JacC( 24, 66)+ 0.2000000000000000D+01*dw( 22, 66)
      JacC( 65, 65) = JacC( 65, 65) - dw( 22, 65)
      JacC( 65, 66) = JacC( 65, 66) - dw( 22, 66)
      JacC( 66, 65) = JacC( 66, 65) - dw( 22, 65)
      JacC( 66, 66) = JacC( 66, 66) - dw( 22, 66)
      JacC( 24, 58) = JacC( 24, 58) + dw( 23, 58)
      JacC( 24, 65) = JacC( 24, 65) + dw( 23, 65)
      JacC( 58, 58) = JacC( 58, 58) - dw( 23, 58)
      JacC( 58, 65) = JacC( 58, 65) - dw( 23, 65)
      JacC( 65, 58) = JacC( 65, 58) - dw( 23, 58)
      JacC( 65, 65) = JacC( 65, 65) - dw( 23, 65)
      JacC( 24, 24) = JacC( 24, 24) - dw( 24, 24)
      JacC( 58, 24) = JacC( 58, 24) + dw( 24, 24)
      JacC( 65, 24) = JacC( 65, 24) + dw( 24, 24)
      JacC( 24, 58) = JacC( 24, 58) - dw( 25, 58)
      JacC( 24, 24) = JacC( 24, 24) - dw( 25, 24)
      JacC( 58, 58) = JacC( 58, 58) - dw( 25, 58)
      JacC( 58, 24) = JacC( 58, 24) - dw( 25, 24)
      JacC( 66, 58) = JacC( 66, 58) + dw( 25, 58)
      JacC( 66, 24) = JacC( 66, 24) + dw( 25, 24)
      JacC( 24, 24) = JacC( 24, 24)- 0.2000000000000000D+01*dw( 26, 24)
      JacC( 24, 24) = JacC( 24, 24)- 0.2000000000000000D+01*dw( 26, 24)
      JacC( 65, 24) = JacC( 65, 24) + dw( 26, 24)
      JacC( 65, 24) = JacC( 65, 24) + dw( 26, 24)
      JacC( 66, 24) = JacC( 66, 24) + dw( 26, 24)
      JacC( 66, 24) = JacC( 66, 24) + dw( 26, 24)
      JacC( 50, 66) = JacC( 50, 66) + dw( 27, 66)
      JacC( 50, 58) = JacC( 50, 58) + dw( 27, 58)
      JacC( 58, 66) = JacC( 58, 66) - dw( 27, 66)
      JacC( 58, 58) = JacC( 58, 58) - dw( 27, 58)
      JacC( 66, 66) = JacC( 66, 66) - dw( 27, 66)
      JacC( 66, 58) = JacC( 66, 58) - dw( 27, 58)
      JacC( 50, 58) = JacC( 50, 58) - dw( 28, 58)
      JacC( 50, 50) = JacC( 50, 50) - dw( 28, 50)
      JacC( 58, 58) = JacC( 58, 58) - dw( 28, 58)
      JacC( 58, 50) = JacC( 58, 50) - dw( 28, 50)
      JacC( 59, 58) = JacC( 59, 58) + dw( 28, 58)
      JacC( 59, 50) = JacC( 59, 50) + dw( 28, 50)
      JacC( 58, 67) = JacC( 58, 67) + dw( 29, 67)
      JacC( 58, 65) = JacC( 58, 65) + dw( 29, 65)
      JacC( 65, 67) = JacC( 65, 67) - dw( 29, 67)
      JacC( 65, 65) = JacC( 65, 65) - dw( 29, 65)
      JacC( 66, 67) = JacC( 66, 67) + dw( 29, 67)
      JacC( 66, 65) = JacC( 66, 65) + dw( 29, 65)
      JacC( 67, 67) = JacC( 67, 67) - dw( 29, 67)
      JacC( 67, 65) = JacC( 67, 65) - dw( 29, 65)
      JacC( 19, 67) = JacC( 19, 67) + dw( 30, 67)
      JacC( 19, 66) = JacC( 19, 66) + dw( 30, 66)
      JacC( 66, 67) = JacC( 66, 67) - dw( 30, 67)
      JacC( 66, 66) = JacC( 66, 66) - dw( 30, 66)
      JacC( 67, 67) = JacC( 67, 67) - dw( 30, 67)
      JacC( 67, 66) = JacC( 67, 66) - dw( 30, 66)
      JacC( 19, 19) = JacC( 19, 19) - dw( 31, 19)
      JacC( 66, 19) = JacC( 66, 19) + dw( 31, 19)
      JacC( 67, 19) = JacC( 67, 19) + dw( 31, 19)
      JacC( 19, 58) = JacC( 19, 58) - dw( 32, 58)
      JacC( 19, 19) = JacC( 19, 19) - dw( 32, 19)
      JacC( 58, 58) = JacC( 58, 58) - dw( 32, 58)
      JacC( 58, 19) = JacC( 58, 19) - dw( 32, 19)
      JacC( 66, 58) = JacC( 66, 58) + dw( 32, 58)
      JacC( 66, 19) = JacC( 66, 19) + dw( 32, 19)
      JacC( 21, 67) = JacC( 21, 67) + dw( 33, 67)
      JacC( 21, 67) = JacC( 21, 67) + dw( 33, 67)
      JacC( 67, 67) = JacC( 67, 67)- 0.2000000000000000D+01*dw( 33, 67)
      JacC( 67, 67) = JacC( 67, 67)- 0.2000000000000000D+01*dw( 33, 67)
      JacC( 21, 67) = JacC( 21, 67) + dw( 34, 67)
      JacC( 21, 67) = JacC( 21, 67) + dw( 34, 67)
      JacC( 67, 67) = JacC( 67, 67)- 0.2000000000000000D+01*dw( 34, 67)
      JacC( 67, 67) = JacC( 67, 67)- 0.2000000000000000D+01*dw( 34, 67)
      JacC( 21, 21) = JacC( 21, 21) - dw( 35, 21)
      JacC( 58, 21) = JacC( 58, 21)+ 0.2000000000000000D+01*dw( 35, 21)
      JacC( 21, 58) = JacC( 21, 58) - dw( 36, 58)
      JacC( 21, 21) = JacC( 21, 21) - dw( 36, 21)
      JacC( 58, 58) = JacC( 58, 58) - dw( 36, 58)
      JacC( 58, 21) = JacC( 58, 21) - dw( 36, 21)
      JacC( 67, 58) = JacC( 67, 58) + dw( 36, 58)
      JacC( 67, 21) = JacC( 67, 21) + dw( 36, 21)
      JacC(  3,  3) = JacC(  3,  3) - dw( 37,  3)
      JacC( 58,  3) = JacC( 58,  3) + dw( 37,  3)
      JacC( 67,  3) = JacC( 67,  3) + dw( 37,  3)
      JacC( 58, 58) = JacC( 58, 58) - dw( 38, 58)
      JacC( 67, 58) = JacC( 67, 58) + dw( 38, 58)
      JacC( 58, 58) = JacC( 58, 58) - dw( 39, 58)
      JacC( 58, 60) = JacC( 58, 60) - dw( 39, 60)
      JacC( 60, 58) = JacC( 60, 58) - dw( 39, 58)
      JacC( 60, 60) = JacC( 60, 60) - dw( 39, 60)
      JacC( 67, 58) = JacC( 67, 58) + dw( 39, 58)
      JacC( 67, 60) = JacC( 67, 60) + dw( 39, 60)
      JacC( 58, 58) = JacC( 58, 58)- 0.2000000000000000D+01*dw( 40, 58)
      JacC( 58, 58) = JacC( 58, 58)- 0.2000000000000000D+01*dw( 40, 58)
      JacC( 60, 58) = JacC( 60, 58) + dw( 40, 58)
      JacC( 60, 58) = JacC( 60, 58) + dw( 40, 58)
      JacC( 21, 58) = JacC( 21, 58) + dw( 41, 58)
      JacC( 21, 58) = JacC( 21, 58) + dw( 41, 58)
      JacC( 58, 58) = JacC( 58, 58)- 0.2000000000000000D+01*dw( 41, 58)
      JacC( 58, 58) = JacC( 58, 58)- 0.2000000000000000D+01*dw( 41, 58)
      JacC( 58, 58) = JacC( 58, 58) - dw( 42, 58)
      JacC( 58, 67) = JacC( 58, 67) - dw( 42, 67)
      JacC( 67, 58) = JacC( 67, 58) - dw( 42, 58)
      JacC( 67, 67) = JacC( 67, 67) - dw( 42, 67)
      JacC( 58, 67) = JacC( 58, 67) + dw( 43, 67)
      JacC( 58, 60) = JacC( 58, 60) + dw( 43, 60)
      JacC( 60, 67) = JacC( 60, 67) - dw( 43, 67)
      JacC( 60, 60) = JacC( 60, 60) - dw( 43, 60)
      JacC( 67, 67) = JacC( 67, 67) - dw( 43, 67)
      JacC( 67, 60) = JacC( 67, 60) - dw( 43, 60)
      JacC( 21, 21) = JacC( 21, 21) - dw( 44, 21)
      JacC( 21, 60) = JacC( 21, 60) - dw( 44, 60)
      JacC( 58, 21) = JacC( 58, 21) + dw( 44, 21)
      JacC( 58, 60) = JacC( 58, 60) + dw( 44, 60)
      JacC( 60, 21) = JacC( 60, 21) - dw( 44, 21)
      JacC( 60, 60) = JacC( 60, 60) - dw( 44, 60)
      JacC( 67, 21) = JacC( 67, 21) + dw( 44, 21)
      JacC( 67, 60) = JacC( 67, 60) + dw( 44, 60)
      JacC( 59, 59) = JacC( 59, 59) - dw( 45, 59)
      JacC( 59, 60) = JacC( 59, 60) - dw( 45, 60)
      JacC( 60, 59) = JacC( 60, 59) - dw( 45, 59)
      JacC( 60, 60) = JacC( 60, 60) - dw( 45, 60)
      JacC( 66, 59) = JacC( 66, 59) + dw( 45, 59)
      JacC( 66, 60) = JacC( 66, 60) + dw( 45, 60)
      JacC( 58, 59) = JacC( 58, 59) - dw( 46, 59)
      JacC( 58, 58) = JacC( 58, 58) - dw( 46, 58)
      JacC( 59, 59) = JacC( 59, 59) - dw( 46, 59)
      JacC( 59, 58) = JacC( 59, 58) - dw( 46, 58)
      JacC( 66, 59) = JacC( 66, 59) + dw( 46, 59)
      JacC( 66, 58) = JacC( 66, 58) + dw( 46, 58)
      JacC( 67, 59) = JacC( 67, 59) + dw( 46, 59)
      JacC( 67, 58) = JacC( 67, 58) + dw( 46, 58)
      JacC( 50, 59) = JacC( 50, 59) + dw( 47, 59)
      JacC( 50, 67) = JacC( 50, 67) + dw( 47, 67)
      JacC( 59, 59) = JacC( 59, 59) - dw( 47, 59)
      JacC( 59, 67) = JacC( 59, 67) - dw( 47, 67)
      JacC( 67, 59) = JacC( 67, 59) - dw( 47, 59)
      JacC( 67, 67) = JacC( 67, 67) - dw( 47, 67)
      JacC( 59, 59) = JacC( 59, 59) - dw( 48, 59)
      JacC( 59, 62) = JacC( 59, 62) - dw( 48, 62)
      JacC( 62, 59) = JacC( 62, 59) - dw( 48, 59)
      JacC( 62, 62) = JacC( 62, 62) - dw( 48, 62)
      JacC( 66, 59) = JacC( 66, 59) + dw( 48, 59)
      JacC( 66, 62) = JacC( 66, 62) + dw( 48, 62)
      JacC( 59, 59) = JacC( 59, 59)- 0.2000000000000000D+01*dw( 49, 59)
      JacC( 59, 59) = JacC( 59, 59)- 0.2000000000000000D+01*dw( 49, 59)
      JacC( 66, 59) = JacC( 66, 59)+ 0.2000000000000000D+01*dw( 49, 59)
      JacC( 66, 59) = JacC( 66, 59)+ 0.2000000000000000D+01*dw( 49, 59)
      JacC( 19, 19) = JacC( 19, 19) - dw( 50, 19)
      JacC( 58, 19) = JacC( 58, 19)+ 0.3900000000000000D+00*dw( 50, 19)
      JacC( 59, 19) = JacC( 59, 19)+ 0.3900000000000000D+00*dw( 50, 19)
      JacC( 66, 19) = JacC( 66, 19)+ 0.6100000000000000D+00*dw( 50, 19)
      JacC( 67, 19) = JacC( 67, 19)+ 0.6100000000000000D+00*dw( 50, 19)
      JacC( 50, 50) = JacC( 50, 50) - dw( 51, 50)
      JacC( 58, 50) = JacC( 58, 50) + dw( 51, 50)
      JacC( 66, 50) = JacC( 66, 50) + dw( 51, 50)
      JacC( 15, 15) = JacC( 15, 15) - dw( 52, 15)
      JacC( 59, 15) = JacC( 59, 15) + dw( 52, 15)
      JacC( 66, 15) = JacC( 66, 15) + dw( 52, 15)
      JacC( 65, 68) = JacC( 65, 68) - dw( 53, 68)
      JacC( 65, 65) = JacC( 65, 65) - dw( 53, 65)
      JacC( 66, 68) = JacC( 66, 68) + dw( 53, 68)
      JacC( 66, 65) = JacC( 66, 65) + dw( 53, 65)
      JacC( 68, 68) = JacC( 68, 68) - dw( 53, 68)
      JacC( 68, 65) = JacC( 68, 65) - dw( 53, 65)
      JacC( 44, 55) = JacC( 44, 55) + dw( 54, 55)
      JacC( 44, 65) = JacC( 44, 65) + dw( 54, 65)
      JacC( 55, 55) = JacC( 55, 55) - dw( 54, 55)
      JacC( 55, 65) = JacC( 55, 65) - dw( 54, 65)
      JacC( 65, 55) = JacC( 65, 55) - dw( 54, 55)
      JacC( 65, 65) = JacC( 65, 65) - dw( 54, 65)
      JacC( 31, 68) = JacC( 31, 68) + dw( 55, 68)
      JacC( 31, 67) = JacC( 31, 67) + dw( 55, 67)
      JacC( 67, 68) = JacC( 67, 68) - dw( 55, 68)
      JacC( 67, 67) = JacC( 67, 67) - dw( 55, 67)
      JacC( 68, 68) = JacC( 68, 68) - dw( 55, 68)
      JacC( 68, 67) = JacC( 68, 67) - dw( 55, 67)
      JacC( 31, 55) = JacC( 31, 55) + dw( 56, 55)
      JacC( 31, 67) = JacC( 31, 67) + dw( 56, 67)
      JacC( 55, 55) = JacC( 55, 55) - dw( 56, 55)
      JacC( 55, 67) = JacC( 55, 67) - dw( 56, 67)
      JacC( 67, 55) = JacC( 67, 55) - dw( 56, 55)
      JacC( 67, 67) = JacC( 67, 67) - dw( 56, 67)
      JacC( 68, 68) = JacC( 68, 68)- 0.2000000000000000D+01*dw( 57, 68)
      JacC( 68, 68) = JacC( 68, 68)- 0.2000000000000000D+01*dw( 57, 68)
      JacC( 55, 55) = JacC( 55, 55)- 0.2000000000000000D+01*dw( 58, 55)
      JacC( 55, 55) = JacC( 55, 55)- 0.2000000000000000D+01*dw( 58, 55)
      JacC( 55, 68) = JacC( 55, 68) - dw( 59, 68)
      JacC( 55, 55) = JacC( 55, 55) - dw( 59, 55)
      JacC( 68, 68) = JacC( 68, 68) - dw( 59, 68)
      JacC( 68, 55) = JacC( 68, 55) - dw( 59, 55)
      JacC( 44, 44) = JacC( 44, 44) - dw( 60, 44)
      JacC( 44, 58) = JacC( 44, 58) - dw( 60, 58)
      JacC( 45, 44) = JacC( 45, 44)+ 0.6600000000000000D+00*dw( 60, 44)
      JacC( 45, 58) = JacC( 45, 58)+ 0.6600000000000000D+00*dw( 60, 58)
      JacC( 48, 44) = JacC( 48, 44)+ 0.3300000000000000D+00*dw( 60, 44)
      JacC( 48, 58) = JacC( 48, 58)+ 0.3300000000000000D+00*dw( 60, 58)
      JacC( 50, 44) = JacC( 50, 44) + dw( 60, 44)
      JacC( 50, 58) = JacC( 50, 58) + dw( 60, 58)
      JacC( 57, 44) = JacC( 57, 44)+ 0.3300000000000000D+00*dw( 60, 44)
      JacC( 57, 58) = JacC( 57, 58)+ 0.3300000000000000D+00*dw( 60, 58)
      JacC( 58, 44) = JacC( 58, 44) - dw( 60, 44)
      JacC( 58, 58) = JacC( 58, 58) - dw( 60, 58)
      JacC( 61, 44) = JacC( 61, 44)+ 0.3300000000000000D+00*dw( 60, 44)
      JacC( 61, 58) = JacC( 61, 58)+ 0.3300000000000000D+00*dw( 60, 58)
      JacC( 67, 44) = JacC( 67, 44) + dw( 60, 44)
      JacC( 67, 58) = JacC( 67, 58) + dw( 60, 58)
      JacC( 44, 44) = JacC( 44, 44) - dw( 61, 44)
      JacC( 45, 44) = JacC( 45, 44)+ 0.6600000000000000D+00*dw( 61, 44)
      JacC( 48, 44) = JacC( 48, 44)+ 0.3300000000000000D+00*dw( 61, 44)
      JacC( 57, 44) = JacC( 57, 44)+ 0.3300000000000000D+00*dw( 61, 44)
      JacC( 61, 44) = JacC( 61, 44)+ 0.3300000000000000D+00*dw( 61, 44)
      JacC( 66, 44) = JacC( 66, 44) + dw( 61, 44)
      JacC( 67, 44) = JacC( 67, 44) + dw( 61, 44)
      JacC( 31, 31) = JacC( 31, 31) - dw( 62, 31)
      JacC( 31, 58) = JacC( 31, 58) - dw( 62, 58)
      JacC( 48, 31) = JacC( 48, 31)+ 0.5000000000000000D+00*dw( 62, 31)
      JacC( 48, 58) = JacC( 48, 58)+ 0.5000000000000000D+00*dw( 62, 58)
      JacC( 58, 31) = JacC( 58, 31) - dw( 62, 31)
      JacC( 58, 58) = JacC( 58, 58) - dw( 62, 58)
      JacC( 61, 31) = JacC( 61, 31)+ 0.5000000000000000D+00*dw( 62, 31)
      JacC( 61, 58) = JacC( 61, 58)+ 0.5000000000000000D+00*dw( 62, 58)
      JacC( 68, 31) = JacC( 68, 31) + dw( 62, 31)
      JacC( 68, 58) = JacC( 68, 58) + dw( 62, 58)
      JacC( 31, 31) = JacC( 31, 31) - dw( 63, 31)
      JacC( 48, 31) = JacC( 48, 31)+ 0.5000000000000000D+00*dw( 63, 31)
      JacC( 58, 31) = JacC( 58, 31) + dw( 63, 31)
      JacC( 61, 31) = JacC( 61, 31)+ 0.5000000000000000D+00*dw( 63, 31)
      JacC( 67, 31) = JacC( 67, 31) + dw( 63, 31)
      JacC( 51, 58) = JacC( 51, 58) - dw( 64, 58)
      JacC( 51, 51) = JacC( 51, 51) - dw( 64, 51)
      JacC( 58, 58) = JacC( 58, 58) - dw( 64, 58)
      JacC( 58, 51) = JacC( 58, 51) - dw( 64, 51)
      JacC( 67, 58) = JacC( 67, 58) + dw( 64, 58)
      JacC( 67, 51) = JacC( 67, 51) + dw( 64, 51)
      JacC(  5, 58) = JacC(  5, 58) - dw( 65, 58)
      JacC(  5,  5) = JacC(  5,  5) - dw( 65,  5)
      JacC( 56, 58) = JacC( 56, 58) + dw( 65, 58)
      JacC( 56,  5) = JacC( 56,  5) + dw( 65,  5)
      JacC( 58, 58) = JacC( 58, 58) - dw( 65, 58)
      JacC( 58,  5) = JacC( 58,  5) - dw( 65,  5)
      JacC( 56, 56) = JacC( 56, 56) - dw( 66, 56)
      JacC( 56, 65) = JacC( 56, 65) - dw( 66, 65)
      JacC( 57, 56) = JacC( 57, 56) + dw( 66, 56)
      JacC( 57, 65) = JacC( 57, 65) + dw( 66, 65)
      JacC( 65, 56) = JacC( 65, 56) - dw( 66, 56)
      JacC( 65, 65) = JacC( 65, 65) - dw( 66, 65)
      JacC( 66, 56) = JacC( 66, 56) + dw( 66, 56)
      JacC( 66, 65) = JacC( 66, 65) + dw( 66, 65)
      JacC( 67, 56) = JacC( 67, 56) + dw( 66, 56)
      JacC( 67, 65) = JacC( 67, 65) + dw( 66, 65)
      JacC( 23, 56) = JacC( 23, 56) + dw( 67, 56)
      JacC( 23, 67) = JacC( 23, 67) + dw( 67, 67)
      JacC( 56, 56) = JacC( 56, 56) - dw( 67, 56)
      JacC( 56, 67) = JacC( 56, 67) - dw( 67, 67)
      JacC( 67, 56) = JacC( 67, 56) - dw( 67, 56)
      JacC( 67, 67) = JacC( 67, 67) - dw( 67, 67)
      JacC( 13, 56) = JacC( 13, 56)+ 0.6300000000000000D+00*dw( 68, 56)
      JacC( 13, 56) = JacC( 13, 56)+ 0.6300000000000000D+00*dw( 68, 56)
      JacC( 56, 56) = JacC( 56, 56)- 0.2000000000000000D+01*dw( 68, 56)
      JacC( 56, 56) = JacC( 56, 56)- 0.2000000000000000D+01*dw( 68, 56)
      JacC( 57, 56) = JacC( 57, 56)+ 0.1370000000000000D+01*dw( 68, 56)
      JacC( 57, 56) = JacC( 57, 56)+ 0.1370000000000000D+01*dw( 68, 56)
      JacC( 67, 56) = JacC( 67, 56)+ 0.7400000000000000D+00*dw( 68, 56)
      JacC( 67, 56) = JacC( 67, 56)+ 0.7400000000000000D+00*dw( 68, 56)
      JacC( 23, 23) = JacC( 23, 23) - dw( 69, 23)
      JacC( 23, 58) = JacC( 23, 58) - dw( 69, 58)
      JacC( 56, 23) = JacC( 56, 23)+ 0.7000000000000000D+00*dw( 69, 23)
      JacC( 56, 58) = JacC( 56, 58)+ 0.7000000000000000D+00*dw( 69, 58)
      JacC( 58, 23) = JacC( 58, 23) - dw( 69, 23)
      JacC( 58, 58) = JacC( 58, 58) - dw( 69, 58)
      JacC( 67, 23) = JacC( 67, 23)+ 0.3000000000000000D-01*dw( 69, 23)
      JacC( 67, 58) = JacC( 67, 58)+ 0.3000000000000000D-01*dw( 69, 58)
      JacC( 68, 23) = JacC( 68, 23)+ 0.3000000000000000D+00*dw( 69, 23)
      JacC( 68, 58) = JacC( 68, 58)+ 0.3000000000000000D+00*dw( 69, 58)
      JacC( 23, 23) = JacC( 23, 23) - dw( 70, 23)
      JacC( 57, 23) = JacC( 57, 23) + dw( 70, 23)
      JacC( 58, 23) = JacC( 58, 23) + dw( 70, 23)
      JacC( 67, 23) = JacC( 67, 23) + dw( 70, 23)
      JacC( 13, 13) = JacC( 13, 13) - dw( 71, 13)
      JacC( 13, 58) = JacC( 13, 58) - dw( 71, 58)
      JacC( 57, 13) = JacC( 57, 13) + dw( 71, 13)
      JacC( 57, 58) = JacC( 57, 58) + dw( 71, 58)
      JacC( 58, 13) = JacC( 58, 13) - dw( 71, 13)
      JacC( 58, 58) = JacC( 58, 58) - dw( 71, 58)
      JacC( 67, 13) = JacC( 67, 13) + dw( 71, 13)
      JacC( 67, 58) = JacC( 67, 58) + dw( 71, 58)
      JacC( 51, 57) = JacC( 51, 57) + dw( 72, 57)
      JacC( 51, 58) = JacC( 51, 58) + dw( 72, 58)
      JacC( 57, 57) = JacC( 57, 57) - dw( 72, 57)
      JacC( 57, 58) = JacC( 57, 58) - dw( 72, 58)
      JacC( 58, 57) = JacC( 58, 57) - dw( 72, 57)
      JacC( 58, 58) = JacC( 58, 58) - dw( 72, 58)
      JacC( 67, 57) = JacC( 67, 57) + dw( 72, 57)
      JacC( 67, 58) = JacC( 67, 58) + dw( 72, 58)
      JacC( 51, 57) = JacC( 51, 57) + dw( 73, 57)
      JacC( 57, 57) = JacC( 57, 57) - dw( 73, 57)
      JacC( 67, 57) = JacC( 67, 57)+ 0.2000000000000000D+01*dw( 73, 57)
      JacC( 51, 57) = JacC( 51, 57) + dw( 74, 57)
      JacC( 57, 57) = JacC( 57, 57) - dw( 74, 57)
      JacC( 51, 57) = JacC( 51, 57) + dw( 75, 57)
      JacC( 51, 60) = JacC( 51, 60) + dw( 75, 60)
      JacC( 57, 57) = JacC( 57, 57) - dw( 75, 57)
      JacC( 57, 60) = JacC( 57, 60) - dw( 75, 60)
      JacC( 58, 57) = JacC( 58, 57) + dw( 75, 57)
      JacC( 58, 60) = JacC( 58, 60) + dw( 75, 60)
      JacC( 60, 57) = JacC( 60, 57) - dw( 75, 57)
      JacC( 60, 60) = JacC( 60, 60) - dw( 75, 60)
      JacC( 67, 57) = JacC( 67, 57) + dw( 75, 57)
      JacC( 67, 60) = JacC( 67, 60) + dw( 75, 60)
      JacC( 50, 57) = JacC( 50, 57) + dw( 76, 57)
      JacC( 50, 59) = JacC( 50, 59) + dw( 76, 59)
      JacC( 51, 57) = JacC( 51, 57) + dw( 76, 57)
      JacC( 51, 59) = JacC( 51, 59) + dw( 76, 59)
      JacC( 57, 57) = JacC( 57, 57) - dw( 76, 57)
      JacC( 57, 59) = JacC( 57, 59) - dw( 76, 59)
      JacC( 59, 57) = JacC( 59, 57) - dw( 76, 57)
      JacC( 59, 59) = JacC( 59, 59) - dw( 76, 59)
      JacC( 67, 57) = JacC( 67, 57) + dw( 76, 57)
      JacC( 67, 59) = JacC( 67, 59) + dw( 76, 59)
      JacC( 22, 57) = JacC( 22, 57) + dw( 77, 57)
      JacC( 22, 67) = JacC( 22, 67) + dw( 77, 67)
      JacC( 57, 57) = JacC( 57, 57) - dw( 77, 57)
      JacC( 57, 67) = JacC( 57, 67) - dw( 77, 67)
      JacC( 67, 57) = JacC( 67, 57) - dw( 77, 57)
      JacC( 67, 67) = JacC( 67, 67) - dw( 77, 67)
      JacC( 22, 22) = JacC( 22, 22) - dw( 78, 22)
      JacC( 57, 22) = JacC( 57, 22) + dw( 78, 22)
      JacC( 67, 22) = JacC( 67, 22) + dw( 78, 22)
      JacC( 22, 22) = JacC( 22, 22) - dw( 79, 22)
      JacC( 22, 65) = JacC( 22, 65) - dw( 79, 65)
      JacC( 34, 22) = JacC( 34, 22) + dw( 79, 22)
      JacC( 34, 65) = JacC( 34, 65) + dw( 79, 65)
      JacC( 65, 22) = JacC( 65, 22) - dw( 79, 22)
      JacC( 65, 65) = JacC( 65, 65) - dw( 79, 65)
      JacC( 66, 22) = JacC( 66, 22) + dw( 79, 22)
      JacC( 66, 65) = JacC( 66, 65) + dw( 79, 65)
      JacC( 67, 22) = JacC( 67, 22) + dw( 79, 22)
      JacC( 67, 65) = JacC( 67, 65) + dw( 79, 65)
      JacC( 22, 22) = JacC( 22, 22) - dw( 80, 22)
      JacC( 22, 67) = JacC( 22, 67) - dw( 80, 67)
      JacC( 23, 22) = JacC( 23, 22) + dw( 80, 22)
      JacC( 23, 67) = JacC( 23, 67) + dw( 80, 67)
      JacC( 67, 22) = JacC( 67, 22) - dw( 80, 22)
      JacC( 67, 67) = JacC( 67, 67) - dw( 80, 67)
      JacC( 34, 34) = JacC( 34, 34) - dw( 81, 34)
      JacC( 34, 58) = JacC( 34, 58) - dw( 81, 58)
      JacC( 58, 34) = JacC( 58, 34) - dw( 81, 34)
      JacC( 58, 58) = JacC( 58, 58) - dw( 81, 58)
      JacC( 67, 34) = JacC( 67, 34) + dw( 81, 34)
      JacC( 67, 58) = JacC( 67, 58) + dw( 81, 58)
      JacC( 58, 61) = JacC( 58, 61) + dw( 82, 61)
      JacC( 58, 60) = JacC( 58, 60) + dw( 82, 60)
      JacC( 60, 61) = JacC( 60, 61) - dw( 82, 61)
      JacC( 60, 60) = JacC( 60, 60) - dw( 82, 60)
      JacC( 61, 61) = JacC( 61, 61) - dw( 82, 61)
      JacC( 61, 60) = JacC( 61, 60) - dw( 82, 60)
      JacC( 64, 61) = JacC( 64, 61) + dw( 82, 61)
      JacC( 64, 60) = JacC( 64, 60) + dw( 82, 60)
      JacC( 58, 61) = JacC( 58, 61) - dw( 83, 61)
      JacC( 58, 58) = JacC( 58, 58) - dw( 83, 58)
      JacC( 61, 61) = JacC( 61, 61) - dw( 83, 61)
      JacC( 61, 58) = JacC( 61, 58) - dw( 83, 58)
      JacC( 64, 61) = JacC( 64, 61) + dw( 83, 61)
      JacC( 64, 58) = JacC( 64, 58) + dw( 83, 58)
      JacC( 50, 61) = JacC( 50, 61) + dw( 84, 61)
      JacC( 50, 59) = JacC( 50, 59) + dw( 84, 59)
      JacC( 59, 61) = JacC( 59, 61) - dw( 84, 61)
      JacC( 59, 59) = JacC( 59, 59) - dw( 84, 59)
      JacC( 61, 61) = JacC( 61, 61) - dw( 84, 61)
      JacC( 61, 59) = JacC( 61, 59) - dw( 84, 59)
      JacC( 64, 61) = JacC( 64, 61) + dw( 84, 61)
      JacC( 64, 59) = JacC( 64, 59) + dw( 84, 59)
      JacC( 51, 61) = JacC( 51, 61) + dw( 85, 61)
      JacC( 56, 61) = JacC( 56, 61) + dw( 85, 61)
      JacC( 61, 61) = JacC( 61, 61) - dw( 85, 61)
      JacC( 67, 61) = JacC( 67, 61) + dw( 85, 61)
      JacC( 56, 64) = JacC( 56, 64) + dw( 86, 64)
      JacC( 56, 65) = JacC( 56, 65) + dw( 86, 65)
      JacC( 64, 64) = JacC( 64, 64) - dw( 86, 64)
      JacC( 64, 65) = JacC( 64, 65) - dw( 86, 65)
      JacC( 65, 64) = JacC( 65, 64) - dw( 86, 64)
      JacC( 65, 65) = JacC( 65, 65) - dw( 86, 65)
      JacC( 66, 64) = JacC( 66, 64) + dw( 86, 64)
      JacC( 66, 65) = JacC( 66, 65) + dw( 86, 65)
      JacC( 12, 64) = JacC( 12, 64) + dw( 87, 64)
      JacC( 12, 66) = JacC( 12, 66) + dw( 87, 66)
      JacC( 64, 64) = JacC( 64, 64) - dw( 87, 64)
      JacC( 64, 66) = JacC( 64, 66) - dw( 87, 66)
      JacC( 66, 64) = JacC( 66, 64) - dw( 87, 64)
      JacC( 66, 66) = JacC( 66, 66) - dw( 87, 66)
      JacC( 12, 12) = JacC( 12, 12) - dw( 88, 12)
      JacC( 64, 12) = JacC( 64, 12) + dw( 88, 12)
      JacC( 66, 12) = JacC( 66, 12) + dw( 88, 12)
      JacC( 12, 12) = JacC( 12, 12) - dw( 89, 12)
      JacC( 64, 12) = JacC( 64, 12) + dw( 89, 12)
      JacC( 66, 12) = JacC( 66, 12) + dw( 89, 12)
      JacC( 32, 64) = JacC( 32, 64)+ 0.8000000000000000D+00*dw( 90, 64)
      JacC( 32, 67) = JacC( 32, 67)+ 0.8000000000000000D+00*dw( 90, 67)
      JacC( 49, 64) = JacC( 49, 64)+ 0.2000000000000000D+00*dw( 90, 64)
      JacC( 49, 67) = JacC( 49, 67)+ 0.2000000000000000D+00*dw( 90, 67)
      JacC( 62, 64) = JacC( 62, 64)+ 0.2000000000000000D+00*dw( 90, 64)
      JacC( 62, 67) = JacC( 62, 67)+ 0.2000000000000000D+00*dw( 90, 67)
      JacC( 64, 64) = JacC( 64, 64) - dw( 90, 64)
      JacC( 64, 67) = JacC( 64, 67) - dw( 90, 67)
      JacC( 67, 64) = JacC( 67, 64) - dw( 90, 64)
      JacC( 67, 67) = JacC( 67, 67) - dw( 90, 67)
      JacC( 49, 64) = JacC( 49, 64)+ 0.1000000000000000D+00*dw( 91, 64)
      JacC( 49, 56) = JacC( 49, 56)+ 0.1000000000000000D+00*dw( 91, 56)
      JacC( 56, 64) = JacC( 56, 64)- 0.9999999999999998D-01*dw( 91, 64)
      JacC( 56, 56) = JacC( 56, 56)- 0.9999999999999998D-01*dw( 91, 56)
      JacC( 57, 64) = JacC( 57, 64) + dw( 91, 64)
      JacC( 57, 56) = JacC( 57, 56) + dw( 91, 56)
      JacC( 64, 64) = JacC( 64, 64) - dw( 91, 64)
      JacC( 64, 56) = JacC( 64, 56) - dw( 91, 56)
      JacC( 67, 64) = JacC( 67, 64)+ 0.9000000000000000D+00*dw( 91, 64)
      JacC( 67, 56) = JacC( 67, 56)+ 0.9000000000000000D+00*dw( 91, 56)
      JacC( 49, 64) = JacC( 49, 64)+ 0.1000000000000000D+00*dw( 92, 64)
      JacC( 49, 68) = JacC( 49, 68)+ 0.1000000000000000D+00*dw( 92, 68)
      JacC( 56, 64) = JacC( 56, 64)+ 0.9000000000000000D+00*dw( 92, 64)
      JacC( 56, 68) = JacC( 56, 68)+ 0.9000000000000000D+00*dw( 92, 68)
      JacC( 64, 64) = JacC( 64, 64) - dw( 92, 64)
      JacC( 64, 68) = JacC( 64, 68) - dw( 92, 68)
      JacC( 68, 64) = JacC( 68, 64) - dw( 92, 64)
      JacC( 68, 68) = JacC( 68, 68) - dw( 92, 68)
      JacC( 56, 64) = JacC( 56, 64)+ 0.2000000000000000D+01*dw( 93, 64)
      JacC( 56, 64) = JacC( 56, 64)+ 0.2000000000000000D+01*dw( 93, 64)
      JacC( 64, 64) = JacC( 64, 64)- 0.2000000000000000D+01*dw( 93, 64)
      JacC( 64, 64) = JacC( 64, 64)- 0.2000000000000000D+01*dw( 93, 64)
      JacC( 32, 32) = JacC( 32, 32) - dw( 94, 32)
      JacC( 32, 58) = JacC( 32, 58) - dw( 94, 58)
      JacC( 58, 32) = JacC( 58, 32) - dw( 94, 32)
      JacC( 58, 58) = JacC( 58, 58) - dw( 94, 58)
      JacC( 64, 32) = JacC( 64, 32) + dw( 94, 32)
      JacC( 64, 58) = JacC( 64, 58) + dw( 94, 58)
      JacC( 32, 32) = JacC( 32, 32) - dw( 95, 32)
      JacC( 56, 32) = JacC( 56, 32) + dw( 95, 32)
      JacC( 58, 32) = JacC( 58, 32) + dw( 95, 32)
      JacC( 49, 49) = JacC( 49, 49) - dw( 96, 49)
      JacC( 49, 58) = JacC( 49, 58) - dw( 96, 58)
      JacC( 56, 49) = JacC( 56, 49) + dw( 96, 49)
      JacC( 56, 58) = JacC( 56, 58) + dw( 96, 58)
      JacC( 58, 49) = JacC( 58, 49) - dw( 96, 49)
      JacC( 58, 58) = JacC( 58, 58) - dw( 96, 58)
      JacC( 48, 48) = JacC( 48, 48) - dw( 97, 48)
      JacC( 48, 60) = JacC( 48, 60) - dw( 97, 60)
      JacC( 58, 48) = JacC( 58, 48) + dw( 97, 48)
      JacC( 58, 60) = JacC( 58, 60) + dw( 97, 60)
      JacC( 60, 48) = JacC( 60, 48) - dw( 97, 48)
      JacC( 60, 60) = JacC( 60, 60) - dw( 97, 60)
      JacC( 63, 48) = JacC( 63, 48) + dw( 97, 48)
      JacC( 63, 60) = JacC( 63, 60) + dw( 97, 60)
      JacC( 48, 48) = JacC( 48, 48) - dw( 98, 48)
      JacC( 48, 58) = JacC( 48, 58) - dw( 98, 58)
      JacC( 58, 48) = JacC( 58, 48) - dw( 98, 48)
      JacC( 58, 58) = JacC( 58, 58) - dw( 98, 58)
      JacC( 63, 48) = JacC( 63, 48) + dw( 98, 48)
      JacC( 63, 58) = JacC( 63, 58) + dw( 98, 58)
      JacC( 48, 48) = JacC( 48, 48) - dw( 99, 48)
      JacC( 48, 59) = JacC( 48, 59) - dw( 99, 59)
      JacC( 50, 48) = JacC( 50, 48) + dw( 99, 48)
      JacC( 50, 59) = JacC( 50, 59) + dw( 99, 59)
      JacC( 59, 48) = JacC( 59, 48) - dw( 99, 48)
      JacC( 59, 59) = JacC( 59, 59) - dw( 99, 59)
      JacC( 63, 48) = JacC( 63, 48) + dw( 99, 48)
      JacC( 63, 59) = JacC( 63, 59) + dw( 99, 59)
      JacC( 48, 48) = JacC( 48, 48) - dw(100, 48)
      JacC( 51, 48) = JacC( 51, 48) + dw(100, 48)
      JacC( 56, 48) = JacC( 56, 48) + dw(100, 48)
      JacC( 67, 48) = JacC( 67, 48) + dw(100, 48)
      JacC( 61, 63) = JacC( 61, 63) + dw(101, 63)
      JacC( 61, 65) = JacC( 61, 65) + dw(101, 65)
      JacC( 63, 63) = JacC( 63, 63) - dw(101, 63)
      JacC( 63, 65) = JacC( 63, 65) - dw(101, 65)
      JacC( 65, 63) = JacC( 65, 63) - dw(101, 63)
      JacC( 65, 65) = JacC( 65, 65) - dw(101, 65)
      JacC( 66, 63) = JacC( 66, 63) + dw(101, 63)
      JacC( 66, 65) = JacC( 66, 65) + dw(101, 65)
      JacC( 67, 63) = JacC( 67, 63) + dw(101, 63)
      JacC( 67, 65) = JacC( 67, 65) + dw(101, 65)
      JacC( 68, 63) = JacC( 68, 63) + dw(101, 63)
      JacC( 68, 65) = JacC( 68, 65) + dw(101, 65)
      JacC( 18, 63) = JacC( 18, 63) + dw(102, 63)
      JacC( 18, 66) = JacC( 18, 66) + dw(102, 66)
      JacC( 63, 63) = JacC( 63, 63) - dw(102, 63)
      JacC( 63, 66) = JacC( 63, 66) - dw(102, 66)
      JacC( 66, 63) = JacC( 66, 63) - dw(102, 63)
      JacC( 66, 66) = JacC( 66, 66) - dw(102, 66)
      JacC( 18, 18) = JacC( 18, 18) - dw(103, 18)
      JacC( 63, 18) = JacC( 63, 18) + dw(103, 18)
      JacC( 66, 18) = JacC( 66, 18) + dw(103, 18)
      JacC( 18, 18) = JacC( 18, 18) - dw(104, 18)
      JacC( 63, 18) = JacC( 63, 18) + dw(104, 18)
      JacC( 66, 18) = JacC( 66, 18) + dw(104, 18)
      JacC( 18, 18) = JacC( 18, 18) - dw(105, 18)
      JacC( 18, 58) = JacC( 18, 58) - dw(105, 58)
      JacC( 58, 18) = JacC( 58, 18) - dw(105, 18)
      JacC( 58, 58) = JacC( 58, 58) - dw(105, 58)
      JacC( 61, 18) = JacC( 61, 18) + dw(105, 18)
      JacC( 61, 58) = JacC( 61, 58) + dw(105, 58)
      JacC( 66, 18) = JacC( 66, 18) + dw(105, 18)
      JacC( 66, 58) = JacC( 66, 58) + dw(105, 58)
      JacC( 32, 63) = JacC( 32, 63)+ 0.8000000000000000D+00*dw(106, 63)
      JacC( 32, 67) = JacC( 32, 67)+ 0.8000000000000000D+00*dw(106, 67)
      JacC( 49, 63) = JacC( 49, 63)+ 0.2000000000000000D+00*dw(106, 63)
      JacC( 49, 67) = JacC( 49, 67)+ 0.2000000000000000D+00*dw(106, 67)
      JacC( 62, 63) = JacC( 62, 63)+ 0.2000000000000000D+00*dw(106, 63)
      JacC( 62, 67) = JacC( 62, 67)+ 0.2000000000000000D+00*dw(106, 67)
      JacC( 63, 63) = JacC( 63, 63) - dw(106, 63)
      JacC( 63, 67) = JacC( 63, 67) - dw(106, 67)
      JacC( 67, 63) = JacC( 67, 63) - dw(106, 63)
      JacC( 67, 67) = JacC( 67, 67) - dw(106, 67)
      JacC( 49, 64) = JacC( 49, 64)+ 0.1000000000000000D+00*dw(107, 64)
      JacC( 49, 56) = JacC( 49, 56)+ 0.1000000000000000D+00*dw(107, 56)
      JacC( 56, 64) = JacC( 56, 64) - dw(107, 64)
      JacC( 56, 56) = JacC( 56, 56) - dw(107, 56)
      JacC( 57, 64) = JacC( 57, 64)+ 0.1000000000000000D+00*dw(107, 64)
      JacC( 57, 56) = JacC( 57, 56)+ 0.1000000000000000D+00*dw(107, 56)
      JacC( 61, 64) = JacC( 61, 64)+ 0.9000000000000000D+00*dw(107, 64)
      JacC( 61, 56) = JacC( 61, 56)+ 0.9000000000000000D+00*dw(107, 56)
      JacC( 64, 64) = JacC( 64, 64) - dw(107, 64)
      JacC( 64, 56) = JacC( 64, 56) - dw(107, 56)
      JacC( 67, 64) = JacC( 67, 64) + dw(107, 64)
      JacC( 67, 56) = JacC( 67, 56) + dw(107, 56)
      JacC( 68, 64) = JacC( 68, 64)+ 0.9000000000000000D+00*dw(107, 64)
      JacC( 68, 56) = JacC( 68, 56)+ 0.9000000000000000D+00*dw(107, 56)
      JacC( 49, 64) = JacC( 49, 64)+ 0.1000000000000000D+00*dw(108, 64)
      JacC( 49, 68) = JacC( 49, 68)+ 0.1000000000000000D+00*dw(108, 68)
      JacC( 61, 64) = JacC( 61, 64)+ 0.9000000000000000D+00*dw(108, 64)
      JacC( 61, 68) = JacC( 61, 68)+ 0.9000000000000000D+00*dw(108, 68)
      JacC( 64, 64) = JacC( 64, 64) - dw(108, 64)
      JacC( 64, 68) = JacC( 64, 68) - dw(108, 68)
      JacC( 68, 64) = JacC( 68, 64) - dw(108, 64)
      JacC( 68, 68) = JacC( 68, 68) - dw(108, 68)
      JacC( 61, 63) = JacC( 61, 63)+ 0.2000000000000000D+01*dw(109, 63)
      JacC( 61, 63) = JacC( 61, 63)+ 0.2000000000000000D+01*dw(109, 63)
      JacC( 63, 63) = JacC( 63, 63)- 0.2000000000000000D+01*dw(109, 63)
      JacC( 63, 63) = JacC( 63, 63)- 0.2000000000000000D+01*dw(109, 63)
      JacC( 67, 63) = JacC( 67, 63)+ 0.2000000000000000D+01*dw(109, 63)
      JacC( 67, 63) = JacC( 67, 63)+ 0.2000000000000000D+01*dw(109, 63)
      JacC( 68, 63) = JacC( 68, 63)+ 0.2000000000000000D+01*dw(109, 63)
      JacC( 68, 63) = JacC( 68, 63)+ 0.2000000000000000D+01*dw(109, 63)
      JacC( 56, 63) = JacC( 56, 63) + dw(110, 63)
      JacC( 56, 64) = JacC( 56, 64) + dw(110, 64)
      JacC( 61, 63) = JacC( 61, 63) + dw(110, 63)
      JacC( 61, 64) = JacC( 61, 64) + dw(110, 64)
      JacC( 63, 63) = JacC( 63, 63) - dw(110, 63)
      JacC( 63, 64) = JacC( 63, 64) - dw(110, 64)
      JacC( 64, 63) = JacC( 64, 63) - dw(110, 63)
      JacC( 64, 64) = JacC( 64, 64) - dw(110, 64)
      JacC( 67, 63) = JacC( 67, 63) + dw(110, 63)
      JacC( 67, 64) = JacC( 67, 64) + dw(110, 64)
      JacC( 68, 63) = JacC( 68, 63) + dw(110, 63)
      JacC( 68, 64) = JacC( 68, 64) + dw(110, 64)
      JacC( 20, 45) = JacC( 20, 45)+ 0.7600000000000000D+00*dw(111, 45)
      JacC( 20, 58) = JacC( 20, 58)+ 0.7600000000000000D+00*dw(111, 58)
      JacC( 45, 45) = JacC( 45, 45)- 0.8900000000000000D+00*dw(111, 45)
      JacC( 45, 58) = JacC( 45, 58)- 0.8900000000000000D+00*dw(111, 58)
      JacC( 48, 45) = JacC( 48, 45)+ 0.5000000000000000D-01*dw(111, 45)
      JacC( 48, 58) = JacC( 48, 58)+ 0.5000000000000000D-01*dw(111, 58)
      JacC( 55, 45) = JacC( 55, 45)+ 0.1300000000000000D+00*dw(111, 45)
      JacC( 55, 58) = JacC( 55, 58)+ 0.1300000000000000D+00*dw(111, 58)
      JacC( 58, 45) = JacC( 58, 45) - dw(111, 45)
      JacC( 58, 58) = JacC( 58, 58) - dw(111, 58)
      JacC( 61, 45) = JacC( 61, 45)+ 0.6000000000000000D-01*dw(111, 45)
      JacC( 61, 58) = JacC( 61, 58)+ 0.6000000000000000D-01*dw(111, 58)
      JacC( 67, 45) = JacC( 67, 45)+ 0.1100000000000000D+00*dw(111, 45)
      JacC( 67, 58) = JacC( 67, 58)+ 0.1100000000000000D+00*dw(111, 58)
      JacC( 68, 45) = JacC( 68, 45)+ 0.8700000000000000D+00*dw(111, 45)
      JacC( 68, 58) = JacC( 68, 58)+ 0.8700000000000000D+00*dw(111, 58)
      JacC( 20, 20) = JacC( 20, 20)- 0.9800000000000000D+00*dw(112, 20)
      JacC( 45, 20) = JacC( 45, 20)+ 0.2100000000000000D+01*dw(112, 20)
      JacC( 48, 20) = JacC( 48, 20)+ 0.5000000000000000D+00*dw(112, 20)
      JacC( 55, 20) = JacC( 55, 20)+ 0.4000000000000000D-01*dw(112, 20)
      JacC( 61, 20) = JacC( 61, 20)+ 0.6000000000000000D+00*dw(112, 20)
      JacC( 67, 20) = JacC( 67, 20)+ 0.9399999999999999D+00*dw(112, 20)
      JacC( 68, 20) = JacC( 68, 20)+ 0.9600000000000000D+00*dw(112, 20)
      JacC( 20, 20) = JacC( 20, 20) - dw(113, 20)
      JacC( 67, 20) = JacC( 67, 20) + dw(113, 20)
      JacC( 20, 20) = JacC( 20, 20) - dw(114, 20)
      JacC( 20, 66) = JacC( 20, 66) - dw(114, 66)
      JacC( 44, 20) = JacC( 44, 20) + dw(114, 20)
      JacC( 44, 66) = JacC( 44, 66) + dw(114, 66)
      JacC( 66, 20) = JacC( 66, 20) - dw(114, 20)
      JacC( 66, 66) = JacC( 66, 66) - dw(114, 66)
      JacC( 35, 60) = JacC( 35, 60) - dw(115, 60)
      JacC( 35, 35) = JacC( 35, 35) - dw(115, 35)
      JacC( 45, 60) = JacC( 45, 60)+ 0.2000000000000000D+00*dw(115, 60)
      JacC( 45, 35) = JacC( 45, 35)+ 0.2000000000000000D+00*dw(115, 35)
      JacC( 48, 60) = JacC( 48, 60)+ 0.3000000000000000D+00*dw(115, 60)
      JacC( 48, 35) = JacC( 48, 35)+ 0.3000000000000000D+00*dw(115, 35)
      JacC( 51, 60) = JacC( 51, 60)+ 0.2000000000000000D+00*dw(115, 60)
      JacC( 51, 35) = JacC( 51, 35)+ 0.2000000000000000D+00*dw(115, 35)
      JacC( 55, 60) = JacC( 55, 60)+ 0.1000000000000000D-01*dw(115, 60)
      JacC( 55, 35) = JacC( 55, 35)+ 0.1000000000000000D-01*dw(115, 35)
      JacC( 57, 60) = JacC( 57, 60)+ 0.2000000000000000D+00*dw(115, 60)
      JacC( 57, 35) = JacC( 57, 35)+ 0.2000000000000000D+00*dw(115, 35)
      JacC( 58, 60) = JacC( 58, 60)+ 0.1000000000000000D+00*dw(115, 60)
      JacC( 58, 35) = JacC( 58, 35)+ 0.1000000000000000D+00*dw(115, 35)
      JacC( 60, 60) = JacC( 60, 60) - dw(115, 60)
      JacC( 60, 35) = JacC( 60, 35) - dw(115, 35)
      JacC( 61, 60) = JacC( 61, 60)+ 0.2000000000000000D+00*dw(115, 60)
      JacC( 61, 35) = JacC( 61, 35)+ 0.2000000000000000D+00*dw(115, 35)
      JacC( 67, 60) = JacC( 67, 60)+ 0.3000000000000000D+00*dw(115, 60)
      JacC( 67, 35) = JacC( 67, 35)+ 0.3000000000000000D+00*dw(115, 35)
      JacC( 68, 60) = JacC( 68, 60)+ 0.2000000000000000D+00*dw(115, 60)
      JacC( 68, 35) = JacC( 68, 35)+ 0.2000000000000000D+00*dw(115, 35)
      JacC( 35, 58) = JacC( 35, 58) - dw(116, 58)
      JacC( 35, 35) = JacC( 35, 35) - dw(116, 35)
      JacC( 45, 58) = JacC( 45, 58)+ 0.7000000000000000D+00*dw(116, 58)
      JacC( 45, 35) = JacC( 45, 35)+ 0.7000000000000000D+00*dw(116, 35)
      JacC( 48, 58) = JacC( 48, 58)+ 0.6200000000000000D+00*dw(116, 58)
      JacC( 48, 35) = JacC( 48, 35)+ 0.6200000000000000D+00*dw(116, 35)
      JacC( 52, 58) = JacC( 52, 58)+ 0.1600000000000000D-02*dw(116, 58)
      JacC( 52, 35) = JacC( 52, 35)+ 0.1600000000000000D-02*dw(116, 35)
      JacC( 57, 58) = JacC( 57, 58)+ 0.8000000000000000D+00*dw(116, 58)
      JacC( 57, 35) = JacC( 57, 35)+ 0.8000000000000000D+00*dw(116, 35)
      JacC( 58, 58) = JacC( 58, 58) - dw(116, 58)
      JacC( 58, 35) = JacC( 58, 35) - dw(116, 35)
      JacC( 61, 58) = JacC( 61, 58)+ 0.3300000000000000D+00*dw(116, 58)
      JacC( 61, 35) = JacC( 61, 35)+ 0.3300000000000000D+00*dw(116, 35)
      JacC( 67, 58) = JacC( 67, 58)+ 0.9500000000000000D+00*dw(116, 58)
      JacC( 67, 35) = JacC( 67, 35)+ 0.9500000000000000D+00*dw(116, 35)
      JacC( 68, 58) = JacC( 68, 58)+ 0.8000000000000000D+00*dw(116, 58)
      JacC( 68, 35) = JacC( 68, 35)+ 0.8000000000000000D+00*dw(116, 35)
      JacC( 35, 62) = JacC( 35, 62) - dw(117, 62)
      JacC( 35, 35) = JacC( 35, 35) - dw(117, 35)
      JacC( 45, 62) = JacC( 45, 62) + dw(117, 62)
      JacC( 45, 35) = JacC( 45, 35) + dw(117, 35)
      JacC( 48, 62) = JacC( 48, 62)+ 0.3200000000000000D+00*dw(117, 62)
      JacC( 48, 35) = JacC( 48, 35)+ 0.3200000000000000D+00*dw(117, 35)
      JacC( 51, 62) = JacC( 51, 62)+ 0.3300000000000000D+00*dw(117, 62)
      JacC( 51, 35) = JacC( 51, 35)+ 0.3300000000000000D+00*dw(117, 35)
      JacC( 52, 62) = JacC( 52, 62)+ 0.1600000000000000D-02*dw(117, 62)
      JacC( 52, 35) = JacC( 52, 35)+ 0.1600000000000000D-02*dw(117, 35)
      JacC( 57, 62) = JacC( 57, 62)+ 0.7400000000000000D+00*dw(117, 62)
      JacC( 57, 35) = JacC( 57, 35)+ 0.7400000000000000D+00*dw(117, 35)
      JacC( 58, 62) = JacC( 58, 62)+ 0.1000000000000000D+00*dw(117, 62)
      JacC( 58, 35) = JacC( 58, 35)+ 0.1000000000000000D+00*dw(117, 35)
      JacC( 61, 62) = JacC( 61, 62)+ 0.1800000000000000D+00*dw(117, 62)
      JacC( 61, 35) = JacC( 61, 35)+ 0.1800000000000000D+00*dw(117, 35)
      JacC( 62, 62) = JacC( 62, 62) - dw(117, 62)
      JacC( 62, 35) = JacC( 62, 35) - dw(117, 35)
      JacC( 67, 62) = JacC( 67, 62)+ 0.4400000000000000D+00*dw(117, 62)
      JacC( 67, 35) = JacC( 67, 35)+ 0.4400000000000000D+00*dw(117, 35)
      JacC( 68, 62) = JacC( 68, 62)+ 0.2200000000000000D+00*dw(117, 62)
      JacC( 68, 35) = JacC( 68, 35)+ 0.2200000000000000D+00*dw(117, 35)
      JacC( 35, 59) = JacC( 35, 59) - dw(118, 59)
      JacC( 35, 35) = JacC( 35, 35) - dw(118, 35)
      JacC( 45, 59) = JacC( 45, 59) + dw(118, 59)
      JacC( 45, 35) = JacC( 45, 35) + dw(118, 35)
      JacC( 48, 59) = JacC( 48, 59)+ 0.5600000000000001D+00*dw(118, 59)
      JacC( 48, 35) = JacC( 48, 35)+ 0.5600000000000001D+00*dw(118, 35)
      JacC( 52, 59) = JacC( 52, 59)+ 0.1600000000000000D-02*dw(118, 59)
      JacC( 52, 35) = JacC( 52, 35)+ 0.1600000000000000D-02*dw(118, 35)
      JacC( 55, 59) = JacC( 55, 59)+ 0.9000000000000000D-01*dw(118, 59)
      JacC( 55, 35) = JacC( 55, 35)+ 0.9000000000000000D-01*dw(118, 35)
      JacC( 57, 59) = JacC( 57, 59) + dw(118, 59)
      JacC( 57, 35) = JacC( 57, 35) + dw(118, 35)
      JacC( 59, 59) = JacC( 59, 59) - dw(118, 59)
      JacC( 59, 35) = JacC( 59, 35) - dw(118, 35)
      JacC( 61, 59) = JacC( 61, 59)+ 0.3500000000000000D+00*dw(118, 59)
      JacC( 61, 35) = JacC( 61, 35)+ 0.3500000000000000D+00*dw(118, 35)
      JacC( 66, 59) = JacC( 66, 59) + dw(118, 59)
      JacC( 66, 35) = JacC( 66, 35) + dw(118, 35)
      JacC( 68, 59) = JacC( 68, 59)+ 0.9100000000000000D+00*dw(118, 59)
      JacC( 68, 35) = JacC( 68, 35)+ 0.9100000000000000D+00*dw(118, 35)
      JacC( 33, 60) = JacC( 33, 60) - dw(119, 60)
      JacC( 33, 33) = JacC( 33, 33) - dw(119, 33)
      JacC( 51, 60) = JacC( 51, 60) + dw(119, 60)
      JacC( 51, 33) = JacC( 51, 33) + dw(119, 33)
      JacC( 57, 60) = JacC( 57, 60) + dw(119, 60)
      JacC( 57, 33) = JacC( 57, 33) + dw(119, 33)
      JacC( 58, 60) = JacC( 58, 60)+ 0.3000000000000000D+00*dw(119, 60)
      JacC( 58, 33) = JacC( 58, 33)+ 0.3000000000000000D+00*dw(119, 33)
      JacC( 60, 60) = JacC( 60, 60) - dw(119, 60)
      JacC( 60, 33) = JacC( 60, 33) - dw(119, 33)
      JacC( 67, 60) = JacC( 67, 60)+ 0.1700000000000000D+01*dw(119, 60)
      JacC( 67, 33) = JacC( 67, 33)+ 0.1700000000000000D+01*dw(119, 33)
      JacC( 68, 60) = JacC( 68, 60)+ 0.7000000000000000D+00*dw(119, 60)
      JacC( 68, 33) = JacC( 68, 33)+ 0.7000000000000000D+00*dw(119, 33)
      JacC( 33, 58) = JacC( 33, 58) - dw(120, 58)
      JacC( 33, 33) = JacC( 33, 33) - dw(120, 33)
      JacC( 48, 58) = JacC( 48, 58)+ 0.2200000000000000D+00*dw(120, 58)
      JacC( 48, 33) = JacC( 48, 33)+ 0.2200000000000000D+00*dw(120, 33)
      JacC( 57, 58) = JacC( 57, 58)+ 0.1560000000000000D+01*dw(120, 58)
      JacC( 57, 33) = JacC( 57, 33)+ 0.1560000000000000D+01*dw(120, 33)
      JacC( 58, 58) = JacC( 58, 58) - dw(120, 58)
      JacC( 58, 33) = JacC( 58, 33) - dw(120, 33)
      JacC( 67, 58) = JacC( 67, 58) + dw(120, 58)
      JacC( 67, 33) = JacC( 67, 33) + dw(120, 33)
      JacC( 68, 58) = JacC( 68, 58) + dw(120, 58)
      JacC( 68, 33) = JacC( 68, 33) + dw(120, 33)
      JacC( 33, 62) = JacC( 33, 62) - dw(121, 62)
      JacC( 33, 33) = JacC( 33, 33) - dw(121, 33)
      JacC( 34, 62) = JacC( 34, 62)+ 0.3700000000000000D+00*dw(121, 62)
      JacC( 34, 33) = JacC( 34, 33)+ 0.3700000000000000D+00*dw(121, 33)
      JacC( 51, 62) = JacC( 51, 62)+ 0.6300000000000000D+00*dw(121, 62)
      JacC( 51, 33) = JacC( 51, 33)+ 0.6300000000000000D+00*dw(121, 33)
      JacC( 57, 62) = JacC( 57, 62) + dw(121, 62)
      JacC( 57, 33) = JacC( 57, 33) + dw(121, 33)
      JacC( 58, 62) = JacC( 58, 62)+ 0.1300000000000000D+00*dw(121, 62)
      JacC( 58, 33) = JacC( 58, 33)+ 0.1300000000000000D+00*dw(121, 33)
      JacC( 62, 62) = JacC( 62, 62) - dw(121, 62)
      JacC( 62, 33) = JacC( 62, 33) - dw(121, 33)
      JacC( 67, 62) = JacC( 67, 62)+ 0.1300000000000000D+00*dw(121, 62)
      JacC( 67, 33) = JacC( 67, 33)+ 0.1300000000000000D+00*dw(121, 33)
      JacC( 33, 59) = JacC( 33, 59) - dw(122, 59)
      JacC( 33, 33) = JacC( 33, 33) - dw(122, 33)
      JacC( 57, 59) = JacC( 57, 59)+ 0.2000000000000000D+01*dw(122, 59)
      JacC( 57, 33) = JacC( 57, 33)+ 0.2000000000000000D+01*dw(122, 33)
      JacC( 59, 59) = JacC( 59, 59) - dw(122, 59)
      JacC( 59, 33) = JacC( 59, 33) - dw(122, 33)
      JacC( 66, 59) = JacC( 66, 59) + dw(122, 59)
      JacC( 66, 33) = JacC( 66, 33) + dw(122, 33)
      JacC( 68, 59) = JacC( 68, 59) + dw(122, 59)
      JacC( 68, 33) = JacC( 68, 33) + dw(122, 33)
      JacC( 36, 36) = JacC( 36, 36) - dw(123, 36)
      JacC( 36, 60) = JacC( 36, 60) - dw(123, 60)
      JacC( 45, 36) = JacC( 45, 36)+ 0.1000000000000000D+00*dw(123, 36)
      JacC( 45, 60) = JacC( 45, 60)+ 0.1000000000000000D+00*dw(123, 60)
      JacC( 48, 36) = JacC( 48, 36)+ 0.6600000000000000D+00*dw(123, 36)
      JacC( 48, 60) = JacC( 48, 60)+ 0.6600000000000000D+00*dw(123, 60)
      JacC( 51, 36) = JacC( 51, 36)+ 0.1000000000000000D+00*dw(123, 36)
      JacC( 51, 60) = JacC( 51, 60)+ 0.1000000000000000D+00*dw(123, 60)
      JacC( 60, 36) = JacC( 60, 36) - dw(123, 36)
      JacC( 60, 60) = JacC( 60, 60) - dw(123, 60)
      JacC( 61, 36) = JacC( 61, 36)+ 0.1240000000000000D+01*dw(123, 36)
      JacC( 61, 60) = JacC( 61, 60)+ 0.1240000000000000D+01*dw(123, 60)
      JacC( 67, 36) = JacC( 67, 36)+ 0.1000000000000000D+00*dw(123, 36)
      JacC( 67, 60) = JacC( 67, 60)+ 0.1000000000000000D+00*dw(123, 60)
      JacC( 68, 36) = JacC( 68, 36)+ 0.1000000000000000D+00*dw(123, 36)
      JacC( 68, 60) = JacC( 68, 60)+ 0.1000000000000000D+00*dw(123, 60)
      JacC( 36, 36) = JacC( 36, 36) - dw(124, 36)
      JacC( 36, 58) = JacC( 36, 58) - dw(124, 58)
      JacC( 48, 36) = JacC( 48, 36)+ 0.7000000000000000D+00*dw(124, 36)
      JacC( 48, 58) = JacC( 48, 58)+ 0.7000000000000000D+00*dw(124, 58)
      JacC( 52, 36) = JacC( 52, 36)+ 0.3000000000000000D-02*dw(124, 36)
      JacC( 52, 58) = JacC( 52, 58)+ 0.3000000000000000D-02*dw(124, 58)
      JacC( 58, 36) = JacC( 58, 36) - dw(124, 36)
      JacC( 58, 58) = JacC( 58, 58) - dw(124, 58)
      JacC( 61, 36) = JacC( 61, 36)+ 0.1300000000000000D+01*dw(124, 36)
      JacC( 61, 58) = JacC( 61, 58)+ 0.1300000000000000D+01*dw(124, 58)
      JacC( 67, 36) = JacC( 67, 36) + dw(124, 36)
      JacC( 67, 58) = JacC( 67, 58) + dw(124, 58)
      JacC( 68, 36) = JacC( 68, 36) + dw(124, 36)
      JacC( 68, 58) = JacC( 68, 58) + dw(124, 58)
      JacC( 36, 36) = JacC( 36, 36) - dw(125, 36)
      JacC( 36, 62) = JacC( 36, 62) - dw(125, 62)
      JacC( 48, 36) = JacC( 48, 36)+ 0.3500000000000000D+00*dw(125, 36)
      JacC( 48, 62) = JacC( 48, 62)+ 0.3500000000000000D+00*dw(125, 62)
      JacC( 51, 36) = JacC( 51, 36)+ 0.2500000000000000D+00*dw(125, 36)
      JacC( 51, 62) = JacC( 51, 62)+ 0.2500000000000000D+00*dw(125, 62)
      JacC( 52, 36) = JacC( 52, 36)+ 0.3000000000000000D-02*dw(125, 36)
      JacC( 52, 62) = JacC( 52, 62)+ 0.3000000000000000D-02*dw(125, 62)
      JacC( 57, 36) = JacC( 57, 36)+ 0.2500000000000000D+00*dw(125, 36)
      JacC( 57, 62) = JacC( 57, 62)+ 0.2500000000000000D+00*dw(125, 62)
      JacC( 58, 36) = JacC( 58, 36)+ 0.5000000000000000D+00*dw(125, 36)
      JacC( 58, 62) = JacC( 58, 62)+ 0.5000000000000000D+00*dw(125, 62)
      JacC( 60, 36) = JacC( 60, 36)+ 0.5000000000000000D+00*dw(125, 36)
      JacC( 60, 62) = JacC( 60, 62)+ 0.5000000000000000D+00*dw(125, 62)
      JacC( 61, 36) = JacC( 61, 36)+ 0.6500000000000000D+00*dw(125, 36)
      JacC( 61, 62) = JacC( 61, 62)+ 0.6500000000000000D+00*dw(125, 62)
      JacC( 62, 36) = JacC( 62, 36) - dw(125, 36)
      JacC( 62, 62) = JacC( 62, 62) - dw(125, 62)
      JacC( 67, 36) = JacC( 67, 36)+ 0.5000000000000000D+00*dw(125, 36)
      JacC( 67, 62) = JacC( 67, 62)+ 0.5000000000000000D+00*dw(125, 62)
      JacC( 36, 36) = JacC( 36, 36) - dw(126, 36)
      JacC( 36, 59) = JacC( 36, 59) - dw(126, 59)
      JacC( 48, 36) = JacC( 48, 36)+ 0.6400000000000000D+00*dw(126, 36)
      JacC( 48, 59) = JacC( 48, 59)+ 0.6400000000000000D+00*dw(126, 59)
      JacC( 52, 36) = JacC( 52, 36)+ 0.3000000000000000D-02*dw(126, 36)
      JacC( 52, 59) = JacC( 52, 59)+ 0.3000000000000000D-02*dw(126, 59)
      JacC( 59, 36) = JacC( 59, 36) - dw(126, 36)
      JacC( 59, 59) = JacC( 59, 59) - dw(126, 59)
      JacC( 61, 36) = JacC( 61, 36)+ 0.1180000000000000D+01*dw(126, 36)
      JacC( 61, 59) = JacC( 61, 59)+ 0.1180000000000000D+01*dw(126, 59)
      JacC( 66, 36) = JacC( 66, 36) + dw(126, 36)
      JacC( 66, 59) = JacC( 66, 59) + dw(126, 59)
      JacC( 67, 36) = JacC( 67, 36) + dw(126, 36)
      JacC( 67, 59) = JacC( 67, 59) + dw(126, 59)
      JacC(  7,  7) = JacC(  7,  7) - dw(127,  7)
      JacC(  7, 58) = JacC(  7, 58) - dw(127, 58)
      JacC( 14,  7) = JacC( 14,  7)+ 0.5600000000000001D+00*dw(127,  7)
      JacC( 14, 58) = JacC( 14, 58)+ 0.5600000000000001D+00*dw(127, 58)
      JacC( 38,  7) = JacC( 38,  7)+ 0.3600000000000000D+00*dw(127,  7)
      JacC( 38, 58) = JacC( 38, 58)+ 0.3600000000000000D+00*dw(127, 58)
      JacC( 53,  7) = JacC( 53,  7)+ 0.2500000000000000D+00*dw(127,  7)
      JacC( 53, 58) = JacC( 53, 58)+ 0.2500000000000000D+00*dw(127, 58)
      JacC( 58,  7) = JacC( 58,  7) - dw(127,  7)
      JacC( 58, 58) = JacC( 58, 58) - dw(127, 58)
      JacC( 67,  7) = JacC( 67,  7)+ 0.4400000000000000D+00*dw(127,  7)
      JacC( 67, 58) = JacC( 67, 58)+ 0.4400000000000000D+00*dw(127, 58)
      JacC( 68,  7) = JacC( 68,  7)+ 0.8000000000000000D-01*dw(127,  7)
      JacC( 68, 58) = JacC( 68, 58)+ 0.8000000000000000D-01*dw(127, 58)
      JacC( 14, 14) = JacC( 14, 14) - dw(128, 14)
      JacC( 14, 65) = JacC( 14, 65) - dw(128, 65)
      JacC( 39, 14) = JacC( 39, 14)+ 0.9000000000000000D+00*dw(128, 14)
      JacC( 39, 65) = JacC( 39, 65)+ 0.9000000000000000D+00*dw(128, 65)
      JacC( 44, 14) = JacC( 44, 14)+ 0.1000000000000000D+00*dw(128, 14)
      JacC( 44, 65) = JacC( 44, 65)+ 0.1000000000000000D+00*dw(128, 65)
      JacC( 65, 14) = JacC( 65, 14) - dw(128, 14)
      JacC( 65, 65) = JacC( 65, 65) - dw(128, 65)
      JacC( 66, 14) = JacC( 66, 14)+ 0.9000000000000000D+00*dw(128, 14)
      JacC( 66, 65) = JacC( 66, 65)+ 0.9000000000000000D+00*dw(128, 65)
      JacC( 67, 14) = JacC( 67, 14)+ 0.9000000000000000D+00*dw(128, 14)
      JacC( 67, 65) = JacC( 67, 65)+ 0.9000000000000000D+00*dw(128, 65)
      JacC( 14, 14) = JacC( 14, 14) - dw(129, 14)
      JacC( 38, 14) = JacC( 38, 14) + dw(129, 14)
      JacC( 67, 14) = JacC( 67, 14) + dw(129, 14)
      JacC( 38, 58) = JacC( 38, 58) - dw(130, 58)
      JacC( 38, 38) = JacC( 38, 38) - dw(130, 38)
      JacC( 39, 58) = JacC( 39, 58)+ 0.3000000000000000D+00*dw(130, 58)
      JacC( 39, 38) = JacC( 39, 38)+ 0.3000000000000000D+00*dw(130, 38)
      JacC( 41, 58) = JacC( 41, 58)+ 0.4000000000000000D+00*dw(130, 58)
      JacC( 41, 38) = JacC( 41, 38)+ 0.4000000000000000D+00*dw(130, 38)
      JacC( 47, 58) = JacC( 47, 58)+ 0.9000000000000000D-01*dw(130, 58)
      JacC( 47, 38) = JacC( 47, 38)+ 0.9000000000000000D-01*dw(130, 38)
      JacC( 52, 58) = JacC( 52, 58)+ 0.1400000000000000D-01*dw(130, 58)
      JacC( 52, 38) = JacC( 52, 38)+ 0.1400000000000000D-01*dw(130, 38)
      JacC( 58, 58) = JacC( 58, 58) - dw(130, 58)
      JacC( 58, 38) = JacC( 58, 38) - dw(130, 38)
      JacC( 67, 58) = JacC( 67, 58)+ 0.6000000000000000D+00*dw(130, 58)
      JacC( 67, 38) = JacC( 67, 38)+ 0.6000000000000000D+00*dw(130, 38)
      JacC( 68, 58) = JacC( 68, 58)+ 0.6000000000000000D+00*dw(130, 58)
      JacC( 68, 38) = JacC( 68, 38)+ 0.6000000000000000D+00*dw(130, 38)
      JacC( 38, 38) = JacC( 38, 38) - dw(131, 38)
      JacC( 38, 59) = JacC( 38, 59) - dw(131, 59)
      JacC( 41, 38) = JacC( 41, 38) + dw(131, 38)
      JacC( 41, 59) = JacC( 41, 59) + dw(131, 59)
      JacC( 47, 38) = JacC( 47, 38)+ 0.1200000000000000D+00*dw(131, 38)
      JacC( 47, 59) = JacC( 47, 59)+ 0.1200000000000000D+00*dw(131, 59)
      JacC( 50, 38) = JacC( 50, 38) + dw(131, 38)
      JacC( 50, 59) = JacC( 50, 59) + dw(131, 59)
      JacC( 52, 38) = JacC( 52, 38)+ 0.4000000000000000D-01*dw(131, 38)
      JacC( 52, 59) = JacC( 52, 59)+ 0.4000000000000000D-01*dw(131, 59)
      JacC( 59, 38) = JacC( 59, 38) - dw(131, 38)
      JacC( 59, 59) = JacC( 59, 59) - dw(131, 59)
      JacC( 41, 41) = JacC( 41, 41) - dw(132, 41)
      JacC( 41, 66) = JacC( 41, 66) - dw(132, 66)
      JacC( 44, 41) = JacC( 44, 41) + dw(132, 41)
      JacC( 44, 66) = JacC( 44, 66) + dw(132, 66)
      JacC( 66, 41) = JacC( 66, 41) - dw(132, 41)
      JacC( 66, 66) = JacC( 66, 66) - dw(132, 66)
      JacC( 38, 41) = JacC( 38, 41) + dw(133, 41)
      JacC( 38, 67) = JacC( 38, 67) + dw(133, 67)
      JacC( 41, 41) = JacC( 41, 41) - dw(133, 41)
      JacC( 41, 67) = JacC( 41, 67) - dw(133, 67)
      JacC( 67, 41) = JacC( 67, 41) - dw(133, 41)
      JacC( 67, 67) = JacC( 67, 67) - dw(133, 67)
      JacC( 39, 39) = JacC( 39, 39) - dw(134, 39)
      JacC( 51, 39) = JacC( 51, 39) + dw(134, 39)
      JacC( 64, 39) = JacC( 64, 39) + dw(134, 39)
      JacC( 67, 39) = JacC( 67, 39) + dw(134, 39)
      JacC( 39, 39) = JacC( 39, 39) - dw(135, 39)
      JacC( 39, 58) = JacC( 39, 58) - dw(135, 58)
      JacC( 51, 39) = JacC( 51, 39)+ 0.2000000000000000D+01*dw(135, 39)
      JacC( 51, 58) = JacC( 51, 58)+ 0.2000000000000000D+01*dw(135, 58)
      JacC( 57, 39) = JacC( 57, 39) + dw(135, 39)
      JacC( 57, 58) = JacC( 57, 58) + dw(135, 58)
      JacC( 58, 39) = JacC( 58, 39) - dw(135, 39)
      JacC( 58, 58) = JacC( 58, 58) - dw(135, 58)
      JacC( 64, 39) = JacC( 64, 39) + dw(135, 39)
      JacC( 64, 58) = JacC( 64, 58) + dw(135, 58)
      JacC( 67, 39) = JacC( 67, 39)+ 0.2000000000000000D+01*dw(135, 39)
      JacC( 67, 58) = JacC( 67, 58)+ 0.2000000000000000D+01*dw(135, 58)
      JacC( 68, 39) = JacC( 68, 39) + dw(135, 39)
      JacC( 68, 58) = JacC( 68, 58) + dw(135, 58)
      JacC( 39, 39) = JacC( 39, 39) - dw(136, 39)
      JacC( 39, 62) = JacC( 39, 62) - dw(136, 62)
      JacC( 40, 39) = JacC( 40, 39)+ 0.2000000000000000D+00*dw(136, 39)
      JacC( 40, 62) = JacC( 40, 62)+ 0.2000000000000000D+00*dw(136, 62)
      JacC( 48, 39) = JacC( 48, 39)+ 0.3000000000000000D-01*dw(136, 39)
      JacC( 48, 62) = JacC( 48, 62)+ 0.3000000000000000D-01*dw(136, 62)
      JacC( 51, 39) = JacC( 51, 39)+ 0.6899999999999999D+00*dw(136, 39)
      JacC( 51, 62) = JacC( 51, 62)+ 0.6899999999999999D+00*dw(136, 62)
      JacC( 57, 39) = JacC( 57, 39)+ 0.7000000000000000D+00*dw(136, 39)
      JacC( 57, 62) = JacC( 57, 62)+ 0.7000000000000000D+00*dw(136, 62)
      JacC( 58, 39) = JacC( 58, 39)+ 0.8000000000000000D-01*dw(136, 39)
      JacC( 58, 62) = JacC( 58, 62)+ 0.8000000000000000D-01*dw(136, 62)
      JacC( 62, 39) = JacC( 62, 39) - dw(136, 39)
      JacC( 62, 62) = JacC( 62, 62) - dw(136, 62)
      JacC( 64, 39) = JacC( 64, 39)+ 0.6200000000000000D+00*dw(136, 39)
      JacC( 64, 62) = JacC( 64, 62)+ 0.6200000000000000D+00*dw(136, 62)
      JacC( 67, 39) = JacC( 67, 39)+ 0.7600000000000000D+00*dw(136, 39)
      JacC( 67, 62) = JacC( 67, 62)+ 0.7600000000000000D+00*dw(136, 62)
      JacC( 68, 39) = JacC( 68, 39)+ 0.3000000000000000D-01*dw(136, 39)
      JacC( 68, 62) = JacC( 68, 62)+ 0.3000000000000000D-01*dw(136, 62)
      JacC(  8, 58) = JacC(  8, 58) - dw(137, 58)
      JacC(  8,  8) = JacC(  8,  8) - dw(137,  8)
      JacC( 14, 58) = JacC( 14, 58)+ 0.3000000000000000D+00*dw(137, 58)
      JacC( 14,  8) = JacC( 14,  8)+ 0.3000000000000000D+00*dw(137,  8)
      JacC( 38, 58) = JacC( 38, 58)+ 0.2000000000000000D-01*dw(137, 58)
      JacC( 38,  8) = JacC( 38,  8)+ 0.2000000000000000D-01*dw(137,  8)
      JacC( 40, 58) = JacC( 40, 58)+ 0.8000000000000000D+00*dw(137, 58)
      JacC( 40,  8) = JacC( 40,  8)+ 0.8000000000000000D+00*dw(137,  8)
      JacC( 45, 58) = JacC( 45, 58)+ 0.1100000000000000D+01*dw(137, 58)
      JacC( 45,  8) = JacC( 45,  8)+ 0.1100000000000000D+01*dw(137,  8)
      JacC( 54, 58) = JacC( 54, 58)+ 0.2740000000000000D+00*dw(137, 58)
      JacC( 54,  8) = JacC( 54,  8)+ 0.2740000000000000D+00*dw(137,  8)
      JacC( 58, 58) = JacC( 58, 58) - dw(137, 58)
      JacC( 58,  8) = JacC( 58,  8) - dw(137,  8)
      JacC( 67, 58) = JacC( 67, 58)+ 0.7000000000000000D+00*dw(137, 58)
      JacC( 67,  8) = JacC( 67,  8)+ 0.7000000000000000D+00*dw(137,  8)
      JacC( 68, 58) = JacC( 68, 58)+ 0.5000000000000000D+00*dw(137, 58)
      JacC( 68,  8) = JacC( 68,  8)+ 0.5000000000000000D+00*dw(137,  8)
      JacC( 40, 58) = JacC( 40, 58) - dw(138, 58)
      JacC( 40, 40) = JacC( 40, 40) - dw(138, 40)
      JacC( 58, 58) = JacC( 58, 58) - dw(138, 58)
      JacC( 58, 40) = JacC( 58, 40) - dw(138, 40)
      JacC( 64, 58) = JacC( 64, 58) + dw(138, 58)
      JacC( 64, 40) = JacC( 64, 40) + dw(138, 40)
      JacC( 68, 58) = JacC( 68, 58) + dw(138, 58)
      JacC( 68, 40) = JacC( 68, 40) + dw(138, 40)
      JacC( 40, 40) = JacC( 40, 40) - dw(139, 40)
      JacC( 51, 40) = JacC( 51, 40) + dw(139, 40)
      JacC( 64, 40) = JacC( 64, 40) + dw(139, 40)
      JacC( 67, 40) = JacC( 67, 40) + dw(139, 40)
      JacC( 42, 60) = JacC( 42, 60) - dw(140, 60)
      JacC( 42, 42) = JacC( 42, 42) - dw(140, 42)
      JacC( 43, 60) = JacC( 43, 60)+ 0.7500000000000000D+00*dw(140, 60)
      JacC( 43, 42) = JacC( 43, 42)+ 0.7500000000000000D+00*dw(140, 42)
      JacC( 45, 60) = JacC( 45, 60)+ 0.2500000000000000D+00*dw(140, 60)
      JacC( 45, 42) = JacC( 45, 42)+ 0.2500000000000000D+00*dw(140, 42)
      JacC( 57, 60) = JacC( 57, 60)+ 0.5000000000000000D+00*dw(140, 60)
      JacC( 57, 42) = JacC( 57, 42)+ 0.5000000000000000D+00*dw(140, 42)
      JacC( 60, 60) = JacC( 60, 60) - dw(140, 60)
      JacC( 60, 42) = JacC( 60, 42) - dw(140, 42)
      JacC( 63, 60) = JacC( 63, 60)+ 0.2500000000000000D+00*dw(140, 60)
      JacC( 63, 42) = JacC( 63, 42)+ 0.2500000000000000D+00*dw(140, 42)
      JacC( 67, 60) = JacC( 67, 60)+ 0.2500000000000000D+00*dw(140, 60)
      JacC( 67, 42) = JacC( 67, 42)+ 0.2500000000000000D+00*dw(140, 42)
      JacC( 68, 60) = JacC( 68, 60)+ 0.2500000000000000D+00*dw(140, 60)
      JacC( 68, 42) = JacC( 68, 42)+ 0.2500000000000000D+00*dw(140, 42)
      JacC( 16, 58) = JacC( 16, 58)+ 0.2320000000000000D+00*dw(141, 58)
      JacC( 16, 42) = JacC( 16, 42)+ 0.2320000000000000D+00*dw(141, 42)
      JacC( 17, 58) = JacC( 17, 58)+ 0.2880000000000000D-01*dw(141, 58)
      JacC( 17, 42) = JacC( 17, 42)+ 0.2880000000000000D-01*dw(141, 42)
      JacC( 42, 58) = JacC( 42, 58) - dw(141, 58)
      JacC( 42, 42) = JacC( 42, 42) - dw(141, 42)
      JacC( 43, 58) = JacC( 43, 58)+ 0.9120000000000000D+00*dw(141, 58)
      JacC( 43, 42) = JacC( 43, 42)+ 0.9120000000000000D+00*dw(141, 42)
      JacC( 55, 58) = JacC( 55, 58)+ 0.8799999999999999D-01*dw(141, 58)
      JacC( 55, 42) = JacC( 55, 42)+ 0.8799999999999999D-01*dw(141, 42)
      JacC( 57, 58) = JacC( 57, 58)+ 0.6290000000000000D+00*dw(141, 58)
      JacC( 57, 42) = JacC( 57, 42)+ 0.6290000000000000D+00*dw(141, 42)
      JacC( 58, 58) = JacC( 58, 58) - dw(141, 58)
      JacC( 58, 42) = JacC( 58, 42) - dw(141, 42)
      JacC( 67, 58) = JacC( 67, 58)+ 0.9120000000000000D+00*dw(141, 58)
      JacC( 67, 42) = JacC( 67, 42)+ 0.9120000000000000D+00*dw(141, 42)
      JacC( 68, 58) = JacC( 68, 58)+ 0.9910000000000000D+00*dw(141, 58)
      JacC( 68, 42) = JacC( 68, 42)+ 0.9910000000000000D+00*dw(141, 42)
      JacC( 42, 62) = JacC( 42, 62) - dw(142, 62)
      JacC( 42, 42) = JacC( 42, 42) - dw(142, 42)
      JacC( 43, 62) = JacC( 43, 62)+ 0.6500000000000000D+00*dw(142, 62)
      JacC( 43, 42) = JacC( 43, 42)+ 0.6500000000000000D+00*dw(142, 42)
      JacC( 45, 62) = JacC( 45, 62)+ 0.3500000000000000D+00*dw(142, 62)
      JacC( 45, 42) = JacC( 45, 42)+ 0.3500000000000000D+00*dw(142, 42)
      JacC( 48, 62) = JacC( 48, 62)+ 0.1500000000000000D+00*dw(142, 62)
      JacC( 48, 42) = JacC( 48, 42)+ 0.1500000000000000D+00*dw(142, 42)
      JacC( 51, 62) = JacC( 51, 62)+ 0.6600000000000000D-01*dw(142, 62)
      JacC( 51, 42) = JacC( 51, 42)+ 0.6600000000000000D-01*dw(142, 42)
      JacC( 57, 62) = JacC( 57, 62)+ 0.6000000000000000D+00*dw(142, 62)
      JacC( 57, 42) = JacC( 57, 42)+ 0.6000000000000000D+00*dw(142, 42)
      JacC( 58, 62) = JacC( 58, 62)+ 0.2660000000000000D+00*dw(142, 62)
      JacC( 58, 42) = JacC( 58, 42)+ 0.2660000000000000D+00*dw(142, 42)
      JacC( 62, 62) = JacC( 62, 62) - dw(142, 62)
      JacC( 62, 42) = JacC( 62, 42) - dw(142, 42)
      JacC( 63, 62) = JacC( 63, 62)+ 0.2000000000000000D+00*dw(142, 62)
      JacC( 63, 42) = JacC( 63, 42)+ 0.2000000000000000D+00*dw(142, 42)
      JacC( 67, 62) = JacC( 67, 62)+ 0.6600000000000000D-01*dw(142, 62)
      JacC( 67, 42) = JacC( 67, 42)+ 0.6600000000000000D-01*dw(142, 42)
      JacC( 68, 62) = JacC( 68, 62)+ 0.2000000000000000D+00*dw(142, 62)
      JacC( 68, 42) = JacC( 68, 42)+ 0.2000000000000000D+00*dw(142, 42)
      JacC( 42, 59) = JacC( 42, 59) - dw(143, 59)
      JacC( 42, 42) = JacC( 42, 42) - dw(143, 42)
      JacC( 43, 59) = JacC( 43, 59)+ 0.2000000000000000D+00*dw(143, 59)
      JacC( 43, 42) = JacC( 43, 42)+ 0.2000000000000000D+00*dw(143, 42)
      JacC( 44, 59) = JacC( 44, 59)+ 0.8000000000000000D+00*dw(143, 59)
      JacC( 44, 42) = JacC( 44, 42)+ 0.8000000000000000D+00*dw(143, 42)
      JacC( 45, 59) = JacC( 45, 59)+ 0.2400000000000000D+01*dw(143, 59)
      JacC( 45, 42) = JacC( 45, 42)+ 0.2400000000000000D+01*dw(143, 42)
      JacC( 48, 59) = JacC( 48, 59)+ 0.8000000000000000D+00*dw(143, 59)
      JacC( 48, 42) = JacC( 48, 42)+ 0.8000000000000000D+00*dw(143, 42)
      JacC( 59, 59) = JacC( 59, 59) - dw(143, 59)
      JacC( 59, 42) = JacC( 59, 42) - dw(143, 42)
      JacC( 66, 59) = JacC( 66, 59)+ 0.2000000000000000D+00*dw(143, 59)
      JacC( 66, 42) = JacC( 66, 42)+ 0.2000000000000000D+00*dw(143, 42)
      JacC( 67, 59) = JacC( 67, 59)+ 0.8000000000000000D+00*dw(143, 59)
      JacC( 67, 42) = JacC( 67, 42)+ 0.8000000000000000D+00*dw(143, 42)
      JacC( 68, 59) = JacC( 68, 59) + dw(143, 59)
      JacC( 68, 42) = JacC( 68, 42) + dw(143, 42)
      JacC( 40, 58) = JacC( 40, 58)+ 0.1680000000000000D+00*dw(144, 58)
      JacC( 40, 43) = JacC( 40, 43)+ 0.1680000000000000D+00*dw(144, 43)
      JacC( 43, 58) = JacC( 43, 58) - dw(144, 58)
      JacC( 43, 43) = JacC( 43, 43) - dw(144, 43)
      JacC( 45, 58) = JacC( 45, 58)+ 0.1565000000000000D+01*dw(144, 58)
      JacC( 45, 43) = JacC( 45, 43)+ 0.1565000000000000D+01*dw(144, 43)
      JacC( 48, 58) = JacC( 48, 58)+ 0.1200000000000000D+00*dw(144, 58)
      JacC( 48, 43) = JacC( 48, 43)+ 0.1200000000000000D+00*dw(144, 43)
      JacC( 51, 58) = JacC( 51, 58)+ 0.3340000000000000D+00*dw(144, 58)
      JacC( 51, 43) = JacC( 51, 43)+ 0.3340000000000000D+00*dw(144, 43)
      JacC( 57, 58) = JacC( 57, 58)+ 0.1670000000000000D+00*dw(144, 58)
      JacC( 57, 43) = JacC( 57, 43)+ 0.1670000000000000D+00*dw(144, 43)
      JacC( 58, 58) = JacC( 58, 58) - dw(144, 58)
      JacC( 58, 43) = JacC( 58, 43) - dw(144, 43)
      JacC( 61, 58) = JacC( 61, 58)+ 0.2520000000000000D+00*dw(144, 58)
      JacC( 61, 43) = JacC( 61, 43)+ 0.2520000000000000D+00*dw(144, 43)
      JacC( 63, 58) = JacC( 63, 58)+ 0.2500000000000000D+00*dw(144, 58)
      JacC( 63, 43) = JacC( 63, 43)+ 0.2500000000000000D+00*dw(144, 43)
      JacC( 64, 58) = JacC( 64, 58)+ 0.2100000000000000D+00*dw(144, 58)
      JacC( 64, 43) = JacC( 64, 43)+ 0.2100000000000000D+00*dw(144, 43)
      JacC( 67, 58) = JacC( 67, 58)+ 0.5030000000000000D+00*dw(144, 58)
      JacC( 67, 43) = JacC( 67, 43)+ 0.5030000000000000D+00*dw(144, 43)
      JacC( 68, 58) = JacC( 68, 58)+ 0.7130000000000000D+00*dw(144, 58)
      JacC( 68, 43) = JacC( 68, 43)+ 0.7130000000000000D+00*dw(144, 43)
      JacC( 40, 62) = JacC( 40, 62)+ 0.8500000000000000D+00*dw(145, 62)
      JacC( 40, 43) = JacC( 40, 43)+ 0.8500000000000000D+00*dw(145, 43)
      JacC( 43, 62) = JacC( 43, 62) - dw(145, 62)
      JacC( 43, 43) = JacC( 43, 43) - dw(145, 43)
      JacC( 45, 62) = JacC( 45, 62)+ 0.3600000000000000D+00*dw(145, 62)
      JacC( 45, 43) = JacC( 45, 43)+ 0.3600000000000000D+00*dw(145, 43)
      JacC( 51, 62) = JacC( 51, 62)+ 0.2250000000000000D+00*dw(145, 62)
      JacC( 51, 43) = JacC( 51, 43)+ 0.2250000000000000D+00*dw(145, 43)
      JacC( 57, 62) = JacC( 57, 62)+ 0.1500000000000000D+00*dw(145, 62)
      JacC( 57, 43) = JacC( 57, 43)+ 0.1500000000000000D+00*dw(145, 43)
      JacC( 58, 62) = JacC( 58, 62)+ 0.2680000000000000D+00*dw(145, 62)
      JacC( 58, 43) = JacC( 58, 43)+ 0.2680000000000000D+00*dw(145, 43)
      JacC( 61, 62) = JacC( 61, 62)+ 0.2000000000000000D-01*dw(145, 62)
      JacC( 61, 43) = JacC( 61, 43)+ 0.2000000000000000D-01*dw(145, 43)
      JacC( 62, 62) = JacC( 62, 62) - dw(145, 62)
      JacC( 62, 43) = JacC( 62, 43) - dw(145, 43)
      JacC( 64, 62) = JacC( 64, 62)+ 0.1140000000000000D+00*dw(145, 62)
      JacC( 64, 43) = JacC( 64, 43)+ 0.1140000000000000D+00*dw(145, 43)
      JacC( 67, 62) = JacC( 67, 62)+ 0.1540000000000000D+00*dw(145, 62)
      JacC( 67, 43) = JacC( 67, 43)+ 0.1540000000000000D+00*dw(145, 43)
      JacC( 68, 62) = JacC( 68, 62)+ 0.6400000000000000D-01*dw(145, 62)
      JacC( 68, 43) = JacC( 68, 43)+ 0.6400000000000000D-01*dw(145, 43)
      JacC( 43, 59) = JacC( 43, 59) - dw(146, 59)
      JacC( 43, 43) = JacC( 43, 43) - dw(146, 43)
      JacC( 44, 59) = JacC( 44, 59)+ 0.8500000000000000D+00*dw(146, 59)
      JacC( 44, 43) = JacC( 44, 43)+ 0.8500000000000000D+00*dw(146, 43)
      JacC( 45, 59) = JacC( 45, 59)+ 0.1282000000000000D+01*dw(146, 59)
      JacC( 45, 43) = JacC( 45, 43)+ 0.1282000000000000D+01*dw(146, 43)
      JacC( 48, 59) = JacC( 48, 59)+ 0.3570000000000000D+00*dw(146, 59)
      JacC( 48, 43) = JacC( 48, 43)+ 0.3570000000000000D+00*dw(146, 43)
      JacC( 50, 59) = JacC( 50, 59)+ 0.1500000000000000D+00*dw(146, 59)
      JacC( 50, 43) = JacC( 50, 43)+ 0.1500000000000000D+00*dw(146, 43)
      JacC( 51, 59) = JacC( 51, 59)+ 0.6430000000000000D+00*dw(146, 59)
      JacC( 51, 43) = JacC( 51, 43)+ 0.6430000000000000D+00*dw(146, 43)
      JacC( 57, 59) = JacC( 57, 59)+ 0.2820000000000000D+00*dw(146, 59)
      JacC( 57, 43) = JacC( 57, 43)+ 0.2820000000000000D+00*dw(146, 43)
      JacC( 59, 59) = JacC( 59, 59) - dw(146, 59)
      JacC( 59, 43) = JacC( 59, 43) - dw(146, 43)
      JacC( 63, 59) = JacC( 63, 59)+ 0.7500000000000000D-01*dw(146, 59)
      JacC( 63, 43) = JacC( 63, 43)+ 0.7500000000000000D-01*dw(146, 43)
      JacC( 67, 59) = JacC( 67, 59)+ 0.9250000000000000D+00*dw(146, 59)
      JacC( 67, 43) = JacC( 67, 43)+ 0.9250000000000000D+00*dw(146, 43)
      JacC( 68, 59) = JacC( 68, 59)+ 0.7500000000000000D-01*dw(146, 59)
      JacC( 68, 43) = JacC( 68, 43)+ 0.7500000000000000D-01*dw(146, 43)
      JacC( 43, 43) = JacC( 43, 43) - dw(147, 43)
      JacC( 45, 43) = JacC( 45, 43)+ 0.8320000000000000D+00*dw(147, 43)
      JacC( 51, 43) = JacC( 51, 43)+ 0.3330000000000000D+00*dw(147, 43)
      JacC( 57, 43) = JacC( 57, 43)+ 0.9000000000000000D+00*dw(147, 43)
      JacC( 61, 43) = JacC( 61, 43)+ 0.6700000000000000D-01*dw(147, 43)
      JacC( 64, 43) = JacC( 64, 43)+ 0.9670000000000000D+00*dw(147, 43)
      JacC( 67, 43) = JacC( 67, 43)+ 0.1033000000000000D+01*dw(147, 43)
      JacC( 68, 43) = JacC( 68, 43)+ 0.7000000000000000D+00*dw(147, 43)
      JacC( 37, 37) = JacC( 37, 37) - dw(148, 37)
      JacC( 37, 60) = JacC( 37, 60) - dw(148, 60)
      JacC( 45, 37) = JacC( 45, 37)+ 0.5120000000000000D+01*dw(148, 37)
      JacC( 45, 60) = JacC( 45, 60)+ 0.5120000000000000D+01*dw(148, 60)
      JacC( 48, 37) = JacC( 48, 37)+ 0.1500000000000000D+00*dw(148, 37)
      JacC( 48, 60) = JacC( 48, 60)+ 0.1500000000000000D+00*dw(148, 60)
      JacC( 60, 37) = JacC( 60, 37) - dw(148, 37)
      JacC( 60, 60) = JacC( 60, 60) - dw(148, 60)
      JacC( 37, 37) = JacC( 37, 37) - dw(149, 37)
      JacC( 37, 58) = JacC( 37, 58) - dw(149, 58)
      JacC( 45, 37) = JacC( 45, 37)+ 0.1660000000000000D+01*dw(149, 37)
      JacC( 45, 58) = JacC( 45, 58)+ 0.1660000000000000D+01*dw(149, 58)
      JacC( 48, 37) = JacC( 48, 37)+ 0.4700000000000000D+00*dw(149, 37)
      JacC( 48, 58) = JacC( 48, 58)+ 0.4700000000000000D+00*dw(149, 58)
      JacC( 55, 37) = JacC( 55, 37)+ 0.2500000000000000D+00*dw(149, 37)
      JacC( 55, 58) = JacC( 55, 58)+ 0.2500000000000000D+00*dw(149, 58)
      JacC( 57, 37) = JacC( 57, 37)+ 0.2800000000000000D+00*dw(149, 37)
      JacC( 57, 58) = JacC( 57, 58)+ 0.2800000000000000D+00*dw(149, 58)
      JacC( 58, 37) = JacC( 58, 37) - dw(149, 37)
      JacC( 58, 58) = JacC( 58, 58) - dw(149, 58)
      JacC( 67, 37) = JacC( 67, 37)+ 0.7500000000000000D+00*dw(149, 37)
      JacC( 67, 58) = JacC( 67, 58)+ 0.7500000000000000D+00*dw(149, 58)
      JacC( 68, 37) = JacC( 68, 37)+ 0.1250000000000000D+01*dw(149, 37)
      JacC( 68, 58) = JacC( 68, 58)+ 0.1250000000000000D+01*dw(149, 58)
      JacC( 37, 37) = JacC( 37, 37) - dw(150, 37)
      JacC( 37, 62) = JacC( 37, 62) - dw(150, 62)
      JacC( 45, 37) = JacC( 45, 37)+ 0.7000000000000000D+01*dw(150, 37)
      JacC( 45, 62) = JacC( 45, 62)+ 0.7000000000000000D+01*dw(150, 62)
      JacC( 48, 37) = JacC( 48, 37)+ 0.2100000000000000D+00*dw(150, 37)
      JacC( 48, 62) = JacC( 48, 62)+ 0.2100000000000000D+00*dw(150, 62)
      JacC( 51, 37) = JacC( 51, 37)+ 0.1000000000000000D-02*dw(150, 37)
      JacC( 51, 62) = JacC( 51, 62)+ 0.1000000000000000D-02*dw(150, 62)
      JacC( 55, 37) = JacC( 55, 37)+ 0.1800000000000000D+00*dw(150, 37)
      JacC( 55, 62) = JacC( 55, 62)+ 0.1800000000000000D+00*dw(150, 62)
      JacC( 57, 37) = JacC( 57, 37)+ 0.2400000000000000D+00*dw(150, 37)
      JacC( 57, 62) = JacC( 57, 62)+ 0.2400000000000000D+00*dw(150, 62)
      JacC( 58, 37) = JacC( 58, 37)+ 0.5700000000000000D+00*dw(150, 37)
      JacC( 58, 62) = JacC( 58, 62)+ 0.5700000000000000D+00*dw(150, 62)
      JacC( 62, 37) = JacC( 62, 37) - dw(150, 37)
      JacC( 62, 62) = JacC( 62, 62) - dw(150, 62)
      JacC( 63, 37) = JacC( 63, 37)+ 0.3900000000000000D+00*dw(150, 37)
      JacC( 63, 62) = JacC( 63, 62)+ 0.3900000000000000D+00*dw(150, 62)
      JacC( 67, 37) = JacC( 67, 37)+ 0.7000000000000001D-01*dw(150, 37)
      JacC( 67, 62) = JacC( 67, 62)+ 0.7000000000000001D-01*dw(150, 62)
      JacC( 68, 37) = JacC( 68, 37)+ 0.7600000000000000D+00*dw(150, 37)
      JacC( 68, 62) = JacC( 68, 62)+ 0.7600000000000000D+00*dw(150, 62)
      JacC( 37, 37) = JacC( 37, 37) - dw(151, 37)
      JacC( 37, 59) = JacC( 37, 59) - dw(151, 59)
      JacC( 44, 37) = JacC( 44, 37)+ 0.5300000000000000D+00*dw(151, 37)
      JacC( 44, 59) = JacC( 44, 59)+ 0.5300000000000000D+00*dw(151, 59)
      JacC( 48, 37) = JacC( 48, 37)+ 0.4700000000000000D+00*dw(151, 37)
      JacC( 48, 59) = JacC( 48, 59)+ 0.4700000000000000D+00*dw(151, 59)
      JacC( 55, 37) = JacC( 55, 37)+ 0.2500000000000000D+00*dw(151, 37)
      JacC( 55, 59) = JacC( 55, 59)+ 0.2500000000000000D+00*dw(151, 59)
      JacC( 59, 37) = JacC( 59, 37) - dw(151, 37)
      JacC( 59, 59) = JacC( 59, 59) - dw(151, 59)
      JacC( 66, 37) = JacC( 66, 37)+ 0.4700000000000000D+00*dw(151, 37)
      JacC( 66, 59) = JacC( 66, 59)+ 0.4700000000000000D+00*dw(151, 59)
      JacC( 67, 37) = JacC( 67, 37)+ 0.2800000000000000D+00*dw(151, 37)
      JacC( 67, 59) = JacC( 67, 59)+ 0.2800000000000000D+00*dw(151, 59)
      JacC( 68, 37) = JacC( 68, 37)+ 0.1030000000000000D+01*dw(151, 37)
      JacC( 68, 59) = JacC( 68, 59)+ 0.1030000000000000D+01*dw(151, 59)
      JacC(  9,  9) = JacC(  9,  9) - dw(152,  9)
      JacC(  9, 58) = JacC(  9, 58) - dw(152, 58)
      JacC( 10,  9) = JacC( 10,  9) + dw(152,  9)
      JacC( 10, 58) = JacC( 10, 58) + dw(152, 58)
      JacC( 58,  9) = JacC( 58,  9) - dw(152,  9)
      JacC( 58, 58) = JacC( 58, 58) - dw(152, 58)
      JacC( 67,  9) = JacC( 67,  9) + dw(152,  9)
      JacC( 67, 58) = JacC( 67, 58) + dw(152, 58)
      JacC(  4, 58) = JacC(  4, 58) - dw(153, 58)
      JacC(  4,  4) = JacC(  4,  4) - dw(153,  4)
      JacC( 48, 58) = JacC( 48, 58)+ 0.5000000000000000D-01*dw(153, 58)
      JacC( 48,  4) = JacC( 48,  4)+ 0.5000000000000000D-01*dw(153,  4)
      JacC( 57, 58) = JacC( 57, 58)+ 0.1000000000000000D+00*dw(153, 58)
      JacC( 57,  4) = JacC( 57,  4)+ 0.1000000000000000D+00*dw(153,  4)
      JacC( 58, 58) = JacC( 58, 58) - dw(153, 58)
      JacC( 58,  4) = JacC( 58,  4) - dw(153,  4)
      JacC( 61, 58) = JacC( 61, 58)+ 0.9000000000000000D+00*dw(153, 58)
      JacC( 61,  4) = JacC( 61,  4)+ 0.9000000000000000D+00*dw(153,  4)
      JacC( 67, 58) = JacC( 67, 58) + dw(153, 58)
      JacC( 67,  4) = JacC( 67,  4) + dw(153,  4)
      JacC( 68, 58) = JacC( 68, 58)+ 0.1000000000000000D+00*dw(153, 58)
      JacC( 68,  4) = JacC( 68,  4)+ 0.1000000000000000D+00*dw(153,  4)
      JacC(  6, 58) = JacC(  6, 58) - dw(154, 58)
      JacC(  6,  6) = JacC(  6,  6) - dw(154,  6)
      JacC( 55, 58) = JacC( 55, 58)+ 0.8999999999999999D-02*dw(154, 58)
      JacC( 55,  6) = JacC( 55,  6)+ 0.8999999999999999D-02*dw(154,  6)
      JacC( 58, 58) = JacC( 58, 58) - dw(154, 58)
      JacC( 58,  6) = JacC( 58,  6) - dw(154,  6)
      JacC( 61, 58) = JacC( 61, 58)+ 0.9910000000000000D+00*dw(154, 58)
      JacC( 61,  6) = JacC( 61,  6)+ 0.9910000000000000D+00*dw(154,  6)
      JacC( 67, 58) = JacC( 67, 58) + dw(154, 58)
      JacC( 67,  6) = JacC( 67,  6) + dw(154,  6)
      JacC( 68, 58) = JacC( 68, 58)+ 0.9910000000000000D+00*dw(154, 58)
      JacC( 68,  6) = JacC( 68,  6)+ 0.9910000000000000D+00*dw(154,  6)
      JacC( 42, 66) = JacC( 42, 66) - dw(155, 66)
      JacC( 42, 42) = JacC( 42, 42) - dw(155, 42)
      JacC( 43, 66) = JacC( 43, 66)+ 0.2000000000000000D+00*dw(155, 66)
      JacC( 43, 42) = JacC( 43, 42)+ 0.2000000000000000D+00*dw(155, 42)
      JacC( 44, 66) = JacC( 44, 66)+ 0.8000000000000000D+00*dw(155, 66)
      JacC( 44, 42) = JacC( 44, 42)+ 0.8000000000000000D+00*dw(155, 42)
      JacC( 45, 66) = JacC( 45, 66)+ 0.2400000000000000D+01*dw(155, 66)
      JacC( 45, 42) = JacC( 45, 42)+ 0.2400000000000000D+01*dw(155, 42)
      JacC( 48, 66) = JacC( 48, 66)+ 0.8000000000000000D+00*dw(155, 66)
      JacC( 48, 42) = JacC( 48, 42)+ 0.8000000000000000D+00*dw(155, 42)
      JacC( 65, 66) = JacC( 65, 66)+ 0.2000000000000000D+00*dw(155, 66)
      JacC( 65, 42) = JacC( 65, 42)+ 0.2000000000000000D+00*dw(155, 42)
      JacC( 66, 66) = JacC( 66, 66) - dw(155, 66)
      JacC( 66, 42) = JacC( 66, 42) - dw(155, 42)
      JacC( 67, 66) = JacC( 67, 66)+ 0.8000000000000000D+00*dw(155, 66)
      JacC( 67, 42) = JacC( 67, 42)+ 0.8000000000000000D+00*dw(155, 42)
      JacC( 68, 66) = JacC( 68, 66) + dw(155, 66)
      JacC( 68, 42) = JacC( 68, 42) + dw(155, 42)
      JacC( 21, 67) = JacC( 21, 67)+ 0.5000000000000000D+00*dw(156, 67)
      JacC( 67, 67) = JacC( 67, 67) - dw(156, 67)
      JacC( 24, 66) = JacC( 24, 66)+ 0.5000000000000000D+00*dw(157, 66)
      JacC( 50, 66) = JacC( 50, 66)+ 0.5000000000000000D+00*dw(157, 66)
      JacC( 66, 66) = JacC( 66, 66) - dw(157, 66)
      JacC( 50, 59) = JacC( 50, 59) + dw(158, 59)
      JacC( 59, 59) = JacC( 59, 59) - dw(158, 59)
      JacC( 15, 15) = JacC( 15, 15) - dw(159, 15)
      JacC( 50, 15) = JacC( 50, 15)+ 0.2000000000000000D+01*dw(159, 15)
      JacC( 11, 11) = JacC( 11, 11) - dw(160, 11)
      JacC( 11, 58) = JacC( 11, 58) - dw(160, 58)
      JacC( 52, 11) = JacC( 52, 11)+ 0.4800000000000000D-01*dw(160, 11)
      JacC( 52, 58) = JacC( 52, 58)+ 0.4800000000000000D-01*dw(160, 58)
      JacC( 25, 25) = JacC( 25, 25) - dw(161, 25)
      JacC( 25, 58) = JacC( 25, 58) - dw(161, 58)
      JacC( 27, 25) = JacC( 27, 25)+ 0.7600000000000000D-01*dw(161, 25)
      JacC( 27, 58) = JacC( 27, 58)+ 0.7600000000000000D-01*dw(161, 58)
      JacC( 29, 25) = JacC( 29, 25)+ 0.1640000000000000D+00*dw(161, 25)
      JacC( 29, 58) = JacC( 29, 58)+ 0.1640000000000000D+00*dw(161, 58)
      JacC( 30, 25) = JacC( 30, 25)+ 0.1170000000000000D+00*dw(161, 25)
      JacC( 30, 58) = JacC( 30, 58)+ 0.1170000000000000D+00*dw(161, 58)
      JacC( 25, 25) = JacC( 25, 25) - dw(162, 25)
      JacC( 25, 62) = JacC( 25, 62) - dw(162, 62)
      JacC( 27, 25) = JacC( 27, 25)+ 0.4400000000000000D-01*dw(162, 25)
      JacC( 27, 62) = JacC( 27, 62)+ 0.4400000000000000D-01*dw(162, 62)
      JacC( 29, 25) = JacC( 29, 25)+ 0.1270000000000000D+00*dw(162, 25)
      JacC( 29, 62) = JacC( 29, 62)+ 0.1270000000000000D+00*dw(162, 62)
      JacC( 30, 25) = JacC( 30, 25)+ 0.1420000000000000D+00*dw(162, 25)
      JacC( 30, 62) = JacC( 30, 62)+ 0.1420000000000000D+00*dw(162, 62)
      JacC( 25, 25) = JacC( 25, 25) - dw(163, 25)
      JacC( 25, 59) = JacC( 25, 59) - dw(163, 59)
      JacC( 28, 25) = JacC( 28, 25)+ 0.8000000000000000D+00*dw(163, 25)
      JacC( 28, 59) = JacC( 28, 59)+ 0.8000000000000000D+00*dw(163, 59)
      JacC( 26, 26) = JacC( 26, 26) - dw(164, 26)
      JacC( 26, 58) = JacC( 26, 58) - dw(164, 58)
      JacC( 27, 26) = JacC( 27, 26)+ 0.3000000000000000D-02*dw(164, 26)
      JacC( 27, 58) = JacC( 27, 58)+ 0.3000000000000000D-02*dw(164, 58)
      JacC( 28, 26) = JacC( 28, 26)+ 0.2400000000000000D-01*dw(164, 26)
      JacC( 28, 58) = JacC( 28, 58)+ 0.2400000000000000D-01*dw(164, 58)
      JacC( 29, 26) = JacC( 29, 26)+ 0.4070000000000000D+00*dw(164, 26)
      JacC( 29, 58) = JacC( 29, 58)+ 0.4070000000000000D+00*dw(164, 58)
      JacC( 30, 26) = JacC( 30, 26)+ 0.1730000000000000D+00*dw(164, 26)
      JacC( 30, 58) = JacC( 30, 58)+ 0.1730000000000000D+00*dw(164, 58)
      JacC( 26, 26) = JacC( 26, 26) - dw(165, 26)
      JacC( 26, 62) = JacC( 26, 62) - dw(165, 62)
      JacC( 29, 26) = JacC( 29, 26)+ 0.1970000000000000D+00*dw(165, 26)
      JacC( 29, 62) = JacC( 29, 62)+ 0.1970000000000000D+00*dw(165, 62)
      JacC( 30, 26) = JacC( 30, 26)+ 0.9400000000000000D-01*dw(165, 26)
      JacC( 30, 62) = JacC( 30, 62)+ 0.9400000000000000D-01*dw(165, 62)
      JacC( 26, 26) = JacC( 26, 26) - dw(166, 26)
      JacC( 26, 59) = JacC( 26, 59) - dw(166, 59)
      JacC( 29, 26) = JacC( 29, 26)+ 0.3090000000000000D+00*dw(166, 26)
      JacC( 29, 59) = JacC( 29, 59)+ 0.3090000000000000D+00*dw(166, 59)
      JacC( 30, 26) = JacC( 30, 26)+ 0.2000000000000000D-01*dw(166, 26)
      JacC( 30, 59) = JacC( 30, 59)+ 0.2000000000000000D-01*dw(166, 59)
      JacC( 46, 53) = JacC( 46, 53)+ 0.7800000000000000D+00*dw(167, 53)
      JacC( 46, 67) = JacC( 46, 67)+ 0.7800000000000000D+00*dw(167, 67)
      JacC( 53, 53) = JacC( 53, 53) - dw(167, 53)
      JacC( 53, 67) = JacC( 53, 67) - dw(167, 67)
      JacC( 46, 53) = JacC( 46, 53)+ 0.7800000000000000D+00*dw(168, 53)
      JacC( 46, 56) = JacC( 46, 56)+ 0.7800000000000000D+00*dw(168, 56)
      JacC( 53, 53) = JacC( 53, 53) - dw(168, 53)
      JacC( 53, 56) = JacC( 53, 56) - dw(168, 56)
      JacC( 46, 53) = JacC( 46, 53)+ 0.7800000000000000D+00*dw(169, 53)
      JacC( 46, 64) = JacC( 46, 64)+ 0.7800000000000000D+00*dw(169, 64)
      JacC( 53, 53) = JacC( 53, 53) - dw(169, 53)
      JacC( 53, 64) = JacC( 53, 64) - dw(169, 64)
      JacC( 47, 53) = JacC( 47, 53)+ 0.3360000000000000D+00*dw(170, 53)
      JacC( 47, 65) = JacC( 47, 65)+ 0.3360000000000000D+00*dw(170, 65)
      JacC( 52, 53) = JacC( 52, 53)+ 0.5300000000000000D-01*dw(170, 53)
      JacC( 52, 65) = JacC( 52, 65)+ 0.5300000000000000D-01*dw(170, 65)
      JacC( 53, 53) = JacC( 53, 53) - dw(170, 53)
      JacC( 53, 65) = JacC( 53, 65) - dw(170, 65)
      JacC( 47, 53) = JacC( 47, 53)+ 0.3360000000000000D+00*dw(171, 53)
      JacC( 47, 59) = JacC( 47, 59)+ 0.3360000000000000D+00*dw(171, 59)
      JacC( 52, 53) = JacC( 52, 53)+ 0.5300000000000000D-01*dw(171, 53)
      JacC( 52, 59) = JacC( 52, 59)+ 0.5300000000000000D-01*dw(171, 59)
      JacC( 53, 53) = JacC( 53, 53) - dw(171, 53)
      JacC( 53, 59) = JacC( 53, 59) - dw(171, 59)
      JacC( 53, 53) = JacC( 53, 53) - dw(172, 53)
      JacC( 54, 54) = JacC( 54, 54) - dw(173, 54)
      JacC( 46, 54) = JacC( 46, 54)+ 0.7100000000000000D+00*dw(174, 54)
      JacC( 46, 67) = JacC( 46, 67)+ 0.7100000000000000D+00*dw(174, 67)
      JacC( 54, 54) = JacC( 54, 54) - dw(174, 54)
      JacC( 54, 67) = JacC( 54, 67) - dw(174, 67)
      JacC( 46, 54) = JacC( 46, 54)+ 0.7100000000000000D+00*dw(175, 54)
      JacC( 46, 56) = JacC( 46, 56)+ 0.7100000000000000D+00*dw(175, 56)
      JacC( 54, 54) = JacC( 54, 54) - dw(175, 54)
      JacC( 54, 56) = JacC( 54, 56) - dw(175, 56)
      JacC( 46, 54) = JacC( 46, 54)+ 0.7100000000000000D+00*dw(176, 54)
      JacC( 46, 64) = JacC( 46, 64)+ 0.7100000000000000D+00*dw(176, 64)
      JacC( 54, 54) = JacC( 54, 54) - dw(176, 54)
      JacC( 54, 64) = JacC( 54, 64) - dw(176, 64)
      JacC( 47, 54) = JacC( 47, 54)+ 0.3200000000000000D+00*dw(177, 54)
      JacC( 47, 65) = JacC( 47, 65)+ 0.3200000000000000D+00*dw(177, 65)
      JacC( 52, 54) = JacC( 52, 54)+ 0.2300000000000000D-01*dw(177, 54)
      JacC( 52, 65) = JacC( 52, 65)+ 0.2300000000000000D-01*dw(177, 65)
      JacC( 54, 54) = JacC( 54, 54) - dw(177, 54)
      JacC( 54, 65) = JacC( 54, 65) - dw(177, 65)
      JacC( 47, 54) = JacC( 47, 54)+ 0.3200000000000000D+00*dw(178, 54)
      JacC( 47, 59) = JacC( 47, 59)+ 0.3200000000000000D+00*dw(178, 59)
      JacC( 52, 54) = JacC( 52, 54)+ 0.2300000000000000D-01*dw(178, 54)
      JacC( 52, 59) = JacC( 52, 59)+ 0.2300000000000000D-01*dw(178, 59)
      JacC( 54, 54) = JacC( 54, 54) - dw(178, 54)
      JacC( 54, 59) = JacC( 54, 59) - dw(178, 59)
 
      do j = 1, ns
         do i = 1, ns
            JacC(i,j) = JacC(i,j) * convers_factor_jac(i,j)
         enddo
      enddo
 
 
      RETURN
      END
 
