C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C     
C     This file is part of the air quality modeling system Polyphemus.
C    
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C    
C     Polyphemus is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C     
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C     
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C
C------------------------------------------------------------------------

      SUBROUTINE LU_solve (ns, M, x)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine solves M * y = x where M is an LU factorization
C     computed by LU_decompose.
C	  This routine is automatically generated by LU.cpp
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C	  nesp: matrix row number from the chemical species number
C     M: LU factorization computed by LU_decompose.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     x: on entry, the right-hand side of the equation. On exit,
C     the solution of the equation.
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

      INTEGER ns
      DOUBLE PRECISION M(ns,ns)
      DOUBLE PRECISION x(ns)
      DOUBLE PRECISION temp


C     Forward substitution.

      x(1) = x(1) / M(1, 1)

      x(2) = x(2) / M(2, 2)

      x(3) = x(3) / M(3, 3)

      x(4) = x(4) / M(4, 4)

      x(5) = x(5) / M(5, 5)

      x(6) = x(6) / M(6, 6)

      x(7) = x(7) / M(7, 7)

      x(8) = x(8) / M(8, 8)

      x(9) = x(9) / M(9, 9)

      temp = M(10, 3) * x(3)
      x(10) = ( x(10) - temp ) / M(10, 10)

      x(11) = x(11) / M(11, 11)

      temp = M(12, 11) * x(11)
      x(12) = ( x(12) - temp ) / M(12, 12)

      x(13) = x(13) / M(13, 13)

      x(14) = x(14) / M(14, 14)

      x(15) = x(15) / M(15, 15)

      temp = M(16, 13) * x(13)
      temp = temp + M(16, 14) * x(14)
      temp = temp + M(16, 15) * x(15)
      x(16) = ( x(16) - temp ) / M(16, 16)

      x(17) = x(17) / M(17, 17)

      x(18) = x(18) / M(18, 18)

      x(19) = x(19) / M(19, 19)

      x(20) = x(20) / M(20, 20)

      x(21) = x(21) / M(21, 21)

      temp = M(22, 7) * x(7)
      x(22) = ( x(22) - temp ) / M(22, 22)

      temp = M(23, 8) * x(8)
      x(23) = ( x(23) - temp ) / M(23, 23)

      x(24) = x(24) / M(24, 24)

      x(25) = x(25) / M(25, 25)

      x(26) = x(26) / M(26, 26)

      x(27) = x(27) / M(27, 27)

      temp = M(28, 27) * x(27)
      x(28) = ( x(28) - temp ) / M(28, 28)

      temp = M(29, 11) * x(11)
      temp = temp + M(29, 27) * x(27)
      x(29) = ( x(29) - temp ) / M(29, 29)

      x(30) = x(30) / M(30, 30)

      temp = M(31, 27) * x(27)
      temp = temp + M(31, 30) * x(30)
      x(31) = ( x(31) - temp ) / M(31, 31)

      temp = M(32, 27) * x(27)
      temp = temp + M(32, 30) * x(30)
      x(32) = ( x(32) - temp ) / M(32, 32)

      temp = M(33, 22) * x(22)
      temp = temp + M(33, 23) * x(23)
      x(33) = ( x(33) - temp ) / M(33, 33)

      x(34) = x(34) / M(34, 34)

      x(35) = x(35) / M(35, 35)

      x(36) = x(36) / M(36, 36)

      x(37) = x(37) / M(37, 37)

      x(38) = x(38) / M(38, 38)

      x(39) = x(39) / M(39, 39)

      temp = M(40, 22) * x(22)
      x(40) = ( x(40) - temp ) / M(40, 40)

      temp = M(41, 40) * x(40)
      x(41) = ( x(41) - temp ) / M(41, 41)

      temp = M(42, 36) * x(36)
      x(42) = ( x(42) - temp ) / M(42, 42)

      temp = M(43, 9) * x(9)
      temp = temp + M(43, 26) * x(26)
      temp = temp + M(43, 35) * x(35)
      x(43) = ( x(43) - temp ) / M(43, 43)

      temp = M(44, 26) * x(26)
      temp = temp + M(44, 27) * x(27)
      temp = temp + M(44, 30) * x(30)
      temp = temp + M(44, 35) * x(35)
      temp = temp + M(44, 43) * x(43)
      x(44) = ( x(44) - temp ) / M(44, 44)

      temp = M(45, 22) * x(22)
      temp = temp + M(45, 23) * x(23)
      temp = temp + M(45, 36) * x(36)
      temp = temp + M(45, 39) * x(39)
      x(45) = ( x(45) - temp ) / M(45, 45)

      temp = M(46, 40) * x(40)
      temp = temp + M(46, 45) * x(45)
      x(46) = ( x(46) - temp ) / M(46, 46)

      temp = M(47, 6) * x(6)
      x(47) = ( x(47) - temp ) / M(47, 47)

      x(48) = x(48) / M(48, 48)

      temp = M(49, 4) * x(4)
      temp = temp + M(49, 25) * x(25)
      temp = temp + M(49, 26) * x(26)
      temp = temp + M(49, 30) * x(30)
      temp = temp + M(49, 35) * x(35)
      temp = temp + M(49, 43) * x(43)
      temp = temp + M(49, 48) * x(48)
      x(49) = ( x(49) - temp ) / M(49, 49)

      temp = M(50, 48) * x(48)
      x(50) = ( x(50) - temp ) / M(50, 50)

      temp = M(51, 23) * x(23)
      x(51) = ( x(51) - temp ) / M(51, 51)

      temp = M(52, 30) * x(30)
      x(52) = ( x(52) - temp ) / M(52, 52)

      temp = M(53, 5) * x(5)
      x(53) = ( x(53) - temp ) / M(53, 53)

      temp = M(54, 35) * x(35)
      temp = temp + M(54, 40) * x(40)
      temp = temp + M(54, 43) * x(43)
      temp = temp + M(54, 51) * x(51)
      x(54) = ( x(54) - temp ) / M(54, 54)

      temp = M(55, 6) * x(6)
      temp = temp + M(55, 40) * x(40)
      temp = temp + M(55, 45) * x(45)
      temp = temp + M(55, 51) * x(51)
      x(55) = ( x(55) - temp ) / M(55, 55)

      temp = M(56, 25) * x(25)
      x(56) = ( x(56) - temp ) / M(56, 56)

      temp = M(57, 6) * x(6)
      x(57) = ( x(57) - temp ) / M(57, 57)

      temp = M(58, 26) * x(26)
      temp = temp + M(58, 35) * x(35)
      temp = temp + M(58, 43) * x(43)
      x(58) = ( x(58) - temp ) / M(58, 58)

      temp = M(59, 26) * x(26)
      temp = temp + M(59, 30) * x(30)
      temp = temp + M(59, 35) * x(35)
      temp = temp + M(59, 43) * x(43)
      temp = temp + M(59, 52) * x(52)
      temp = temp + M(59, 58) * x(58)
      x(59) = ( x(59) - temp ) / M(59, 59)

      temp = M(60, 26) * x(26)
      temp = temp + M(60, 30) * x(30)
      temp = temp + M(60, 35) * x(35)
      temp = temp + M(60, 43) * x(43)
      temp = temp + M(60, 58) * x(58)
      temp = temp + M(60, 59) * x(59)
      x(60) = ( x(60) - temp ) / M(60, 60)

      temp = M(61, 60) * x(60)
      x(61) = ( x(61) - temp ) / M(61, 61)

      temp = M(62, 52) * x(52)
      temp = temp + M(62, 58) * x(58)
      temp = temp + M(62, 59) * x(59)
      x(62) = ( x(62) - temp ) / M(62, 62)

      temp = M(63, 25) * x(25)
      temp = temp + M(63, 26) * x(26)
      temp = temp + M(63, 27) * x(27)
      temp = temp + M(63, 30) * x(30)
      temp = temp + M(63, 35) * x(35)
      temp = temp + M(63, 43) * x(43)
      temp = temp + M(63, 59) * x(59)
      temp = temp + M(63, 60) * x(60)
      temp = temp + M(63, 62) * x(62)
      x(63) = ( x(63) - temp ) / M(63, 63)

      temp = M(64, 25) * x(25)
      temp = temp + M(64, 26) * x(26)
      temp = temp + M(64, 27) * x(27)
      temp = temp + M(64, 30) * x(30)
      temp = temp + M(64, 35) * x(35)
      temp = temp + M(64, 43) * x(43)
      temp = temp + M(64, 59) * x(59)
      temp = temp + M(64, 60) * x(60)
      temp = temp + M(64, 62) * x(62)
      temp = temp + M(64, 63) * x(63)
      x(64) = ( x(64) - temp ) / M(64, 64)

      temp = M(65, 22) * x(22)
      temp = temp + M(65, 23) * x(23)
      temp = temp + M(65, 25) * x(25)
      temp = temp + M(65, 26) * x(26)
      temp = temp + M(65, 27) * x(27)
      temp = temp + M(65, 30) * x(30)
      temp = temp + M(65, 35) * x(35)
      temp = temp + M(65, 36) * x(36)
      temp = temp + M(65, 43) * x(43)
      temp = temp + M(65, 45) * x(45)
      temp = temp + M(65, 48) * x(48)
      temp = temp + M(65, 54) * x(54)
      temp = temp + M(65, 59) * x(59)
      temp = temp + M(65, 60) * x(60)
      temp = temp + M(65, 62) * x(62)
      x(65) = ( x(65) - temp ) / M(65, 65)

      temp = M(66, 4) * x(4)
      temp = temp + M(66, 40) * x(40)
      temp = temp + M(66, 42) * x(42)
      temp = temp + M(66, 45) * x(45)
      temp = temp + M(66, 51) * x(51)
      temp = temp + M(66, 54) * x(54)
      temp = temp + M(66, 59) * x(59)
      temp = temp + M(66, 65) * x(65)
      x(66) = ( x(66) - temp ) / M(66, 66)

      temp = M(67, 4) * x(4)
      temp = temp + M(67, 25) * x(25)
      temp = temp + M(67, 26) * x(26)
      temp = temp + M(67, 27) * x(27)
      temp = temp + M(67, 30) * x(30)
      temp = temp + M(67, 35) * x(35)
      temp = temp + M(67, 43) * x(43)
      temp = temp + M(67, 48) * x(48)
      temp = temp + M(67, 54) * x(54)
      temp = temp + M(67, 59) * x(59)
      temp = temp + M(67, 60) * x(60)
      temp = temp + M(67, 62) * x(62)
      temp = temp + M(67, 65) * x(65)
      temp = temp + M(67, 66) * x(66)
      x(67) = ( x(67) - temp ) / M(67, 67)

      temp = M(68, 62) * x(62)
      temp = temp + M(68, 65) * x(65)
      x(68) = ( x(68) - temp ) / M(68, 68)

      temp = M(69, 27) * x(27)
      temp = temp + M(69, 65) * x(65)
      x(69) = ( x(69) - temp ) / M(69, 69)

      temp = M(70, 26) * x(26)
      temp = temp + M(70, 27) * x(27)
      temp = temp + M(70, 30) * x(30)
      temp = temp + M(70, 35) * x(35)
      temp = temp + M(70, 43) * x(43)
      temp = temp + M(70, 59) * x(59)
      temp = temp + M(70, 60) * x(60)
      temp = temp + M(70, 62) * x(62)
      temp = temp + M(70, 65) * x(65)
      x(70) = ( x(70) - temp ) / M(70, 70)

      temp = M(71, 30) * x(30)
      temp = temp + M(71, 53) * x(53)
      temp = temp + M(71, 54) * x(54)
      temp = temp + M(71, 56) * x(56)
      temp = temp + M(71, 57) * x(57)
      temp = temp + M(71, 58) * x(58)
      temp = temp + M(71, 59) * x(59)
      temp = temp + M(71, 60) * x(60)
      temp = temp + M(71, 61) * x(61)
      temp = temp + M(71, 62) * x(62)
      temp = temp + M(71, 63) * x(63)
      temp = temp + M(71, 64) * x(64)
      temp = temp + M(71, 65) * x(65)
      temp = temp + M(71, 68) * x(68)
      temp = temp + M(71, 70) * x(70)
      x(71) = ( x(71) - temp ) / M(71, 71)

      temp = M(72, 40) * x(40)
      temp = temp + M(72, 42) * x(42)
      temp = temp + M(72, 45) * x(45)
      temp = temp + M(72, 47) * x(47)
      temp = temp + M(72, 48) * x(48)
      temp = temp + M(72, 51) * x(51)
      temp = temp + M(72, 54) * x(54)
      temp = temp + M(72, 59) * x(59)
      temp = temp + M(72, 65) * x(65)
      temp = temp + M(72, 70) * x(70)
      x(72) = ( x(72) - temp ) / M(72, 72)

      temp = M(73, 40) * x(40)
      temp = temp + M(73, 42) * x(42)
      temp = temp + M(73, 45) * x(45)
      temp = temp + M(73, 51) * x(51)
      temp = temp + M(73, 52) * x(52)
      temp = temp + M(73, 53) * x(53)
      temp = temp + M(73, 56) * x(56)
      temp = temp + M(73, 57) * x(57)
      temp = temp + M(73, 58) * x(58)
      temp = temp + M(73, 59) * x(59)
      temp = temp + M(73, 61) * x(61)
      temp = temp + M(73, 65) * x(65)
      temp = temp + M(73, 68) * x(68)
      temp = temp + M(73, 69) * x(69)
      temp = temp + M(73, 70) * x(70)
      x(73) = ( x(73) - temp ) / M(73, 73)

      temp = M(74, 17) * x(17)
      temp = temp + M(74, 45) * x(45)
      temp = temp + M(74, 54) * x(54)
      temp = temp + M(74, 59) * x(59)
      temp = temp + M(74, 65) * x(65)
      temp = temp + M(74, 66) * x(66)
      temp = temp + M(74, 72) * x(72)
      x(74) = ( x(74) - temp ) / M(74, 74)

      temp = M(75, 7) * x(7)
      temp = temp + M(75, 8) * x(8)
      temp = temp + M(75, 26) * x(26)
      temp = temp + M(75, 35) * x(35)
      temp = temp + M(75, 38) * x(38)
      temp = temp + M(75, 43) * x(43)
      temp = temp + M(75, 45) * x(45)
      temp = temp + M(75, 48) * x(48)
      temp = temp + M(75, 50) * x(50)
      temp = temp + M(75, 53) * x(53)
      temp = temp + M(75, 54) * x(54)
      temp = temp + M(75, 57) * x(57)
      temp = temp + M(75, 59) * x(59)
      temp = temp + M(75, 65) * x(65)
      temp = temp + M(75, 70) * x(70)
      temp = temp + M(75, 73) * x(73)
      x(75) = ( x(75) - temp ) / M(75, 75)

      temp = M(76, 4) * x(4)
      temp = temp + M(76, 73) * x(73)
      temp = temp + M(76, 75) * x(75)
      x(76) = ( x(76) - temp ) / M(76, 76)

      temp = M(77, 5) * x(5)
      temp = temp + M(77, 18) * x(18)
      temp = temp + M(77, 27) * x(27)
      temp = temp + M(77, 53) * x(53)
      temp = temp + M(77, 54) * x(54)
      temp = temp + M(77, 57) * x(57)
      temp = temp + M(77, 59) * x(59)
      temp = temp + M(77, 60) * x(60)
      temp = temp + M(77, 61) * x(61)
      temp = temp + M(77, 62) * x(62)
      temp = temp + M(77, 63) * x(63)
      temp = temp + M(77, 64) * x(64)
      temp = temp + M(77, 65) * x(65)
      temp = temp + M(77, 68) * x(68)
      temp = temp + M(77, 69) * x(69)
      temp = temp + M(77, 70) * x(70)
      temp = temp + M(77, 73) * x(73)
      temp = temp + M(77, 75) * x(75)
      temp = temp + M(77, 76) * x(76)
      x(77) = ( x(77) - temp ) / M(77, 77)

      temp = M(78, 27) * x(27)
      temp = temp + M(78, 30) * x(30)
      temp = temp + M(78, 34) * x(34)
      temp = temp + M(78, 53) * x(53)
      temp = temp + M(78, 57) * x(57)
      temp = temp + M(78, 60) * x(60)
      temp = temp + M(78, 62) * x(62)
      temp = temp + M(78, 65) * x(65)
      temp = temp + M(78, 76) * x(76)
      temp = temp + M(78, 77) * x(77)
      x(78) = ( x(78) - temp ) / M(78, 78)

      temp = M(79, 4) * x(4)
      temp = temp + M(79, 21) * x(21)
      temp = temp + M(79, 25) * x(25)
      temp = temp + M(79, 26) * x(26)
      temp = temp + M(79, 30) * x(30)
      temp = temp + M(79, 35) * x(35)
      temp = temp + M(79, 38) * x(38)
      temp = temp + M(79, 40) * x(40)
      temp = temp + M(79, 42) * x(42)
      temp = temp + M(79, 43) * x(43)
      temp = temp + M(79, 45) * x(45)
      temp = temp + M(79, 47) * x(47)
      temp = temp + M(79, 48) * x(48)
      temp = temp + M(79, 50) * x(50)
      temp = temp + M(79, 51) * x(51)
      temp = temp + M(79, 52) * x(52)
      temp = temp + M(79, 53) * x(53)
      temp = temp + M(79, 54) * x(54)
      temp = temp + M(79, 56) * x(56)
      temp = temp + M(79, 57) * x(57)
      temp = temp + M(79, 58) * x(58)
      temp = temp + M(79, 59) * x(59)
      temp = temp + M(79, 60) * x(60)
      temp = temp + M(79, 61) * x(61)
      temp = temp + M(79, 62) * x(62)
      temp = temp + M(79, 63) * x(63)
      temp = temp + M(79, 64) * x(64)
      temp = temp + M(79, 65) * x(65)
      temp = temp + M(79, 66) * x(66)
      temp = temp + M(79, 68) * x(68)
      temp = temp + M(79, 69) * x(69)
      temp = temp + M(79, 70) * x(70)
      temp = temp + M(79, 75) * x(75)
      temp = temp + M(79, 76) * x(76)
      temp = temp + M(79, 77) * x(77)
      temp = temp + M(79, 78) * x(78)
      x(79) = ( x(79) - temp ) / M(79, 79)

      temp = M(80, 3) * x(3)
      temp = temp + M(80, 4) * x(4)
      temp = temp + M(80, 5) * x(5)
      temp = temp + M(80, 6) * x(6)
      temp = temp + M(80, 7) * x(7)
      temp = temp + M(80, 8) * x(8)
      temp = temp + M(80, 9) * x(9)
      temp = temp + M(80, 11) * x(11)
      temp = temp + M(80, 13) * x(13)
      temp = temp + M(80, 14) * x(14)
      temp = temp + M(80, 15) * x(15)
      temp = temp + M(80, 18) * x(18)
      temp = temp + M(80, 21) * x(21)
      temp = temp + M(80, 22) * x(22)
      temp = temp + M(80, 23) * x(23)
      temp = temp + M(80, 24) * x(24)
      temp = temp + M(80, 25) * x(25)
      temp = temp + M(80, 26) * x(26)
      temp = temp + M(80, 27) * x(27)
      temp = temp + M(80, 30) * x(30)
      temp = temp + M(80, 33) * x(33)
      temp = temp + M(80, 34) * x(34)
      temp = temp + M(80, 35) * x(35)
      temp = temp + M(80, 36) * x(36)
      temp = temp + M(80, 37) * x(37)
      temp = temp + M(80, 38) * x(38)
      temp = temp + M(80, 43) * x(43)
      temp = temp + M(80, 44) * x(44)
      temp = temp + M(80, 45) * x(45)
      temp = temp + M(80, 47) * x(47)
      temp = temp + M(80, 48) * x(48)
      temp = temp + M(80, 50) * x(50)
      temp = temp + M(80, 54) * x(54)
      temp = temp + M(80, 59) * x(59)
      temp = temp + M(80, 60) * x(60)
      temp = temp + M(80, 62) * x(62)
      temp = temp + M(80, 65) * x(65)
      temp = temp + M(80, 66) * x(66)
      temp = temp + M(80, 67) * x(67)
      temp = temp + M(80, 70) * x(70)
      temp = temp + M(80, 72) * x(72)
      temp = temp + M(80, 73) * x(73)
      temp = temp + M(80, 74) * x(74)
      temp = temp + M(80, 75) * x(75)
      temp = temp + M(80, 76) * x(76)
      temp = temp + M(80, 77) * x(77)
      temp = temp + M(80, 78) * x(78)
      temp = temp + M(80, 79) * x(79)
      x(80) = ( x(80) - temp ) / M(80, 80)

      temp = M(81, 4) * x(4)
      temp = temp + M(81, 6) * x(6)
      temp = temp + M(81, 18) * x(18)
      temp = temp + M(81, 27) * x(27)
      temp = temp + M(81, 43) * x(43)
      temp = temp + M(81, 53) * x(53)
      temp = temp + M(81, 54) * x(54)
      temp = temp + M(81, 56) * x(56)
      temp = temp + M(81, 57) * x(57)
      temp = temp + M(81, 59) * x(59)
      temp = temp + M(81, 60) * x(60)
      temp = temp + M(81, 61) * x(61)
      temp = temp + M(81, 62) * x(62)
      temp = temp + M(81, 63) * x(63)
      temp = temp + M(81, 64) * x(64)
      temp = temp + M(81, 65) * x(65)
      temp = temp + M(81, 68) * x(68)
      temp = temp + M(81, 69) * x(69)
      temp = temp + M(81, 70) * x(70)
      temp = temp + M(81, 73) * x(73)
      temp = temp + M(81, 75) * x(75)
      temp = temp + M(81, 76) * x(76)
      temp = temp + M(81, 77) * x(77)
      temp = temp + M(81, 78) * x(78)
      temp = temp + M(81, 80) * x(80)
      x(81) = ( x(81) - temp ) / M(81, 81)

      temp = M(82, 21) * x(21)
      temp = temp + M(82, 26) * x(26)
      temp = temp + M(82, 35) * x(35)
      temp = temp + M(82, 37) * x(37)
      temp = temp + M(82, 38) * x(38)
      temp = temp + M(82, 40) * x(40)
      temp = temp + M(82, 42) * x(42)
      temp = temp + M(82, 43) * x(43)
      temp = temp + M(82, 45) * x(45)
      temp = temp + M(82, 51) * x(51)
      temp = temp + M(82, 52) * x(52)
      temp = temp + M(82, 53) * x(53)
      temp = temp + M(82, 54) * x(54)
      temp = temp + M(82, 56) * x(56)
      temp = temp + M(82, 57) * x(57)
      temp = temp + M(82, 58) * x(58)
      temp = temp + M(82, 59) * x(59)
      temp = temp + M(82, 60) * x(60)
      temp = temp + M(82, 61) * x(61)
      temp = temp + M(82, 62) * x(62)
      temp = temp + M(82, 63) * x(63)
      temp = temp + M(82, 64) * x(64)
      temp = temp + M(82, 65) * x(65)
      temp = temp + M(82, 68) * x(68)
      temp = temp + M(82, 69) * x(69)
      temp = temp + M(82, 70) * x(70)
      temp = temp + M(82, 75) * x(75)
      temp = temp + M(82, 76) * x(76)
      temp = temp + M(82, 77) * x(77)
      temp = temp + M(82, 78) * x(78)
      temp = temp + M(82, 80) * x(80)
      temp = temp + M(82, 81) * x(81)
      x(82) = ( x(82) - temp ) / M(82, 82)

      temp = M(83, 39) * x(39)
      temp = temp + M(83, 40) * x(40)
      temp = temp + M(83, 45) * x(45)
      temp = temp + M(83, 48) * x(48)
      temp = temp + M(83, 51) * x(51)
      temp = temp + M(83, 52) * x(52)
      temp = temp + M(83, 53) * x(53)
      temp = temp + M(83, 57) * x(57)
      temp = temp + M(83, 58) * x(58)
      temp = temp + M(83, 59) * x(59)
      temp = temp + M(83, 63) * x(63)
      temp = temp + M(83, 64) * x(64)
      temp = temp + M(83, 65) * x(65)
      temp = temp + M(83, 69) * x(69)
      temp = temp + M(83, 76) * x(76)
      temp = temp + M(83, 77) * x(77)
      temp = temp + M(83, 78) * x(78)
      temp = temp + M(83, 80) * x(80)
      temp = temp + M(83, 81) * x(81)
      temp = temp + M(83, 82) * x(82)
      x(83) = ( x(83) - temp ) / M(83, 83)

      temp = M(84, 17) * x(17)
      temp = temp + M(84, 22) * x(22)
      temp = temp + M(84, 23) * x(23)
      temp = temp + M(84, 24) * x(24)
      temp = temp + M(84, 33) * x(33)
      temp = temp + M(84, 36) * x(36)
      temp = temp + M(84, 39) * x(39)
      temp = temp + M(84, 40) * x(40)
      temp = temp + M(84, 42) * x(42)
      temp = temp + M(84, 43) * x(43)
      temp = temp + M(84, 45) * x(45)
      temp = temp + M(84, 48) * x(48)
      temp = temp + M(84, 50) * x(50)
      temp = temp + M(84, 51) * x(51)
      temp = temp + M(84, 52) * x(52)
      temp = temp + M(84, 53) * x(53)
      temp = temp + M(84, 54) * x(54)
      temp = temp + M(84, 56) * x(56)
      temp = temp + M(84, 57) * x(57)
      temp = temp + M(84, 58) * x(58)
      temp = temp + M(84, 59) * x(59)
      temp = temp + M(84, 61) * x(61)
      temp = temp + M(84, 63) * x(63)
      temp = temp + M(84, 64) * x(64)
      temp = temp + M(84, 65) * x(65)
      temp = temp + M(84, 68) * x(68)
      temp = temp + M(84, 69) * x(69)
      temp = temp + M(84, 70) * x(70)
      temp = temp + M(84, 74) * x(74)
      temp = temp + M(84, 75) * x(75)
      temp = temp + M(84, 76) * x(76)
      temp = temp + M(84, 77) * x(77)
      temp = temp + M(84, 78) * x(78)
      temp = temp + M(84, 79) * x(79)
      temp = temp + M(84, 80) * x(80)
      temp = temp + M(84, 81) * x(81)
      temp = temp + M(84, 82) * x(82)
      temp = temp + M(84, 83) * x(83)
      x(84) = ( x(84) - temp ) / M(84, 84)

      temp = M(85, 33) * x(33)
      temp = temp + M(85, 36) * x(36)
      temp = temp + M(85, 40) * x(40)
      temp = temp + M(85, 42) * x(42)
      temp = temp + M(85, 43) * x(43)
      temp = temp + M(85, 45) * x(45)
      temp = temp + M(85, 51) * x(51)
      temp = temp + M(85, 52) * x(52)
      temp = temp + M(85, 53) * x(53)
      temp = temp + M(85, 56) * x(56)
      temp = temp + M(85, 57) * x(57)
      temp = temp + M(85, 58) * x(58)
      temp = temp + M(85, 59) * x(59)
      temp = temp + M(85, 61) * x(61)
      temp = temp + M(85, 63) * x(63)
      temp = temp + M(85, 64) * x(64)
      temp = temp + M(85, 65) * x(65)
      temp = temp + M(85, 68) * x(68)
      temp = temp + M(85, 69) * x(69)
      temp = temp + M(85, 70) * x(70)
      temp = temp + M(85, 75) * x(75)
      temp = temp + M(85, 76) * x(76)
      temp = temp + M(85, 77) * x(77)
      temp = temp + M(85, 78) * x(78)
      temp = temp + M(85, 80) * x(80)
      temp = temp + M(85, 81) * x(81)
      temp = temp + M(85, 82) * x(82)
      temp = temp + M(85, 83) * x(83)
      temp = temp + M(85, 84) * x(84)
      x(85) = ( x(85) - temp ) / M(85, 85)

      temp = M(86, 48) * x(48)
      temp = temp + M(86, 54) * x(54)
      temp = temp + M(86, 59) * x(59)
      temp = temp + M(86, 65) * x(65)
      temp = temp + M(86, 80) * x(80)
      temp = temp + M(86, 81) * x(81)
      temp = temp + M(86, 82) * x(82)
      temp = temp + M(86, 83) * x(83)
      temp = temp + M(86, 84) * x(84)
      temp = temp + M(86, 85) * x(85)
      x(86) = ( x(86) - temp ) / M(86, 86)

      temp = M(87, 17) * x(17)
      temp = temp + M(87, 24) * x(24)
      temp = temp + M(87, 25) * x(25)
      temp = temp + M(87, 26) * x(26)
      temp = temp + M(87, 27) * x(27)
      temp = temp + M(87, 30) * x(30)
      temp = temp + M(87, 35) * x(35)
      temp = temp + M(87, 40) * x(40)
      temp = temp + M(87, 42) * x(42)
      temp = temp + M(87, 43) * x(43)
      temp = temp + M(87, 45) * x(45)
      temp = temp + M(87, 48) * x(48)
      temp = temp + M(87, 50) * x(50)
      temp = temp + M(87, 51) * x(51)
      temp = temp + M(87, 52) * x(52)
      temp = temp + M(87, 53) * x(53)
      temp = temp + M(87, 54) * x(54)
      temp = temp + M(87, 56) * x(56)
      temp = temp + M(87, 57) * x(57)
      temp = temp + M(87, 58) * x(58)
      temp = temp + M(87, 59) * x(59)
      temp = temp + M(87, 60) * x(60)
      temp = temp + M(87, 61) * x(61)
      temp = temp + M(87, 62) * x(62)
      temp = temp + M(87, 63) * x(63)
      temp = temp + M(87, 64) * x(64)
      temp = temp + M(87, 65) * x(65)
      temp = temp + M(87, 66) * x(66)
      temp = temp + M(87, 68) * x(68)
      temp = temp + M(87, 69) * x(69)
      temp = temp + M(87, 70) * x(70)
      temp = temp + M(87, 72) * x(72)
      temp = temp + M(87, 74) * x(74)
      temp = temp + M(87, 75) * x(75)
      temp = temp + M(87, 76) * x(76)
      temp = temp + M(87, 77) * x(77)
      temp = temp + M(87, 78) * x(78)
      temp = temp + M(87, 79) * x(79)
      temp = temp + M(87, 80) * x(80)
      temp = temp + M(87, 81) * x(81)
      temp = temp + M(87, 82) * x(82)
      temp = temp + M(87, 83) * x(83)
      temp = temp + M(87, 84) * x(84)
      temp = temp + M(87, 85) * x(85)
      temp = temp + M(87, 86) * x(86)
      x(87) = ( x(87) - temp ) / M(87, 87)

      temp = M(88, 3) * x(3)
      temp = temp + M(88, 4) * x(4)
      temp = temp + M(88, 5) * x(5)
      temp = temp + M(88, 6) * x(6)
      temp = temp + M(88, 7) * x(7)
      temp = temp + M(88, 8) * x(8)
      temp = temp + M(88, 18) * x(18)
      temp = temp + M(88, 21) * x(21)
      temp = temp + M(88, 22) * x(22)
      temp = temp + M(88, 23) * x(23)
      temp = temp + M(88, 24) * x(24)
      temp = temp + M(88, 25) * x(25)
      temp = temp + M(88, 26) * x(26)
      temp = temp + M(88, 27) * x(27)
      temp = temp + M(88, 30) * x(30)
      temp = temp + M(88, 35) * x(35)
      temp = temp + M(88, 36) * x(36)
      temp = temp + M(88, 38) * x(38)
      temp = temp + M(88, 39) * x(39)
      temp = temp + M(88, 40) * x(40)
      temp = temp + M(88, 42) * x(42)
      temp = temp + M(88, 43) * x(43)
      temp = temp + M(88, 44) * x(44)
      temp = temp + M(88, 45) * x(45)
      temp = temp + M(88, 47) * x(47)
      temp = temp + M(88, 48) * x(48)
      temp = temp + M(88, 51) * x(51)
      temp = temp + M(88, 52) * x(52)
      temp = temp + M(88, 53) * x(53)
      temp = temp + M(88, 54) * x(54)
      temp = temp + M(88, 56) * x(56)
      temp = temp + M(88, 57) * x(57)
      temp = temp + M(88, 58) * x(58)
      temp = temp + M(88, 59) * x(59)
      temp = temp + M(88, 60) * x(60)
      temp = temp + M(88, 61) * x(61)
      temp = temp + M(88, 62) * x(62)
      temp = temp + M(88, 63) * x(63)
      temp = temp + M(88, 64) * x(64)
      temp = temp + M(88, 65) * x(65)
      temp = temp + M(88, 66) * x(66)
      temp = temp + M(88, 67) * x(67)
      temp = temp + M(88, 68) * x(68)
      temp = temp + M(88, 69) * x(69)
      temp = temp + M(88, 70) * x(70)
      temp = temp + M(88, 72) * x(72)
      temp = temp + M(88, 73) * x(73)
      temp = temp + M(88, 75) * x(75)
      temp = temp + M(88, 76) * x(76)
      temp = temp + M(88, 77) * x(77)
      temp = temp + M(88, 78) * x(78)
      temp = temp + M(88, 79) * x(79)
      temp = temp + M(88, 80) * x(80)
      temp = temp + M(88, 81) * x(81)
      temp = temp + M(88, 82) * x(82)
      temp = temp + M(88, 83) * x(83)
      temp = temp + M(88, 84) * x(84)
      temp = temp + M(88, 85) * x(85)
      temp = temp + M(88, 86) * x(86)
      temp = temp + M(88, 87) * x(87)
      x(88) = ( x(88) - temp ) / M(88, 88)

      temp = M(89, 26) * x(26)
      temp = temp + M(89, 35) * x(35)
      temp = temp + M(89, 38) * x(38)
      temp = temp + M(89, 40) * x(40)
      temp = temp + M(89, 42) * x(42)
      temp = temp + M(89, 43) * x(43)
      temp = temp + M(89, 45) * x(45)
      temp = temp + M(89, 47) * x(47)
      temp = temp + M(89, 48) * x(48)
      temp = temp + M(89, 50) * x(50)
      temp = temp + M(89, 51) * x(51)
      temp = temp + M(89, 52) * x(52)
      temp = temp + M(89, 53) * x(53)
      temp = temp + M(89, 54) * x(54)
      temp = temp + M(89, 56) * x(56)
      temp = temp + M(89, 57) * x(57)
      temp = temp + M(89, 58) * x(58)
      temp = temp + M(89, 59) * x(59)
      temp = temp + M(89, 61) * x(61)
      temp = temp + M(89, 63) * x(63)
      temp = temp + M(89, 64) * x(64)
      temp = temp + M(89, 65) * x(65)
      temp = temp + M(89, 68) * x(68)
      temp = temp + M(89, 69) * x(69)
      temp = temp + M(89, 70) * x(70)
      temp = temp + M(89, 72) * x(72)
      temp = temp + M(89, 75) * x(75)
      temp = temp + M(89, 76) * x(76)
      temp = temp + M(89, 77) * x(77)
      temp = temp + M(89, 78) * x(78)
      temp = temp + M(89, 80) * x(80)
      temp = temp + M(89, 81) * x(81)
      temp = temp + M(89, 82) * x(82)
      temp = temp + M(89, 83) * x(83)
      temp = temp + M(89, 84) * x(84)
      temp = temp + M(89, 85) * x(85)
      temp = temp + M(89, 86) * x(86)
      temp = temp + M(89, 87) * x(87)
      temp = temp + M(89, 88) * x(88)
      x(89) = ( x(89) - temp ) / M(89, 89)


C     Backward substitution.

      temp = M(88, 89) * x(89)
      x(88) = x(88) - temp

      temp = M(87, 88) * x(88)
      temp = temp + M(87, 89) * x(89)
      x(87) = x(87) - temp

      temp = M(86, 87) * x(87)
      temp = temp + M(86, 88) * x(88)
      temp = temp + M(86, 89) * x(89)
      x(86) = x(86) - temp

      temp = M(85, 86) * x(86)
      temp = temp + M(85, 87) * x(87)
      temp = temp + M(85, 88) * x(88)
      temp = temp + M(85, 89) * x(89)
      x(85) = x(85) - temp

      temp = M(84, 85) * x(85)
      temp = temp + M(84, 86) * x(86)
      temp = temp + M(84, 87) * x(87)
      temp = temp + M(84, 88) * x(88)
      temp = temp + M(84, 89) * x(89)
      x(84) = x(84) - temp

      temp = M(83, 84) * x(84)
      temp = temp + M(83, 85) * x(85)
      temp = temp + M(83, 86) * x(86)
      temp = temp + M(83, 87) * x(87)
      temp = temp + M(83, 88) * x(88)
      temp = temp + M(83, 89) * x(89)
      x(83) = x(83) - temp

      temp = M(82, 83) * x(83)
      temp = temp + M(82, 84) * x(84)
      temp = temp + M(82, 85) * x(85)
      temp = temp + M(82, 86) * x(86)
      temp = temp + M(82, 87) * x(87)
      temp = temp + M(82, 88) * x(88)
      temp = temp + M(82, 89) * x(89)
      x(82) = x(82) - temp

      temp = M(81, 82) * x(82)
      temp = temp + M(81, 83) * x(83)
      temp = temp + M(81, 84) * x(84)
      temp = temp + M(81, 85) * x(85)
      temp = temp + M(81, 86) * x(86)
      temp = temp + M(81, 87) * x(87)
      temp = temp + M(81, 88) * x(88)
      temp = temp + M(81, 89) * x(89)
      x(81) = x(81) - temp

      temp = M(80, 81) * x(81)
      temp = temp + M(80, 82) * x(82)
      temp = temp + M(80, 83) * x(83)
      temp = temp + M(80, 84) * x(84)
      temp = temp + M(80, 85) * x(85)
      temp = temp + M(80, 86) * x(86)
      temp = temp + M(80, 87) * x(87)
      temp = temp + M(80, 88) * x(88)
      temp = temp + M(80, 89) * x(89)
      x(80) = x(80) - temp

      temp = M(79, 80) * x(80)
      temp = temp + M(79, 82) * x(82)
      temp = temp + M(79, 83) * x(83)
      temp = temp + M(79, 84) * x(84)
      temp = temp + M(79, 85) * x(85)
      temp = temp + M(79, 86) * x(86)
      temp = temp + M(79, 87) * x(87)
      temp = temp + M(79, 88) * x(88)
      temp = temp + M(79, 89) * x(89)
      x(79) = x(79) - temp

      temp = M(78, 80) * x(80)
      temp = temp + M(78, 82) * x(82)
      temp = temp + M(78, 83) * x(83)
      temp = temp + M(78, 84) * x(84)
      temp = temp + M(78, 85) * x(85)
      temp = temp + M(78, 86) * x(86)
      temp = temp + M(78, 87) * x(87)
      temp = temp + M(78, 88) * x(88)
      temp = temp + M(78, 89) * x(89)
      x(78) = x(78) - temp

      temp = M(77, 78) * x(78)
      temp = temp + M(77, 80) * x(80)
      temp = temp + M(77, 82) * x(82)
      temp = temp + M(77, 83) * x(83)
      temp = temp + M(77, 84) * x(84)
      temp = temp + M(77, 85) * x(85)
      temp = temp + M(77, 86) * x(86)
      temp = temp + M(77, 87) * x(87)
      temp = temp + M(77, 88) * x(88)
      temp = temp + M(77, 89) * x(89)
      x(77) = x(77) - temp

      temp = M(76, 77) * x(77)
      temp = temp + M(76, 78) * x(78)
      temp = temp + M(76, 80) * x(80)
      temp = temp + M(76, 82) * x(82)
      temp = temp + M(76, 83) * x(83)
      temp = temp + M(76, 84) * x(84)
      temp = temp + M(76, 85) * x(85)
      temp = temp + M(76, 86) * x(86)
      temp = temp + M(76, 87) * x(87)
      temp = temp + M(76, 88) * x(88)
      temp = temp + M(76, 89) * x(89)
      x(76) = x(76) - temp

      temp = M(75, 76) * x(76)
      temp = temp + M(75, 77) * x(77)
      temp = temp + M(75, 78) * x(78)
      temp = temp + M(75, 80) * x(80)
      temp = temp + M(75, 82) * x(82)
      temp = temp + M(75, 84) * x(84)
      temp = temp + M(75, 85) * x(85)
      temp = temp + M(75, 86) * x(86)
      temp = temp + M(75, 87) * x(87)
      temp = temp + M(75, 88) * x(88)
      temp = temp + M(75, 89) * x(89)
      x(75) = x(75) - temp

      temp = M(74, 76) * x(76)
      temp = temp + M(74, 77) * x(77)
      temp = temp + M(74, 79) * x(79)
      temp = temp + M(74, 80) * x(80)
      temp = temp + M(74, 81) * x(81)
      temp = temp + M(74, 82) * x(82)
      temp = temp + M(74, 84) * x(84)
      temp = temp + M(74, 85) * x(85)
      temp = temp + M(74, 86) * x(86)
      temp = temp + M(74, 87) * x(87)
      temp = temp + M(74, 88) * x(88)
      temp = temp + M(74, 89) * x(89)
      x(74) = x(74) - temp

      temp = M(73, 75) * x(75)
      temp = temp + M(73, 76) * x(76)
      temp = temp + M(73, 77) * x(77)
      temp = temp + M(73, 78) * x(78)
      temp = temp + M(73, 80) * x(80)
      temp = temp + M(73, 82) * x(82)
      temp = temp + M(73, 84) * x(84)
      temp = temp + M(73, 85) * x(85)
      temp = temp + M(73, 86) * x(86)
      temp = temp + M(73, 87) * x(87)
      temp = temp + M(73, 88) * x(88)
      temp = temp + M(73, 89) * x(89)
      x(73) = x(73) - temp

      temp = M(72, 76) * x(76)
      temp = temp + M(72, 77) * x(77)
      temp = temp + M(72, 80) * x(80)
      temp = temp + M(72, 82) * x(82)
      temp = temp + M(72, 84) * x(84)
      temp = temp + M(72, 85) * x(85)
      temp = temp + M(72, 86) * x(86)
      temp = temp + M(72, 87) * x(87)
      temp = temp + M(72, 88) * x(88)
      temp = temp + M(72, 89) * x(89)
      x(72) = x(72) - temp

      temp = M(71, 76) * x(76)
      temp = temp + M(71, 77) * x(77)
      temp = temp + M(71, 78) * x(78)
      temp = temp + M(71, 80) * x(80)
      temp = temp + M(71, 82) * x(82)
      temp = temp + M(71, 84) * x(84)
      temp = temp + M(71, 85) * x(85)
      temp = temp + M(71, 86) * x(86)
      temp = temp + M(71, 87) * x(87)
      temp = temp + M(71, 88) * x(88)
      temp = temp + M(71, 89) * x(89)
      x(71) = x(71) - temp

      temp = M(70, 77) * x(77)
      temp = temp + M(70, 80) * x(80)
      temp = temp + M(70, 82) * x(82)
      temp = temp + M(70, 84) * x(84)
      temp = temp + M(70, 85) * x(85)
      temp = temp + M(70, 86) * x(86)
      temp = temp + M(70, 87) * x(87)
      temp = temp + M(70, 88) * x(88)
      temp = temp + M(70, 89) * x(89)
      x(70) = x(70) - temp

      temp = M(69, 80) * x(80)
      temp = temp + M(69, 82) * x(82)
      temp = temp + M(69, 84) * x(84)
      temp = temp + M(69, 85) * x(85)
      temp = temp + M(69, 86) * x(86)
      temp = temp + M(69, 87) * x(87)
      temp = temp + M(69, 88) * x(88)
      temp = temp + M(69, 89) * x(89)
      x(69) = x(69) - temp

      temp = M(68, 80) * x(80)
      temp = temp + M(68, 82) * x(82)
      temp = temp + M(68, 84) * x(84)
      temp = temp + M(68, 85) * x(85)
      temp = temp + M(68, 86) * x(86)
      temp = temp + M(68, 87) * x(87)
      temp = temp + M(68, 88) * x(88)
      temp = temp + M(68, 89) * x(89)
      x(68) = x(68) - temp

      temp = M(67, 72) * x(72)
      temp = temp + M(67, 76) * x(76)
      temp = temp + M(67, 79) * x(79)
      temp = temp + M(67, 80) * x(80)
      temp = temp + M(67, 81) * x(81)
      temp = temp + M(67, 82) * x(82)
      temp = temp + M(67, 84) * x(84)
      temp = temp + M(67, 85) * x(85)
      temp = temp + M(67, 86) * x(86)
      temp = temp + M(67, 87) * x(87)
      temp = temp + M(67, 88) * x(88)
      temp = temp + M(67, 89) * x(89)
      x(67) = x(67) - temp

      temp = M(66, 76) * x(76)
      temp = temp + M(66, 80) * x(80)
      temp = temp + M(66, 82) * x(82)
      temp = temp + M(66, 84) * x(84)
      temp = temp + M(66, 85) * x(85)
      temp = temp + M(66, 86) * x(86)
      temp = temp + M(66, 87) * x(87)
      temp = temp + M(66, 88) * x(88)
      temp = temp + M(66, 89) * x(89)
      x(66) = x(66) - temp

      temp = M(65, 80) * x(80)
      temp = temp + M(65, 82) * x(82)
      temp = temp + M(65, 84) * x(84)
      temp = temp + M(65, 85) * x(85)
      temp = temp + M(65, 86) * x(86)
      temp = temp + M(65, 87) * x(87)
      temp = temp + M(65, 88) * x(88)
      temp = temp + M(65, 89) * x(89)
      x(65) = x(65) - temp

      temp = M(64, 65) * x(65)
      temp = temp + M(64, 80) * x(80)
      temp = temp + M(64, 82) * x(82)
      temp = temp + M(64, 84) * x(84)
      temp = temp + M(64, 85) * x(85)
      temp = temp + M(64, 87) * x(87)
      temp = temp + M(64, 88) * x(88)
      temp = temp + M(64, 89) * x(89)
      x(64) = x(64) - temp

      temp = M(63, 64) * x(64)
      temp = temp + M(63, 65) * x(65)
      temp = temp + M(63, 80) * x(80)
      temp = temp + M(63, 82) * x(82)
      temp = temp + M(63, 84) * x(84)
      temp = temp + M(63, 85) * x(85)
      temp = temp + M(63, 87) * x(87)
      temp = temp + M(63, 88) * x(88)
      temp = temp + M(63, 89) * x(89)
      x(63) = x(63) - temp

      temp = M(62, 65) * x(65)
      temp = temp + M(62, 80) * x(80)
      temp = temp + M(62, 82) * x(82)
      temp = temp + M(62, 84) * x(84)
      temp = temp + M(62, 85) * x(85)
      temp = temp + M(62, 87) * x(87)
      temp = temp + M(62, 88) * x(88)
      temp = temp + M(62, 89) * x(89)
      x(62) = x(62) - temp

      temp = M(61, 65) * x(65)
      temp = temp + M(61, 80) * x(80)
      temp = temp + M(61, 82) * x(82)
      temp = temp + M(61, 84) * x(84)
      temp = temp + M(61, 85) * x(85)
      temp = temp + M(61, 87) * x(87)
      temp = temp + M(61, 88) * x(88)
      temp = temp + M(61, 89) * x(89)
      x(61) = x(61) - temp

      temp = M(60, 65) * x(65)
      temp = temp + M(60, 80) * x(80)
      temp = temp + M(60, 82) * x(82)
      temp = temp + M(60, 84) * x(84)
      temp = temp + M(60, 85) * x(85)
      temp = temp + M(60, 87) * x(87)
      temp = temp + M(60, 88) * x(88)
      temp = temp + M(60, 89) * x(89)
      x(60) = x(60) - temp

      temp = M(59, 65) * x(65)
      temp = temp + M(59, 80) * x(80)
      temp = temp + M(59, 82) * x(82)
      temp = temp + M(59, 84) * x(84)
      temp = temp + M(59, 85) * x(85)
      temp = temp + M(59, 87) * x(87)
      temp = temp + M(59, 88) * x(88)
      temp = temp + M(59, 89) * x(89)
      x(59) = x(59) - temp

      temp = M(58, 59) * x(59)
      temp = temp + M(58, 65) * x(65)
      temp = temp + M(58, 80) * x(80)
      temp = temp + M(58, 82) * x(82)
      temp = temp + M(58, 84) * x(84)
      temp = temp + M(58, 85) * x(85)
      temp = temp + M(58, 87) * x(87)
      temp = temp + M(58, 88) * x(88)
      temp = temp + M(58, 89) * x(89)
      x(58) = x(58) - temp

      temp = M(57, 80) * x(80)
      temp = temp + M(57, 82) * x(82)
      temp = temp + M(57, 85) * x(85)
      temp = temp + M(57, 87) * x(87)
      temp = temp + M(57, 88) * x(88)
      temp = temp + M(57, 89) * x(89)
      x(57) = x(57) - temp

      temp = M(56, 65) * x(65)
      temp = temp + M(56, 80) * x(80)
      temp = temp + M(56, 82) * x(82)
      temp = temp + M(56, 85) * x(85)
      temp = temp + M(56, 87) * x(87)
      temp = temp + M(56, 88) * x(88)
      temp = temp + M(56, 89) * x(89)
      x(56) = x(56) - temp

      temp = M(55, 60) * x(60)
      temp = temp + M(55, 62) * x(62)
      temp = temp + M(55, 65) * x(65)
      temp = temp + M(55, 80) * x(80)
      temp = temp + M(55, 82) * x(82)
      temp = temp + M(55, 84) * x(84)
      temp = temp + M(55, 85) * x(85)
      temp = temp + M(55, 87) * x(87)
      temp = temp + M(55, 88) * x(88)
      temp = temp + M(55, 89) * x(89)
      x(55) = x(55) - temp

      temp = M(54, 59) * x(59)
      temp = temp + M(54, 65) * x(65)
      temp = temp + M(54, 80) * x(80)
      temp = temp + M(54, 82) * x(82)
      temp = temp + M(54, 84) * x(84)
      temp = temp + M(54, 85) * x(85)
      temp = temp + M(54, 87) * x(87)
      temp = temp + M(54, 88) * x(88)
      temp = temp + M(54, 89) * x(89)
      x(54) = x(54) - temp

      temp = M(53, 80) * x(80)
      temp = temp + M(53, 82) * x(82)
      temp = temp + M(53, 85) * x(85)
      temp = temp + M(53, 87) * x(87)
      temp = temp + M(53, 88) * x(88)
      temp = temp + M(53, 89) * x(89)
      x(53) = x(53) - temp

      temp = M(52, 65) * x(65)
      temp = temp + M(52, 80) * x(80)
      temp = temp + M(52, 82) * x(82)
      temp = temp + M(52, 85) * x(85)
      temp = temp + M(52, 87) * x(87)
      temp = temp + M(52, 88) * x(88)
      temp = temp + M(52, 89) * x(89)
      x(52) = x(52) - temp

      temp = M(51, 65) * x(65)
      temp = temp + M(51, 80) * x(80)
      temp = temp + M(51, 82) * x(82)
      temp = temp + M(51, 84) * x(84)
      temp = temp + M(51, 85) * x(85)
      temp = temp + M(51, 87) * x(87)
      temp = temp + M(51, 88) * x(88)
      temp = temp + M(51, 89) * x(89)
      x(51) = x(51) - temp

      temp = M(50, 65) * x(65)
      temp = temp + M(50, 80) * x(80)
      temp = temp + M(50, 84) * x(84)
      temp = temp + M(50, 86) * x(86)
      temp = temp + M(50, 87) * x(87)
      temp = temp + M(50, 89) * x(89)
      x(50) = x(50) - temp

      temp = M(49, 54) * x(54)
      temp = temp + M(49, 59) * x(59)
      temp = temp + M(49, 60) * x(60)
      temp = temp + M(49, 65) * x(65)
      temp = temp + M(49, 80) * x(80)
      temp = temp + M(49, 84) * x(84)
      temp = temp + M(49, 85) * x(85)
      temp = temp + M(49, 86) * x(86)
      temp = temp + M(49, 87) * x(87)
      x(49) = x(49) - temp

      temp = M(48, 65) * x(65)
      temp = temp + M(48, 80) * x(80)
      temp = temp + M(48, 84) * x(84)
      temp = temp + M(48, 86) * x(86)
      temp = temp + M(48, 87) * x(87)
      x(48) = x(48) - temp

      temp = M(47, 48) * x(48)
      temp = temp + M(47, 59) * x(59)
      temp = temp + M(47, 70) * x(70)
      temp = temp + M(47, 80) * x(80)
      temp = temp + M(47, 82) * x(82)
      x(47) = x(47) - temp

      temp = M(46, 51) * x(51)
      temp = temp + M(46, 65) * x(65)
      temp = temp + M(46, 80) * x(80)
      temp = temp + M(46, 82) * x(82)
      temp = temp + M(46, 84) * x(84)
      temp = temp + M(46, 85) * x(85)
      temp = temp + M(46, 87) * x(87)
      temp = temp + M(46, 88) * x(88)
      temp = temp + M(46, 89) * x(89)
      x(46) = x(46) - temp

      temp = M(45, 65) * x(65)
      temp = temp + M(45, 80) * x(80)
      temp = temp + M(45, 84) * x(84)
      temp = temp + M(45, 87) * x(87)
      temp = temp + M(45, 88) * x(88)
      x(45) = x(45) - temp

      temp = M(44, 59) * x(59)
      temp = temp + M(44, 60) * x(60)
      temp = temp + M(44, 62) * x(62)
      temp = temp + M(44, 65) * x(65)
      temp = temp + M(44, 80) * x(80)
      temp = temp + M(44, 84) * x(84)
      temp = temp + M(44, 85) * x(85)
      temp = temp + M(44, 87) * x(87)
      temp = temp + M(44, 88) * x(88)
      x(44) = x(44) - temp

      temp = M(43, 59) * x(59)
      temp = temp + M(43, 65) * x(65)
      temp = temp + M(43, 80) * x(80)
      temp = temp + M(43, 84) * x(84)
      temp = temp + M(43, 85) * x(85)
      temp = temp + M(43, 87) * x(87)
      x(43) = x(43) - temp

      temp = M(42, 45) * x(45)
      temp = temp + M(42, 65) * x(65)
      temp = temp + M(42, 80) * x(80)
      temp = temp + M(42, 82) * x(82)
      temp = temp + M(42, 84) * x(84)
      temp = temp + M(42, 85) * x(85)
      temp = temp + M(42, 87) * x(87)
      temp = temp + M(42, 88) * x(88)
      temp = temp + M(42, 89) * x(89)
      x(42) = x(42) - temp

      temp = M(41, 51) * x(51)
      temp = temp + M(41, 65) * x(65)
      temp = temp + M(41, 80) * x(80)
      temp = temp + M(41, 82) * x(82)
      temp = temp + M(41, 84) * x(84)
      temp = temp + M(41, 85) * x(85)
      temp = temp + M(41, 87) * x(87)
      temp = temp + M(41, 88) * x(88)
      temp = temp + M(41, 89) * x(89)
      x(41) = x(41) - temp

      temp = M(40, 65) * x(65)
      temp = temp + M(40, 80) * x(80)
      temp = temp + M(40, 82) * x(82)
      temp = temp + M(40, 84) * x(84)
      temp = temp + M(40, 85) * x(85)
      temp = temp + M(40, 87) * x(87)
      temp = temp + M(40, 88) * x(88)
      temp = temp + M(40, 89) * x(89)
      x(40) = x(40) - temp

      temp = M(39, 45) * x(45)
      temp = temp + M(39, 80) * x(80)
      temp = temp + M(39, 84) * x(84)
      temp = temp + M(39, 87) * x(87)
      temp = temp + M(39, 88) * x(88)
      x(39) = x(39) - temp

      temp = M(38, 54) * x(54)
      temp = temp + M(38, 65) * x(65)
      temp = temp + M(38, 80) * x(80)
      temp = temp + M(38, 88) * x(88)
      temp = temp + M(38, 89) * x(89)
      x(38) = x(38) - temp

      temp = M(37, 60) * x(60)
      temp = temp + M(37, 62) * x(62)
      temp = temp + M(37, 65) * x(65)
      temp = temp + M(37, 80) * x(80)
      x(37) = x(37) - temp

      temp = M(36, 45) * x(45)
      temp = temp + M(36, 65) * x(65)
      temp = temp + M(36, 80) * x(80)
      temp = temp + M(36, 84) * x(84)
      x(36) = x(36) - temp

      temp = M(35, 43) * x(43)
      temp = temp + M(35, 65) * x(65)
      temp = temp + M(35, 80) * x(80)
      temp = temp + M(35, 87) * x(87)
      x(35) = x(35) - temp

      temp = M(34, 60) * x(60)
      temp = temp + M(34, 62) * x(62)
      temp = temp + M(34, 65) * x(65)
      temp = temp + M(34, 80) * x(80)
      x(34) = x(34) - temp

      temp = M(33, 36) * x(36)
      temp = temp + M(33, 65) * x(65)
      temp = temp + M(33, 80) * x(80)
      temp = temp + M(33, 84) * x(84)
      temp = temp + M(33, 85) * x(85)
      x(33) = x(33) - temp

      temp = M(32, 65) * x(65)
      temp = temp + M(32, 80) * x(80)
      temp = temp + M(32, 87) * x(87)
      x(32) = x(32) - temp

      temp = M(31, 65) * x(65)
      temp = temp + M(31, 80) * x(80)
      temp = temp + M(31, 87) * x(87)
      x(31) = x(31) - temp

      temp = M(30, 65) * x(65)
      temp = temp + M(30, 80) * x(80)
      temp = temp + M(30, 87) * x(87)
      x(30) = x(30) - temp

      temp = M(29, 30) * x(30)
      temp = temp + M(29, 65) * x(65)
      temp = temp + M(29, 80) * x(80)
      temp = temp + M(29, 87) * x(87)
      x(29) = x(29) - temp

      temp = M(28, 30) * x(30)
      temp = temp + M(28, 65) * x(65)
      temp = temp + M(28, 80) * x(80)
      temp = temp + M(28, 87) * x(87)
      x(28) = x(28) - temp

      temp = M(27, 65) * x(65)
      temp = temp + M(27, 80) * x(80)
      temp = temp + M(27, 87) * x(87)
      x(27) = x(27) - temp

      temp = M(26, 65) * x(65)
      temp = temp + M(26, 80) * x(80)
      temp = temp + M(26, 87) * x(87)
      x(26) = x(26) - temp

      temp = M(25, 65) * x(65)
      temp = temp + M(25, 80) * x(80)
      temp = temp + M(25, 87) * x(87)
      x(25) = x(25) - temp

      temp = M(24, 80) * x(80)
      temp = temp + M(24, 84) * x(84)
      temp = temp + M(24, 88) * x(88)
      x(24) = x(24) - temp

      temp = M(23, 65) * x(65)
      temp = temp + M(23, 80) * x(80)
      temp = temp + M(23, 84) * x(84)
      x(23) = x(23) - temp

      temp = M(22, 65) * x(65)
      temp = temp + M(22, 80) * x(80)
      temp = temp + M(22, 84) * x(84)
      x(22) = x(22) - temp

      temp = M(21, 80) * x(80)
      temp = temp + M(21, 82) * x(82)
      temp = temp + M(21, 88) * x(88)
      x(21) = x(21) - temp

      temp = M(20, 35) * x(35)
      temp = temp + M(20, 80) * x(80)
      x(20) = x(20) - temp

      temp = M(19, 35) * x(35)
      temp = temp + M(19, 80) * x(80)
      x(19) = x(19) - temp

      temp = M(18, 54) * x(54)
      temp = temp + M(18, 80) * x(80)
      x(18) = x(18) - temp

      temp = M(17, 84) * x(84)
      temp = temp + M(17, 87) * x(87)
      x(17) = x(17) - temp

      temp = M(16, 80) * x(80)
      x(16) = x(16) - temp

      temp = M(15, 80) * x(80)
      x(15) = x(15) - temp

      temp = M(14, 80) * x(80)
      x(14) = x(14) - temp

      temp = M(13, 80) * x(80)
      x(13) = x(13) - temp

      temp = M(12, 80) * x(80)
      x(12) = x(12) - temp

      temp = M(11, 80) * x(80)
      x(11) = x(11) - temp

      temp = M(10, 80) * x(80)
      x(10) = x(10) - temp

      temp = M(9, 65) * x(65)
      x(9) = x(9) - temp

      temp = M(8, 80) * x(80)
      x(8) = x(8) - temp

      temp = M(7, 80) * x(80)
      x(7) = x(7) - temp

      temp = M(6, 80) * x(80)
      x(6) = x(6) - temp

      temp = M(5, 80) * x(80)
      x(5) = x(5) - temp

      temp = M(4, 80) * x(80)
      x(4) = x(4) - temp

      temp = M(3, 80) * x(80)
      x(3) = x(3) - temp


      END
