C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C
C     This file is part of the air quality modeling system Polyphemus.
C
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C
C     Polyphemus is free software; you can redistribute i and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C------------------------------------------------------------------------
 
      subroutine rates(ns,nr,rk,y,w)
 
C------------------------------------------------------------------------
C
C     -- DESCRIPTION
C
C     This routine computes the reaction rates.
C     This routine is automatically generated by SPACK.
C     Mechanism: RACM2_AEC           
C     Species: _ciRACM2_AEC        
C
C------------------------------------------------------------------------
C
C     -- INPUT VARIABLES
C
C     Ns: chemical species number.
C     NR: reaction number.
C     RK: kinetic rates.
C     Y: chemical concentrations.
C
C     -- INPUT/OUTPUT VARIABLES
C
C     -- OUTPUT VARIABLES
C
C     W: reaction rates.
C
C------------------------------------------------------------------------
C
C     -- REMARKS
C
C------------------------------------------------------------------------
C
C     -- MODIFICATIONS
C
C------------------------------------------------------------------------
C
C     -- AUTHOR(S)
C
C     SPACK.
C
C------------------------------------------------------------------------
 
      implicit none
 
      integer nr,ns
      double precision rk(nr),y(ns),w(nr)
 
 
 
      w(  1) =  rk(  1) * Y(124)
      w(  2) =  rk(  2) * Y( 90)
      w(  3) =  rk(  3) * Y( 90)
      w(  4) =  rk(  4) * Y( 23)
      w(  5) =  rk(  5) * Y(103)
      w(  6) =  rk(  6) * Y( 42)
      w(  7) =  rk(  7) * Y(121)
      w(  8) =  rk(  8) * Y(121)
      w(  9) =  rk(  9) * Y( 49)
      w( 10) =  rk( 10) * Y(119)
      w( 11) =  rk( 11) * Y(119)
      w( 12) =  rk( 12) * Y(100)
      w( 13) =  rk( 13) * Y(112)
      w( 14) =  rk( 14) * Y( 73)
      w( 15) =  rk( 15) * Y( 36)
      w( 16) =  rk( 16) * Y(109)
      w( 17) =  rk( 17) * Y( 77)
      w( 18) =  rk( 18) * Y( 84)
      w( 19) =  rk( 19) * Y( 81)
      w( 20) =  rk( 20) * Y( 87)
      w( 21) =  rk( 21) * Y(104)
      w( 22) =  rk( 22) * Y(104)
      w( 23) =  rk( 23) * Y(104)
      w( 24) =  rk( 24) * Y(102)
      w( 25) =  rk( 25) * Y( 69)
      w( 26) =  rk( 26) * Y( 65)
      w( 27) =  rk( 27) * Y( 91)
      w( 28) =  rk( 28) * Y( 63)
      w( 29) =  rk( 29) * Y( 39)
      w( 30) =  rk( 30) * Y(115)
      w( 31) =  rk( 31) * Y( 71)
      w( 32) =  rk( 32) * Y(111)
      w( 33) =  rk( 33) * Y( 40)
      w( 34) =  rk( 34) * Y( 40)
      w( 35) =  rk( 35) * Y( 48)
      w( 36) =  rk( 36) * Y( 48) * Y( 90)
      w( 37) =  rk( 37) * Y(  3)
      w( 38) =  rk( 38) * Y(  3)
      w( 39) =  rk( 39) * Y(  3)
      w( 40) =  rk( 40) * Y( 90) * Y(120)
      w( 41) =  rk( 41) * Y( 90) * Y(123)
      w( 42) =  rk( 42) * Y(120) * Y(123)
      w( 43) =  rk( 43) * Y( 49) * Y(120)
      w( 44) =  rk( 44) * Y(123) * Y(123)
      w( 45) =  rk( 45) * Y(123) * Y(123)
      w( 46) =  rk( 46) * Y( 48) * Y(117)
      w( 47) =  rk( 47) * Y( 48) * Y(124)
      w( 48) =  rk( 48) * Y( 48) * Y(124)
      w( 49) =  rk( 49) * Y(120) * Y(117)
      w( 50) =  rk( 50) * Y(120) * Y(124)
      w( 51) =  rk( 51) * Y(120) * Y(121)
      w( 52) =  rk( 52) * Y(123) * Y(117)
      w( 53) =  rk( 53) * Y(123) * Y(124)
      w( 54) =  rk( 54) * Y( 42)
      w( 55) =  rk( 55) * Y(123) * Y(121)
      w( 56) =  rk( 56) * Y(120) * Y( 23)
      w( 57) =  rk( 57) * Y(120) * Y(103)
      w( 58) =  rk( 58) * Y(120) * Y( 42)
      w( 59) =  rk( 59) * Y( 90) * Y(117)
      w( 60) =  rk( 60) * Y( 90) * Y(124)
      w( 61) =  rk( 61) * Y(117) * Y(117)
      w( 62) =  rk( 62) * Y(121) * Y(117)
      w( 63) =  rk( 63) * Y(121) * Y(124)
      w( 64) =  rk( 64) * Y(121) * Y(124)
      w( 65) =  rk( 65) * Y( 17)
      w( 66) =  rk( 66) * Y( 17)
      w( 67) =  rk( 67) * Y(121) * Y(121)
      w( 68) =  rk( 68) * Y(120)
      w( 69) =  rk( 69) * Y(120) * Y(  4)
      w( 70) =  rk( 70) * Y(108) * Y(120)
      w( 71) =  rk( 71) * Y( 45) * Y(120)
      w( 72) =  rk( 72) * Y( 38) * Y(120)
      w( 73) =  rk( 73) * Y( 99) * Y(120)
      w( 74) =  rk( 74) * Y( 25) * Y(120)
      w( 75) =  rk( 75) * Y( 95) * Y(120)
      w( 76) =  rk( 76) * Y(  6) * Y(120)
      w( 77) =  rk( 77) * Y(  8) * Y(120)
      w( 78) =  rk( 78) * Y(  9) * Y(120)
      w( 79) =  rk( 79) * Y( 10) * Y(120)
      w( 80) =  rk( 80) * Y( 27) * Y(120)
      w( 81) =  rk( 81) * Y( 37) * Y(120)
      w( 82) =  rk( 82) * Y( 89) * Y(120)
      w( 83) =  rk( 83) * Y( 24) * Y(120)
      w( 84) =  rk( 84) * Y( 30) * Y(120)
      w( 85) =  rk( 85) * Y( 22) * Y(120)
      w( 86) =  rk( 86) * Y( 31) * Y(120)
      w( 87) =  rk( 87) * Y( 29) * Y(120)
      w( 88) =  rk( 88) * Y( 46) * Y(120)
      w( 89) =  rk( 89) * Y( 34) * Y(120)
      w( 90) =  rk( 90) * Y( 76) * Y(120)
      w( 91) =  rk( 91) * Y( 18) * Y(120)
      w( 92) =  rk( 92) * Y( 28) * Y(120)
      w( 93) =  rk( 93) * Y(  7) * Y(120)
      w( 94) =  rk( 94) * Y( 11) * Y(120)
      w( 95) =  rk( 95) * Y( 53) * Y(117)
      w( 96) =  rk( 96) * Y( 12)
      w( 97) =  rk( 97) * Y( 54)
      w( 98) =  rk( 98) * Y( 54) * Y(117)
      w( 99) =  rk( 99) * Y( 52) * Y(117)
      w(100) =  rk(100) * Y( 15) * Y(120)
      w(101) =  rk(101) * Y( 13) * Y(120)
      w(102) =  rk(102) * Y( 55) * Y(117)
      w(103) =  rk(103) * Y( 14)
      w(104) =  rk(104) * Y( 16)
      w(105) =  rk(105) * Y( 56)
      w(106) =  rk(106) * Y( 64)
      w(107) =  rk(107) * Y( 56) * Y(117)
      w(108) =  rk(108) * Y( 62) * Y(117)
      w(109) =  rk(109) * Y( 63) * Y(120)
      w(110) =  rk(110) * Y( 67) * Y(117)
      w(111) =  rk(111) * Y( 50) * Y(117)
      w(112) =  rk(112) * Y( 51) * Y(124)
      w(113) =  rk(113) * Y( 19) * Y(120)
      w(114) =  rk(114) * Y( 58) * Y(120)
      w(115) =  rk(115) * Y( 35) * Y(120)
      w(116) =  rk(116) * Y( 35) * Y(121)
      w(117) =  rk(117) * Y( 97) * Y( 90)
      w(118) =  rk(118) * Y( 97) * Y(124)
      w(119) =  rk(119) * Y( 96) * Y(117)
      w(120) =  rk(120) * Y( 96) * Y(114)
      w(121) =  rk(121) * Y( 96) * Y(118)
      w(122) =  rk(122) * Y( 96) * Y(123)
      w(123) =  rk(123) * Y( 96) * Y(121)
      w(124) =  rk(124) * Y(119) * Y(120)
      w(125) =  rk(125) * Y(100) * Y(120)
      w(126) =  rk(126) * Y(112) * Y(120)
      w(127) =  rk(127) * Y( 73) * Y(120)
      w(128) =  rk(128) * Y( 36) * Y(120)
      w(129) =  rk(129) * Y(109) * Y(120)
      w(130) =  rk(130) * Y( 77) * Y(120)
      w(131) =  rk(131) * Y(104) * Y(120)
      w(132) =  rk(132) * Y(102) * Y(120)
      w(133) =  rk(133) * Y( 84) * Y(120)
      w(134) =  rk(134) * Y( 81) * Y(120)
      w(135) =  rk(135) * Y( 87) * Y(120)
      w(136) =  rk(136) * Y( 26) * Y(120)
      w(137) =  rk(137) * Y( 65) * Y(120)
      w(138) =  rk(138) * Y( 69) * Y(120)
      w(139) =  rk(139) * Y( 91) * Y(120)
      w(140) =  rk(140) * Y( 39) * Y(120)
      w(141) =  rk(141) * Y(115) * Y(120)
      w(142) =  rk(142) * Y( 71) * Y(120)
      w(143) =  rk(143) * Y( 40) * Y(120)
      w(144) =  rk(144) * Y( 41) * Y(120)
      w(145) =  rk(145) * Y( 47) * Y(120)
      w(146) =  rk(146) * Y(111) * Y(120)
      w(147) =  rk(147) * Y( 82) * Y(120)
      w(148) =  rk(148) * Y(106) * Y(120)
      w(149) =  rk(149) * Y(119) * Y(121)
      w(150) =  rk(150) * Y(100) * Y(121)
      w(151) =  rk(151) * Y(112) * Y(121)
      w(152) =  rk(152) * Y(104) * Y(121)
      w(153) =  rk(153) * Y(102) * Y(121)
      w(154) =  rk(154) * Y( 26) * Y(121)
      w(155) =  rk(155) * Y( 19) * Y(121)
      w(156) =  rk(156) * Y( 58) * Y(121)
      w(157) =  rk(157) * Y( 61) * Y(117)
      w(158) =  rk(158) * Y( 61) * Y(121)
      w(159) =  rk(159) * Y( 61) * Y(114)
      w(160) =  rk(160) * Y( 61) * Y(118)
      w(161) =  rk(161) * Y( 61) * Y(123)
      w(162) =  rk(162) * Y( 27) * Y(121)
      w(163) =  rk(163) * Y( 37) * Y(121)
      w(164) =  rk(164) * Y( 89) * Y(121)
      w(165) =  rk(165) * Y( 24) * Y(121)
      w(166) =  rk(166) * Y( 30) * Y(121)
      w(167) =  rk(167) * Y( 84) * Y(121)
      w(168) =  rk(168) * Y( 87) * Y(121)
      w(169) =  rk(169) * Y( 22) * Y(121)
      w(170) =  rk(170) * Y( 31) * Y(121)
      w(171) =  rk(171) * Y( 47) * Y(121)
      w(172) =  rk(172) * Y( 27) * Y( 90)
      w(173) =  rk(173) * Y( 37) * Y( 90)
      w(174) =  rk(174) * Y( 89) * Y( 90)
      w(175) =  rk(175) * Y( 24) * Y( 90)
      w(176) =  rk(176) * Y( 30) * Y( 90)
      w(177) =  rk(177) * Y( 84) * Y( 90)
      w(178) =  rk(178) * Y( 81) * Y( 90)
      w(179) =  rk(179) * Y( 87) * Y( 90)
      w(180) =  rk(180) * Y( 22) * Y( 90)
      w(181) =  rk(181) * Y( 31) * Y( 90)
      w(182) =  rk(182) * Y( 26) * Y( 90)
      w(183) =  rk(183) * Y( 91) * Y( 90)
      w(184) =  rk(184) * Y( 60) * Y(124)
      w(185) =  rk(185) * Y(118) * Y(124)
      w(186) =  rk(186) * Y(122) * Y(124)
      w(187) =  rk(187) * Y( 40)
      w(188) =  rk(188) * Y( 41)
      w(189) =  rk(189) * Y(105) * Y(124)
      w(190) =  rk(190) * Y( 47)
      w(191) =  rk(191) * Y(114) * Y(117)
      w(192) =  rk(192) * Y(113) * Y(117)
      w(193) =  rk(193) * Y(110) * Y(117)
      w(194) =  rk(194) * Y( 72) * Y(117)
      w(195) =  rk(195) * Y( 75) * Y(117)
      w(196) =  rk(196) * Y( 85) * Y(117)
      w(197) =  rk(197) * Y( 70) * Y(117)
      w(198) =  rk(198) * Y( 92) * Y(117)
      w(199) =  rk(199) * Y( 80) * Y(117)
      w(200) =  rk(200) * Y(105) * Y(117)
      w(201) =  rk(201) * Y( 83) * Y(117)
      w(202) =  rk(202) * Y( 68) * Y(117)
      w(203) =  rk(203) * Y( 88) * Y(117)
      w(204) =  rk(204) * Y( 74) * Y(117)
      w(205) =  rk(205) * Y( 79) * Y(117)
      w(206) =  rk(206) * Y( 86) * Y(117)
      w(207) =  rk(207) * Y( 64) * Y(117)
      w(208) =  rk(208) * Y( 78) * Y(117)
      w(209) =  rk(209) * Y(118) * Y(117)
      w(210) =  rk(210) * Y(122) * Y(117)
      w(211) =  rk(211) * Y(101) * Y(117)
      w(212) =  rk(212) * Y( 98) * Y(117)
      w(213) =  rk(213) * Y( 93) * Y(117)
      w(214) =  rk(214) * Y( 94) * Y(117)
      w(215) =  rk(215) * Y(114) * Y(123)
      w(216) =  rk(216) * Y(113) * Y(123)
      w(217) =  rk(217) * Y(110) * Y(123)
      w(218) =  rk(218) * Y( 72) * Y(123)
      w(219) =  rk(219) * Y( 75) * Y(123)
      w(220) =  rk(220) * Y( 85) * Y(123)
      w(221) =  rk(221) * Y( 70) * Y(123)
      w(222) =  rk(222) * Y( 92) * Y(123)
      w(223) =  rk(223) * Y( 80) * Y(123)
      w(224) =  rk(224) * Y(105) * Y(123)
      w(225) =  rk(225) * Y( 83) * Y(123)
      w(226) =  rk(226) * Y( 88) * Y(123)
      w(227) =  rk(227) * Y( 74) * Y(123)
      w(228) =  rk(228) * Y( 79) * Y(123)
      w(229) =  rk(229) * Y( 86) * Y(123)
      w(230) =  rk(230) * Y( 54) * Y(123)
      w(231) =  rk(231) * Y( 56) * Y(123)
      w(232) =  rk(232) * Y( 64) * Y(123)
      w(233) =  rk(233) * Y( 78) * Y(123)
      w(234) =  rk(234) * Y( 60) * Y(123)
      w(235) =  rk(235) * Y(118) * Y(123)
      w(236) =  rk(236) * Y(122) * Y(123)
      w(237) =  rk(237) * Y( 98) * Y(123)
      w(238) =  rk(238) * Y( 68) * Y(123)
      w(239) =  rk(239) * Y(101) * Y(123)
      w(240) =  rk(240) * Y( 93) * Y(123)
      w(241) =  rk(241) * Y( 94) * Y(123)
      w(242) =  rk(242) * Y(114) * Y(114)
      w(243) =  rk(243) * Y(113) * Y(114)
      w(244) =  rk(244) * Y(110) * Y(114)
      w(245) =  rk(245) * Y( 72) * Y(114)
      w(246) =  rk(246) * Y( 75) * Y(114)
      w(247) =  rk(247) * Y( 85) * Y(114)
      w(248) =  rk(248) * Y( 70) * Y(114)
      w(249) =  rk(249) * Y( 92) * Y(114)
      w(250) =  rk(250) * Y( 80) * Y(114)
      w(251) =  rk(251) * Y(105) * Y(114)
      w(252) =  rk(252) * Y( 83) * Y(114)
      w(253) =  rk(253) * Y( 88) * Y(114)
      w(254) =  rk(254) * Y( 74) * Y(114)
      w(255) =  rk(255) * Y( 79) * Y(114)
      w(256) =  rk(256) * Y( 86) * Y(114)
      w(257) =  rk(257) * Y( 54) * Y(114)
      w(258) =  rk(258) * Y( 53) * Y(114)
      w(259) =  rk(259) * Y( 52) * Y(114)
      w(260) =  rk(260) * Y( 64) * Y(114)
      w(261) =  rk(261) * Y( 55) * Y(114)
      w(262) =  rk(262) * Y( 56) * Y(114)
      w(263) =  rk(263) * Y( 62) * Y(114)
      w(264) =  rk(264) * Y( 67) * Y(114)
      w(265) =  rk(265) * Y( 50) * Y(114)
      w(266) =  rk(266) * Y( 78) * Y(114)
      w(267) =  rk(267) * Y(118) * Y(114)
      w(268) =  rk(268) * Y(122) * Y(114)
      w(269) =  rk(269) * Y( 98) * Y(114)
      w(270) =  rk(270) * Y( 68) * Y(114)
      w(271) =  rk(271) * Y(101) * Y(114)
      w(272) =  rk(272) * Y( 93) * Y(114)
      w(273) =  rk(273) * Y( 94) * Y(114)
      w(274) =  rk(274) * Y(113) * Y(118)
      w(275) =  rk(275) * Y(110) * Y(118)
      w(276) =  rk(276) * Y( 72) * Y(118)
      w(277) =  rk(277) * Y( 75) * Y(118)
      w(278) =  rk(278) * Y( 85) * Y(118)
      w(279) =  rk(279) * Y( 70) * Y(118)
      w(280) =  rk(280) * Y( 92) * Y(118)
      w(281) =  rk(281) * Y( 80) * Y(118)
      w(282) =  rk(282) * Y(105) * Y(118)
      w(283) =  rk(283) * Y( 83) * Y(118)
      w(284) =  rk(284) * Y( 88) * Y(118)
      w(285) =  rk(285) * Y( 74) * Y(118)
      w(286) =  rk(286) * Y( 79) * Y(118)
      w(287) =  rk(287) * Y( 86) * Y(118)
      w(288) =  rk(288) * Y( 54) * Y(118)
      w(289) =  rk(289) * Y( 53) * Y(118)
      w(290) =  rk(290) * Y( 52) * Y(118)
      w(291) =  rk(291) * Y( 62) * Y(118)
      w(292) =  rk(292) * Y( 67) * Y(118)
      w(293) =  rk(293) * Y( 50) * Y(118)
      w(294) =  rk(294) * Y( 64) * Y(118)
      w(295) =  rk(295) * Y( 55) * Y(118)
      w(296) =  rk(296) * Y( 56) * Y(118)
      w(297) =  rk(297) * Y( 78) * Y(118)
      w(298) =  rk(298) * Y(118) * Y(118)
      w(299) =  rk(299) * Y(122) * Y(122)
      w(300) =  rk(300) * Y(101) * Y(118)
      w(301) =  rk(301) * Y( 98) * Y(118)
      w(302) =  rk(302) * Y( 68) * Y(118)
      w(303) =  rk(303) * Y( 93) * Y(118)
      w(304) =  rk(304) * Y( 94) * Y(118)
      w(305) =  rk(305) * Y( 93) * Y( 93)
      w(306) =  rk(306) * Y( 93) * Y( 94)
      w(307) =  rk(307) * Y( 94) * Y( 94)
      w(308) =  rk(308) * Y(114) * Y(121)
      w(309) =  rk(309) * Y(113) * Y(121)
      w(310) =  rk(310) * Y(110) * Y(121)
      w(311) =  rk(311) * Y( 72) * Y(121)
      w(312) =  rk(312) * Y( 75) * Y(121)
      w(313) =  rk(313) * Y( 85) * Y(121)
      w(314) =  rk(314) * Y( 70) * Y(121)
      w(315) =  rk(315) * Y( 92) * Y(121)
      w(316) =  rk(316) * Y( 80) * Y(121)
      w(317) =  rk(317) * Y( 74) * Y(121)
      w(318) =  rk(318) * Y( 79) * Y(121)
      w(319) =  rk(319) * Y( 86) * Y(121)
      w(320) =  rk(320) * Y( 64) * Y(121)
      w(321) =  rk(321) * Y( 78) * Y(121)
      w(322) =  rk(322) * Y(118) * Y(121)
      w(323) =  rk(323) * Y(122) * Y(121)
      w(324) =  rk(324) * Y( 68) * Y(121)
      w(325) =  rk(325) * Y(101) * Y(121)
      w(326) =  rk(326) * Y( 98) * Y(121)
      w(327) =  rk(327) * Y( 93) * Y(121)
      w(328) =  rk(328) * Y( 94) * Y(121)
      w(329) =  rk(329) * Y( 83) * Y(121)
      w(330) =  rk(330) * Y(105) * Y(121)
      w(331) =  rk(331) * Y( 53) * Y(121)
      w(332) =  rk(332) * Y( 54) * Y(121)
      w(333) =  rk(333) * Y( 52) * Y(121)
      w(334) =  rk(334) * Y( 55) * Y(121)
      w(335) =  rk(335) * Y( 56) * Y(121)
      w(336) =  rk(336) * Y( 62) * Y(121)
      w(337) =  rk(337) * Y( 67) * Y(121)
      w(338) =  rk(338) * Y( 50) * Y(121)
      w(339) =  rk(339) * Y( 88) * Y(121)
      w(340) =  rk(340) * Y(116) * Y(123)
      w(341) =  rk(341) * Y(116) * Y(114)
      w(342) =  rk(342) * Y(116) * Y(118)
      w(343) =  rk(343) * Y(116) * Y(116)
      w(344) =  rk(344) * Y(116) * Y(117)
      w(345) =  rk(345) * Y(116) * Y(121)
      w(346) =  rk(346) * Y(107) * Y(117)
      w(347) =  rk(347) * Y(107) * Y(123)
      w(348) =  rk(348) * Y(107) * Y(114)
      w(349) =  rk(349) * Y(107) * Y(118)
      w(350) =  rk(350) * Y(107) * Y(121)
      w(351) =  rk(351) * Y(122) * Y(118)
      w(352) =  rk(352) * Y(123)
      w(353) =  rk(353) * Y(124)
      w(354) =  rk(354) * Y(121)
      w(355) =  rk(355) * Y( 17)
 
      RETURN
      END
 
