C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C
C     This file is part of the air quality modeling system Polyphemus.
C
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C
C     Polyphemus is free software; you can redistribute i and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C------------------------------------------------------------------------
 
      subroutine fexchem(NS,Nr,nemis,y,rk,ZCsourc,convers_factor,chem)
 
C------------------------------------------------------------------------
C
C     -- DESCRIPTION
C
C     This routine computes the chemical production term.
C     This routine is automatically generated by SPACK.
C     Mechanism: CB05_SORGAM         
C     Species: _ciCB05_SORGAM      
C
C------------------------------------------------------------------------
C
C     -- INPUT VARIABLES
C
C     Ns: chemical species number.
C     Y: chemical concentrations.
C     RK: kinetic rates.
C     ZCSOURC: volumic emissions.
C
C     -- INPUT/OUTPUT VARIABLES
C
C     -- OUTPUT VARIABLES
C
C     CHEM: array of chemical production terms.
C
C------------------------------------------------------------------------
C
C     -- REMARKS
C
C------------------------------------------------------------------------
C
C     -- MODIFICATIONS
C
C------------------------------------------------------------------------
C
C     -- AUTHOR(S)
C
C     SPACK.
C
C------------------------------------------------------------------------
 
      implicit none
 
      integer nemis
      integer nr,ns,i
      double precision w(nr),rk(nr),y(ns),chem(ns),ZCsourc(ns)
      double precision conc(ns), convers_factor(ns)
 
      do i=1,ns
       chem(i)=0.d0
      enddo
 
C     Conversion mug/m3 to molecules/cm3.
 
      do i = 1, ns
         conc(i) = y(i) * convers_factor(i)
      enddo
 
C     Compute reaction rates.
 
      call rates(ns,nr,rk,conc,w)
 
C     Chemical production terms.
 
      chem( 57) = chem( 57) + w(  1)
      chem( 64) = chem( 64) + w(  1)
      chem( 65) = chem( 65) - w(  1)
      chem( 57) = chem( 57) - w(  2)
      chem( 59) = chem( 59) + w(  2)
      chem( 59) = chem( 59) - w(  3)
      chem( 64) = chem( 64) - w(  3)
      chem( 65) = chem( 65) + w(  3)
      chem( 57) = chem( 57) - w(  4)
      chem( 64) = chem( 64) + w(  4)
      chem( 65) = chem( 65) - w(  4)
      chem( 56) = chem( 56) + w(  5)
      chem( 57) = chem( 57) - w(  5)
      chem( 65) = chem( 65) - w(  5)
      chem( 57) = chem( 57) - w(  6)
      chem( 64) = chem( 64) - w(  6)
      chem( 65) = chem( 65) + w(  6)
      chem( 56) = chem( 56) + w(  7)
      chem( 59) = chem( 59) - w(  7)
      chem( 65) = chem( 65) - w(  7)
      chem( 57) = chem( 57) + w(  8)
      chem( 59) = chem( 59) - w(  8)
      chem(  3) = chem(  3) + w(  9)
      chem( 59) = chem( 59) - w(  9)
      chem(  3) = chem(  3) - w( 10)
      chem( 57) = chem( 57) + w( 10)
      chem(  3) = chem(  3) - w( 11)
      chem( 55) = chem( 55) +  0.2000000000000000D+01 * w( 11)
      chem( 55) = chem( 55) - w( 12)
      chem( 59) = chem( 59) - w( 12)
      chem( 61) = chem( 61) + w( 12)
      chem( 55) = chem( 55) + w( 13)
      chem( 59) = chem( 59) - w( 13)
      chem( 61) = chem( 61) - w( 13)
      chem( 56) = chem( 56) - w( 14)
      chem( 57) = chem( 57) + w( 14)
      chem( 65) = chem( 65) + w( 14)
      chem( 56) = chem( 56) - w( 15)
      chem( 64) = chem( 64) + w( 15)
      chem( 56) = chem( 56) - w( 16)
      chem( 64) = chem( 64) - w( 16)
      chem( 65) = chem( 65) +  0.2000000000000000D+01 * w( 16)
      chem( 56) = chem( 56) - w( 17)
      chem( 64) = chem( 64) + w( 17)
      chem( 16) = chem( 16) + w( 18)
      chem( 56) = chem( 56) - w( 18)
      chem( 65) = chem( 65) - w( 18)
      chem( 16) = chem( 16) - w( 19)
      chem( 50) = chem( 50) +  0.2000000000000000D+01 * w( 19)
      chem( 16) = chem( 16) - w( 20)
      chem( 56) = chem( 56) + w( 20)
      chem( 65) = chem( 65) + w( 20)
      chem( 64) = chem( 64) -  0.2000000000000000D+01 * w( 21)
      chem( 65) = chem( 65) +  0.2000000000000000D+01 * w( 21)
      chem( 23) = chem( 23) +  0.2000000000000000D+01 * w( 22)
      chem( 64) = chem( 64) - w( 22)
      chem( 65) = chem( 65) - w( 22)
      chem( 23) = chem( 23) + w( 23)
      chem( 55) = chem( 55) - w( 23)
      chem( 64) = chem( 64) - w( 23)
      chem( 23) = chem( 23) - w( 24)
      chem( 55) = chem( 55) + w( 24)
      chem( 64) = chem( 64) + w( 24)
      chem( 23) = chem( 23) - w( 25)
      chem( 55) = chem( 55) - w( 25)
      chem( 65) = chem( 65) + w( 25)
      chem( 23) = chem( 23) -  0.2000000000000000D+01 * w( 26)
      chem( 64) = chem( 64) + w( 26)
      chem( 65) = chem( 65) + w( 26)
      chem( 50) = chem( 50) + w( 27)
      chem( 55) = chem( 55) - w( 27)
      chem( 65) = chem( 65) - w( 27)
      chem( 50) = chem( 50) - w( 28)
      chem( 55) = chem( 55) - w( 28)
      chem( 56) = chem( 56) + w( 28)
      chem( 55) = chem( 55) + w( 29)
      chem( 61) = chem( 61) - w( 29)
      chem( 64) = chem( 64) - w( 29)
      chem( 65) = chem( 65) + w( 29)
      chem( 17) = chem( 17) + w( 30)
      chem( 61) = chem( 61) - w( 30)
      chem( 65) = chem( 65) - w( 30)
      chem( 17) = chem( 17) - w( 31)
      chem( 61) = chem( 61) + w( 31)
      chem( 65) = chem( 65) + w( 31)
      chem( 17) = chem( 17) - w( 32)
      chem( 55) = chem( 55) - w( 32)
      chem( 65) = chem( 65) + w( 32)
      chem( 20) = chem( 20) + w( 33)
      chem( 61) = chem( 61) -  0.2000000000000000D+01 * w( 33)
      chem( 20) = chem( 20) + w( 34)
      chem( 61) = chem( 61) -  0.2000000000000000D+01 * w( 34)
      chem( 20) = chem( 20) - w( 35)
      chem( 55) = chem( 55) +  0.2000000000000000D+01 * w( 35)
      chem( 20) = chem( 20) - w( 36)
      chem( 55) = chem( 55) - w( 36)
      chem( 61) = chem( 61) + w( 36)
      chem(  3) = chem(  3) - w( 37)
      chem( 55) = chem( 55) + w( 37)
      chem( 61) = chem( 61) + w( 37)
      chem( 55) = chem( 55) - w( 38)
      chem( 61) = chem( 61) + w( 38)
      chem( 55) = chem( 55) - w( 39)
      chem( 57) = chem( 57) - w( 39)
      chem( 61) = chem( 61) + w( 39)
      chem( 55) = chem( 55) -  0.2000000000000000D+01 * w( 40)
      chem( 57) = chem( 57) + w( 40)
      chem( 20) = chem( 20) + w( 41)
      chem( 55) = chem( 55) -  0.2000000000000000D+01 * w( 41)
      chem( 55) = chem( 55) - w( 42)
      chem( 61) = chem( 61) - w( 42)
      chem( 55) = chem( 55) + w( 43)
      chem( 57) = chem( 57) - w( 43)
      chem( 61) = chem( 61) - w( 43)
      chem( 20) = chem( 20) - w( 44)
      chem( 55) = chem( 55) + w( 44)
      chem( 57) = chem( 57) - w( 44)
      chem( 61) = chem( 61) + w( 44)
      chem( 56) = chem( 56) - w( 45)
      chem( 57) = chem( 57) - w( 45)
      chem( 65) = chem( 65) + w( 45)
      chem( 55) = chem( 55) - w( 46)
      chem( 56) = chem( 56) - w( 46)
      chem( 61) = chem( 61) + w( 46)
      chem( 65) = chem( 65) + w( 46)
      chem( 50) = chem( 50) + w( 47)
      chem( 56) = chem( 56) - w( 47)
      chem( 61) = chem( 61) - w( 47)
      chem( 56) = chem( 56) - w( 48)
      chem( 59) = chem( 59) - w( 48)
      chem( 65) = chem( 65) + w( 48)
      chem( 56) = chem( 56) -  0.2000000000000000D+01 * w( 49)
      chem( 65) = chem( 65) +  0.2000000000000000D+01 * w( 49)
      chem( 17) = chem( 17) - w( 50)
      chem( 55) = chem( 55) +  0.3900000000000000D+00 * w( 50)
      chem( 56) = chem( 56) +  0.3900000000000000D+00 * w( 50)
      chem( 61) = chem( 61) +  0.6100000000000000D+00 * w( 50)
      chem( 65) = chem( 65) +  0.6100000000000000D+00 * w( 50)
      chem( 50) = chem( 50) - w( 51)
      chem( 55) = chem( 55) + w( 51)
      chem( 65) = chem( 65) + w( 51)
      chem( 16) = chem( 16) - w( 52)
      chem( 56) = chem( 56) + w( 52)
      chem( 65) = chem( 65) + w( 52)
      chem( 63) = chem( 63) - w( 53)
      chem( 64) = chem( 64) - w( 53)
      chem( 65) = chem( 65) + w( 53)
      chem( 46) = chem( 46) + w( 54)
      chem( 52) = chem( 52) - w( 54)
      chem( 64) = chem( 64) - w( 54)
      chem( 32) = chem( 32) + w( 55)
      chem( 61) = chem( 61) - w( 55)
      chem( 63) = chem( 63) - w( 55)
      chem( 32) = chem( 32) + w( 56)
      chem( 52) = chem( 52) - w( 56)
      chem( 61) = chem( 61) - w( 56)
      chem( 63) = chem( 63) -  0.2000000000000000D+01 * w( 57)
      chem( 52) = chem( 52) -  0.2000000000000000D+01 * w( 58)
      chem( 52) = chem( 52) - w( 59)
      chem( 63) = chem( 63) - w( 59)
      chem( 46) = chem( 46) - w( 60)
      chem( 47) = chem( 47) +  0.6600000000000000D+00 * w( 60)
      chem( 48) = chem( 48) +  0.3300000000000000D+00 * w( 60)
      chem( 50) = chem( 50) + w( 60)
      chem( 54) = chem( 54) +  0.3300000000000000D+00 * w( 60)
      chem( 55) = chem( 55) - w( 60)
      chem( 60) = chem( 60) +  0.3300000000000000D+00 * w( 60)
      chem( 61) = chem( 61) + w( 60)
      chem( 46) = chem( 46) - w( 61)
      chem( 47) = chem( 47) +  0.6600000000000000D+00 * w( 61)
      chem( 48) = chem( 48) +  0.3300000000000000D+00 * w( 61)
      chem( 54) = chem( 54) +  0.3300000000000000D+00 * w( 61)
      chem( 60) = chem( 60) +  0.3300000000000000D+00 * w( 61)
      chem( 61) = chem( 61) + w( 61)
      chem( 65) = chem( 65) + w( 61)
      chem( 32) = chem( 32) - w( 62)
      chem( 48) = chem( 48) +  0.5000000000000000D+00 * w( 62)
      chem( 55) = chem( 55) - w( 62)
      chem( 60) = chem( 60) +  0.5000000000000000D+00 * w( 62)
      chem( 63) = chem( 63) + w( 62)
      chem( 32) = chem( 32) - w( 63)
      chem( 48) = chem( 48) +  0.5000000000000000D+00 * w( 63)
      chem( 55) = chem( 55) + w( 63)
      chem( 60) = chem( 60) +  0.5000000000000000D+00 * w( 63)
      chem( 61) = chem( 61) + w( 63)
      chem( 51) = chem( 51) - w( 64)
      chem( 55) = chem( 55) - w( 64)
      chem( 61) = chem( 61) + w( 64)
      chem(  5) = chem(  5) - w( 65)
      chem( 53) = chem( 53) + w( 65)
      chem( 55) = chem( 55) - w( 65)
      chem( 53) = chem( 53) - w( 66)
      chem( 54) = chem( 54) + w( 66)
      chem( 61) = chem( 61) + w( 66)
      chem( 64) = chem( 64) - w( 66)
      chem( 65) = chem( 65) + w( 66)
      chem( 22) = chem( 22) + w( 67)
      chem( 53) = chem( 53) - w( 67)
      chem( 61) = chem( 61) - w( 67)
      chem( 14) = chem( 14) +  0.6300000000000000D+00 * w( 68)
      chem( 53) = chem( 53) -  0.2000000000000000D+01 * w( 68)
      chem( 54) = chem( 54) +  0.1370000000000000D+01 * w( 68)
      chem( 61) = chem( 61) +  0.7400000000000000D+00 * w( 68)
      chem( 22) = chem( 22) - w( 69)
      chem( 53) = chem( 53) +  0.7000000000000000D+00 * w( 69)
      chem( 55) = chem( 55) - w( 69)
      chem( 61) = chem( 61) +  0.3000000000000000D-01 * w( 69)
      chem( 63) = chem( 63) +  0.3000000000000000D+00 * w( 69)
      chem( 22) = chem( 22) - w( 70)
      chem( 54) = chem( 54) + w( 70)
      chem( 55) = chem( 55) + w( 70)
      chem( 61) = chem( 61) + w( 70)
      chem( 14) = chem( 14) - w( 71)
      chem( 54) = chem( 54) + w( 71)
      chem( 55) = chem( 55) - w( 71)
      chem( 61) = chem( 61) + w( 71)
      chem( 51) = chem( 51) + w( 72)
      chem( 54) = chem( 54) - w( 72)
      chem( 55) = chem( 55) - w( 72)
      chem( 61) = chem( 61) + w( 72)
      chem( 51) = chem( 51) + w( 73)
      chem( 54) = chem( 54) - w( 73)
      chem( 61) = chem( 61) +  0.2000000000000000D+01 * w( 73)
      chem( 51) = chem( 51) + w( 74)
      chem( 54) = chem( 54) - w( 74)
      chem( 51) = chem( 51) + w( 75)
      chem( 54) = chem( 54) - w( 75)
      chem( 55) = chem( 55) + w( 75)
      chem( 57) = chem( 57) - w( 75)
      chem( 61) = chem( 61) + w( 75)
      chem( 50) = chem( 50) + w( 76)
      chem( 51) = chem( 51) + w( 76)
      chem( 54) = chem( 54) - w( 76)
      chem( 56) = chem( 56) - w( 76)
      chem( 61) = chem( 61) + w( 76)
      chem( 21) = chem( 21) + w( 77)
      chem( 54) = chem( 54) - w( 77)
      chem( 61) = chem( 61) - w( 77)
      chem( 21) = chem( 21) - w( 78)
      chem( 54) = chem( 54) + w( 78)
      chem( 61) = chem( 61) + w( 78)
      chem( 21) = chem( 21) - w( 79)
      chem( 35) = chem( 35) + w( 79)
      chem( 61) = chem( 61) + w( 79)
      chem( 64) = chem( 64) - w( 79)
      chem( 65) = chem( 65) + w( 79)
      chem( 21) = chem( 21) - w( 80)
      chem( 22) = chem( 22) + w( 80)
      chem( 61) = chem( 61) - w( 80)
      chem( 35) = chem( 35) - w( 81)
      chem( 55) = chem( 55) - w( 81)
      chem( 61) = chem( 61) + w( 81)
      chem( 55) = chem( 55) + w( 82)
      chem( 57) = chem( 57) - w( 82)
      chem( 60) = chem( 60) - w( 82)
      chem( 62) = chem( 62) + w( 82)
      chem( 55) = chem( 55) - w( 83)
      chem( 60) = chem( 60) - w( 83)
      chem( 62) = chem( 62) + w( 83)
      chem( 50) = chem( 50) + w( 84)
      chem( 56) = chem( 56) - w( 84)
      chem( 60) = chem( 60) - w( 84)
      chem( 62) = chem( 62) + w( 84)
      chem( 51) = chem( 51) + w( 85)
      chem( 53) = chem( 53) + w( 85)
      chem( 60) = chem( 60) - w( 85)
      chem( 61) = chem( 61) + w( 85)
      chem( 53) = chem( 53) + w( 86)
      chem( 62) = chem( 62) - w( 86)
      chem( 64) = chem( 64) - w( 86)
      chem( 65) = chem( 65) + w( 86)
      chem( 13) = chem( 13) + w( 87)
      chem( 62) = chem( 62) - w( 87)
      chem( 65) = chem( 65) - w( 87)
      chem( 13) = chem( 13) - w( 88)
      chem( 62) = chem( 62) + w( 88)
      chem( 65) = chem( 65) + w( 88)
      chem( 13) = chem( 13) - w( 89)
      chem( 62) = chem( 62) + w( 89)
      chem( 65) = chem( 65) + w( 89)
      chem( 33) = chem( 33) +  0.8000000000000000D+00 * w( 90)
      chem( 49) = chem( 49) +  0.2000000000000000D+00 * w( 90)
      chem( 59) = chem( 59) +  0.2000000000000000D+00 * w( 90)
      chem( 61) = chem( 61) - w( 90)
      chem( 62) = chem( 62) - w( 90)
      chem( 49) = chem( 49) +  0.1000000000000000D+00 * w( 91)
      chem( 53) = chem( 53) -  0.9999999999999998D-01 * w( 91)
      chem( 54) = chem( 54) + w( 91)
      chem( 61) = chem( 61) +  0.9000000000000000D+00 * w( 91)
      chem( 62) = chem( 62) - w( 91)
      chem( 49) = chem( 49) +  0.1000000000000000D+00 * w( 92)
      chem( 53) = chem( 53) +  0.9000000000000000D+00 * w( 92)
      chem( 62) = chem( 62) - w( 92)
      chem( 63) = chem( 63) - w( 92)
      chem( 53) = chem( 53) +  0.2000000000000000D+01 * w( 93)
      chem( 62) = chem( 62) -  0.2000000000000000D+01 * w( 93)
      chem( 33) = chem( 33) - w( 94)
      chem( 55) = chem( 55) - w( 94)
      chem( 62) = chem( 62) + w( 94)
      chem( 33) = chem( 33) - w( 95)
      chem( 53) = chem( 53) + w( 95)
      chem( 55) = chem( 55) + w( 95)
      chem( 49) = chem( 49) - w( 96)
      chem( 53) = chem( 53) + w( 96)
      chem( 55) = chem( 55) - w( 96)
      chem( 48) = chem( 48) - w( 97)
      chem( 55) = chem( 55) + w( 97)
      chem( 57) = chem( 57) - w( 97)
      chem( 58) = chem( 58) + w( 97)
      chem( 48) = chem( 48) - w( 98)
      chem( 55) = chem( 55) - w( 98)
      chem( 58) = chem( 58) + w( 98)
      chem( 48) = chem( 48) - w( 99)
      chem( 50) = chem( 50) + w( 99)
      chem( 56) = chem( 56) - w( 99)
      chem( 58) = chem( 58) + w( 99)
      chem( 48) = chem( 48) - w(100)
      chem( 51) = chem( 51) + w(100)
      chem( 53) = chem( 53) + w(100)
      chem( 61) = chem( 61) + w(100)
      chem( 58) = chem( 58) - w(101)
      chem( 60) = chem( 60) + w(101)
      chem( 61) = chem( 61) + w(101)
      chem( 63) = chem( 63) + w(101)
      chem( 64) = chem( 64) - w(101)
      chem( 65) = chem( 65) + w(101)
      chem( 18) = chem( 18) + w(102)
      chem( 58) = chem( 58) - w(102)
      chem( 65) = chem( 65) - w(102)
      chem( 18) = chem( 18) - w(103)
      chem( 58) = chem( 58) + w(103)
      chem( 65) = chem( 65) + w(103)
      chem( 18) = chem( 18) - w(104)
      chem( 58) = chem( 58) + w(104)
      chem( 65) = chem( 65) + w(104)
      chem( 18) = chem( 18) - w(105)
      chem( 55) = chem( 55) - w(105)
      chem( 60) = chem( 60) + w(105)
      chem( 65) = chem( 65) + w(105)
      chem( 33) = chem( 33) +  0.8000000000000000D+00 * w(106)
      chem( 49) = chem( 49) +  0.2000000000000000D+00 * w(106)
      chem( 58) = chem( 58) - w(106)
      chem( 59) = chem( 59) +  0.2000000000000000D+00 * w(106)
      chem( 61) = chem( 61) - w(106)
      chem( 49) = chem( 49) +  0.1000000000000000D+00 * w(107)
      chem( 53) = chem( 53) - w(107)
      chem( 54) = chem( 54) +  0.1000000000000000D+00 * w(107)
      chem( 60) = chem( 60) +  0.9000000000000000D+00 * w(107)
      chem( 61) = chem( 61) + w(107)
      chem( 62) = chem( 62) - w(107)
      chem( 63) = chem( 63) +  0.9000000000000000D+00 * w(107)
      chem( 49) = chem( 49) +  0.1000000000000000D+00 * w(108)
      chem( 60) = chem( 60) +  0.9000000000000000D+00 * w(108)
      chem( 62) = chem( 62) - w(108)
      chem( 63) = chem( 63) - w(108)
      chem( 58) = chem( 58) -  0.2000000000000000D+01 * w(109)
      chem( 61) = chem( 61) +  0.2000000000000000D+01 * w(109)
      chem( 63) = chem( 63) +  0.2000000000000000D+01 * w(109)
      chem( 53) = chem( 53) + w(110)
      chem( 58) = chem( 58) - w(110)
      chem( 60) = chem( 60) + w(110)
      chem( 61) = chem( 61) + w(110)
      chem( 62) = chem( 62) - w(110)
      chem( 63) = chem( 63) + w(110)
      chem( 19) = chem( 19) +  0.7600000000000000D+00 * w(111)
      chem( 47) = chem( 47) -  0.8900000000000000D+00 * w(111)
      chem( 48) = chem( 48) +  0.5000000000000000D-01 * w(111)
      chem( 52) = chem( 52) +  0.1300000000000000D+00 * w(111)
      chem( 55) = chem( 55) - w(111)
      chem( 60) = chem( 60) +  0.6000000000000000D-01 * w(111)
      chem( 61) = chem( 61) +  0.1100000000000000D+00 * w(111)
      chem( 63) = chem( 63) +  0.8700000000000000D+00 * w(111)
      chem( 19) = chem( 19) -  0.9800000000000000D+00 * w(112)
      chem( 47) = chem( 47) +  0.2100000000000000D+01 * w(112)
      chem( 48) = chem( 48) +  0.5000000000000000D+00 * w(112)
      chem( 52) = chem( 52) +  0.4000000000000000D-01 * w(112)
      chem( 60) = chem( 60) +  0.6000000000000000D+00 * w(112)
      chem( 61) = chem( 61) +  0.9399999999999999D+00 * w(112)
      chem( 63) = chem( 63) +  0.9600000000000000D+00 * w(112)
      chem( 19) = chem( 19) - w(113)
      chem( 61) = chem( 61) + w(113)
      chem( 19) = chem( 19) - w(114)
      chem( 46) = chem( 46) + w(114)
      chem( 65) = chem( 65) - w(114)
      chem( 36) = chem( 36) - w(115)
      chem( 47) = chem( 47) +  0.2000000000000000D+00 * w(115)
      chem( 48) = chem( 48) +  0.3000000000000000D+00 * w(115)
      chem( 51) = chem( 51) +  0.2000000000000000D+00 * w(115)
      chem( 52) = chem( 52) +  0.1000000000000000D-01 * w(115)
      chem( 54) = chem( 54) +  0.2000000000000000D+00 * w(115)
      chem( 55) = chem( 55) +  0.1000000000000000D+00 * w(115)
      chem( 57) = chem( 57) - w(115)
      chem( 60) = chem( 60) +  0.2000000000000000D+00 * w(115)
      chem( 61) = chem( 61) +  0.3000000000000000D+00 * w(115)
      chem( 63) = chem( 63) +  0.2000000000000000D+00 * w(115)
      chem( 36) = chem( 36) - w(116)
      chem( 38) = chem( 38) +  0.8000000000000000D-02 * w(116)
      chem( 47) = chem( 47) +  0.7000000000000000D+00 * w(116)
      chem( 48) = chem( 48) +  0.6200000000000000D+00 * w(116)
      chem( 54) = chem( 54) +  0.8000000000000000D+00 * w(116)
      chem( 55) = chem( 55) - w(116)
      chem( 60) = chem( 60) +  0.3300000000000000D+00 * w(116)
      chem( 61) = chem( 61) +  0.9500000000000000D+00 * w(116)
      chem( 63) = chem( 63) +  0.8000000000000000D+00 * w(116)
      chem( 36) = chem( 36) - w(117)
      chem( 38) = chem( 38) +  0.8000000000000000D-02 * w(117)
      chem( 47) = chem( 47) + w(117)
      chem( 48) = chem( 48) +  0.3200000000000000D+00 * w(117)
      chem( 51) = chem( 51) +  0.3300000000000000D+00 * w(117)
      chem( 54) = chem( 54) +  0.7400000000000000D+00 * w(117)
      chem( 55) = chem( 55) +  0.1000000000000000D+00 * w(117)
      chem( 59) = chem( 59) - w(117)
      chem( 60) = chem( 60) +  0.1800000000000000D+00 * w(117)
      chem( 61) = chem( 61) +  0.4400000000000000D+00 * w(117)
      chem( 63) = chem( 63) +  0.2200000000000000D+00 * w(117)
      chem( 36) = chem( 36) - w(118)
      chem( 38) = chem( 38) +  0.8000000000000000D-02 * w(118)
      chem( 47) = chem( 47) + w(118)
      chem( 48) = chem( 48) +  0.5600000000000001D+00 * w(118)
      chem( 52) = chem( 52) +  0.9000000000000000D-01 * w(118)
      chem( 54) = chem( 54) + w(118)
      chem( 56) = chem( 56) - w(118)
      chem( 60) = chem( 60) +  0.3500000000000000D+00 * w(118)
      chem( 63) = chem( 63) +  0.9100000000000000D+00 * w(118)
      chem( 65) = chem( 65) + w(118)
      chem( 34) = chem( 34) - w(119)
      chem( 51) = chem( 51) + w(119)
      chem( 54) = chem( 54) + w(119)
      chem( 55) = chem( 55) +  0.3000000000000000D+00 * w(119)
      chem( 57) = chem( 57) - w(119)
      chem( 61) = chem( 61) +  0.1700000000000000D+01 * w(119)
      chem( 63) = chem( 63) +  0.7000000000000000D+00 * w(119)
      chem( 34) = chem( 34) - w(120)
      chem( 48) = chem( 48) +  0.2200000000000000D+00 * w(120)
      chem( 54) = chem( 54) +  0.1560000000000000D+01 * w(120)
      chem( 55) = chem( 55) - w(120)
      chem( 61) = chem( 61) + w(120)
      chem( 63) = chem( 63) + w(120)
      chem( 34) = chem( 34) - w(121)
      chem( 35) = chem( 35) +  0.3700000000000000D+00 * w(121)
      chem( 51) = chem( 51) +  0.6300000000000000D+00 * w(121)
      chem( 54) = chem( 54) + w(121)
      chem( 55) = chem( 55) +  0.1300000000000000D+00 * w(121)
      chem( 59) = chem( 59) - w(121)
      chem( 61) = chem( 61) +  0.1300000000000000D+00 * w(121)
      chem( 34) = chem( 34) - w(122)
      chem( 54) = chem( 54) +  0.2000000000000000D+01 * w(122)
      chem( 56) = chem( 56) - w(122)
      chem( 63) = chem( 63) + w(122)
      chem( 65) = chem( 65) + w(122)
      chem( 37) = chem( 37) - w(123)
      chem( 47) = chem( 47) +  0.1000000000000000D+00 * w(123)
      chem( 48) = chem( 48) +  0.6600000000000000D+00 * w(123)
      chem( 51) = chem( 51) +  0.1000000000000000D+00 * w(123)
      chem( 57) = chem( 57) - w(123)
      chem( 60) = chem( 60) +  0.1240000000000000D+01 * w(123)
      chem( 61) = chem( 61) +  0.1000000000000000D+00 * w(123)
      chem( 63) = chem( 63) +  0.1000000000000000D+00 * w(123)
      chem( 37) = chem( 37) - w(124)
      chem( 38) = chem( 38) +  0.8000000000000000D-02 * w(124)
      chem( 48) = chem( 48) +  0.7000000000000000D+00 * w(124)
      chem( 55) = chem( 55) - w(124)
      chem( 60) = chem( 60) +  0.1300000000000000D+01 * w(124)
      chem( 61) = chem( 61) + w(124)
      chem( 63) = chem( 63) + w(124)
      chem( 37) = chem( 37) - w(125)
      chem( 38) = chem( 38) +  0.8000000000000000D-02 * w(125)
      chem( 48) = chem( 48) +  0.3500000000000000D+00 * w(125)
      chem( 51) = chem( 51) +  0.2500000000000000D+00 * w(125)
      chem( 54) = chem( 54) +  0.2500000000000000D+00 * w(125)
      chem( 55) = chem( 55) +  0.5000000000000000D+00 * w(125)
      chem( 57) = chem( 57) +  0.5000000000000000D+00 * w(125)
      chem( 59) = chem( 59) - w(125)
      chem( 60) = chem( 60) +  0.6500000000000000D+00 * w(125)
      chem( 61) = chem( 61) +  0.5000000000000000D+00 * w(125)
      chem( 37) = chem( 37) - w(126)
      chem( 38) = chem( 38) +  0.8000000000000000D-02 * w(126)
      chem( 48) = chem( 48) +  0.6400000000000000D+00 * w(126)
      chem( 56) = chem( 56) - w(126)
      chem( 60) = chem( 60) +  0.1180000000000000D+01 * w(126)
      chem( 61) = chem( 61) + w(126)
      chem( 65) = chem( 65) + w(126)
      chem(  7) = chem(  7) - w(127)
      chem( 15) = chem( 15) +  0.5600000000000001D+00 * w(127)
      chem( 30) = chem( 30) +  0.3900000000000000D-01 * w(127)
      chem( 31) = chem( 31) +  0.1080000000000000D+00 * w(127)
      chem( 40) = chem( 40) +  0.3600000000000000D+00 * w(127)
      chem( 55) = chem( 55) - w(127)
      chem( 61) = chem( 61) +  0.4400000000000000D+00 * w(127)
      chem( 63) = chem( 63) +  0.8000000000000000D-01 * w(127)
      chem( 15) = chem( 15) - w(128)
      chem( 41) = chem( 41) +  0.9000000000000000D+00 * w(128)
      chem( 46) = chem( 46) +  0.1000000000000000D+00 * w(128)
      chem( 61) = chem( 61) +  0.9000000000000000D+00 * w(128)
      chem( 64) = chem( 64) - w(128)
      chem( 65) = chem( 65) +  0.9000000000000000D+00 * w(128)
      chem( 15) = chem( 15) - w(129)
      chem( 40) = chem( 40) + w(129)
      chem( 61) = chem( 61) + w(129)
      chem( 30) = chem( 30) +  0.3900000000000000D-01 * w(130)
      chem( 31) = chem( 31) +  0.1080000000000000D+00 * w(130)
      chem( 40) = chem( 40) - w(130)
      chem( 41) = chem( 41) +  0.3000000000000000D+00 * w(130)
      chem( 43) = chem( 43) +  0.4000000000000000D+00 * w(130)
      chem( 55) = chem( 55) - w(130)
      chem( 61) = chem( 61) +  0.6000000000000000D+00 * w(130)
      chem( 63) = chem( 63) +  0.6000000000000000D+00 * w(130)
      chem( 30) = chem( 30) +  0.3900000000000000D-01 * w(131)
      chem( 31) = chem( 31) +  0.1080000000000000D+00 * w(131)
      chem( 40) = chem( 40) - w(131)
      chem( 43) = chem( 43) + w(131)
      chem( 50) = chem( 50) + w(131)
      chem( 56) = chem( 56) - w(131)
      chem( 43) = chem( 43) - w(132)
      chem( 46) = chem( 46) + w(132)
      chem( 65) = chem( 65) - w(132)
      chem( 40) = chem( 40) + w(133)
      chem( 43) = chem( 43) - w(133)
      chem( 61) = chem( 61) - w(133)
      chem( 41) = chem( 41) - w(134)
      chem( 51) = chem( 51) + w(134)
      chem( 61) = chem( 61) + w(134)
      chem( 62) = chem( 62) + w(134)
      chem( 41) = chem( 41) - w(135)
      chem( 51) = chem( 51) +  0.2000000000000000D+01 * w(135)
      chem( 54) = chem( 54) + w(135)
      chem( 55) = chem( 55) - w(135)
      chem( 61) = chem( 61) +  0.2000000000000000D+01 * w(135)
      chem( 62) = chem( 62) + w(135)
      chem( 63) = chem( 63) + w(135)
      chem( 41) = chem( 41) - w(136)
      chem( 42) = chem( 42) +  0.2000000000000000D+00 * w(136)
      chem( 48) = chem( 48) +  0.3000000000000000D-01 * w(136)
      chem( 51) = chem( 51) +  0.6899999999999999D+00 * w(136)
      chem( 54) = chem( 54) +  0.7000000000000000D+00 * w(136)
      chem( 55) = chem( 55) +  0.8000000000000000D-01 * w(136)
      chem( 59) = chem( 59) - w(136)
      chem( 61) = chem( 61) +  0.7600000000000000D+00 * w(136)
      chem( 62) = chem( 62) +  0.6200000000000000D+00 * w(136)
      chem( 63) = chem( 63) +  0.3000000000000000D-01 * w(136)
      chem(  8) = chem(  8) - w(137)
      chem( 15) = chem( 15) +  0.3000000000000000D+00 * w(137)
      chem( 30) = chem( 30) +  0.3900000000000000D-01 * w(137)
      chem( 31) = chem( 31) +  0.1080000000000000D+00 * w(137)
      chem( 40) = chem( 40) +  0.2000000000000000D-01 * w(137)
      chem( 42) = chem( 42) +  0.8000000000000000D+00 * w(137)
      chem( 47) = chem( 47) +  0.1100000000000000D+01 * w(137)
      chem( 55) = chem( 55) - w(137)
      chem( 61) = chem( 61) +  0.7000000000000000D+00 * w(137)
      chem( 63) = chem( 63) +  0.5000000000000000D+00 * w(137)
      chem( 42) = chem( 42) - w(138)
      chem( 55) = chem( 55) - w(138)
      chem( 62) = chem( 62) + w(138)
      chem( 63) = chem( 63) + w(138)
      chem( 42) = chem( 42) - w(139)
      chem( 51) = chem( 51) + w(139)
      chem( 61) = chem( 61) + w(139)
      chem( 62) = chem( 62) + w(139)
      chem( 44) = chem( 44) - w(140)
      chem( 45) = chem( 45) +  0.7500000000000000D+00 * w(140)
      chem( 47) = chem( 47) +  0.2500000000000000D+00 * w(140)
      chem( 54) = chem( 54) +  0.5000000000000000D+00 * w(140)
      chem( 57) = chem( 57) - w(140)
      chem( 58) = chem( 58) +  0.2500000000000000D+00 * w(140)
      chem( 61) = chem( 61) +  0.2500000000000000D+00 * w(140)
      chem( 63) = chem( 63) +  0.2500000000000000D+00 * w(140)
      chem( 44) = chem( 44) - w(141)
      chem( 45) = chem( 45) +  0.9120000000000000D+00 * w(141)
      chem( 52) = chem( 52) +  0.8799999999999999D-01 * w(141)
      chem( 54) = chem( 54) +  0.6290000000000000D+00 * w(141)
      chem( 55) = chem( 55) - w(141)
      chem( 61) = chem( 61) +  0.9120000000000000D+00 * w(141)
      chem( 63) = chem( 63) +  0.9910000000000000D+00 * w(141)
      chem( 44) = chem( 44) - w(142)
      chem( 45) = chem( 45) +  0.6500000000000000D+00 * w(142)
      chem( 47) = chem( 47) +  0.3500000000000000D+00 * w(142)
      chem( 48) = chem( 48) +  0.1500000000000000D+00 * w(142)
      chem( 51) = chem( 51) +  0.6600000000000000D-01 * w(142)
      chem( 54) = chem( 54) +  0.6000000000000000D+00 * w(142)
      chem( 55) = chem( 55) +  0.2660000000000000D+00 * w(142)
      chem( 58) = chem( 58) +  0.2000000000000000D+00 * w(142)
      chem( 59) = chem( 59) - w(142)
      chem( 61) = chem( 61) +  0.6600000000000000D-01 * w(142)
      chem( 63) = chem( 63) +  0.2000000000000000D+00 * w(142)
      chem( 44) = chem( 44) - w(143)
      chem( 45) = chem( 45) +  0.2000000000000000D+00 * w(143)
      chem( 46) = chem( 46) +  0.8000000000000000D+00 * w(143)
      chem( 47) = chem( 47) +  0.2400000000000000D+01 * w(143)
      chem( 48) = chem( 48) +  0.8000000000000000D+00 * w(143)
      chem( 56) = chem( 56) - w(143)
      chem( 61) = chem( 61) +  0.8000000000000000D+00 * w(143)
      chem( 63) = chem( 63) + w(143)
      chem( 65) = chem( 65) +  0.2000000000000000D+00 * w(143)
      chem( 42) = chem( 42) +  0.1680000000000000D+00 * w(144)
      chem( 45) = chem( 45) - w(144)
      chem( 47) = chem( 47) +  0.1565000000000000D+01 * w(144)
      chem( 48) = chem( 48) +  0.1200000000000000D+00 * w(144)
      chem( 51) = chem( 51) +  0.3340000000000000D+00 * w(144)
      chem( 54) = chem( 54) +  0.1670000000000000D+00 * w(144)
      chem( 55) = chem( 55) - w(144)
      chem( 58) = chem( 58) +  0.2500000000000000D+00 * w(144)
      chem( 60) = chem( 60) +  0.2520000000000000D+00 * w(144)
      chem( 61) = chem( 61) +  0.5030000000000000D+00 * w(144)
      chem( 62) = chem( 62) +  0.2100000000000000D+00 * w(144)
      chem( 63) = chem( 63) +  0.7130000000000000D+00 * w(144)
      chem( 42) = chem( 42) +  0.8500000000000000D+00 * w(145)
      chem( 45) = chem( 45) - w(145)
      chem( 47) = chem( 47) +  0.3600000000000000D+00 * w(145)
      chem( 51) = chem( 51) +  0.2250000000000000D+00 * w(145)
      chem( 54) = chem( 54) +  0.1500000000000000D+00 * w(145)
      chem( 55) = chem( 55) +  0.2680000000000000D+00 * w(145)
      chem( 59) = chem( 59) - w(145)
      chem( 60) = chem( 60) +  0.2000000000000000D-01 * w(145)
      chem( 61) = chem( 61) +  0.1540000000000000D+00 * w(145)
      chem( 62) = chem( 62) +  0.1140000000000000D+00 * w(145)
      chem( 63) = chem( 63) +  0.6400000000000000D-01 * w(145)
      chem( 45) = chem( 45) - w(146)
      chem( 46) = chem( 46) +  0.8500000000000000D+00 * w(146)
      chem( 47) = chem( 47) +  0.1282000000000000D+01 * w(146)
      chem( 48) = chem( 48) +  0.3570000000000000D+00 * w(146)
      chem( 50) = chem( 50) +  0.1500000000000000D+00 * w(146)
      chem( 51) = chem( 51) +  0.6430000000000000D+00 * w(146)
      chem( 54) = chem( 54) +  0.2820000000000000D+00 * w(146)
      chem( 56) = chem( 56) - w(146)
      chem( 58) = chem( 58) +  0.7500000000000000D-01 * w(146)
      chem( 61) = chem( 61) +  0.9250000000000000D+00 * w(146)
      chem( 63) = chem( 63) +  0.7500000000000000D-01 * w(146)
      chem( 45) = chem( 45) - w(147)
      chem( 47) = chem( 47) +  0.8320000000000000D+00 * w(147)
      chem( 51) = chem( 51) +  0.3330000000000000D+00 * w(147)
      chem( 54) = chem( 54) +  0.9000000000000000D+00 * w(147)
      chem( 60) = chem( 60) +  0.6700000000000000D-01 * w(147)
      chem( 61) = chem( 61) +  0.1033000000000000D+01 * w(147)
      chem( 62) = chem( 62) +  0.9670000000000000D+00 * w(147)
      chem( 63) = chem( 63) +  0.7000000000000000D+00 * w(147)
      chem( 39) = chem( 39) - w(148)
      chem( 47) = chem( 47) +  0.5120000000000000D+01 * w(148)
      chem( 48) = chem( 48) +  0.1500000000000000D+00 * w(148)
      chem( 57) = chem( 57) - w(148)
      chem( 39) = chem( 39) - w(149)
      chem( 47) = chem( 47) +  0.1660000000000000D+01 * w(149)
      chem( 48) = chem( 48) +  0.4700000000000000D+00 * w(149)
      chem( 52) = chem( 52) +  0.2500000000000000D+00 * w(149)
      chem( 54) = chem( 54) +  0.2800000000000000D+00 * w(149)
      chem( 55) = chem( 55) - w(149)
      chem( 61) = chem( 61) +  0.7500000000000000D+00 * w(149)
      chem( 63) = chem( 63) +  0.1250000000000000D+01 * w(149)
      chem( 39) = chem( 39) - w(150)
      chem( 47) = chem( 47) +  0.7000000000000000D+01 * w(150)
      chem( 48) = chem( 48) +  0.2100000000000000D+00 * w(150)
      chem( 51) = chem( 51) +  0.1000000000000000D-02 * w(150)
      chem( 52) = chem( 52) +  0.1800000000000000D+00 * w(150)
      chem( 54) = chem( 54) +  0.2400000000000000D+00 * w(150)
      chem( 55) = chem( 55) +  0.5700000000000000D+00 * w(150)
      chem( 58) = chem( 58) +  0.3900000000000000D+00 * w(150)
      chem( 59) = chem( 59) - w(150)
      chem( 61) = chem( 61) +  0.7000000000000001D-01 * w(150)
      chem( 63) = chem( 63) +  0.7600000000000000D+00 * w(150)
      chem( 39) = chem( 39) - w(151)
      chem( 46) = chem( 46) +  0.5300000000000000D+00 * w(151)
      chem( 48) = chem( 48) +  0.4700000000000000D+00 * w(151)
      chem( 52) = chem( 52) +  0.2500000000000000D+00 * w(151)
      chem( 56) = chem( 56) - w(151)
      chem( 61) = chem( 61) +  0.2800000000000000D+00 * w(151)
      chem( 63) = chem( 63) +  0.1030000000000000D+01 * w(151)
      chem( 65) = chem( 65) +  0.4700000000000000D+00 * w(151)
      chem(  9) = chem(  9) - w(152)
      chem( 10) = chem( 10) + w(152)
      chem( 55) = chem( 55) - w(152)
      chem( 61) = chem( 61) + w(152)
      chem(  4) = chem(  4) - w(153)
      chem( 48) = chem( 48) +  0.5000000000000000D-01 * w(153)
      chem( 54) = chem( 54) +  0.1000000000000000D+00 * w(153)
      chem( 55) = chem( 55) - w(153)
      chem( 60) = chem( 60) +  0.9000000000000000D+00 * w(153)
      chem( 61) = chem( 61) + w(153)
      chem( 63) = chem( 63) +  0.1000000000000000D+00 * w(153)
      chem(  6) = chem(  6) - w(154)
      chem( 52) = chem( 52) +  0.8999999999999999D-02 * w(154)
      chem( 55) = chem( 55) - w(154)
      chem( 60) = chem( 60) +  0.9910000000000000D+00 * w(154)
      chem( 61) = chem( 61) + w(154)
      chem( 63) = chem( 63) +  0.9910000000000000D+00 * w(154)
      chem( 44) = chem( 44) - w(155)
      chem( 45) = chem( 45) +  0.2000000000000000D+00 * w(155)
      chem( 46) = chem( 46) +  0.8000000000000000D+00 * w(155)
      chem( 47) = chem( 47) +  0.2400000000000000D+01 * w(155)
      chem( 48) = chem( 48) +  0.8000000000000000D+00 * w(155)
      chem( 61) = chem( 61) +  0.8000000000000000D+00 * w(155)
      chem( 63) = chem( 63) + w(155)
      chem( 64) = chem( 64) +  0.2000000000000000D+00 * w(155)
      chem( 65) = chem( 65) - w(155)
      chem( 20) = chem( 20) +  0.5000000000000000D+00 * w(156)
      chem( 61) = chem( 61) - w(156)
      chem( 23) = chem( 23) +  0.5000000000000000D+00 * w(157)
      chem( 50) = chem( 50) +  0.5000000000000000D+00 * w(157)
      chem( 65) = chem( 65) - w(157)
      chem( 50) = chem( 50) + w(158)
      chem( 56) = chem( 56) - w(158)
      chem( 16) = chem( 16) - w(159)
      chem( 50) = chem( 50) +  0.2000000000000000D+01 * w(159)
      chem( 11) = chem( 11) - w(160)
      chem( 12) = chem( 12) +  0.4800000000000000D-01 * w(160)
      chem( 24) = chem( 24) - w(161)
      chem( 25) = chem( 25) +  0.6384000000000000D-02 * w(161)
      chem( 26) = chem( 26) +  0.5494800000000000D-01 * w(161)
      chem( 24) = chem( 24) - w(162)
      chem( 25) = chem( 25) +  0.2158800000000000D-01 * w(162)
      chem( 26) = chem( 26) +  0.1858110000000000D+00 * w(162)
      chem( 27) = chem( 27) - w(163)
      chem( 28) = chem( 28) +  0.3716400000000000D-01 * w(163)
      chem( 29) = chem( 29) +  0.5631600000000000D-01 * w(163)
      chem( 27) = chem( 27) - w(164)
      chem( 28) = chem( 28) +  0.1256730000000000D+00 * w(164)
      chem( 29) = chem( 29) +  0.1904370000000000D+00 * w(164)
      chem( 24) = chem( 24) - w(165)
      chem( 27) = chem( 27) - w(166)
 
C    Conversion molecules/cm3 to mug/m3.
 
      do i = 1, ns
         chem(i) = chem(i) / convers_factor(i)
      enddo
 
C     Volumic source terms.
 
      IF(nemis.gt.0)THEN
      do i=1,ns
      chem(i)=chem(i)+ZCsourc(i)
      enddo
      endif
 
      RETURN
      END
 
