C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C
C     This file is part of the air quality modeling system Polyphemus.
C
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C
C     Polyphemus is free software; you can redistribute i and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C------------------------------------------------------------------------
 
      subroutine rates(ns,nr,rk,y,w)
 
C------------------------------------------------------------------------
C
C     -- DESCRIPTION
C
C     This routine computes the reaction rates.
C     This routine is automatically generated by SPACK.
C     Mechanism: CB05_SORGAM         
C     Species: _ciCB05_SORGAM      
C
C------------------------------------------------------------------------
C
C     -- INPUT VARIABLES
C
C     Ns: chemical species number.
C     NR: reaction number.
C     RK: kinetic rates.
C     Y: chemical concentrations.
C
C     -- INPUT/OUTPUT VARIABLES
C
C     -- OUTPUT VARIABLES
C
C     W: reaction rates.
C
C------------------------------------------------------------------------
C
C     -- REMARKS
C
C------------------------------------------------------------------------
C
C     -- MODIFICATIONS
C
C------------------------------------------------------------------------
C
C     -- AUTHOR(S)
C
C     SPACK.
C
C------------------------------------------------------------------------
 
      implicit none
 
      integer nr,ns
      double precision rk(nr),y(ns),w(nr)
 
 
 
      w(  1) =  rk(  1) * Y( 65)
      w(  2) =  rk(  2) * Y( 57)
      w(  3) =  rk(  3) * Y( 59) * Y( 64)
      w(  4) =  rk(  4) * Y( 57) * Y( 65)
      w(  5) =  rk(  5) * Y( 57) * Y( 65)
      w(  6) =  rk(  6) * Y( 57) * Y( 64)
      w(  7) =  rk(  7) * Y( 65) * Y( 59)
      w(  8) =  rk(  8) * Y( 59)
      w(  9) =  rk(  9) * Y( 59)
      w( 10) =  rk( 10) * Y(  3)
      w( 11) =  rk( 11) * Y(  3)
      w( 12) =  rk( 12) * Y( 59) * Y( 55)
      w( 13) =  rk( 13) * Y( 59) * Y( 61)
      w( 14) =  rk( 14) * Y( 56)
      w( 15) =  rk( 15) * Y( 56)
      w( 16) =  rk( 16) * Y( 56) * Y( 64)
      w( 17) =  rk( 17) * Y( 56) * Y( 65)
      w( 18) =  rk( 18) * Y( 56) * Y( 65)
      w( 19) =  rk( 19) * Y( 16)
      w( 20) =  rk( 20) * Y( 16)
      w( 21) =  rk( 21) * Y( 64) * Y( 64)
      w( 22) =  rk( 22) * Y( 64) * Y( 65)
      w( 23) =  rk( 23) * Y( 55) * Y( 64)
      w( 24) =  rk( 24) * Y( 23)
      w( 25) =  rk( 25) * Y( 55) * Y( 23)
      w( 26) =  rk( 26) * Y( 23) * Y( 23)
      w( 27) =  rk( 27) * Y( 65) * Y( 55)
      w( 28) =  rk( 28) * Y( 55) * Y( 50)
      w( 29) =  rk( 29) * Y( 61) * Y( 64)
      w( 30) =  rk( 30) * Y( 61) * Y( 65)
      w( 31) =  rk( 31) * Y( 17)
      w( 32) =  rk( 32) * Y( 55) * Y( 17)
      w( 33) =  rk( 33) * Y( 61) * Y( 61)
      w( 34) =  rk( 34) * Y( 61) * Y( 61)
      w( 35) =  rk( 35) * Y( 20)
      w( 36) =  rk( 36) * Y( 55) * Y( 20)
      w( 37) =  rk( 37) * Y(  3)
      w( 38) =  rk( 38) * Y( 55)
      w( 39) =  rk( 39) * Y( 55) * Y( 57)
      w( 40) =  rk( 40) * Y( 55) * Y( 55)
      w( 41) =  rk( 41) * Y( 55) * Y( 55)
      w( 42) =  rk( 42) * Y( 55) * Y( 61)
      w( 43) =  rk( 43) * Y( 61) * Y( 57)
      w( 44) =  rk( 44) * Y( 20) * Y( 57)
      w( 45) =  rk( 45) * Y( 56) * Y( 57)
      w( 46) =  rk( 46) * Y( 56) * Y( 55)
      w( 47) =  rk( 47) * Y( 56) * Y( 61)
      w( 48) =  rk( 48) * Y( 56) * Y( 59)
      w( 49) =  rk( 49) * Y( 56) * Y( 56)
      w( 50) =  rk( 50) * Y( 17)
      w( 51) =  rk( 51) * Y( 50)
      w( 52) =  rk( 52) * Y( 16)
      w( 53) =  rk( 53) * Y( 63) * Y( 64)
      w( 54) =  rk( 54) * Y( 52) * Y( 64)
      w( 55) =  rk( 55) * Y( 63) * Y( 61)
      w( 56) =  rk( 56) * Y( 52) * Y( 61)
      w( 57) =  rk( 57) * Y( 63) * Y( 63)
      w( 58) =  rk( 58) * Y( 52) * Y( 52)
      w( 59) =  rk( 59) * Y( 63) * Y( 52)
      w( 60) =  rk( 60) * Y( 46) * Y( 55)
      w( 61) =  rk( 61) * Y( 46)
      w( 62) =  rk( 62) * Y( 32) * Y( 55)
      w( 63) =  rk( 63) * Y( 32)
      w( 64) =  rk( 64) * Y( 55) * Y( 51)
      w( 65) =  rk( 65) * Y( 55) * Y(  5)
      w( 66) =  rk( 66) * Y( 53) * Y( 64)
      w( 67) =  rk( 67) * Y( 53) * Y( 61)
      w( 68) =  rk( 68) * Y( 53) * Y( 53)
      w( 69) =  rk( 69) * Y( 22) * Y( 55)
      w( 70) =  rk( 70) * Y( 22)
      w( 71) =  rk( 71) * Y( 14) * Y( 55)
      w( 72) =  rk( 72) * Y( 54) * Y( 55)
      w( 73) =  rk( 73) * Y( 54)
      w( 74) =  rk( 74) * Y( 54)
      w( 75) =  rk( 75) * Y( 54) * Y( 57)
      w( 76) =  rk( 76) * Y( 54) * Y( 56)
      w( 77) =  rk( 77) * Y( 54) * Y( 61)
      w( 78) =  rk( 78) * Y( 21)
      w( 79) =  rk( 79) * Y( 21) * Y( 64)
      w( 80) =  rk( 80) * Y( 21) * Y( 61)
      w( 81) =  rk( 81) * Y( 35) * Y( 55)
      w( 82) =  rk( 82) * Y( 60) * Y( 57)
      w( 83) =  rk( 83) * Y( 60) * Y( 55)
      w( 84) =  rk( 84) * Y( 60) * Y( 56)
      w( 85) =  rk( 85) * Y( 60)
      w( 86) =  rk( 86) * Y( 62) * Y( 64)
      w( 87) =  rk( 87) * Y( 62) * Y( 65)
      w( 88) =  rk( 88) * Y( 13)
      w( 89) =  rk( 89) * Y( 13)
      w( 90) =  rk( 90) * Y( 62) * Y( 61)
      w( 91) =  rk( 91) * Y( 62) * Y( 53)
      w( 92) =  rk( 92) * Y( 62) * Y( 63)
      w( 93) =  rk( 93) * Y( 62) * Y( 62)
      w( 94) =  rk( 94) * Y( 33) * Y( 55)
      w( 95) =  rk( 95) * Y( 33)
      w( 96) =  rk( 96) * Y( 49) * Y( 55)
      w( 97) =  rk( 97) * Y( 48) * Y( 57)
      w( 98) =  rk( 98) * Y( 48) * Y( 55)
      w( 99) =  rk( 99) * Y( 48) * Y( 56)
      w(100) =  rk(100) * Y( 48)
      w(101) =  rk(101) * Y( 58) * Y( 64)
      w(102) =  rk(102) * Y( 58) * Y( 65)
      w(103) =  rk(103) * Y( 18)
      w(104) =  rk(104) * Y( 18)
      w(105) =  rk(105) * Y( 18) * Y( 55)
      w(106) =  rk(106) * Y( 58) * Y( 61)
      w(107) =  rk(107) * Y( 62) * Y( 53)
      w(108) =  rk(108) * Y( 62) * Y( 63)
      w(109) =  rk(109) * Y( 58) * Y( 58)
      w(110) =  rk(110) * Y( 58) * Y( 62)
      w(111) =  rk(111) * Y( 47) * Y( 55)
      w(112) =  rk(112) * Y( 19)
      w(113) =  rk(113) * Y( 19)
      w(114) =  rk(114) * Y( 19) * Y( 65)
      w(115) =  rk(115) * Y( 57) * Y( 36)
      w(116) =  rk(116) * Y( 55) * Y( 36)
      w(117) =  rk(117) * Y( 59) * Y( 36)
      w(118) =  rk(118) * Y( 56) * Y( 36)
      w(119) =  rk(119) * Y( 57) * Y( 34)
      w(120) =  rk(120) * Y( 55) * Y( 34)
      w(121) =  rk(121) * Y( 59) * Y( 34)
      w(122) =  rk(122) * Y( 56) * Y( 34)
      w(123) =  rk(123) * Y( 37) * Y( 57)
      w(124) =  rk(124) * Y( 37) * Y( 55)
      w(125) =  rk(125) * Y( 37) * Y( 59)
      w(126) =  rk(126) * Y( 37) * Y( 56)
      w(127) =  rk(127) * Y(  7) * Y( 55)
      w(128) =  rk(128) * Y( 15) * Y( 64)
      w(129) =  rk(129) * Y( 15)
      w(130) =  rk(130) * Y( 55) * Y( 40)
      w(131) =  rk(131) * Y( 40) * Y( 56)
      w(132) =  rk(132) * Y( 43) * Y( 65)
      w(133) =  rk(133) * Y( 43) * Y( 61)
      w(134) =  rk(134) * Y( 41)
      w(135) =  rk(135) * Y( 41) * Y( 55)
      w(136) =  rk(136) * Y( 41) * Y( 59)
      w(137) =  rk(137) * Y( 55) * Y(  8)
      w(138) =  rk(138) * Y( 55) * Y( 42)
      w(139) =  rk(139) * Y( 42)
      w(140) =  rk(140) * Y( 57) * Y( 44)
      w(141) =  rk(141) * Y( 55) * Y( 44)
      w(142) =  rk(142) * Y( 59) * Y( 44)
      w(143) =  rk(143) * Y( 56) * Y( 44)
      w(144) =  rk(144) * Y( 55) * Y( 45)
      w(145) =  rk(145) * Y( 59) * Y( 45)
      w(146) =  rk(146) * Y( 56) * Y( 45)
      w(147) =  rk(147) * Y( 45)
      w(148) =  rk(148) * Y( 39) * Y( 57)
      w(149) =  rk(149) * Y( 39) * Y( 55)
      w(150) =  rk(150) * Y( 39) * Y( 59)
      w(151) =  rk(151) * Y( 39) * Y( 56)
      w(152) =  rk(152) * Y(  9) * Y( 55)
      w(153) =  rk(153) * Y( 55) * Y(  4)
      w(154) =  rk(154) * Y( 55) * Y(  6)
      w(155) =  rk(155) * Y( 65) * Y( 44)
      w(156) =  rk(156) * Y( 61)
      w(157) =  rk(157) * Y( 65)
      w(158) =  rk(158) * Y( 56)
      w(159) =  rk(159) * Y( 16)
      w(160) =  rk(160) * Y( 11) * Y( 55)
      w(161) =  rk(161) * Y( 24) * Y( 55)
      w(162) =  rk(162) * Y( 24) * Y( 59)
      w(163) =  rk(163) * Y( 27) * Y( 55)
      w(164) =  rk(164) * Y( 27) * Y( 59)
      w(165) =  rk(165) * Y( 24) * Y( 56)
      w(166) =  rk(166) * Y( 27) * Y( 56)
 
      RETURN
      END
 
