C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C
C     This file is part of the air quality modeling system Polyphemus.
C
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C
C     Polyphemus is free software; you can redistribute i and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C------------------------------------------------------------------------
 
      subroutine kinetic_cb05(nr,rk,temp,xlw,Press,azi,att,
     $     option_photolysis)
 
C------------------------------------------------------------------------
C
C     -- DESCRIPTION
C
C     This routine computes the kinetic rates for the gas-phase.
C     This routine is automatically generated by SPACK.
C     Mechanism: CB05                
C     Species: _ciCB05             
C
C------------------------------------------------------------------------
C
C     -- INPUT VARIABLES
C
C     NR: reaction number.
C     TEMP: temperature ([K]).
C     XLW: water massic fraction.
C     PRESS: pressure ([Pa]).
C     AZI: zenithal angle ([degree]).
C     ATT: attenuation variable.
C
C     -- INPUT/OUTPUT VARIABLES
C
C     -- OUTPUT VARIABLES
C
C     RK: kinetic rates.
C
C------------------------------------------------------------------------
C
C     -- REMARKS
C
C------------------------------------------------------------------------
C
C     -- MODIFICATIONS
C
C------------------------------------------------------------------------
C
C     -- AUTHOR(S)
C
C     SPACK.
C
C------------------------------------------------------------------------
 
      implicit none
 
      integer nr
      double precision rk(nr),temp,xlw,Press
      double precision Effko,Rapk,facteur,SumM,azi,att
      double precision YlH2O
      integer option_photolysis
 
C     Compute third body.
C     Conversion = Avogadro*1d-6/Perfect gas constant.
C     PRESS in Pascal, SUMM in molecules/cm3, TEMP in Kelvin
 
      SumM = Press * 7.243D16 / temp
 
C     Number of water molecules computed from the massic fraction
C     (absolute humidity)
 
      YlH2O = 29.d0*SumM*xlw/(18.d0+11.d0*xlw)
 
C     For the zenithal angle at tropics
 
      azi=abs(azi)
 
C
      if(option_photolysis.eq.2) then
       rk(  1)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk(  1)=-0.1302720567168795D-07
       rk(  1)=-0.7822279432831311D-06+(azi- 0.00D+00) * rk(  1)
       rk(  1)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(  1)
       rk(  1)= 0.9310260000000001D-02+(azi- 0.00D+00) * rk(  1)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk(  1)= 0.3771617015067078D-08
       rk(  1)=-0.1173044113433769D-05+(azi- 0.10D+02) * rk(  1)
       rk(  1)=-0.1955272056716901D-04+(azi- 0.10D+02) * rk(  1)
       rk(  1)= 0.9219010000000000D-02+(azi- 0.10D+02) * rk(  1)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk(  1)=-0.5859262388581815D-08
       rk(  1)=-0.1059895602981758D-05+(azi- 0.20D+02) * rk(  1)
       rk(  1)=-0.4188211773132428D-04+(azi- 0.20D+02) * rk(  1)
       rk(  1)= 0.8909950000000000D-02+(azi- 0.20D+02) * rk(  1)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk(  1)=-0.7024567460738029D-08
       rk(  1)=-0.1235673474639213D-05+(azi- 0.30D+02) * rk(  1)
       rk(  1)=-0.6483780850753392D-04+(azi- 0.30D+02) * rk(  1)
       rk(  1)= 0.8379279999999999D-02+(azi- 0.30D+02) * rk(  1)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk(  1)=-0.9202467768466835D-08
       rk(  1)=-0.1446410498461367D-05+(azi- 0.40D+02) * rk(  1)
       rk(  1)=-0.9165864823853972D-04+(azi- 0.40D+02) * rk(  1)
       rk(  1)= 0.7600310000000000D-02+(azi- 0.40D+02) * rk(  1)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk(  1)=-0.1612556146540100D-07
       rk(  1)=-0.1722484531515342D-05+(azi- 0.50D+02) * rk(  1)
       rk(  1)=-0.1233475985383066D-03+(azi- 0.50D+02) * rk(  1)
       rk(  1)= 0.6529880000000000D-02+(azi- 0.50D+02) * rk(  1)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk(  1)= 0.3226471363007382D-07
       rk(  1)=-0.2206251375477548D-05+(azi- 0.60D+02) * rk(  1)
       rk(  1)=-0.1626349576082332D-03+(azi- 0.60D+02) * rk(  1)
       rk(  1)= 0.5108030000000000D-02+(azi- 0.60D+02) * rk(  1)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk(  1)= 0.2027078243961372D-06
       rk(  1)=-0.1238309966574737D-05+(azi- 0.70D+02) * rk(  1)
       rk(  1)=-0.1970805710287543D-03+(azi- 0.70D+02) * rk(  1)
       rk(  1)= 0.3293320000000000D-02+(azi- 0.70D+02) * rk(  1)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk(  1)=-0.7448311471194499D-07
       rk(  1)= 0.3626677818932555D-05+(azi- 0.78D+02) * rk(  1)
       rk(  1)=-0.1779736282099126D-03+(azi- 0.78D+02) * rk(  1)
       rk(  1)= 0.1741210000000000D-02+(azi- 0.78D+02) * rk(  1)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk(  1)= 0.2490309929270573D-05
       rk(  1)= 0.1839083065842406D-05+(azi- 0.86D+02) * rk(  1)
       rk(  1)=-0.1342475411316713D-03+(azi- 0.86D+02) * rk(  1)
       rk(  1)= 0.5113930000000000D-03+(azi- 0.86D+02) * rk(  1)
      elseif(azi.ge.90.D0)then
       rk(  1)= 0.1632080000000000D-03
      endif
      if(att.lt.0.99999) rk(  1) = rk(  1) * att
      endif
C
      rk(  2) = SumM * 6.0d-34 * (temp/3.d2) ** (-2.4d0)
      rk(  2) = rk(  2) * SumM * 0.2d0
      rk(  3) =  DEXP(-0.2653240882726044D+02
     & - (  0.1500000000000000D+04 )/temp)
      rk(  4) =  DEXP(-0.2590825451818744D+02
     & - ( -0.1800000000000000D+03 )/temp)
      Effko =  0.2500000000000000D-30* (temp / 3.d2)
     &           **(- ( 0.1800000000000000D+01))
      Rapk =  0.2200000000000000D-10* (temp / 3.d2)
     &            **(- ( 0.7000000000000000D+00))
      rk(  5) = (Effko * SumM / 
     &            ( 1.0d0 + Effko * SumM / Rapk)) *
     &            0.6000D+00** (1.0d0 / (1.0d0 + 
     &             (dlog10(Effko * SumM / Rapk))**2))
      Effko =  0.9000000000000000D-31* (temp / 3.d2)
     &           **(- ( 0.1500000000000000D+01))
      Rapk =  0.3000000000000000D-10* (temp / 3.d2)
     &            **(- ( 0.0000000000000000D+00))
      rk(  6) = (Effko * SumM / 
     &            ( 1.0d0 + Effko * SumM / Rapk)) *
     &            0.6000D+00** (1.0d0 / (1.0d0 + 
     &             (dlog10(Effko * SumM / Rapk))**2))
      rk(  7) =  DEXP(-0.2975128465212864D+02
     & - (  0.2450000000000000D+04 )/temp)
C
      if(option_photolysis.eq.2) then
       rk(  8)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk(  8)=-0.5928286648807996D-09
       rk(  8)=-0.3096171335119280D-07+(azi- 0.00D+00) * rk(  8)
       rk(  8)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(  8)
       rk(  8)= 0.4927580000000000D-03+(azi- 0.00D+00) * rk(  8)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk(  8)= 0.1444859946426876D-09
       rk(  8)=-0.4874657329761677D-07+(azi- 0.10D+02) * rk(  8)
       rk(  8)=-0.7970828664880956D-06+(azi- 0.10D+02) * rk(  8)
       rk(  8)= 0.4890690000000000D-03+(azi- 0.10D+02) * rk(  8)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk(  8)=-0.5511531369012520D-10
       rk(  8)=-0.4441199345833616D-07+(azi- 0.20D+02) * rk(  8)
       rk(  8)=-0.1728668534047625D-05+(azi- 0.20D+02) * rk(  8)
       rk(  8)= 0.4763680000000000D-03+(azi- 0.20D+02) * rk(  8)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk(  8)=-0.3000247398821449D-09
       rk(  8)=-0.4606545286904014D-07+(azi- 0.30D+02) * rk(  8)
       rk(  8)=-0.2633442997321385D-05+(azi- 0.30D+02) * rk(  8)
       rk(  8)= 0.4545850000000000D-03+(azi- 0.30D+02) * rk(  8)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk(  8)=-0.2397857267812366D-09
       rk(  8)=-0.5506619506550444D-07+(azi- 0.40D+02) * rk(  8)
       rk(  8)=-0.3644759476666826D-05+(azi- 0.40D+02) * rk(  8)
       rk(  8)= 0.4233440000000000D-03+(azi- 0.40D+02) * rk(  8)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk(  8)=-0.1844832352993067D-08
       rk(  8)=-0.6225976686893995D-07+(azi- 0.50D+02) * rk(  8)
       rk(  8)=-0.4818019096011278D-05+(azi- 0.50D+02) * rk(  8)
       rk(  8)= 0.3811500000000000D-03+(azi- 0.50D+02) * rk(  8)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk(  8)= 0.1101151387530619D-09
       rk(  8)=-0.1176047374587370D-06+(azi- 0.60D+02) * rk(  8)
       rk(  8)=-0.6616664139287950D-05+(azi- 0.60D+02) * rk(  8)
       rk(  8)= 0.3248990000000000D-03+(azi- 0.60D+02) * rk(  8)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk(  8)=-0.1557211541866474D-07
       rk(  8)=-0.1143012832961418D-06+(azi- 0.70D+02) * rk(  8)
       rk(  8)=-0.8935724346837023D-05+(azi- 0.70D+02) * rk(  8)
       rk(  8)= 0.2470820000000000D-03+(azi- 0.70D+02) * rk(  8)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk(  8)= 0.4048472604232427D-07
       rk(  8)=-0.4880320533439059D-06+(azi- 0.78D+02) * rk(  8)
       rk(  8)=-0.1375439103995816D-04+(azi- 0.78D+02) * rk(  8)
       rk(  8)= 0.1603080000000000D-03+(azi- 0.78D+02) * rk(  8)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk(  8)= 0.2066880316654862D-06
       rk(  8)= 0.4836013716715513D-06+(azi- 0.86D+02) * rk(  8)
       rk(  8)=-0.1378983649333310D-04+(azi- 0.86D+02) * rk(  8)
       rk(  8)= 0.3976700000000000D-04+(azi- 0.86D+02) * rk(  8)
      elseif(azi.ge.90.D0)then
       rk(  8)= 0.5573310000000000D-05
      endif
      if(att.lt.0.99999) rk(  8) = rk(  8) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk(  9)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk(  9)=-0.8776629099833464D-10
       rk(  9)=-0.1165033709001661D-07+(azi- 0.00D+00) * rk(  9)
       rk(  9)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(  9)
       rk(  9)= 0.3523480000000000D-04+(azi- 0.00D+00) * rk(  9)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk(  9)= 0.1474988729949909D-09
       rk(  9)=-0.1428332581996665D-07+(azi- 0.10D+02) * rk(  9)
       rk(  9)=-0.2593366290998327D-06+(azi- 0.10D+02) * rk(  9)
       rk(  9)= 0.3398200000000000D-04+(azi- 0.10D+02) * rk(  9)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk(  9)= 0.1300707990183827D-09
       rk(  9)=-0.9858359630116941D-08+(azi- 0.20D+02) * rk(  9)
       rk(  9)=-0.5007534836006686D-06+(azi- 0.20D+02) * rk(  9)
       rk(  9)= 0.3010780000000000D-04+(azi- 0.20D+02) * rk(  9)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk(  9)= 0.1988179309314732D-09
       rk(  9)=-0.5956235659565481D-08+(azi- 0.30D+02) * rk(  9)
       rk(  9)=-0.6588994364974921D-06+(azi- 0.30D+02) * rk(  9)
       rk(  9)= 0.2424450000000000D-04+(azi- 0.30D+02) * rk(  9)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk(  9)= 0.2219574772557277D-09
       rk(  9)= 0.8302268378835231D-11+(azi- 0.40D+02) * rk(  9)
       rk(  9)=-0.7183787704093613D-06+(azi- 0.40D+02) * rk(  9)
       rk(  9)= 0.1725870000000000D-04+(azi- 0.40D+02) * rk(  9)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk(  9)= 0.1913521600455895D-09
       rk(  9)= 0.6667026586050136D-08+(azi- 0.50D+02) * rk(  9)
       rk(  9)=-0.6516254818650674D-06+(azi- 0.50D+02) * rk(  9)
       rk(  9)= 0.1029770000000000D-04+(azi- 0.50D+02) * rk(  9)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk(  9)= 0.1602388256152816D-10
       rk(  9)= 0.1240759138741867D-07+(azi- 0.60D+02) * rk(  9)
       rk(  9)=-0.4608793021303539D-06+(azi- 0.60D+02) * rk(  9)
       rk(  9)= 0.4639500000000000D-05+(azi- 0.60D+02) * rk(  9)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk(  9)=-0.3089359890783960D-09
       rk(  9)= 0.1288830786428400D-07+(azi- 0.70D+02) * rk(  9)
       rk(  9)=-0.2079203096133002D-06+(azi- 0.70D+02) * rk(  9)
       rk(  9)= 0.1287490000000000D-05+(azi- 0.70D+02) * rk(  9)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk(  9)=-0.2034952628632162D-09
       rk(  9)= 0.5473844126395715D-08+(azi- 0.78D+02) * rk(  9)
       rk(  9)=-0.6102309368797090D-07+(azi- 0.78D+02) * rk(  9)
       rk(  9)= 0.2908040000000000D-06+(azi- 0.78D+02) * rk(  9)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk(  9)= 0.1623544916128788D-09
       rk(  9)= 0.5899578175158973D-09+(azi- 0.86D+02) * rk(  9)
       rk(  9)=-0.1251267813581064D-07+(azi- 0.86D+02) * rk(  9)
       rk(  9)= 0.4875570000000000D-07+(azi- 0.86D+02) * rk(  9)
      elseif(azi.ge.90.D0)then
       rk(  9)= 0.1853500000000000D-07
      endif
      if(att.lt.0.99999) rk(  9) = rk(  9) * att
      endif
C
      rk( 10) =  DEXP(-0.2458649867820512D+02
     & - ( -0.1020000000000000D+03 )/temp)
      rk( 10) = rk( 10) * SumM
      rk( 11) =  0.2200000000000000D-09
      rk( 11) = rk( 11) * YlH2O
      rk( 12) =  DEXP(-0.2710039286486638D+02
     & - (  0.9400000000000000D+03 )/temp)
      rk( 13) =  DEXP(-0.3223619130191664D+02
     & - (  0.4900000000000000D+03 )/temp)
C
      if(option_photolysis.eq.2) then
       rk( 14)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 14)=-0.1926445199576598D-06
       rk( 14)=-0.1114355480042343D-04+(azi- 0.00D+00) * rk( 14)
       rk( 14)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 14)
       rk( 14)= 0.2129960000000000D+00+(azi- 0.00D+00) * rk( 14)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 14)=-0.3806644012699938D-07
       rk( 14)=-0.1692289039915322D-04+(azi- 0.10D+02) * rk( 14)
       rk( 14)=-0.2806644519957665D-03+(azi- 0.10D+02) * rk( 14)
       rk( 14)= 0.2116890000000000D+00+(azi- 0.10D+02) * rk( 14)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 14)= 0.3591028046562922D-07
       rk( 14)=-0.1806488360296321D-04+(azi- 0.20D+02) * rk( 14)
       rk( 14)=-0.6305421920169308D-03+(azi- 0.20D+02) * rk( 14)
       rk( 14)= 0.2071520000000000D+00+(azi- 0.20D+02) * rk( 14)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 14)=-0.2185746817355116D-06
       rk( 14)=-0.1698757518899435D-04+(azi- 0.30D+02) * rk( 14)
       rk( 14)=-0.9810667799365058D-03+(azi- 0.30D+02) * rk( 14)
       rk( 14)= 0.1990760000000000D+00+(azi- 0.30D+02) * rk( 14)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 14)=-0.2006115535235656D-06
       rk( 14)=-0.2354481564105959D-04+(azi- 0.40D+02) * rk( 14)
       rk( 14)=-0.1386390688237046D-02+(azi- 0.40D+02) * rk( 14)
       rk( 14)= 0.1873480000000000D+00+(azi- 0.40D+02) * rk( 14)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 14)=-0.1055979104170267D-05
       rk( 14)=-0.2956316224676618D-04+(azi- 0.50D+02) * rk( 14)
       rk( 14)=-0.1917470467115309D-02+(azi- 0.50D+02) * rk( 14)
       rk( 14)= 0.1709290000000000D+00+(azi- 0.50D+02) * rk( 14)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 14)=-0.3204720297952934D-06
       rk( 14)=-0.6124253537187832D-04+(azi- 0.60D+02) * rk( 14)
       rk( 14)=-0.2825527443301723D-02+(azi- 0.60D+02) * rk( 14)
       rk( 14)= 0.1477420000000000D+00+(azi- 0.60D+02) * rk( 14)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 14)=-0.6785572971821502D-05
       rk( 14)=-0.7085669626571978D-04+(azi- 0.70D+02) * rk( 14)
       rk( 14)=-0.4146519759677725D-02+(azi- 0.70D+02) * rk( 14)
       rk( 14)= 0.1130420000000000D+00+(azi- 0.70D+02) * rk( 14)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 14)= 0.2349184361304102D-04
       rk( 14)=-0.2337104475894081D-03+(azi- 0.78D+02) * rk( 14)
       rk( 14)=-0.6583056910518970D-02+(azi- 0.78D+02) * rk( 14)
       rk( 14)= 0.7186080000000000D-01+(azi- 0.78D+02) * rk( 14)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 14)= 0.6606749385962285D-04
       rk( 14)= 0.3300937991232988D-03+(azi- 0.86D+02) * rk( 14)
       rk( 14)=-0.5811990098247399D-02+(azi- 0.86D+02) * rk( 14)
       rk( 14)= 0.1626670000000000D-01+(azi- 0.86D+02) * rk( 14)
      elseif(azi.ge.90.D0)then
       rk( 14)= 0.2528560000000000D-02
      endif
      if(att.lt.0.99999) rk( 14) = rk( 14) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 15)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 15)= 0.2691897351034453D-06
       rk( 15)=-0.8269897351034459D-05+(azi- 0.00D+00) * rk( 15)
       rk( 15)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 15)
       rk( 15)= 0.2641020000000000D-01+(azi- 0.00D+00) * rk( 15)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 15)=-0.7916920531033595D-07
       rk( 15)=-0.1942052979310991D-06+(azi- 0.10D+02) * rk( 15)
       rk( 15)=-0.8464102648965558D-04+(azi- 0.10D+02) * rk( 15)
       rk( 15)= 0.2585240000000000D-01+(azi- 0.10D+02) * rk( 15)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 15)=-0.1051291386209900D-07
       rk( 15)=-0.2569281457241183D-05+(azi- 0.20D+02) * rk( 15)
       rk( 15)=-0.1122758940413783D-03+(azi- 0.20D+02) * rk( 15)
       rk( 15)= 0.2490740000000000D-01+(azi- 0.20D+02) * rk( 15)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 15)= 0.2352086075873541D-07
       rk( 15)=-0.2884668873104183D-05+(azi- 0.30D+02) * rk( 15)
       rk( 15)=-0.1668153973448314D-03+(azi- 0.30D+02) * rk( 15)
       rk( 15)= 0.2351720000000000D-01+(azi- 0.30D+02) * rk( 15)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 15)=-0.3394705291728600D-06
       rk( 15)=-0.2179043050341877D-05+(azi- 0.40D+02) * rk( 15)
       rk( 15)=-0.2174525165792940D-03+(azi- 0.40D+02) * rk( 15)
       rk( 15)= 0.2158410000000000D-01+(azi- 0.40D+02) * rk( 15)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 15)= 0.7547612559327481D-06
       rk( 15)=-0.1236315892552816D-04+(azi- 0.50D+02) * rk( 15)
       rk( 15)=-0.3628745363379940D-03+(azi- 0.50D+02) * rk( 15)
       rk( 15)= 0.1885220000000000D-01+(azi- 0.50D+02) * rk( 15)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 15)=-0.2220654494558202D-05
       rk( 15)= 0.1027967875245374D-04+(azi- 0.60D+02) * rk( 15)
       rk( 15)=-0.3837093380687356D-03+(azi- 0.60D+02) * rk( 15)
       rk( 15)= 0.1474190000000000D-01+(azi- 0.60D+02) * rk( 15)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 15)= 0.5674461094709940D-05
       rk( 15)=-0.5633995608429060D-04+(azi- 0.70D+02) * rk( 15)
       rk( 15)=-0.8443121113871077D-03+(azi- 0.70D+02) * rk( 15)
       rk( 15)= 0.9712119999999999D-02+(azi- 0.70D+02) * rk( 15)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 15)=-0.3645845749349064D-05
       rk( 15)= 0.7984711018874102D-04+(azi- 0.78D+02) * rk( 15)
       rk( 15)=-0.6562548785515876D-03+(azi- 0.78D+02) * rk( 15)
       rk( 15)= 0.2257190000000000D-02+(azi- 0.78D+02) * rk( 15)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 15)= 0.2915187536922659D-05
       rk( 15)=-0.7653187795608751D-05+(azi- 0.86D+02) * rk( 15)
       rk( 15)=-0.7870349940697352D-04+(azi- 0.86D+02) * rk( 15)
       rk( 15)= 0.2506930000000000D-03+(azi- 0.86D+02) * rk( 15)
      elseif(azi.ge.90.D0)then
       rk( 15)= 0.0000000000000000D+00
      endif
      if(att.lt.0.99999) rk( 15) = rk( 15) * att
      endif
C
      rk( 16) =  DEXP(-0.2492297091482634D+02
     & - ( -0.1700000000000000D+03 )/temp)
      rk( 17) =  DEXP(-0.3073211390514037D+02
     & - (  0.1260000000000000D+04 )/temp)
      Effko =  0.2000000000000000D-29* (temp / 3.d2)
     &           **(- ( 0.4400000000000000D+01))
      Rapk =  0.1400000000000000D-11* (temp / 3.d2)
     &            **(- ( 0.7000000000000000D+00))
      rk( 18) = (Effko * SumM / 
     &            ( 1.0d0 + Effko * SumM / Rapk)) *
     &            0.6000D+00** (1.0d0 / (1.0d0 + 
     &             (dlog10(Effko * SumM / Rapk))**2))
      rk( 19) =  0.1000000000000000D-21
      rk( 19) = rk( 19) * YlH2O
      Effko =  0.1300000000000000D-02* (temp / 3.d2)
     &           **(- ( 0.3500000000000000D+01))*
     &           dexp(- 0.1100000000000000D+05/temp)
      Rapk =  0.9700000000000000D+15* (temp / 3.d2)
     &            **(- (-0.1000000000000000D+00))*
     &           dexp(- 0.1108000000000000D+05/temp)
      rk( 20) = (Effko*SumM / ( 1.0d0 + Effko * SumM / 
     &         Rapk)) * 0.4500D+00** (1.0d0 / (1.0d0 + 
     &          (dlog10(Effko * SumM / Rapk))**2))
      rk( 21) =  DEXP(-0.8860689615829534D+02
     & - ( -0.5300000000000000D+03 )/temp)
      rk( 21) = rk( 21) * SumM * 0.2d0
      rk( 22) =  0.5000000000000000D-39
      rk( 22) = rk( 22) * YlH2O
      Effko =  0.7000000000000000D-30* (temp / 3.d2)
     &           **(- ( 0.2600000000000000D+01))
      Rapk =  0.3600000000000000D-10* (temp / 3.d2)
     &            **(- ( 0.1000000000000000D+00))
      rk( 23) = (Effko * SumM / 
     &            ( 1.0d0 + Effko * SumM / Rapk)) *
     &            0.6000D+00** (1.0d0 / (1.0d0 + 
     &             (dlog10(Effko * SumM / Rapk))**2))
C
      if(option_photolysis.eq.2) then
       rk( 24)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 24)= 0.3358820209399256D-07
       rk( 24)=-0.1043982020939927D-05+(azi- 0.00D+00) * rk( 24)
       rk( 24)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 24)
       rk( 24)= 0.2025720000000000D-02+(azi- 0.00D+00) * rk( 24)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 24)=-0.9874606281977163D-08
       rk( 24)=-0.3633595812015011D-07+(azi- 0.10D+02) * rk( 24)
       rk( 24)=-0.1080317979060077D-04+(azi- 0.10D+02) * rk( 24)
       rk( 24)= 0.1954910000000000D-02+(azi- 0.10D+02) * rk( 24)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 24)=-0.2977696608429058D-10
       rk( 24)=-0.3325741465794663D-06+(azi- 0.20D+02) * rk( 24)
       rk( 24)=-0.1449228083759692D-04+(azi- 0.20D+02) * rk( 24)
       rk( 24)= 0.1833370000000000D-02+(azi- 0.20D+02) * rk( 24)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 24)= 0.8437141463148027D-09
       rk( 24)=-0.3334674555619925D-06+(azi- 0.30D+02) * rk( 24)
       rk( 24)=-0.2115269685901144D-04+(azi- 0.30D+02) * rk( 24)
       rk( 24)= 0.1655160000000000D-02+(azi- 0.30D+02) * rk( 24)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 24)=-0.1460507961917107D-07
       rk( 24)=-0.3081560311725585D-06+(azi- 0.40D+02) * rk( 24)
       rk( 24)=-0.2756893172635704D-04+(azi- 0.40D+02) * rk( 24)
       rk( 24)= 0.1411130000000000D-02+(azi- 0.40D+02) * rk( 24)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 24)= 0.5519060433037940D-07
       rk( 24)=-0.7463084197477311D-06+(azi- 0.50D+02) * rk( 24)
       rk( 24)=-0.3811357623556078D-04+(azi- 0.50D+02) * rk( 24)
       rk( 24)= 0.1090020000000000D-02+(azi- 0.50D+02) * rk( 24)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 24)=-0.5452433770230863D-07
       rk( 24)= 0.9094097101634748D-06+(azi- 0.60D+02) * rk( 24)
       rk( 24)=-0.3648256333140497D-04+(azi- 0.60D+02) * rk( 24)
       rk( 24)= 0.6894440000000000D-03+(azi- 0.60D+02) * rk( 24)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 24)= 0.1398688875948149D-06
       rk( 24)=-0.7263204209054588D-06+(azi- 0.70D+02) * rk( 24)
       rk( 24)=-0.3465167043883305D-04+(azi- 0.70D+02) * rk( 24)
       rk( 24)= 0.3610350000000000D-03+(azi- 0.70D+02) * rk( 24)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 24)=-0.1705248796231296D-06
       rk( 24)= 0.2630532881374437D-05+(azi- 0.78D+02) * rk( 24)
       rk( 24)=-0.1941797075512286D-04+(azi- 0.78D+02) * rk( 24)
       rk( 24)= 0.1089500000000000D-03+(azi- 0.78D+02) * rk( 24)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 24)= 0.4534736536970785D-06
       rk( 24)=-0.1462064229587612D-05+(azi- 0.86D+02) * rk( 24)
       rk( 24)=-0.1007022154081438D-04+(azi- 0.86D+02) * rk( 24)
       rk( 24)= 0.3465160000000000D-04+(azi- 0.86D+02) * rk( 24)
      elseif(azi.ge.90.D0)then
       rk( 24)= 0.0000000000000000D+00
      endif
      if(att.lt.0.99999) rk( 24) = rk( 24) * att
      endif
C
      rk( 25) =  DEXP(-0.2474064935803238D+02
     & - (  0.3900000000000000D+03 )/temp)
      rk( 26) =  0.9999999999999999D-20
      Effko =  0.2000000000000000D-29* (temp / 3.d2)
     &           **(- ( 0.3000000000000000D+01))
      Rapk =  0.2500000000000000D-10* (temp / 3.d2)
     &            **(- ( 0.0000000000000000D+00))
      rk( 27) = (Effko * SumM / 
     &            ( 1.0d0 + Effko * SumM / Rapk)) *
     &            0.6000D+00** (1.0d0 / (1.0d0 + 
     &             (dlog10(Effko * SumM / Rapk))**2))
      Effko = 2.4d-14 * dexp(460.0d0 / temp)
      Rapk = 2.7d-17 * dexp(2199.0d0 / temp)
      facteur =6.5d-34 * dexp(1335.0d0 / temp) * SumM
      rk( 28) = Effko + facteur/(1.0d0 + facteur / Rapk)
      rk( 29) =  DEXP(-0.2637825814743318D+02
     & - ( -0.2500000000000000D+03 )/temp)
      Effko =  0.1800000000000000D-30* (temp / 3.d2)
     &           **(- ( 0.3200000000000000D+01))
      Rapk =  0.4700000000000000D-11* (temp / 3.d2)
     &            **(- ( 0.0000000000000000D+00))
      rk( 30) = (Effko * SumM / 
     &            ( 1.0d0 + Effko * SumM / Rapk)) *
     &            0.6000D+00** (1.0d0 / (1.0d0 + 
     &             (dlog10(Effko * SumM / Rapk))**2))
      Effko =  0.4100000000000000D-04* (temp / 3.d2)
     &           **(- ( 0.0000000000000000D+00))*
     &           dexp(- 0.1065000000000000D+05/temp)
      Rapk =  0.4800000000000000D+16* (temp / 3.d2)
     &            **(- ( 0.0000000000000000D+00))*
     &           dexp(- 0.1117000000000000D+05/temp)
      rk( 31) = (Effko*SumM / ( 1.0d0 + Effko * SumM / 
     &         Rapk)) * 0.6000D+00** (1.0d0 / (1.0d0 + 
     &          (dlog10(Effko * SumM / Rapk))**2))
      rk( 32) =  DEXP(-0.2736865685146106D+02
     & - ( -0.3800000000000000D+03 )/temp)
      rk( 33) = 2.3d-13 * dexp(600.0d0 / temp)
     &            + 1.7d-33* SumM * dexp(1000.0d0 / temp)
      rk( 34) = 3.22d-34 * dexp(2800.0d0 / temp) + 
     &            2.38d-54 * SumM * dexp(3200.0d0 / temp)
      rk( 34) = rk( 34) * YlH2O
C
      if(option_photolysis.eq.2) then
       rk( 35)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 35)= 0.2216060691947382D-09
       rk( 35)=-0.6725860691947380D-08+(azi- 0.00D+00) * rk( 35)
       rk( 35)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 35)
       rk( 35)= 0.8255920000000000D-05+(azi- 0.00D+00) * rk( 35)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 35)=-0.5649820758421535D-10
       rk( 35)=-0.7767861610523388D-10+(azi- 0.10D+02) * rk( 35)
       rk( 35)=-0.6803539308052615D-07+(azi- 0.10D+02) * rk( 35)
       rk( 35)= 0.7804940000000000D-05+(azi- 0.10D+02) * rk( 35)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 35)= 0.1760676114212627D-10
       rk( 35)=-0.1772624843631704D-08+(azi- 0.20D+02) * rk( 35)
       rk( 35)=-0.8653842767789544D-07+(azi- 0.20D+02) * rk( 35)
       rk( 35)= 0.7060320000000000D-05+(azi- 0.20D+02) * rk( 35)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 35)= 0.1508116301571906D-10
       rk( 35)=-0.1244422009367949D-08+(azi- 0.30D+02) * rk( 35)
       rk( 35)=-0.1167088962078915D-06+(azi- 0.30D+02) * rk( 35)
       rk( 35)= 0.6035280000000000D-05+(azi- 0.30D+02) * rk( 35)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 35)=-0.1192141320499066D-10
       rk( 35)=-0.7919871188965364D-09+(azi- 0.40D+02) * rk( 35)
       rk( 35)=-0.1370729874905361D-06+(azi- 0.40D+02) * rk( 35)
       rk( 35)= 0.4758830000000000D-05+(azi- 0.40D+02) * rk( 35)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 35)= 0.1889144898042480D-09
       rk( 35)=-0.1149629515046230D-08+(azi- 0.50D+02) * rk( 35)
       rk( 35)=-0.1564891538299593D-06+(azi- 0.50D+02) * rk( 35)
       rk( 35)= 0.3296980000000000D-05+(azi- 0.50D+02) * rk( 35)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 35)=-0.1875895460122537D-09
       rk( 35)= 0.4517805179082057D-08+(azi- 0.60D+02) * rk( 35)
       rk( 35)=-0.1228073971896028D-06+(azi- 0.60D+02) * rk( 35)
       rk( 35)= 0.1806040000000000D-05+(azi- 0.60D+02) * rk( 35)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 35)= 0.3126106565924376D-09
       rk( 35)=-0.1109881201287672D-08+(azi- 0.70D+02) * rk( 35)
       rk( 35)=-0.8872815741164876D-07+(azi- 0.70D+02) * rk( 35)
       rk( 35)= 0.8421570000000000D-06+(azi- 0.70D+02) * rk( 35)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 35)=-0.3834374748254757D-09
       rk( 35)= 0.6392774556951159D-08+(azi- 0.78D+02) * rk( 35)
       rk( 35)=-0.4646501056669323D-07+(azi- 0.78D+02) * rk( 35)
       rk( 35)= 0.2213560000000000D-06+(azi- 0.78D+02) * rk( 35)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 35)= 0.8391335736077782D-09
       rk( 35)=-0.2809724838968679D-08+(azi- 0.86D+02) * rk( 35)
       rk( 35)=-0.1780061282185760D-07+(azi- 0.86D+02) * rk( 35)
       rk( 35)= 0.6245350000000000D-07+(azi- 0.86D+02) * rk( 35)
      elseif(azi.ge.90.D0)then
       rk( 35)= 0.0000000000000000D+00
      endif
      if(att.lt.0.99999) rk( 35) = rk( 35) * att
      endif
C
      rk( 36) =  DEXP(-0.2656631037893612D+02
     & - (  0.1600000000000000D+03 )/temp)
      rk( 37) =  0.1100000000000000D-09
      rk( 37) = rk( 37) * SumM * 5.8d-7
      rk( 38) =  DEXP(-0.2592627302369012D+02
     & - (  0.2000000000000000D+04 )/temp)
      rk( 38) = rk( 38) * SumM * 5.8d-7
      rk( 39) =  DEXP(-0.2453997866257023D+02
     & - ( -0.1200000000000000D+03 )/temp)
      rk( 40) =  DEXP(-0.2619593659063922D+02
     & - (  0.2400000000000000D+03 )/temp)
      Effko =  0.6900000000000000D-30* (temp / 3.d2)
     &           **(- ( 0.1000000000000000D+01))
      Rapk =  0.2600000000000000D-10* (temp / 3.d2)
     &            **(- ( 0.0000000000000000D+00))
      rk( 41) = (Effko * SumM / 
     &            ( 1.0d0 + Effko * SumM / Rapk)) *
     &            0.6000D+00** (1.0d0 / (1.0d0 + 
     &             (dlog10(Effko * SumM / Rapk))**2))
      rk( 42) =  DEXP(-0.2375982010502066D+02
     & - ( -0.2500000000000000D+03 )/temp)
      rk( 43) =  DEXP(-0.2422982373426639D+02
     & - ( -0.2000000000000000D+03 )/temp)
      rk( 44) =  DEXP(-0.2729454887930734D+02
     & - (  0.2000000000000000D+04 )/temp)
      rk( 45) =  0.9999999999999999D-11
      rk( 46) =  0.2200000000000000D-10
      rk( 47) =  0.3500000000000000D-11
      rk( 48) =  0.1000000000000000D-16
      rk( 49) =  DEXP(-0.2779354004542632D+02
     & - (  0.2450000000000000D+04 )/temp)
C
      if(option_photolysis.eq.2) then
       rk( 50)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 50)= 0.1850605733273734D-09
       rk( 50)=-0.5514205733273736D-08+(azi- 0.00D+00) * rk( 50)
       rk( 50)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 50)
       rk( 50)= 0.4923370000000000D-05+(azi- 0.00D+00) * rk( 50)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 50)=-0.4192171998211967D-10
       rk( 50)= 0.3761146654746969D-10+(azi- 0.10D+02) * rk( 50)
       rk( 50)=-0.5476594266726266D-07+(azi- 0.10D+02) * rk( 50)
       rk( 50)= 0.4557010000000000D-05+(azi- 0.10D+02) * rk( 50)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 50)= 0.2238630660110397D-10
       rk( 50)=-0.1220040132916125D-08+(azi- 0.20D+02) * rk( 50)
       rk( 50)=-0.6659022933094917D-07+(azi- 0.20D+02) * rk( 50)
       rk( 50)= 0.3971190000000000D-05+(azi- 0.20D+02) * rk( 50)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 50)= 0.1576649357770847D-10
       rk( 50)=-0.5484509348830261D-09+(azi- 0.30D+02) * rk( 50)
       rk( 50)=-0.8427514000894023D-07+(azi- 0.30D+02) * rk( 50)
       rk( 50)= 0.3205670000000000D-05+(azi- 0.30D+02) * rk( 50)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 50)= 0.1206771908806989D-10
       rk( 50)=-0.7545612755185144D-10+(azi- 0.40D+02) * rk( 50)
       rk( 50)=-0.9051421063328874D-07+(azi- 0.40D+02) * rk( 50)
       rk( 50)= 0.2323840000000000D-05+(azi- 0.40D+02) * rk( 50)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 50)= 0.8075863006999223D-10
       rk( 50)= 0.2865754450903247D-09+(azi- 0.50D+02) * rk( 50)
       rk( 50)=-0.8840301745790528D-07+(azi- 0.50D+02) * rk( 50)
       rk( 50)= 0.1423220000000000D-05+(azi- 0.50D+02) * rk( 50)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 50)=-0.8859823936806245D-10
       rk( 50)= 0.2709334347190515D-08+(azi- 0.60D+02) * rk( 50)
       rk( 50)=-0.5844391953509519D-07+(azi- 0.60D+02) * rk( 50)
       rk( 50)= 0.6486060000000000D-06+(azi- 0.60D+02) * rk( 50)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 50)= 0.8567218081942493D-10
       rk( 50)= 0.5138716615245352D-10+(azi- 0.70D+02) * rk( 50)
       rk( 50)=-0.3083670440171124D-07+(azi- 0.70D+02) * rk( 50)
       rk( 50)= 0.2465020000000000D-06+(azi- 0.70D+02) * rk( 50)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 50)=-0.1200567190726544D-09
       rk( 50)= 0.2107519505822040D-08+(azi- 0.78D+02) * rk( 50)
       rk( 50)=-0.1356545102605081D-07+(azi- 0.78D+02) * rk( 50)
       rk( 50)= 0.4696130000000000D-07+(azi- 0.78D+02) * rk( 50)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 50)= 0.1893075627626330D-09
       rk( 50)=-0.7738417520165332D-09+(azi- 0.86D+02) * rk( 50)
       rk( 50)=-0.2896028995606759D-08+(azi- 0.86D+02) * rk( 50)
       rk( 50)= 0.1184990000000000D-07+(azi- 0.86D+02) * rk( 50)
      elseif(azi.ge.90.D0)then
       rk( 50)= 0.0000000000000000D+00
      endif
      if(att.lt.0.99999) rk( 50) = rk( 50) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 51)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 51)= 0.2835620650517077D-10
       rk( 51)=-0.8420820650517078D-09+(azi- 0.00D+00) * rk( 51)
       rk( 51)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 51)
       rk( 51)= 0.7299460000000000D-06+(azi- 0.00D+00) * rk( 51)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 51)=-0.6284619515512310D-11
       rk( 51)= 0.8604130103415510D-11+(azi- 0.10D+02) * rk( 51)
       rk( 51)=-0.8334779349482924D-08+(azi- 0.10D+02) * rk( 51)
       rk( 51)= 0.6740940000000000D-06+(azi- 0.10D+02) * rk( 51)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 51)= 0.3554271556878662D-11
       rk( 51)=-0.1799344553619555D-09+(azi- 0.20D+02) * rk( 51)
       rk( 51)=-0.1004808260206831D-07+(azi- 0.20D+02) * rk( 51)
       rk( 51)= 0.5853220000000000D-06+(azi- 0.20D+02) * rk( 51)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 51)= 0.2431533287998218D-11
       rk( 51)=-0.7330630865559817D-10+(azi- 0.30D+02) * rk( 51)
       rk( 51)=-0.1258049024224377D-07+(azi- 0.30D+02) * rk( 51)
       rk( 51)= 0.4704020000000000D-06+(azi- 0.30D+02) * rk( 51)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 51)= 0.1708595291129147D-11
       rk( 51)=-0.3603100156557604D-12+(azi- 0.40D+02) * rk( 51)
       rk( 51)=-0.1331715642895625D-07+(azi- 0.40D+02) * rk( 51)
       rk( 51)= 0.3396980000000000D-06+(azi- 0.40D+02) * rk( 51)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 51)= 0.1130738554747514D-10
       rk( 51)= 0.5089754871829475D-10+(azi- 0.50D+02) * rk( 51)
       rk( 51)=-0.1281178404193076D-07+(azi- 0.50D+02) * rk( 51)
       rk( 51)= 0.2081990000000000D-06+(azi- 0.50D+02) * rk( 51)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 51)=-0.1318373748097847D-10
       rk( 51)= 0.3901191151423505D-09+(azi- 0.60D+02) * rk( 51)
       rk( 51)=-0.8401617403322399D-08+(azi- 0.60D+02) * rk( 51)
       rk( 51)= 0.9647830000000000D-07+(azi- 0.60D+02) * rk( 51)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 51)= 0.1326701826653411D-10
       rk( 51)=-0.5393009286421154D-11+(azi- 0.70D+02) * rk( 51)
       rk( 51)=-0.4554356344772846D-08+(azi- 0.70D+02) * rk( 51)
       rk( 51)= 0.3829030000000000D-07+(azi- 0.70D+02) * rk( 51)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 51)=-0.1825640932374452D-10
       rk( 51)= 0.3130154291112444D-09+(azi- 0.78D+02) * rk( 51)
       rk( 51)=-0.2093376986187813D-08+(azi- 0.78D+02) * rk( 51)
       rk( 51)= 0.8303010000000000D-08+(azi- 0.78D+02) * rk( 51)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 51)= 0.3315558058273682D-10
       rk( 51)=-0.1251383946687884D-09+(azi- 0.86D+02) * rk( 51)
       rk( 51)=-0.5903607106210601D-09+(azi- 0.86D+02) * rk( 51)
       rk( 51)= 0.2241700000000000D-08+(azi- 0.86D+02) * rk( 51)
      elseif(azi.ge.90.D0)then
       rk( 51)= 0.0000000000000000D+00
      endif
      if(att.lt.0.99999) rk( 51) = rk( 51) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 52)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 52)=-0.1726633761595217D-06
       rk( 52)=-0.3763226238404795D-05+(azi- 0.00D+00) * rk( 52)
       rk( 52)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 52)
       rk( 52)= 0.2758968400000000D-01+(azi- 0.00D+00) * rk( 52)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 52)= 0.8277361284785716D-06
       rk( 52)=-0.8943127523190445D-05+(azi- 0.10D+02) * rk( 52)
       rk( 52)=-0.1270635376159524D-03+(azi- 0.10D+02) * rk( 52)
       rk( 52)= 0.2704069800000000D-01+(azi- 0.10D+02) * rk( 52)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 52)=-0.1363361137754772D-05
       rk( 52)= 0.1588895633116670D-04+(azi- 0.20D+02) * rk( 52)
       rk( 52)=-0.5760524953618990D-04+(azi- 0.20D+02) * rk( 52)
       rk( 52)= 0.2570348600000000D-01+(azi- 0.20D+02) * rk( 52)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 52)= 0.9462274225405240D-06
       rk( 52)=-0.2501187780147645D-04+(azi- 0.30D+02) * rk( 52)
       rk( 52)=-0.1488344642392872D-03+(azi- 0.30D+02) * rk( 52)
       rk( 52)= 0.2535296800000000D-01+(azi- 0.30D+02) * rk( 52)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 52)=-0.2183585524073524D-06
       rk( 52)= 0.3374944874739267D-05+(azi- 0.40D+02) * rk( 52)
       rk( 52)=-0.3652037935066590D-03+(azi- 0.40D+02) * rk( 52)
       rk( 52)= 0.2230966300000000D-01+(azi- 0.40D+02) * rk( 52)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 52)= 0.1378647870888786D-06
       rk( 52)=-0.3175811697481157D-05+(azi- 0.50D+02) * rk( 52)
       rk( 52)=-0.3632124617340762D-03+(azi- 0.50D+02) * rk( 52)
       rk( 52)= 0.1877676100000000D-01+(azi- 0.50D+02) * rk( 52)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 52)=-0.3865635959481289D-06
       rk( 52)= 0.9601319151840079D-06+(azi- 0.60D+02) * rk( 52)
       rk( 52)=-0.3853692595570321D-03+(azi- 0.60D+02) * rk( 52)
       rk( 52)= 0.1496492000000000D-01+(azi- 0.60D+02) * rk( 52)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 52)=-0.1916508555648358D-06
       rk( 52)=-0.1063677596325682D-04+(azi- 0.70D+02) * rk( 52)
       rk( 52)=-0.4821357000377863D-03+(azi- 0.70D+02) * rk( 52)
       rk( 52)= 0.1082067700000000D-01+(azi- 0.70D+02) * rk( 52)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 52)= 0.2540478756918318D-05
       rk( 52)=-0.1523639649680941D-04+(azi- 0.78D+02) * rk( 52)
       rk( 52)=-0.6891210797183578D-03+(azi- 0.78D+02) * rk( 52)
       rk( 52)= 0.6184712500000000D-02+(azi- 0.78D+02) * rk( 52)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 52)= 0.1651057353835306D-05
       rk( 52)= 0.4573509366928574D-04+(azi- 0.86D+02) * rk( 52)
       rk( 52)=-0.4451315023386027D-03+(azi- 0.86D+02) * rk( 52)
       rk( 52)= 0.9973396100000000D-03+(azi- 0.86D+02) * rk( 52)
      elseif(azi.ge.90.D0)then
       rk( 52)= 0.5424277000000000D-04
      endif
      if(att.lt.0.99999) rk( 52) = rk( 52) * att
      endif
C
      rk( 53) =  DEXP(-0.2667550967090111D+02
     & - ( -0.3650000000000000D+03 )/temp)
      rk( 54) =  DEXP(-0.2667550967090111D+02
     & - ( -0.3650000000000000D+03 )/temp)
      rk( 55) =  DEXP(-0.2791870318838033D+02
     & - ( -0.7000000000000000D+03 )/temp)
      rk( 56) =  DEXP(-0.2791870318838033D+02
     & - ( -0.7000000000000000D+03 )/temp)
      rk( 57) =  0.6800000000000000D-13
      rk( 58) =  0.6800000000000000D-13
      rk( 59) =  0.6800000000000000D-13
      rk( 60) =  DEXP(-0.2815865385801092D+02
     & - (  0.3600000000000000D+03 )/temp)
C
      if(option_photolysis.eq.2) then
       rk( 61)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 61)= 0.1169588192958314D-09
       rk( 61)=-0.3496188192958315D-08+(azi- 0.00D+00) * rk( 61)
       rk( 61)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 61)
       rk( 61)= 0.3306320000000000D-05+(azi- 0.00D+00) * rk( 61)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 61)=-0.2706645788749460D-10
       rk( 61)= 0.1257638591662934D-10+(azi- 0.10D+02) * rk( 61)
       rk( 61)=-0.3483611807041687D-07+(azi- 0.10D+02) * rk( 61)
       rk( 61)= 0.3073660000000000D-05+(azi- 0.10D+02) * rk( 61)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 61)= 0.1341701225414685D-10
       rk( 61)=-0.7994173507082115D-09+(azi- 0.20D+02) * rk( 61)
       rk( 61)=-0.4270452771833258D-07+(azi- 0.20D+02) * rk( 61)
       rk( 61)= 0.2699490000000000D-05+(azi- 0.20D+02) * rk( 61)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 61)= 0.9728408870905781D-11
       rk( 61)=-0.3969069830837928D-09+(azi- 0.30D+02) * rk( 61)
       rk( 61)=-0.5466777105625237D-07+(azi- 0.30D+02) * rk( 61)
       rk( 61)= 0.2205920000000000D-05+(azi- 0.30D+02) * rk( 61)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 61)= 0.5679352262236120D-11
       rk( 61)=-0.1050547169566624D-09+(azi- 0.40D+02) * rk( 61)
       rk( 61)=-0.5968738805665679D-07+(azi- 0.40D+02) * rk( 61)
       rk( 61)= 0.1629280000000000D-05+(azi- 0.40D+02) * rk( 61)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 61)= 0.5858118208013745D-10
       rk( 61)= 0.6532585091035501D-10+(azi- 0.50D+02) * rk( 61)
       rk( 61)=-0.6008467671711881D-07+(azi- 0.50D+02) * rk( 61)
       rk( 61)= 0.1027580000000000D-05+(azi- 0.50D+02) * rk( 61)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 61)=-0.6293908058262076D-10
       rk( 61)= 0.1822761313313685D-08+(azi- 0.60D+02) * rk( 61)
       rk( 61)=-0.4120380507487587D-07+(azi- 0.60D+02) * rk( 61)
       rk( 61)= 0.4918470000000000D-06+(azi- 0.60D+02) * rk( 61)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 61)= 0.7100905182188004D-10
       rk( 61)=-0.6541110415900914D-10+(azi- 0.70D+02) * rk( 61)
       rk( 61)=-0.2363030298337316D-07+(azi- 0.70D+02) * rk( 61)
       rk( 61)= 0.1991460000000000D-06+(azi- 0.70D+02) * rk( 61)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 61)=-0.9377314713171188D-10
       rk( 61)= 0.1638806139579664D-08+(azi- 0.78D+02) * rk( 61)
       rk( 61)=-0.1104314270014345D-07+(azi- 0.78D+02) * rk( 61)
       rk( 61)= 0.4227390000000000D-07+(azi- 0.78D+02) * rk( 61)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 61)= 0.1608475801823887D-09
       rk( 61)=-0.6117493915949734D-09+(azi- 0.86D+02) * rk( 61)
       rk( 61)=-0.2826688716211709D-08+(azi- 0.86D+02) * rk( 61)
       rk( 61)= 0.1080050000000000D-07+(azi- 0.86D+02) * rk( 61)
      elseif(azi.ge.90.D0)then
       rk( 61)= 0.0000000000000000D+00
      endif
      if(att.lt.0.99999) rk( 61) = rk( 61) * att
      endif
C
      rk( 62) =  DEXP(-0.2652908103716776D+02
     & - ( -0.1900000000000000D+03 )/temp)
C
      if(option_photolysis.eq.2) then
       rk( 63)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 63)= 0.1455492237670210D-09
       rk( 63)=-0.4424192237670211D-08+(azi- 0.00D+00) * rk( 63)
       rk( 63)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 63)
       rk( 63)= 0.5613540000000000D-05+(azi- 0.00D+00) * rk( 63)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 63)=-0.3745767130106283D-10
       rk( 63)=-0.5771552465957910D-10+(azi- 0.10D+02) * rk( 63)
       rk( 63)=-0.4481907762329791D-07+(azi- 0.10D+02) * rk( 63)
       rk( 63)= 0.5316670000000000D-05+(azi- 0.10D+02) * rk( 63)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 63)= 0.1087146143723073D-10
       rk( 63)=-0.1181445663691473D-08+(azi- 0.20D+02) * rk( 63)
       rk( 63)=-0.5721068950680835D-07+(azi- 0.20D+02) * rk( 63)
       rk( 63)= 0.4825250000000000D-05+(azi- 0.20D+02) * rk( 63)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 63)= 0.9551825552145950D-11
       rk( 63)=-0.8553018205745464D-09+(azi- 0.30D+02) * rk( 63)
       rk( 63)=-0.7757816434946842D-07+(azi- 0.30D+02) * rk( 63)
       rk( 63)= 0.4145870000000000D-05+(azi- 0.30D+02) * rk( 63)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 63)=-0.1084876364581310D-10
       rk( 63)=-0.5687470540102275D-09+(azi- 0.40D+02) * rk( 63)
       rk( 63)=-0.9181865309531611D-07+(azi- 0.40D+02) * rk( 63)
       rk( 63)= 0.3294110000000000D-05+(azi- 0.40D+02) * rk( 63)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 63)= 0.1309432290311127D-09
       rk( 63)=-0.8942099633849118D-09+(azi- 0.50D+02) * rk( 63)
       rk( 63)=-0.1064482232692663D-06+(azi- 0.50D+02) * rk( 63)
       rk( 63)= 0.2308200000000000D-05+(azi- 0.50D+02) * rk( 63)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 63)=-0.1296291524786552D-09
       rk( 63)= 0.3034086907549210D-08+(azi- 0.60D+02) * rk( 63)
       rk( 63)=-0.8504945382761955D-07+(azi- 0.60D+02) * rk( 63)
       rk( 63)= 0.1285240000000000D-05+(azi- 0.60D+02) * rk( 63)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 63)= 0.2265412149160239D-09
       rk( 63)=-0.8547876668062117D-09+(azi- 0.70D+02) * rk( 63)
       rk( 63)=-0.6325646142023192D-07+(azi- 0.70D+02) * rk( 63)
       rk( 63)= 0.6085250000000000D-06+(azi- 0.70D+02) * rk( 63)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 63)=-0.2780378688140548D-09
       rk( 63)= 0.4582201491181749D-08+(azi- 0.78D+02) * rk( 63)
       rk( 63)=-0.3343715082528183D-07+(azi- 0.78D+02) * rk( 63)
       rk( 63)= 0.1637560000000000D-06+(azi- 0.78D+02) * rk( 63)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 63)= 0.6298095137861198D-09
       rk( 63)=-0.2090707360382672D-08+(azi- 0.86D+02) * rk( 63)
       rk( 63)=-0.1350519777867237D-07+(azi- 0.86D+02) * rk( 63)
       rk( 63)= 0.4716430000000000D-07+(azi- 0.86D+02) * rk( 63)
      elseif(azi.ge.90.D0)then
       rk( 63)= 0.0000000000000000D+00
      endif
      if(att.lt.0.99999) rk( 63) = rk( 63) * att
      endif
C
      rk( 64) = 1.44d-13 * (1.0d0 + 2.381d-20 * 
     & 8.0d-1 * SumM)
      rk( 65) =  DEXP(-0.2673493309137191D+02
     & - (  0.1775000000000000D+04 )/temp)
      rk( 66) =  DEXP(-0.2660140169874739D+02
     & - ( -0.3000000000000000D+03 )/temp)
      rk( 67) =  DEXP(-0.2852261923521233D+02
     & - ( -0.7500000000000000D+03 )/temp)
      rk( 68) =  DEXP(-0.2998489950331015D+02
     & - ( -0.3900000000000000D+03 )/temp)
      rk( 69) =  DEXP(-0.2629602004919621D+02
     & - ( -0.2000000000000000D+03 )/temp)
C
      if(option_photolysis.eq.2) then
       rk( 70)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 70)= 0.1455492237670210D-09
       rk( 70)=-0.4424192237670211D-08+(azi- 0.00D+00) * rk( 70)
       rk( 70)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 70)
       rk( 70)= 0.5613540000000000D-05+(azi- 0.00D+00) * rk( 70)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 70)=-0.3745767130106283D-10
       rk( 70)=-0.5771552465957910D-10+(azi- 0.10D+02) * rk( 70)
       rk( 70)=-0.4481907762329791D-07+(azi- 0.10D+02) * rk( 70)
       rk( 70)= 0.5316670000000000D-05+(azi- 0.10D+02) * rk( 70)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 70)= 0.1087146143723073D-10
       rk( 70)=-0.1181445663691473D-08+(azi- 0.20D+02) * rk( 70)
       rk( 70)=-0.5721068950680835D-07+(azi- 0.20D+02) * rk( 70)
       rk( 70)= 0.4825250000000000D-05+(azi- 0.20D+02) * rk( 70)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 70)= 0.9551825552145950D-11
       rk( 70)=-0.8553018205745464D-09+(azi- 0.30D+02) * rk( 70)
       rk( 70)=-0.7757816434946842D-07+(azi- 0.30D+02) * rk( 70)
       rk( 70)= 0.4145870000000000D-05+(azi- 0.30D+02) * rk( 70)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 70)=-0.1084876364581310D-10
       rk( 70)=-0.5687470540102275D-09+(azi- 0.40D+02) * rk( 70)
       rk( 70)=-0.9181865309531611D-07+(azi- 0.40D+02) * rk( 70)
       rk( 70)= 0.3294110000000000D-05+(azi- 0.40D+02) * rk( 70)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 70)= 0.1309432290311127D-09
       rk( 70)=-0.8942099633849118D-09+(azi- 0.50D+02) * rk( 70)
       rk( 70)=-0.1064482232692663D-06+(azi- 0.50D+02) * rk( 70)
       rk( 70)= 0.2308200000000000D-05+(azi- 0.50D+02) * rk( 70)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 70)=-0.1296291524786552D-09
       rk( 70)= 0.3034086907549210D-08+(azi- 0.60D+02) * rk( 70)
       rk( 70)=-0.8504945382761955D-07+(azi- 0.60D+02) * rk( 70)
       rk( 70)= 0.1285240000000000D-05+(azi- 0.60D+02) * rk( 70)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 70)= 0.2265412149160239D-09
       rk( 70)=-0.8547876668062117D-09+(azi- 0.70D+02) * rk( 70)
       rk( 70)=-0.6325646142023192D-07+(azi- 0.70D+02) * rk( 70)
       rk( 70)= 0.6085250000000000D-06+(azi- 0.70D+02) * rk( 70)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 70)=-0.2780378688140548D-09
       rk( 70)= 0.4582201491181749D-08+(azi- 0.78D+02) * rk( 70)
       rk( 70)=-0.3343715082528183D-07+(azi- 0.78D+02) * rk( 70)
       rk( 70)= 0.1637560000000000D-06+(azi- 0.78D+02) * rk( 70)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 70)= 0.6298095137861198D-09
       rk( 70)=-0.2090707360382672D-08+(azi- 0.86D+02) * rk( 70)
       rk( 70)=-0.1350519777867237D-07+(azi- 0.86D+02) * rk( 70)
       rk( 70)= 0.4716430000000000D-07+(azi- 0.86D+02) * rk( 70)
      elseif(azi.ge.90.D0)then
       rk( 70)= 0.0000000000000000D+00
      endif
      if(att.lt.0.99999) rk( 70) = rk( 70) * att
      endif
C
      rk( 71) =  DEXP(-0.2564314676777420D+02
     & - (  0.6200000000000000D+03 )/temp)
      rk( 72) =  0.9000000000000000D-11
C
      if(option_photolysis.eq.2) then
       rk( 73)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 73)=-0.5816837387219519D-10
       rk( 73)=-0.5184316261278087D-08+(azi- 0.00D+00) * rk( 73)
       rk( 73)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 73)
       rk( 73)= 0.3220560000000000D-04+(azi- 0.00D+00) * rk( 73)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 73)= 0.3450512161659949D-10
       rk( 73)=-0.6929367477443941D-08+(azi- 0.10D+02) * rk( 73)
       rk( 73)=-0.1211368373872203D-06+(azi- 0.10D+02) * rk( 73)
       rk( 73)= 0.3162900000000000D-04+(azi- 0.10D+02) * rk( 73)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 73)= 0.3647887405787883D-11
       rk( 73)=-0.5894213828945960D-08+(azi- 0.20D+02) * rk( 73)
       rk( 73)=-0.2493726504511192D-06+(azi- 0.20D+02) * rk( 73)
       rk( 73)= 0.2975920000000000D-04+(azi- 0.20D+02) * rk( 73)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 73)= 0.2530332876025029D-10
       rk( 73)=-0.5784777206772343D-08+(azi- 0.30D+02) * rk( 73)
       rk( 73)=-0.3661625608083018D-06+(azi- 0.30D+02) * rk( 73)
       rk( 73)= 0.2667970000000000D-04+(azi- 0.30D+02) * rk( 73)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 73)= 0.6013879755321277D-10
       rk( 73)=-0.5025677343964861D-08+(azi- 0.40D+02) * rk( 73)
       rk( 73)=-0.4742671063156733D-06+(azi- 0.40D+02) * rk( 73)
       rk( 73)= 0.2246490000000000D-04+(azi- 0.40D+02) * rk( 73)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 73)= 0.1004414810269593D-09
       rk( 73)=-0.3221513417368319D-08+(azi- 0.50D+02) * rk( 73)
       rk( 73)=-0.5567390139290089D-06+(azi- 0.50D+02) * rk( 73)
       rk( 73)= 0.1727980000000000D-04+(azi- 0.50D+02) * rk( 73)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 73)= 0.3107352783389442D-09
       rk( 73)=-0.2082689865616575D-09+(azi- 0.60D+02) * rk( 73)
       rk( 73)=-0.5910368379682989D-06+(azi- 0.60D+02) * rk( 73)
       rk( 73)= 0.1149070000000000D-04+(azi- 0.60D+02) * rk( 73)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 73)= 0.1345128013872392D-09
       rk( 73)= 0.9113789363612173D-08+(azi- 0.70D+02) * rk( 73)
       rk( 73)=-0.5019816341977565D-06+(azi- 0.70D+02) * rk( 73)
       rk( 73)= 0.5870240000000000D-05+(azi- 0.70D+02) * rk( 73)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 73)=-0.1960445509611151D-09
       rk( 73)= 0.1234209659691269D-07+(azi- 0.78D+02) * rk( 73)
       rk( 73)=-0.3303345465135304D-06+(azi- 0.78D+02) * rk( 73)
       rk( 73)= 0.2506540000000000D-05+(azi- 0.78D+02) * rk( 73)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 73)= 0.2279277828298341D-08
       rk( 73)= 0.7637027373778166D-08+(azi- 0.86D+02) * rk( 73)
       rk( 73)=-0.1705015547476783D-06+(azi- 0.86D+02) * rk( 73)
       rk( 73)= 0.5533830000000000D-06+(azi- 0.86D+02) * rk( 73)
      elseif(azi.ge.90.D0)then
       rk( 73)= 0.1394430000000000D-06
      endif
      if(att.lt.0.99999) rk( 73) = rk( 73) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 74)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 74)=-0.7261045436751545D-10
       rk( 74)=-0.5576895456324842D-08+(azi- 0.00D+00) * rk( 74)
       rk( 74)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 74)
       rk( 74)= 0.4669460000000000D-04+(azi- 0.00D+00) * rk( 74)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 74)= 0.2853136310254372D-10
       rk( 74)=-0.7755209087350302D-08+(azi- 0.10D+02) * rk( 74)
       rk( 74)=-0.1333210454367515D-06+(azi- 0.10D+02) * rk( 74)
       rk( 74)= 0.4606430000000000D-04+(azi- 0.10D+02) * rk( 74)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 74)=-0.1901499804265726D-10
       rk( 74)=-0.6899268194273995D-08+(azi- 0.20D+02) * rk( 74)
       rk( 74)=-0.2798658182529944D-06+(azi- 0.20D+02) * rk( 74)
       rk( 74)= 0.4398410000000000D-04+(azi- 0.20D+02) * rk( 74)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 74)=-0.9471370931908783D-11
       rk( 74)=-0.7469718135553710D-08+(azi- 0.30D+02) * rk( 74)
       rk( 74)=-0.4235556815512711D-06+(azi- 0.30D+02) * rk( 74)
       rk( 74)= 0.4047650000000000D-04+(azi- 0.30D+02) * rk( 74)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 74)= 0.1440048177028887D-10
       rk( 74)=-0.7753859263510966D-08+(azi- 0.40D+02) * rk( 74)
       rk( 74)=-0.5757914555419174D-06+(azi- 0.40D+02) * rk( 74)
       rk( 74)= 0.3548450000000000D-04+(azi- 0.40D+02) * rk( 74)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 74)= 0.3856944385081257D-10
       rk( 74)=-0.7321844810402538D-08+(azi- 0.50D+02) * rk( 74)
       rk( 74)=-0.7265484962810543D-06+(azi- 0.50D+02) * rk( 74)
       rk( 74)= 0.2896560000000000D-04+(azi- 0.50D+02) * rk( 74)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 74)= 0.4136217428262900D-09
       rk( 74)=-0.6164761494878585D-08+(azi- 0.60D+02) * rk( 74)
       rk( 74)=-0.8614145593338596D-06+(azi- 0.60D+02) * rk( 74)
       rk( 74)= 0.2100650000000000D-04+(azi- 0.60D+02) * rk( 74)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 74)= 0.5376701572532502D-09
       rk( 74)= 0.6243890789914774D-08+(azi- 0.70D+02) * rk( 74)
       rk( 74)=-0.8606232663835604D-06+(azi- 0.70D+02) * rk( 74)
       rk( 74)= 0.1218950000000000D-04+(azi- 0.70D+02) * rk( 74)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 74)=-0.5508273899935273D-09
       rk( 74)= 0.1914797456399955D-07+(azi- 0.78D+02) * rk( 74)
       rk( 74)=-0.6574883435524898D-06+(azi- 0.78D+02) * rk( 74)
       rk( 74)= 0.5979410000000000D-05+(azi- 0.78D+02) * rk( 74)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 74)= 0.8530305661922505D-08
       rk( 74)= 0.5928117204100688D-08+(azi- 0.86D+02) * rk( 74)
       rk( 74)=-0.4568796094072541D-06+(azi- 0.86D+02) * rk( 74)
       rk( 74)= 0.1662950000000000D-05+(azi- 0.86D+02) * rk( 74)
      elseif(azi.ge.90.D0)then
       rk( 74)= 0.4762210000000000D-06
      endif
      if(att.lt.0.99999) rk( 74) = rk( 74) * att
      endif
C
      rk( 75) =  DEXP(-0.2410466059131239D+02
     & - (  0.1600000000000000D+04 )/temp)
      rk( 76) =  0.5800000000000000D-15
      rk( 77) =  DEXP(-0.3226665050940135D+02
     & - ( -0.6250000000000000D+03 )/temp)
      rk( 78) =  DEXP( 0.2850648985328245D+02
     & - (  0.7000000000000000D+04 )/temp)
      rk( 79) =  0.5600000000000000D-11
      rk( 80) =  DEXP(-0.3281600979716958D+02
     & - ( -0.2300000000000000D+04 )/temp)
      rk( 81) =  0.4000000000000000D-12
      rk( 82) =  DEXP(-0.2474064935803238D+02
     & - (  0.1100000000000000D+04 )/temp)
      rk( 83) =  DEXP(-0.2590825451818744D+02
     & - ( -0.2700000000000000D+03 )/temp)
      rk( 84) =  DEXP(-0.2729454887930734D+02
     & - (  0.1900000000000000D+04 )/temp)
C
      if(option_photolysis.eq.2) then
       rk( 85)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 85)= 0.2380589610091973D-09
       rk( 85)=-0.7081389610091975D-08+(azi- 0.00D+00) * rk( 85)
       rk( 85)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 85)
       rk( 85)= 0.5957230000000000D-05+(azi- 0.00D+00) * rk( 85)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 85)=-0.5308688302759109D-10
       rk( 85)= 0.6037922018394511D-10+(azi- 0.10D+02) * rk( 85)
       rk( 85)=-0.7021010389908028D-07+(azi- 0.10D+02) * rk( 85)
       rk( 85)= 0.5487150000000000D-05+(azi- 0.10D+02) * rk( 85)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 85)= 0.3062857110116430D-10
       rk( 85)=-0.1532227270643788D-08+(azi- 0.20D+02) * rk( 85)
       rk( 85)=-0.8492858440367860D-07+(azi- 0.20D+02) * rk( 85)
       rk( 85)= 0.4738000000000000D-05+(azi- 0.20D+02) * rk( 85)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 85)= 0.2166259862293630D-10
       rk( 85)=-0.6133701376088394D-09+(azi- 0.30D+02) * rk( 85)
       rk( 85)=-0.1063845584862048D-06+(azi- 0.30D+02) * rk( 85)
       rk( 85)= 0.3766120000000000D-05+(azi- 0.30D+02) * rk( 85)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 85)= 0.2104103440710084D-10
       rk( 85)= 0.3650782107930249D-10+(azi- 0.40D+02) * rk( 85)
       rk( 85)=-0.1121531816515012D-06+(azi- 0.40D+02) * rk( 85)
       rk( 85)= 0.2662600000000000D-05+(azi- 0.40D+02) * rk( 85)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 85)= 0.8675826374852520D-10
       rk( 85)= 0.6677388532924337D-09+(azi- 0.50D+02) * rk( 85)
       rk( 85)=-0.1051107149077819D-06+(azi- 0.50D+02) * rk( 85)
       rk( 85)= 0.1565760000000000D-05+(azi- 0.50D+02) * rk( 85)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 85)=-0.1017700894010149D-09
       rk( 85)= 0.3270486765746919D-08+(azi- 0.60D+02) * rk( 85)
       rk( 85)=-0.6572845871737228D-07+(azi- 0.60D+02) * rk( 85)
       rk( 85)= 0.6681850000000000D-06+(azi- 0.60D+02) * rk( 85)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 85)= 0.7628539145252615D-10
       rk( 85)= 0.2173840837156257D-09+(azi- 0.70D+02) * rk( 85)
       rk( 85)=-0.3084975022272650D-07+(azi- 0.70D+02) * rk( 85)
       rk( 85)= 0.2361790000000000D-06+(azi- 0.70D+02) * rk( 85)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 85)=-0.1180751266210847D-09
       rk( 85)= 0.2048233478549148D-08+(azi- 0.78D+02) * rk( 85)
       rk( 85)=-0.1272480972458120D-07+(azi- 0.78D+02) * rk( 85)
       rk( 85)= 0.4235170000000000D-07+(azi- 0.78D+02) * rk( 85)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 85)= 0.1855844762805106D-09
       rk( 85)=-0.7855695603568857D-09+(azi- 0.86D+02) * rk( 85)
       rk( 85)=-0.2623498378609423D-08+(azi- 0.86D+02) * rk( 85)
       rk( 85)= 0.1118570000000000D-07+(azi- 0.86D+02) * rk( 85)
      elseif(azi.ge.90.D0)then
       rk( 85)= 0.0000000000000000D+00
      endif
      if(att.lt.0.99999) rk( 85) = rk( 85) * att
      endif
C
      rk( 86) =  DEXP(-0.2553915705425015D+02
     & - ( -0.2700000000000000D+03 )/temp)
      Effko =  0.2700000000000000D-27* (temp / 3.d2)
     &           **(- ( 0.7100000000000000D+01))
      Rapk =  0.1200000000000000D-10* (temp / 3.d2)
     &            **(- ( 0.9000000000000000D+00))
      rk( 87) = (Effko * SumM / 
     &            ( 1.0d0 + Effko * SumM / Rapk)) *
     &            0.3000D+00** (1.0d0 / (1.0d0 + 
     &             (dlog10(Effko * SumM / Rapk))**2))
      Effko =  0.4900000000000000D-02* (temp / 3.d2)
     &           **(- ( 0.0000000000000000D+00))*
     &           dexp(- 0.1210000000000000D+05/temp)
      Rapk =  0.5400000000000000D+17* (temp / 3.d2)
     &            **(- ( 0.0000000000000000D+00))*
     &           dexp(- 0.1383000000000000D+05/temp)
      rk( 88) = (Effko*SumM / ( 1.0d0 + Effko * SumM / 
     &         Rapk)) * 0.3000D+00** (1.0d0 / (1.0d0 + 
     &          (dlog10(Effko * SumM / Rapk))**2))
C
      if(option_photolysis.eq.2) then
       rk( 89)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 89)=-0.5245828038559129D-12
       rk( 89)=-0.1048523196144091D-10+(azi- 0.00D+00) * rk( 89)
       rk( 89)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 89)
       rk( 89)= 0.4777587000000000D-07+(azi- 0.00D+00) * rk( 89)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 89)= 0.2522760411567752D-11
       rk( 89)=-0.2622271607711829D-10+(azi- 0.10D+02) * rk( 89)
       rk( 89)=-0.3670794803855920D-09+(azi- 0.10D+02) * rk( 89)
       rk( 89)= 0.4620276400000000D-07+(azi- 0.10D+02) * rk( 89)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 89)=-0.3810250842415100D-11
       rk( 89)= 0.4946009626991426D-10+(azi- 0.20D+02) * rk( 89)
       rk( 89)=-0.1347056784576322D-09+(azi- 0.20D+02) * rk( 89)
       rk( 89)= 0.4243245800000000D-07+(azi- 0.20D+02) * rk( 89)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 89)= 0.2339466958092650D-11
       rk( 89)=-0.6484742900253869D-10+(azi- 0.30D+02) * rk( 89)
       rk( 89)=-0.2885790057838769D-09+(azi- 0.30D+02) * rk( 89)
       rk( 89)= 0.4222116000000000D-07+(azi- 0.30D+02) * rk( 89)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 89)= 0.1867501004448772D-13
       rk( 89)= 0.5336579740240855D-11+(azi- 0.40D+02) * rk( 89)
       rk( 89)=-0.8836874984068571D-09+(azi- 0.40D+02) * rk( 89)
       rk( 89)= 0.3519009400000000D-07+(azi- 0.40D+02) * rk( 89)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 89)= 0.8226700172943887D-13
       rk( 89)= 0.5896830041575641D-11+(azi- 0.50D+02) * rk( 89)
       rk( 89)=-0.7713534005886921D-09+(azi- 0.50D+02) * rk( 89)
       rk( 89)= 0.2690555200000000D-07+(azi- 0.50D+02) * rk( 89)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 89)=-0.9853030169627836D-12
       rk( 89)= 0.8364840093458807D-11+(azi- 0.60D+02) * rk( 89)
       rk( 89)=-0.6287366992383443D-09+(azi- 0.60D+02) * rk( 89)
       rk( 89)= 0.1986396800000000D-07+(azi- 0.60D+02) * rk( 89)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 89)= 0.1136116301266380D-11
       rk( 89)=-0.2119425041541064D-10+(azi- 0.70D+02) * rk( 89)
       rk( 89)=-0.7570308024579321D-09+(azi- 0.70D+02) * rk( 89)
       rk( 89)= 0.1342778200000000D-07+(azi- 0.70D+02) * rk( 89)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 89)= 0.1853495648302295D-11
       rk( 89)= 0.6072540815002347D-11+(azi- 0.78D+02) * rk( 89)
       rk( 89)=-0.8780044792615161D-09+(azi- 0.78D+02) * rk( 89)
       rk( 89)= 0.6596795100000000D-08+(azi- 0.78D+02) * rk( 89)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 89)= 0.4275243906997995D-12
       rk( 89)= 0.5055643637423095D-10+(azi- 0.86D+02) * rk( 89)
       rk( 89)=-0.4249726617465909D-09+(azi- 0.86D+02) * rk( 89)
       rk( 89)= 0.9103916500000000D-09+(azi- 0.86D+02) * rk( 89)
      elseif(azi.ge.90.D0)then
       rk( 89)= 0.4676554600000000D-10
      endif
      if(att.lt.0.99999) rk( 89) = rk( 89) * att
      endif
C
      rk( 90) =  DEXP(-0.2847499118622308D+02
     & - ( -0.1040000000000000D+04 )/temp)
      rk( 91) =  DEXP(-0.2693787393536860D+02
     & - ( -0.5000000000000000D+03 )/temp)
      rk( 92) =  DEXP(-0.2845200166799838D+02
     & - ( -0.1070000000000000D+04 )/temp)
      rk( 93) =  DEXP(-0.2656631037893612D+02
     & - ( -0.5000000000000000D+03 )/temp)
      rk( 94) =  DEXP(-0.2854731184780270D+02
     & - ( -0.2000000000000000D+03 )/temp)
C
      if(option_photolysis.eq.2) then
       rk( 95)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 95)= 0.0000000000000000D+00
       rk( 95)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 95)
       rk( 95)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 95)
       rk( 95)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 95)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 95)= 0.0000000000000000D+00
       rk( 95)= 0.0000000000000000D+00+(azi- 0.10D+02) * rk( 95)
       rk( 95)= 0.0000000000000000D+00+(azi- 0.10D+02) * rk( 95)
       rk( 95)= 0.0000000000000000D+00+(azi- 0.10D+02) * rk( 95)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 95)= 0.0000000000000000D+00
       rk( 95)= 0.0000000000000000D+00+(azi- 0.20D+02) * rk( 95)
       rk( 95)= 0.0000000000000000D+00+(azi- 0.20D+02) * rk( 95)
       rk( 95)= 0.0000000000000000D+00+(azi- 0.20D+02) * rk( 95)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 95)= 0.0000000000000000D+00
       rk( 95)= 0.0000000000000000D+00+(azi- 0.30D+02) * rk( 95)
       rk( 95)= 0.0000000000000000D+00+(azi- 0.30D+02) * rk( 95)
       rk( 95)= 0.0000000000000000D+00+(azi- 0.30D+02) * rk( 95)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 95)= 0.0000000000000000D+00
       rk( 95)= 0.0000000000000000D+00+(azi- 0.40D+02) * rk( 95)
       rk( 95)= 0.0000000000000000D+00+(azi- 0.40D+02) * rk( 95)
       rk( 95)= 0.0000000000000000D+00+(azi- 0.40D+02) * rk( 95)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 95)= 0.0000000000000000D+00
       rk( 95)= 0.0000000000000000D+00+(azi- 0.50D+02) * rk( 95)
       rk( 95)= 0.0000000000000000D+00+(azi- 0.50D+02) * rk( 95)
       rk( 95)= 0.0000000000000000D+00+(azi- 0.50D+02) * rk( 95)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 95)= 0.0000000000000000D+00
       rk( 95)= 0.0000000000000000D+00+(azi- 0.60D+02) * rk( 95)
       rk( 95)= 0.0000000000000000D+00+(azi- 0.60D+02) * rk( 95)
       rk( 95)= 0.0000000000000000D+00+(azi- 0.60D+02) * rk( 95)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 95)= 0.0000000000000000D+00
       rk( 95)= 0.0000000000000000D+00+(azi- 0.70D+02) * rk( 95)
       rk( 95)= 0.0000000000000000D+00+(azi- 0.70D+02) * rk( 95)
       rk( 95)= 0.0000000000000000D+00+(azi- 0.70D+02) * rk( 95)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 95)= 0.0000000000000000D+00
       rk( 95)= 0.0000000000000000D+00+(azi- 0.78D+02) * rk( 95)
       rk( 95)= 0.0000000000000000D+00+(azi- 0.78D+02) * rk( 95)
       rk( 95)= 0.0000000000000000D+00+(azi- 0.78D+02) * rk( 95)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 95)= 0.0000000000000000D+00
       rk( 95)= 0.0000000000000000D+00+(azi- 0.86D+02) * rk( 95)
       rk( 95)= 0.0000000000000000D+00+(azi- 0.86D+02) * rk( 95)
       rk( 95)= 0.0000000000000000D+00+(azi- 0.86D+02) * rk( 95)
      elseif(azi.ge.90.D0)then
       rk( 95)= 0.0000000000000000D+00
      endif
      if(att.lt.0.99999) rk( 95) = rk( 95) * att
      endif
C
      rk( 96) =  DEXP(-0.2854731184780270D+02
     & - ( -0.2000000000000000D+03 )/temp)
      rk( 97) =  DEXP(-0.2506607175846701D+02
     & - (  0.8700000000000000D+03 )/temp)
      rk( 98) =  DEXP(-0.2600178057619827D+02
     & - ( -0.4050000000000000D+03 )/temp)
      rk( 99) =  0.6500000000000000D-14
C
      if(option_photolysis.eq.2) then
       rk(100)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk(100)=-0.2543209447272390D-06
       rk(100)=-0.4665430552727591D-05+(azi- 0.00D+00) * rk(100)
       rk(100)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(100)
       rk(100)= 0.2672443200000000D-01+(azi- 0.00D+00) * rk(100)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk(100)= 0.1160138834181708D-05
       rk(100)=-0.1229505889454476D-04+(azi- 0.10D+02) * rk(100)
       rk(100)=-0.1696048944727235D-03+(azi- 0.10D+02) * rk(100)
       rk(100)= 0.2600356800000000D-01+(azi- 0.10D+02) * rk(100)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk(100)=-0.1797915391999585D-05
       rk(100)= 0.2250910613090648D-04+(azi- 0.20D+02) * rk(100)
       rk(100)=-0.6746442210910607D-04+(azi- 0.20D+02) * rk(100)
       rk(100)= 0.2423815200000000D-01+(azi- 0.20D+02) * rk(100)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk(100)= 0.1113225733816626D-05
       rk(100)=-0.3142835562908105D-04+(azi- 0.30D+02) * rk(100)
       rk(100)=-0.1566569170908517D-03+(azi- 0.30D+02) * rk(100)
       rk(100)= 0.2401650300000000D-01+(azi- 0.30D+02) * rk(100)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk(100)=-0.4892354326693738D-07
       rk(100)= 0.1968416385417769D-05+(azi- 0.40D+02) * rk(100)
       rk(100)=-0.4512563095274845D-03+(azi- 0.40D+02) * rk(100)
       rk(100)= 0.2042032400000000D-01+(azi- 0.40D+02) * rk(100)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk(100)= 0.1418524392511286D-06
       rk(100)= 0.5007100874097285D-06+(azi- 0.50D+02) * rk(100)
       rk(100)=-0.4265650447992115D-03+(azi- 0.50D+02) * rk(100)
       rk(100)= 0.1605567900000000D-01+(azi- 0.50D+02) * rk(100)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk(100)=-0.6037011137374412D-06
       rk(100)= 0.4756283264942610D-05+(azi- 0.60D+02) * rk(100)
       rk(100)=-0.3739951112756851D-03+(azi- 0.60D+02) * rk(100)
       rk(100)= 0.1198195200000000D-01+(azi- 0.60D+02) * rk(100)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk(100)= 0.7324219730526701D-06
       rk(100)=-0.1335475014717716D-04+(azi- 0.70D+02) * rk(100)
       rk(100)=-0.4599797800980132D-03+(azi- 0.70D+02) * rk(100)
       rk(100)= 0.8113928100000001D-02+(azi- 0.70D+02) * rk(100)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk(100)= 0.1115677554341943D-05
       rk(100)= 0.4223377206111212D-05+(azi- 0.78D+02) * rk(100)
       rk(100)=-0.5330307636267073D-03+(azi- 0.78D+02) * rk(100)
       rk(100)= 0.3954385900000000D-02+(azi- 0.78D+02) * rk(100)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk(100)= 0.6769853777566226D-07
       rk(100)= 0.3099963851027621D-04+(azi- 0.86D+02) * rk(100)
       rk(100)=-0.2512466378952194D-03+(azi- 0.86D+02) * rk(100)
       rk(100)= 0.5316628400000000D-03+(azi- 0.86D+02) * rk(100)
      elseif(azi.ge.90.D0)then
       rk(100)= 0.2700321100000000D-04
      endif
      if(att.lt.0.99999) rk(100) = rk(100) * att
      endif
C
      rk(101) =  DEXP(-0.2572891358953163D+02
     & - ( -0.3400000000000000D+03 )/temp)
      Effko =  0.2700000000000000D-27* (temp / 3.d2)
     &           **(- ( 0.7100000000000000D+01))
      Rapk =  0.1200000000000000D-10* (temp / 3.d2)
     &            **(- ( 0.9000000000000000D+00))
      rk(102) = (Effko * SumM / 
     &            ( 1.0d0 + Effko * SumM / Rapk)) *
     &            0.3000D+00** (1.0d0 / (1.0d0 + 
     &             (dlog10(Effko * SumM / Rapk))**2))
      Effko =  0.4900000000000000D-02* (temp / 3.d2)
     &           **(- ( 0.0000000000000000D+00))*
     &           dexp(- 0.1210000000000000D+05/temp)
      Rapk =  0.5400000000000000D+17* (temp / 3.d2)
     &            **(- ( 0.0000000000000000D+00))*
     &           dexp(- 0.1383000000000000D+05/temp)
      rk(103) = (Effko*SumM / ( 1.0d0 + Effko * SumM / 
     &         Rapk)) * 0.3000D+00** (1.0d0 / (1.0d0 + 
     &          (dlog10(Effko * SumM / Rapk))**2))
C
      if(option_photolysis.eq.2) then
       rk(104)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk(104)=-0.5245828038559129D-12
       rk(104)=-0.1048523196144091D-10+(azi- 0.00D+00) * rk(104)
       rk(104)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(104)
       rk(104)= 0.4777587000000000D-07+(azi- 0.00D+00) * rk(104)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk(104)= 0.2522760411567752D-11
       rk(104)=-0.2622271607711829D-10+(azi- 0.10D+02) * rk(104)
       rk(104)=-0.3670794803855920D-09+(azi- 0.10D+02) * rk(104)
       rk(104)= 0.4620276400000000D-07+(azi- 0.10D+02) * rk(104)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk(104)=-0.3810250842415100D-11
       rk(104)= 0.4946009626991426D-10+(azi- 0.20D+02) * rk(104)
       rk(104)=-0.1347056784576322D-09+(azi- 0.20D+02) * rk(104)
       rk(104)= 0.4243245800000000D-07+(azi- 0.20D+02) * rk(104)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk(104)= 0.2339466958092650D-11
       rk(104)=-0.6484742900253869D-10+(azi- 0.30D+02) * rk(104)
       rk(104)=-0.2885790057838769D-09+(azi- 0.30D+02) * rk(104)
       rk(104)= 0.4222116000000000D-07+(azi- 0.30D+02) * rk(104)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk(104)= 0.1867501004448772D-13
       rk(104)= 0.5336579740240855D-11+(azi- 0.40D+02) * rk(104)
       rk(104)=-0.8836874984068571D-09+(azi- 0.40D+02) * rk(104)
       rk(104)= 0.3519009400000000D-07+(azi- 0.40D+02) * rk(104)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk(104)= 0.8226700172943887D-13
       rk(104)= 0.5896830041575641D-11+(azi- 0.50D+02) * rk(104)
       rk(104)=-0.7713534005886921D-09+(azi- 0.50D+02) * rk(104)
       rk(104)= 0.2690555200000000D-07+(azi- 0.50D+02) * rk(104)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk(104)=-0.9853030169627836D-12
       rk(104)= 0.8364840093458807D-11+(azi- 0.60D+02) * rk(104)
       rk(104)=-0.6287366992383443D-09+(azi- 0.60D+02) * rk(104)
       rk(104)= 0.1986396800000000D-07+(azi- 0.60D+02) * rk(104)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk(104)= 0.1136116301266380D-11
       rk(104)=-0.2119425041541064D-10+(azi- 0.70D+02) * rk(104)
       rk(104)=-0.7570308024579321D-09+(azi- 0.70D+02) * rk(104)
       rk(104)= 0.1342778200000000D-07+(azi- 0.70D+02) * rk(104)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk(104)= 0.1853495648302295D-11
       rk(104)= 0.6072540815002347D-11+(azi- 0.78D+02) * rk(104)
       rk(104)=-0.8780044792615161D-09+(azi- 0.78D+02) * rk(104)
       rk(104)= 0.6596795100000000D-08+(azi- 0.78D+02) * rk(104)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk(104)= 0.4275243906997995D-12
       rk(104)= 0.5055643637423095D-10+(azi- 0.86D+02) * rk(104)
       rk(104)=-0.4249726617465909D-09+(azi- 0.86D+02) * rk(104)
       rk(104)= 0.9103916500000000D-09+(azi- 0.86D+02) * rk(104)
      elseif(azi.ge.90.D0)then
       rk(104)= 0.4676554600000000D-10
      endif
      if(att.lt.0.99999) rk(104) = rk(104) * att
      endif
C
      rk(105) =  0.3000000000000000D-12
      rk(106) =  DEXP(-0.2847499118622308D+02
     & - ( -0.1040000000000000D+04 )/temp)
      rk(107) =  DEXP(-0.2693787393536860D+02
     & - ( -0.5000000000000000D+03 )/temp)
      rk(108) =  DEXP(-0.2845200166799838D+02
     & - ( -0.1070000000000000D+04 )/temp)
      rk(109) =  DEXP(-0.2656631037893612D+02
     & - ( -0.5000000000000000D+03 )/temp)
      rk(110) =  DEXP(-0.2656631037893612D+02
     & - ( -0.5000000000000000D+03 )/temp)
      rk(111) =  0.8100000000000000D-12
      rk(112) =  DEXP( 0.3453877639491068D+02
     & - (  0.8000000000000000D+04 )/temp)
      rk(113) =  0.1600000000000000D+04
      rk(114) =  0.1500000000000000D-10
      rk(115) =  DEXP(-0.2531848569208134D+02
     & - (  0.2800000000000000D+03 )/temp)
      rk(116) =  0.3200000000000000D-10
      rk(117) =  DEXP(-0.3266697421800909D+02
     & - (  0.1900000000000000D+04 )/temp)
      rk(118) =  DEXP(-0.2798769605986728D+02
     & - (  0.2160000000000000D+04 )/temp)
      rk(119) =  DEXP(-0.2499196378631329D+02
     & - (  0.7920000000000000D+03 )/temp)
      Effko =  0.1000000000000000D-27* (temp / 3.d2)
     &           **(- ( 0.8000000000000000D+00))
      Rapk =  0.8800000000000000D-11* (temp / 3.d2)
     &            **(- ( 0.0000000000000000D+00))
      rk(120) = (Effko * SumM / 
     &            ( 1.0d0 + Effko * SumM / Rapk)) *
     &            0.6000D+00** (1.0d0 / (1.0d0 + 
     &             (dlog10(Effko * SumM / Rapk))**2))
      rk(121) =  DEXP(-0.3205386974512268D+02
     & - (  0.2630000000000000D+04 )/temp)
      rk(122) =  DEXP(-0.2643709864745611D+02
     & - (  0.2880000000000000D+04 )/temp)
      rk(123) =  0.2300000000000000D-10
      rk(124) =  DEXP(-0.2532843602293450D+02
     & - ( -0.5500000000000000D+03 )/temp)
      rk(125) =  DEXP(-0.3241054468906142D+02
     & - (  0.1100000000000000D+04 )/temp)
      rk(126) =  DEXP(-0.2767184311044880D+02
     & - (  0.2700000000000000D+03 )/temp)
      rk(127) =  DEXP(-0.2704323445102643D+02
     & - ( -0.3550000000000000D+03 )/temp)
      rk(128) =  0.8100000000000000D-11
      rk(129) =  0.4200000000000000D+01
      rk(130) =  0.4100000000000000D-10
      rk(131) =  0.2200000000000000D-10
      rk(132) =  0.1400000000000000D-10
      rk(133) =  0.5500000000000000D-11
C
      if(option_photolysis.eq.2) then
       rk(134)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk(134)=-0.8584948998100693D-09
       rk(134)=-0.6414505100189953D-07+(azi- 0.00D+00) * rk(134)
       rk(134)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(134)
       rk(134)= 0.5609260000000000D-03+(azi- 0.00D+00) * rk(134)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk(134)= 0.3254846994303392D-09
       rk(134)=-0.8989989799620162D-07+(azi- 0.10D+02) * rk(134)
       rk(134)=-0.1540449489981011D-05+(azi- 0.10D+02) * rk(134)
       rk(134)= 0.5536530000000000D-03+(azi- 0.10D+02) * rk(134)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk(134)=-0.2454438979115351D-09
       rk(134)=-0.8013535701329145D-07+(azi- 0.20D+02) * rk(134)
       rk(134)=-0.3240802040075941D-05+(azi- 0.20D+02) * rk(134)
       rk(134)= 0.5295840000000000D-03+(azi- 0.20D+02) * rk(134)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk(134)=-0.1557091077839579D-09
       rk(134)=-0.8749867395063711D-07+(azi- 0.30D+02) * rk(134)
       rk(134)=-0.4917142349715225D-05+(azi- 0.30D+02) * rk(134)
       rk(134)= 0.4889170000000000D-03+(azi- 0.30D+02) * rk(134)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk(134)= 0.5928032904741575D-10
       rk(134)=-0.9216994718415690D-07+(azi- 0.40D+02) * rk(134)
       rk(134)=-0.6713828561063159D-05+(azi- 0.40D+02) * rk(134)
       rk(134)= 0.4308400000000000D-03+(azi- 0.40D+02) * rk(134)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk(134)= 0.2595877915944963D-09
       rk(134)=-0.9039153731273486D-07+(azi- 0.50D+02) * rk(134)
       rk(134)=-0.8539443406032087D-05+(azi- 0.50D+02) * rk(134)
       rk(134)= 0.3545440000000000D-03+(azi- 0.50D+02) * rk(134)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk(134)= 0.4590368504578084D-08
       rk(134)=-0.8260390356490844D-07+(azi- 0.60D+02) * rk(134)
       rk(134)=-0.1026939781480858D-04+(azi- 0.60D+02) * rk(134)
       rk(134)= 0.2603700000000000D-03+(azi- 0.60D+02) * rk(134)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk(134)= 0.7530009721131077D-08
       rk(134)= 0.5510715157249846D-07+(azi- 0.70D+02) * rk(134)
       rk(134)=-0.1054436533473309D-04+(azi- 0.70D+02) * rk(134)
       rk(134)= 0.1540060000000000D-03+(azi- 0.70D+02) * rk(134)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk(134)=-0.7917656811272118D-08
       rk(134)= 0.2358273848796985D-06+(azi- 0.78D+02) * rk(134)
       rk(134)=-0.8216889043116161D-05+(azi- 0.78D+02) * rk(134)
       rk(134)= 0.7703330000000000D-04+(azi- 0.78D+02) * rk(134)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk(134)= 0.1166127504485630D-06
       rk(134)= 0.4580362140873401D-07+(azi- 0.86D+02) * rk(134)
       rk(134)=-0.5963840992804365D-05+(azi- 0.86D+02) * rk(134)
       rk(134)= 0.2233730000000000D-04+(azi- 0.86D+02) * rk(134)
      elseif(azi.ge.90.D0)then
       rk(134)= 0.6678010000000000D-05
      endif
      if(att.lt.0.99999) rk(134) = rk(134) * att
      endif
C
      rk(135) =  0.3000000000000000D-10
      rk(136) =  DEXP(-0.3745754762732854D+02
     & - (  0.5000000000000000D+03 )/temp)
      rk(137) =  DEXP(-0.2479780777187233D+02
     & - ( -0.1160000000000000D+03 )/temp)
      rk(138) =  0.1700000000000000D-10
C
      if(option_photolysis.eq.2) then
       rk(139)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk(139)=-0.1826021023809213D-09
       rk(139)=-0.1228397897619082D-07+(azi- 0.00D+00) * rk(139)
       rk(139)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(139)
       rk(139)= 0.1204770000000000D-03+(azi- 0.00D+00) * rk(139)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk(139)= 0.7680630714277358D-10
       rk(139)=-0.1776204204761847D-07+(azi- 0.10D+02) * rk(139)
       rk(139)=-0.3004602102380929D-06+(azi- 0.10D+02) * rk(139)
       rk(139)= 0.1190660000000000D-03+(azi- 0.10D+02) * rk(139)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk(139)=-0.4662312619017368D-10
       rk(139)=-0.1545785283333527D-07+(azi- 0.20D+02) * rk(139)
       rk(139)=-0.6326591590476302D-06+(azi- 0.20D+02) * rk(139)
       rk(139)= 0.1143620000000000D-03+(azi- 0.20D+02) * rk(139)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk(139)=-0.3391380238206294D-10
       rk(139)=-0.1685654661904045D-07+(azi- 0.30D+02) * rk(139)
       rk(139)=-0.9558031535713878D-06+(azi- 0.30D+02) * rk(139)
       rk(139)= 0.1064430000000000D-03+(azi- 0.30D+02) * rk(139)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk(139)=-0.3482166428159112D-10
       rk(139)=-0.1787396069050238D-07+(azi- 0.40D+02) * rk(139)
       rk(139)=-0.1303108226666818D-05+(azi- 0.40D+02) * rk(139)
       rk(139)= 0.9516540000000000D-04+(azi- 0.40D+02) * rk(139)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk(139)=-0.9419954049165213D-10
       rk(139)=-0.1891861061895016D-07+(azi- 0.50D+02) * rk(139)
       rk(139)=-0.1671033939761339D-05+(azi- 0.50D+02) * rk(139)
       rk(139)= 0.8031210000000001D-04+(azi- 0.50D+02) * rk(139)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk(139)= 0.4307198262473663D-09
       rk(139)=-0.2174459683369613D-07+(azi- 0.60D+02) * rk(139)
       rk(139)=-0.2077666014287802D-05+(azi- 0.60D+02) * rk(139)
       rk(139)= 0.6161569999999999D-04+(azi- 0.60D+02) * rk(139)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk(139)= 0.1932828429018806D-08
       rk(139)=-0.8823002046250573D-08+(azi- 0.70D+02) * rk(139)
       rk(139)=-0.2383342003087316D-05+(azi- 0.70D+02) * rk(139)
       rk(139)= 0.3909530000000000D-04+(azi- 0.70D+02) * rk(139)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk(139)= 0.7078805396671869D-10
       rk(139)= 0.3756488025025498D-07+(azi- 0.78D+02) * rk(139)
       rk(139)=-0.2153406977455823D-05+(azi- 0.78D+02) * rk(139)
       rk(139)= 0.2045350000000000D-04+(azi- 0.78D+02) * rk(139)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk(139)= 0.2551390080685143D-07
       rk(139)= 0.3926379354523939D-07+(azi- 0.86D+02) * rk(139)
       rk(139)=-0.1538777587090784D-05+(azi- 0.86D+02) * rk(139)
       rk(139)= 0.5666640000000000D-05+(azi- 0.86D+02) * rk(139)
      elseif(azi.ge.90.D0)then
       rk(139)= 0.1772640000000000D-05
      endif
      if(att.lt.0.99999) rk(139) = rk(139) * att
      endif
C
      rk(140) =  0.3600000000000000D-10
      rk(141) =  DEXP(-0.2439627194190406D+02
     & - ( -0.4076000000000000D+03 )/temp)
      rk(142) =  DEXP(-0.3247698978846957D+02
     & - (  0.1912000000000000D+04 )/temp)
      rk(143) =  DEXP(-0.2652245849640727D+02
     & - (  0.4480000000000000D+03 )/temp)
      rk(144) =  0.3360000000000000D-10
      rk(145) =  0.7100000000000001D-17
      rk(146) =  0.1000000000000000D-14
C
      if(option_photolysis.eq.2) then
       rk(147)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk(147)=-0.2724056225766411D-11
       rk(147)=-0.2068594377423350D-09+(azi- 0.00D+00) * rk(147)
       rk(147)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(147)
       rk(147)= 0.1769770000000000D-05+(azi- 0.00D+00) * rk(147)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk(147)= 0.1042168677298912D-11
       rk(147)=-0.2885811245153273D-09+(azi- 0.10D+02) * rk(147)
       rk(147)=-0.4954405622576623D-08+(azi- 0.10D+02) * rk(147)
       rk(147)= 0.1746360000000000D-05+(azi- 0.10D+02) * rk(147)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk(147)=-0.7346184834290850D-12
       rk(147)=-0.2573160641963604D-09+(azi- 0.20D+02) * rk(147)
       rk(147)=-0.1041337750969350D-07+(azi- 0.20D+02) * rk(147)
       rk(147)= 0.1669000000000000D-05+(azi- 0.20D+02) * rk(147)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk(147)=-0.4136947435822000D-12
       rk(147)=-0.2793546186992334D-09+(azi- 0.30D+02) * rk(147)
       rk(147)=-0.1578008433864942D-07+(azi- 0.30D+02) * rk(147)
       rk(147)= 0.1538400000000000D-05+(azi- 0.30D+02) * rk(147)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk(147)= 0.3593974577559286D-12
       rk(147)=-0.2917654610066926D-09+(azi- 0.40D+02) * rk(147)
       rk(147)=-0.2149128513570870D-07+(azi- 0.40D+02) * rk(147)
       rk(147)= 0.1352250000000000D-05+(azi- 0.40D+02) * rk(147)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk(147)= 0.1158104912559730D-11
       rk(147)=-0.2809835372740098D-09+(azi- 0.50D+02) * rk(147)
       rk(147)=-0.2721877511851595D-07+(azi- 0.50D+02) * rk(147)
       rk(147)= 0.1108520000000000D-05+(azi- 0.50D+02) * rk(147)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk(147)= 0.1481218289200588D-10
       rk(147)=-0.2462403898971914D-09+(azi- 0.60D+02) * rk(147)
       rk(147)=-0.3249101439022863D-07+(azi- 0.60D+02) * rk(147)
       rk(147)= 0.8093920000000000D-06+(azi- 0.60D+02) * rk(147)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk(147)= 0.2251236790098139D-10
       rk(147)= 0.1981250968631836D-09+(azi- 0.70D+02) * rk(147)
       rk(147)=-0.3297216732056966D-07+(azi- 0.70D+02) * rk(147)
       rk(147)= 0.4746700000000000D-06+(azi- 0.70D+02) * rk(147)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk(147)=-0.2282006684570455D-10
       rk(147)= 0.7384219264865253D-09+(azi- 0.78D+02) * rk(147)
       rk(147)=-0.2547979113377114D-07+(azi- 0.78D+02) * rk(147)
       rk(147)= 0.2350990000000000D-06+(azi- 0.78D+02) * rk(147)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk(147)= 0.3441785534773510D-09
       rk(147)= 0.1907403221845338D-09+(azi- 0.86D+02) * rk(147)
       rk(147)=-0.1804649314436201D-07+(azi- 0.86D+02) * rk(147)
       rk(147)= 0.6683580000000001D-07+(azi- 0.86D+02) * rk(147)
      elseif(azi.ge.90.D0)then
       rk(147)= 0.1972910000000000D-07
      endif
      if(att.lt.0.99999) rk(147) = rk(147) * att
      endif
C
      rk(148) =  0.3600000000000000D-10
      rk(149) =  DEXP(-0.2492297091482634D+02
     & - ( -0.4490000000000000D+03 )/temp)
      rk(150) =  DEXP(-0.3435645483811673D+02
     & - (  0.8210000000000000D+03 )/temp)
      rk(151) =  DEXP(-0.2632268829627837D+02
     & - ( -0.1750000000000000D+03 )/temp)
      Effko =  0.3300000000000000D-30* (temp / 3.d2)
     &           **(- ( 0.3300000000000000D+01))
      Rapk =  0.1500000000000000D-11* (temp / 3.d2)
     &            **(- ( 0.0000000000000000D+00))
      rk(152) = (Effko * SumM / 
     &            ( 1.0d0 + Effko * SumM / Rapk)) *
     &            0.6000D+00** (1.0d0 / (1.0d0 + 
     &             (dlog10(Effko * SumM / Rapk))**2))
      rk(153) =  DEXP(-0.2569949970432533D+02
     & - (  0.2300000000000000D+03 )/temp)
      rk(154) =  DEXP(-0.2546769809026801D+02
     & - (  0.1070000000000000D+04 )/temp)
      rk(155) =  0.1500000000000000D-18
 
      RETURN
      END
 
