C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C     
C     This file is part of the air quality modeling system Polyphemus.
C    
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C    
C     Polyphemus is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C     
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C     
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C
C------------------------------------------------------------------------

      SUBROUTINE LU_solve_tr_racm2 (ns, M, x)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine solves M^t * y = x where M is an LU factorization
C     computed by LU_decompose.
C     This routine is automatically generated by "LU.cpp".
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     ns: matrix row number from the chemical species number.
C     M: LU factorization computed by LU_decompose.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     x: on entry, the right-hand side of the equation. On exit,
C     the solution of the equation.
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

      INTEGER ns
      DOUBLE PRECISION M(ns,ns)
      DOUBLE PRECISION x(ns)
      DOUBLE PRECISION temp


C     Forward substitution.

      temp = M(17, 39) * x(17)
      x(39) = x(39) - temp

      temp = M(29, 47) * x(29)
      x(47) = x(47) - temp

      temp = M(47, 48) * x(47)
      x(48) = x(48) - temp

      temp = M(48, 53) * x(48)
      temp = temp + M(51, 53) * x(51)
      x(53) = x(53) - temp

      temp = M(45, 54) * x(45)
      temp = temp + M(46, 54) * x(46)
      x(54) = x(54) - temp

      temp = M(47, 55) * x(47)
      temp = temp + M(48, 55) * x(48)
      temp = temp + M(49, 55) * x(49)
      temp = temp + M(51, 55) * x(51)
      x(55) = x(55) - temp

      temp = M(25, 59) * x(25)
      temp = temp + M(39, 59) * x(39)
      x(59) = x(59) - temp

      temp = M(58, 60) * x(58)
      x(60) = x(60) - temp

      temp = M(32, 69) * x(32)
      temp = temp + M(33, 69) * x(33)
      temp = temp + M(38, 69) * x(38)
      x(69) = x(69) - temp

      temp = M(70, 71) * x(70)
      x(71) = x(71) - temp

      temp = M(67, 78) * x(67)
      temp = temp + M(74, 78) * x(74)
      x(78) = x(78) - temp

      temp = M(67, 80) * x(67)
      x(80) = x(80) - temp

      temp = M(1, 81) * x(1)
      temp = temp + M(19, 81) * x(19)
      temp = temp + M(20, 81) * x(20)
      temp = temp + M(22, 81) * x(22)
      temp = temp + M(23, 81) * x(23)
      temp = temp + M(26, 81) * x(26)
      temp = temp + M(27, 81) * x(27)
      temp = temp + M(31, 81) * x(31)
      temp = temp + M(32, 81) * x(32)
      temp = temp + M(33, 81) * x(33)
      temp = temp + M(38, 81) * x(38)
      temp = temp + M(39, 81) * x(39)
      temp = temp + M(44, 81) * x(44)
      temp = temp + M(57, 81) * x(57)
      temp = temp + M(58, 81) * x(58)
      temp = temp + M(59, 81) * x(59)
      temp = temp + M(60, 81) * x(60)
      temp = temp + M(61, 81) * x(61)
      temp = temp + M(65, 81) * x(65)
      temp = temp + M(66, 81) * x(66)
      temp = temp + M(67, 81) * x(67)
      temp = temp + M(68, 81) * x(68)
      temp = temp + M(69, 81) * x(69)
      temp = temp + M(70, 81) * x(70)
      temp = temp + M(71, 81) * x(71)
      temp = temp + M(72, 81) * x(72)
      temp = temp + M(73, 81) * x(73)
      temp = temp + M(74, 81) * x(74)
      temp = temp + M(78, 81) * x(78)
      temp = temp + M(79, 81) * x(79)
      temp = temp + M(80, 81) * x(80)
      x(81) = x(81) - temp

      temp = M(81, 83) * x(81)
      temp = temp + M(82, 83) * x(82)
      x(83) = x(83) - temp

      temp = M(30, 86) * x(30)
      temp = temp + M(58, 86) * x(58)
      temp = temp + M(64, 86) * x(64)
      temp = temp + M(65, 86) * x(65)
      temp = temp + M(77, 86) * x(77)
      temp = temp + M(85, 86) * x(85)
      x(86) = x(86) - temp

      temp = M(24, 88) * x(24)
      x(88) = x(88) - temp

      temp = M(77, 92) * x(77)
      temp = temp + M(85, 92) * x(85)
      temp = temp + M(87, 92) * x(87)
      temp = temp + M(89, 92) * x(89)
      temp = temp + M(91, 92) * x(91)
      x(92) = x(92) - temp

      temp = M(28, 95) * x(28)
      temp = temp + M(40, 95) * x(40)
      temp = temp + M(73, 95) * x(73)
      temp = temp + M(85, 95) * x(85)
      temp = temp + M(87, 95) * x(87)
      temp = temp + M(89, 95) * x(89)
      temp = temp + M(93, 95) * x(93)
      temp = temp + M(94, 95) * x(94)
      x(95) = x(95) - temp

      temp = M(90, 97) * x(90)
      temp = temp + M(91, 97) * x(91)
      temp = temp + M(94, 97) * x(94)
      temp = temp + M(96, 97) * x(96)
      x(97) = x(97) - temp

      temp = M(37, 98) * x(37)
      temp = temp + M(74, 98) * x(74)
      temp = temp + M(97, 98) * x(97)
      x(98) = x(98) - temp

      temp = M(58, 99) * x(58)
      temp = temp + M(65, 99) * x(65)
      temp = temp + M(85, 99) * x(85)
      temp = temp + M(87, 99) * x(87)
      temp = temp + M(89, 99) * x(89)
      temp = temp + M(91, 99) * x(91)
      temp = temp + M(94, 99) * x(94)
      temp = temp + M(96, 99) * x(96)
      temp = temp + M(97, 99) * x(97)
      x(99) = x(99) - temp

      temp = M(21, 100) * x(21)
      temp = temp + M(24, 100) * x(24)
      temp = temp + M(34, 100) * x(34)
      temp = temp + M(41, 100) * x(41)
      temp = temp + M(42, 100) * x(42)
      temp = temp + M(43, 100) * x(43)
      temp = temp + M(45, 100) * x(45)
      temp = temp + M(46, 100) * x(46)
      temp = temp + M(47, 100) * x(47)
      temp = temp + M(48, 100) * x(48)
      temp = temp + M(49, 100) * x(49)
      temp = temp + M(50, 100) * x(50)
      temp = temp + M(51, 100) * x(51)
      temp = temp + M(52, 100) * x(52)
      temp = temp + M(53, 100) * x(53)
      temp = temp + M(54, 100) * x(54)
      temp = temp + M(55, 100) * x(55)
      temp = temp + M(56, 100) * x(56)
      temp = temp + M(57, 100) * x(57)
      temp = temp + M(58, 100) * x(58)
      temp = temp + M(59, 100) * x(59)
      temp = temp + M(60, 100) * x(60)
      temp = temp + M(61, 100) * x(61)
      temp = temp + M(62, 100) * x(62)
      temp = temp + M(63, 100) * x(63)
      temp = temp + M(64, 100) * x(64)
      temp = temp + M(65, 100) * x(65)
      temp = temp + M(66, 100) * x(66)
      temp = temp + M(67, 100) * x(67)
      temp = temp + M(68, 100) * x(68)
      temp = temp + M(69, 100) * x(69)
      temp = temp + M(70, 100) * x(70)
      temp = temp + M(71, 100) * x(71)
      temp = temp + M(72, 100) * x(72)
      temp = temp + M(73, 100) * x(73)
      temp = temp + M(75, 100) * x(75)
      temp = temp + M(76, 100) * x(76)
      temp = temp + M(77, 100) * x(77)
      temp = temp + M(78, 100) * x(78)
      temp = temp + M(79, 100) * x(79)
      temp = temp + M(80, 100) * x(80)
      temp = temp + M(81, 100) * x(81)
      temp = temp + M(82, 100) * x(82)
      temp = temp + M(83, 100) * x(83)
      temp = temp + M(84, 100) * x(84)
      temp = temp + M(85, 100) * x(85)
      temp = temp + M(86, 100) * x(86)
      temp = temp + M(87, 100) * x(87)
      temp = temp + M(88, 100) * x(88)
      temp = temp + M(89, 100) * x(89)
      temp = temp + M(90, 100) * x(90)
      temp = temp + M(91, 100) * x(91)
      temp = temp + M(92, 100) * x(92)
      temp = temp + M(93, 100) * x(93)
      temp = temp + M(94, 100) * x(94)
      temp = temp + M(95, 100) * x(95)
      temp = temp + M(96, 100) * x(96)
      temp = temp + M(97, 100) * x(97)
      temp = temp + M(98, 100) * x(98)
      temp = temp + M(99, 100) * x(99)
      x(100) = x(100) - temp

      temp = M(100, 101) * x(100)
      x(101) = x(101) - temp

      temp = M(15, 102) * x(15)
      temp = temp + M(30, 102) * x(30)
      temp = temp + M(39, 102) * x(39)
      temp = temp + M(41, 102) * x(41)
      temp = temp + M(42, 102) * x(42)
      temp = temp + M(43, 102) * x(43)
      temp = temp + M(44, 102) * x(44)
      temp = temp + M(45, 102) * x(45)
      temp = temp + M(46, 102) * x(46)
      temp = temp + M(47, 102) * x(47)
      temp = temp + M(48, 102) * x(48)
      temp = temp + M(49, 102) * x(49)
      temp = temp + M(50, 102) * x(50)
      temp = temp + M(51, 102) * x(51)
      temp = temp + M(52, 102) * x(52)
      temp = temp + M(53, 102) * x(53)
      temp = temp + M(54, 102) * x(54)
      temp = temp + M(55, 102) * x(55)
      temp = temp + M(56, 102) * x(56)
      temp = temp + M(57, 102) * x(57)
      temp = temp + M(58, 102) * x(58)
      temp = temp + M(59, 102) * x(59)
      temp = temp + M(60, 102) * x(60)
      temp = temp + M(61, 102) * x(61)
      temp = temp + M(62, 102) * x(62)
      temp = temp + M(63, 102) * x(63)
      temp = temp + M(64, 102) * x(64)
      temp = temp + M(65, 102) * x(65)
      temp = temp + M(66, 102) * x(66)
      temp = temp + M(67, 102) * x(67)
      temp = temp + M(68, 102) * x(68)
      temp = temp + M(69, 102) * x(69)
      temp = temp + M(70, 102) * x(70)
      temp = temp + M(71, 102) * x(71)
      temp = temp + M(72, 102) * x(72)
      temp = temp + M(73, 102) * x(73)
      temp = temp + M(75, 102) * x(75)
      temp = temp + M(76, 102) * x(76)
      temp = temp + M(77, 102) * x(77)
      temp = temp + M(78, 102) * x(78)
      temp = temp + M(79, 102) * x(79)
      temp = temp + M(80, 102) * x(80)
      temp = temp + M(81, 102) * x(81)
      temp = temp + M(82, 102) * x(82)
      temp = temp + M(83, 102) * x(83)
      temp = temp + M(84, 102) * x(84)
      temp = temp + M(85, 102) * x(85)
      temp = temp + M(86, 102) * x(86)
      temp = temp + M(87, 102) * x(87)
      temp = temp + M(88, 102) * x(88)
      temp = temp + M(89, 102) * x(89)
      temp = temp + M(90, 102) * x(90)
      temp = temp + M(91, 102) * x(91)
      temp = temp + M(92, 102) * x(92)
      temp = temp + M(93, 102) * x(93)
      temp = temp + M(94, 102) * x(94)
      temp = temp + M(95, 102) * x(95)
      temp = temp + M(96, 102) * x(96)
      temp = temp + M(97, 102) * x(97)
      temp = temp + M(98, 102) * x(98)
      temp = temp + M(99, 102) * x(99)
      temp = temp + M(100, 102) * x(100)
      temp = temp + M(101, 102) * x(101)
      x(102) = x(102) - temp

      temp = M(92, 103) * x(92)
      temp = temp + M(93, 103) * x(93)
      temp = temp + M(94, 103) * x(94)
      temp = temp + M(96, 103) * x(96)
      temp = temp + M(97, 103) * x(97)
      temp = temp + M(100, 103) * x(100)
      temp = temp + M(101, 103) * x(101)
      temp = temp + M(102, 103) * x(102)
      x(103) = x(103) - temp

      temp = M(21, 104) * x(21)
      temp = temp + M(87, 104) * x(87)
      temp = temp + M(89, 104) * x(89)
      temp = temp + M(94, 104) * x(94)
      temp = temp + M(96, 104) * x(96)
      temp = temp + M(97, 104) * x(97)
      temp = temp + M(100, 104) * x(100)
      temp = temp + M(101, 104) * x(101)
      temp = temp + M(102, 104) * x(102)
      temp = temp + M(103, 104) * x(103)
      x(104) = x(104) - temp

      temp = M(35, 105) * x(35)
      temp = temp + M(41, 105) * x(41)
      temp = temp + M(42, 105) * x(42)
      temp = temp + M(43, 105) * x(43)
      temp = temp + M(45, 105) * x(45)
      temp = temp + M(46, 105) * x(46)
      temp = temp + M(47, 105) * x(47)
      temp = temp + M(48, 105) * x(48)
      temp = temp + M(49, 105) * x(49)
      temp = temp + M(50, 105) * x(50)
      temp = temp + M(51, 105) * x(51)
      temp = temp + M(52, 105) * x(52)
      temp = temp + M(53, 105) * x(53)
      temp = temp + M(54, 105) * x(54)
      temp = temp + M(55, 105) * x(55)
      temp = temp + M(56, 105) * x(56)
      temp = temp + M(57, 105) * x(57)
      temp = temp + M(58, 105) * x(58)
      temp = temp + M(59, 105) * x(59)
      temp = temp + M(60, 105) * x(60)
      temp = temp + M(61, 105) * x(61)
      temp = temp + M(62, 105) * x(62)
      temp = temp + M(63, 105) * x(63)
      temp = temp + M(64, 105) * x(64)
      temp = temp + M(65, 105) * x(65)
      temp = temp + M(66, 105) * x(66)
      temp = temp + M(67, 105) * x(67)
      temp = temp + M(68, 105) * x(68)
      temp = temp + M(69, 105) * x(69)
      temp = temp + M(70, 105) * x(70)
      temp = temp + M(71, 105) * x(71)
      temp = temp + M(72, 105) * x(72)
      temp = temp + M(73, 105) * x(73)
      temp = temp + M(74, 105) * x(74)
      temp = temp + M(75, 105) * x(75)
      temp = temp + M(76, 105) * x(76)
      temp = temp + M(77, 105) * x(77)
      temp = temp + M(78, 105) * x(78)
      temp = temp + M(79, 105) * x(79)
      temp = temp + M(80, 105) * x(80)
      temp = temp + M(81, 105) * x(81)
      temp = temp + M(82, 105) * x(82)
      temp = temp + M(83, 105) * x(83)
      temp = temp + M(84, 105) * x(84)
      temp = temp + M(85, 105) * x(85)
      temp = temp + M(86, 105) * x(86)
      temp = temp + M(87, 105) * x(87)
      temp = temp + M(88, 105) * x(88)
      temp = temp + M(89, 105) * x(89)
      temp = temp + M(90, 105) * x(90)
      temp = temp + M(91, 105) * x(91)
      temp = temp + M(92, 105) * x(92)
      temp = temp + M(93, 105) * x(93)
      temp = temp + M(94, 105) * x(94)
      temp = temp + M(95, 105) * x(95)
      temp = temp + M(96, 105) * x(96)
      temp = temp + M(97, 105) * x(97)
      temp = temp + M(98, 105) * x(98)
      temp = temp + M(99, 105) * x(99)
      temp = temp + M(100, 105) * x(100)
      temp = temp + M(101, 105) * x(101)
      temp = temp + M(102, 105) * x(102)
      temp = temp + M(103, 105) * x(103)
      temp = temp + M(104, 105) * x(104)
      x(105) = x(105) - temp

      temp = M(99, 106) * x(99)
      temp = temp + M(100, 106) * x(100)
      temp = temp + M(101, 106) * x(101)
      temp = temp + M(102, 106) * x(102)
      temp = temp + M(103, 106) * x(103)
      temp = temp + M(104, 106) * x(104)
      temp = temp + M(105, 106) * x(105)
      x(106) = x(106) - temp

      temp = M(94, 107) * x(94)
      temp = temp + M(96, 107) * x(96)
      temp = temp + M(98, 107) * x(98)
      temp = temp + M(100, 107) * x(100)
      temp = temp + M(101, 107) * x(101)
      temp = temp + M(102, 107) * x(102)
      temp = temp + M(103, 107) * x(103)
      temp = temp + M(104, 107) * x(104)
      temp = temp + M(105, 107) * x(105)
      temp = temp + M(106, 107) * x(106)
      x(107) = x(107) - temp

      temp = M(94, 108) * x(94)
      temp = temp + M(96, 108) * x(96)
      x(108) = x(108) - temp

      temp = M(16, 109) * x(16)
      temp = temp + M(18, 109) * x(18)
      temp = temp + M(19, 109) * x(19)
      temp = temp + M(20, 109) * x(20)
      temp = temp + M(22, 109) * x(22)
      temp = temp + M(23, 109) * x(23)
      temp = temp + M(26, 109) * x(26)
      temp = temp + M(27, 109) * x(27)
      temp = temp + M(29, 109) * x(29)
      temp = temp + M(31, 109) * x(31)
      temp = temp + M(32, 109) * x(32)
      temp = temp + M(33, 109) * x(33)
      temp = temp + M(38, 109) * x(38)
      temp = temp + M(39, 109) * x(39)
      temp = temp + M(40, 109) * x(40)
      temp = temp + M(41, 109) * x(41)
      temp = temp + M(42, 109) * x(42)
      temp = temp + M(43, 109) * x(43)
      temp = temp + M(44, 109) * x(44)
      temp = temp + M(45, 109) * x(45)
      temp = temp + M(46, 109) * x(46)
      temp = temp + M(47, 109) * x(47)
      temp = temp + M(48, 109) * x(48)
      temp = temp + M(49, 109) * x(49)
      temp = temp + M(50, 109) * x(50)
      temp = temp + M(51, 109) * x(51)
      temp = temp + M(52, 109) * x(52)
      temp = temp + M(53, 109) * x(53)
      temp = temp + M(54, 109) * x(54)
      temp = temp + M(55, 109) * x(55)
      temp = temp + M(56, 109) * x(56)
      temp = temp + M(57, 109) * x(57)
      temp = temp + M(58, 109) * x(58)
      temp = temp + M(59, 109) * x(59)
      temp = temp + M(60, 109) * x(60)
      temp = temp + M(61, 109) * x(61)
      temp = temp + M(62, 109) * x(62)
      temp = temp + M(63, 109) * x(63)
      temp = temp + M(64, 109) * x(64)
      temp = temp + M(65, 109) * x(65)
      temp = temp + M(66, 109) * x(66)
      temp = temp + M(67, 109) * x(67)
      temp = temp + M(68, 109) * x(68)
      temp = temp + M(69, 109) * x(69)
      temp = temp + M(70, 109) * x(70)
      temp = temp + M(71, 109) * x(71)
      temp = temp + M(72, 109) * x(72)
      temp = temp + M(73, 109) * x(73)
      temp = temp + M(75, 109) * x(75)
      temp = temp + M(76, 109) * x(76)
      temp = temp + M(77, 109) * x(77)
      temp = temp + M(78, 109) * x(78)
      temp = temp + M(79, 109) * x(79)
      temp = temp + M(80, 109) * x(80)
      temp = temp + M(81, 109) * x(81)
      temp = temp + M(82, 109) * x(82)
      temp = temp + M(83, 109) * x(83)
      temp = temp + M(84, 109) * x(84)
      temp = temp + M(85, 109) * x(85)
      temp = temp + M(86, 109) * x(86)
      temp = temp + M(87, 109) * x(87)
      temp = temp + M(88, 109) * x(88)
      temp = temp + M(89, 109) * x(89)
      temp = temp + M(90, 109) * x(90)
      temp = temp + M(91, 109) * x(91)
      temp = temp + M(92, 109) * x(92)
      temp = temp + M(93, 109) * x(93)
      temp = temp + M(94, 109) * x(94)
      temp = temp + M(95, 109) * x(95)
      temp = temp + M(96, 109) * x(96)
      temp = temp + M(97, 109) * x(97)
      temp = temp + M(98, 109) * x(98)
      temp = temp + M(99, 109) * x(99)
      temp = temp + M(100, 109) * x(100)
      temp = temp + M(101, 109) * x(101)
      temp = temp + M(102, 109) * x(102)
      temp = temp + M(103, 109) * x(103)
      temp = temp + M(104, 109) * x(104)
      temp = temp + M(105, 109) * x(105)
      temp = temp + M(106, 109) * x(106)
      temp = temp + M(107, 109) * x(107)
      temp = temp + M(108, 109) * x(108)
      x(109) = x(109) - temp

      temp = M(16, 110) * x(16)
      temp = temp + M(35, 110) * x(35)
      temp = temp + M(36, 110) * x(36)
      temp = temp + M(37, 110) * x(37)
      temp = temp + M(40, 110) * x(40)
      temp = temp + M(44, 110) * x(44)
      temp = temp + M(46, 110) * x(46)
      temp = temp + M(48, 110) * x(48)
      temp = temp + M(51, 110) * x(51)
      temp = temp + M(73, 110) * x(73)
      temp = temp + M(75, 110) * x(75)
      temp = temp + M(76, 110) * x(76)
      temp = temp + M(81, 110) * x(81)
      temp = temp + M(82, 110) * x(82)
      temp = temp + M(83, 110) * x(83)
      temp = temp + M(84, 110) * x(84)
      temp = temp + M(85, 110) * x(85)
      temp = temp + M(87, 110) * x(87)
      temp = temp + M(88, 110) * x(88)
      temp = temp + M(89, 110) * x(89)
      temp = temp + M(91, 110) * x(91)
      temp = temp + M(92, 110) * x(92)
      temp = temp + M(93, 110) * x(93)
      temp = temp + M(94, 110) * x(94)
      temp = temp + M(95, 110) * x(95)
      temp = temp + M(96, 110) * x(96)
      temp = temp + M(97, 110) * x(97)
      temp = temp + M(98, 110) * x(98)
      temp = temp + M(100, 110) * x(100)
      temp = temp + M(101, 110) * x(101)
      temp = temp + M(102, 110) * x(102)
      temp = temp + M(103, 110) * x(103)
      temp = temp + M(104, 110) * x(104)
      temp = temp + M(105, 110) * x(105)
      temp = temp + M(106, 110) * x(106)
      temp = temp + M(107, 110) * x(107)
      temp = temp + M(108, 110) * x(108)
      temp = temp + M(109, 110) * x(109)
      x(110) = x(110) - temp

      temp = M(25, 111) * x(25)
      temp = temp + M(28, 111) * x(28)
      temp = temp + M(34, 111) * x(34)
      temp = temp + M(36, 111) * x(36)
      temp = temp + M(38, 111) * x(38)
      temp = temp + M(47, 111) * x(47)
      temp = temp + M(48, 111) * x(48)
      temp = temp + M(51, 111) * x(51)
      temp = temp + M(55, 111) * x(55)
      temp = temp + M(56, 111) * x(56)
      temp = temp + M(57, 111) * x(57)
      temp = temp + M(58, 111) * x(58)
      temp = temp + M(59, 111) * x(59)
      temp = temp + M(60, 111) * x(60)
      temp = temp + M(61, 111) * x(61)
      temp = temp + M(62, 111) * x(62)
      temp = temp + M(63, 111) * x(63)
      temp = temp + M(64, 111) * x(64)
      temp = temp + M(65, 111) * x(65)
      temp = temp + M(66, 111) * x(66)
      temp = temp + M(67, 111) * x(67)
      temp = temp + M(68, 111) * x(68)
      temp = temp + M(69, 111) * x(69)
      temp = temp + M(70, 111) * x(70)
      temp = temp + M(71, 111) * x(71)
      temp = temp + M(72, 111) * x(72)
      temp = temp + M(73, 111) * x(73)
      temp = temp + M(74, 111) * x(74)
      temp = temp + M(75, 111) * x(75)
      temp = temp + M(76, 111) * x(76)
      temp = temp + M(77, 111) * x(77)
      temp = temp + M(78, 111) * x(78)
      temp = temp + M(79, 111) * x(79)
      temp = temp + M(80, 111) * x(80)
      temp = temp + M(81, 111) * x(81)
      temp = temp + M(82, 111) * x(82)
      temp = temp + M(83, 111) * x(83)
      temp = temp + M(84, 111) * x(84)
      temp = temp + M(85, 111) * x(85)
      temp = temp + M(86, 111) * x(86)
      temp = temp + M(87, 111) * x(87)
      temp = temp + M(88, 111) * x(88)
      temp = temp + M(89, 111) * x(89)
      temp = temp + M(90, 111) * x(90)
      temp = temp + M(91, 111) * x(91)
      temp = temp + M(92, 111) * x(92)
      temp = temp + M(93, 111) * x(93)
      temp = temp + M(94, 111) * x(94)
      temp = temp + M(95, 111) * x(95)
      temp = temp + M(96, 111) * x(96)
      temp = temp + M(97, 111) * x(97)
      temp = temp + M(98, 111) * x(98)
      temp = temp + M(99, 111) * x(99)
      temp = temp + M(100, 111) * x(100)
      temp = temp + M(101, 111) * x(101)
      temp = temp + M(102, 111) * x(102)
      temp = temp + M(103, 111) * x(103)
      temp = temp + M(104, 111) * x(104)
      temp = temp + M(105, 111) * x(105)
      temp = temp + M(106, 111) * x(106)
      temp = temp + M(107, 111) * x(107)
      temp = temp + M(108, 111) * x(108)
      temp = temp + M(109, 111) * x(109)
      temp = temp + M(110, 111) * x(110)
      x(111) = x(111) - temp

      temp = M(2, 112) * x(2)
      temp = temp + M(3, 112) * x(3)
      temp = temp + M(4, 112) * x(4)
      temp = temp + M(5, 112) * x(5)
      temp = temp + M(6, 112) * x(6)
      temp = temp + M(7, 112) * x(7)
      temp = temp + M(8, 112) * x(8)
      temp = temp + M(9, 112) * x(9)
      temp = temp + M(10, 112) * x(10)
      temp = temp + M(11, 112) * x(11)
      temp = temp + M(12, 112) * x(12)
      temp = temp + M(13, 112) * x(13)
      temp = temp + M(14, 112) * x(14)
      temp = temp + M(15, 112) * x(15)
      temp = temp + M(17, 112) * x(17)
      temp = temp + M(18, 112) * x(18)
      temp = temp + M(19, 112) * x(19)
      temp = temp + M(20, 112) * x(20)
      temp = temp + M(21, 112) * x(21)
      temp = temp + M(22, 112) * x(22)
      temp = temp + M(23, 112) * x(23)
      temp = temp + M(24, 112) * x(24)
      temp = temp + M(25, 112) * x(25)
      temp = temp + M(26, 112) * x(26)
      temp = temp + M(27, 112) * x(27)
      temp = temp + M(28, 112) * x(28)
      temp = temp + M(29, 112) * x(29)
      temp = temp + M(30, 112) * x(30)
      temp = temp + M(31, 112) * x(31)
      temp = temp + M(32, 112) * x(32)
      temp = temp + M(33, 112) * x(33)
      temp = temp + M(34, 112) * x(34)
      temp = temp + M(35, 112) * x(35)
      temp = temp + M(36, 112) * x(36)
      temp = temp + M(37, 112) * x(37)
      temp = temp + M(38, 112) * x(38)
      temp = temp + M(39, 112) * x(39)
      temp = temp + M(40, 112) * x(40)
      temp = temp + M(41, 112) * x(41)
      temp = temp + M(42, 112) * x(42)
      temp = temp + M(43, 112) * x(43)
      temp = temp + M(44, 112) * x(44)
      temp = temp + M(47, 112) * x(47)
      temp = temp + M(48, 112) * x(48)
      temp = temp + M(49, 112) * x(49)
      temp = temp + M(50, 112) * x(50)
      temp = temp + M(51, 112) * x(51)
      temp = temp + M(52, 112) * x(52)
      temp = temp + M(53, 112) * x(53)
      temp = temp + M(54, 112) * x(54)
      temp = temp + M(55, 112) * x(55)
      temp = temp + M(56, 112) * x(56)
      temp = temp + M(57, 112) * x(57)
      temp = temp + M(58, 112) * x(58)
      temp = temp + M(59, 112) * x(59)
      temp = temp + M(60, 112) * x(60)
      temp = temp + M(61, 112) * x(61)
      temp = temp + M(62, 112) * x(62)
      temp = temp + M(63, 112) * x(63)
      temp = temp + M(64, 112) * x(64)
      temp = temp + M(65, 112) * x(65)
      temp = temp + M(66, 112) * x(66)
      temp = temp + M(67, 112) * x(67)
      temp = temp + M(68, 112) * x(68)
      temp = temp + M(69, 112) * x(69)
      temp = temp + M(70, 112) * x(70)
      temp = temp + M(71, 112) * x(71)
      temp = temp + M(72, 112) * x(72)
      temp = temp + M(73, 112) * x(73)
      temp = temp + M(74, 112) * x(74)
      temp = temp + M(75, 112) * x(75)
      temp = temp + M(76, 112) * x(76)
      temp = temp + M(77, 112) * x(77)
      temp = temp + M(78, 112) * x(78)
      temp = temp + M(79, 112) * x(79)
      temp = temp + M(80, 112) * x(80)
      temp = temp + M(81, 112) * x(81)
      temp = temp + M(82, 112) * x(82)
      temp = temp + M(83, 112) * x(83)
      temp = temp + M(84, 112) * x(84)
      temp = temp + M(85, 112) * x(85)
      temp = temp + M(86, 112) * x(86)
      temp = temp + M(87, 112) * x(87)
      temp = temp + M(88, 112) * x(88)
      temp = temp + M(89, 112) * x(89)
      temp = temp + M(90, 112) * x(90)
      temp = temp + M(91, 112) * x(91)
      temp = temp + M(92, 112) * x(92)
      temp = temp + M(93, 112) * x(93)
      temp = temp + M(94, 112) * x(94)
      temp = temp + M(95, 112) * x(95)
      temp = temp + M(96, 112) * x(96)
      temp = temp + M(97, 112) * x(97)
      temp = temp + M(98, 112) * x(98)
      temp = temp + M(99, 112) * x(99)
      temp = temp + M(100, 112) * x(100)
      temp = temp + M(101, 112) * x(101)
      temp = temp + M(102, 112) * x(102)
      temp = temp + M(103, 112) * x(103)
      temp = temp + M(104, 112) * x(104)
      temp = temp + M(105, 112) * x(105)
      temp = temp + M(106, 112) * x(106)
      temp = temp + M(107, 112) * x(107)
      temp = temp + M(108, 112) * x(108)
      temp = temp + M(109, 112) * x(109)
      temp = temp + M(110, 112) * x(110)
      temp = temp + M(111, 112) * x(111)
      x(112) = x(112) - temp

      temp = M(99, 113) * x(99)
      temp = temp + M(100, 113) * x(100)
      temp = temp + M(101, 113) * x(101)
      temp = temp + M(102, 113) * x(102)
      temp = temp + M(103, 113) * x(103)
      temp = temp + M(104, 113) * x(104)
      temp = temp + M(105, 113) * x(105)
      temp = temp + M(106, 113) * x(106)
      temp = temp + M(107, 113) * x(107)
      temp = temp + M(108, 113) * x(108)
      temp = temp + M(109, 113) * x(109)
      temp = temp + M(110, 113) * x(110)
      temp = temp + M(111, 113) * x(111)
      temp = temp + M(112, 113) * x(112)
      x(113) = x(113) - temp


C     Backward substitution.

      x(113) = x(113) / M(113, 113)

      temp = M(113, 112) * x(113)
      x(112) = ( x(112) - temp ) / M(112, 112)

      temp = M(112, 111) * x(112)
      temp = temp + M(113, 111) * x(113)
      x(111) = ( x(111) - temp ) / M(111, 111)

      temp = M(111, 110) * x(111)
      temp = temp + M(112, 110) * x(112)
      temp = temp + M(113, 110) * x(113)
      x(110) = ( x(110) - temp ) / M(110, 110)

      temp = M(110, 109) * x(110)
      temp = temp + M(111, 109) * x(111)
      temp = temp + M(112, 109) * x(112)
      temp = temp + M(113, 109) * x(113)
      x(109) = ( x(109) - temp ) / M(109, 109)

      temp = M(109, 108) * x(109)
      temp = temp + M(110, 108) * x(110)
      temp = temp + M(111, 108) * x(111)
      temp = temp + M(112, 108) * x(112)
      x(108) = ( x(108) - temp ) / M(108, 108)

      temp = M(108, 107) * x(108)
      temp = temp + M(109, 107) * x(109)
      temp = temp + M(110, 107) * x(110)
      temp = temp + M(111, 107) * x(111)
      temp = temp + M(112, 107) * x(112)
      temp = temp + M(113, 107) * x(113)
      x(107) = ( x(107) - temp ) / M(107, 107)

      temp = M(107, 106) * x(107)
      temp = temp + M(108, 106) * x(108)
      temp = temp + M(109, 106) * x(109)
      temp = temp + M(110, 106) * x(110)
      temp = temp + M(111, 106) * x(111)
      temp = temp + M(112, 106) * x(112)
      temp = temp + M(113, 106) * x(113)
      x(106) = ( x(106) - temp ) / M(106, 106)

      temp = M(106, 105) * x(106)
      temp = temp + M(107, 105) * x(107)
      temp = temp + M(108, 105) * x(108)
      temp = temp + M(109, 105) * x(109)
      temp = temp + M(110, 105) * x(110)
      temp = temp + M(111, 105) * x(111)
      temp = temp + M(112, 105) * x(112)
      temp = temp + M(113, 105) * x(113)
      x(105) = ( x(105) - temp ) / M(105, 105)

      temp = M(105, 104) * x(105)
      temp = temp + M(106, 104) * x(106)
      temp = temp + M(107, 104) * x(107)
      temp = temp + M(108, 104) * x(108)
      temp = temp + M(109, 104) * x(109)
      temp = temp + M(110, 104) * x(110)
      temp = temp + M(111, 104) * x(111)
      temp = temp + M(112, 104) * x(112)
      temp = temp + M(113, 104) * x(113)
      x(104) = ( x(104) - temp ) / M(104, 104)

      temp = M(104, 103) * x(104)
      temp = temp + M(105, 103) * x(105)
      temp = temp + M(106, 103) * x(106)
      temp = temp + M(107, 103) * x(107)
      temp = temp + M(108, 103) * x(108)
      temp = temp + M(109, 103) * x(109)
      temp = temp + M(110, 103) * x(110)
      temp = temp + M(111, 103) * x(111)
      temp = temp + M(112, 103) * x(112)
      temp = temp + M(113, 103) * x(113)
      x(103) = ( x(103) - temp ) / M(103, 103)

      temp = M(103, 102) * x(103)
      temp = temp + M(104, 102) * x(104)
      temp = temp + M(105, 102) * x(105)
      temp = temp + M(106, 102) * x(106)
      temp = temp + M(107, 102) * x(107)
      temp = temp + M(108, 102) * x(108)
      temp = temp + M(109, 102) * x(109)
      temp = temp + M(110, 102) * x(110)
      temp = temp + M(111, 102) * x(111)
      temp = temp + M(112, 102) * x(112)
      temp = temp + M(113, 102) * x(113)
      x(102) = ( x(102) - temp ) / M(102, 102)

      temp = M(102, 101) * x(102)
      temp = temp + M(103, 101) * x(103)
      temp = temp + M(104, 101) * x(104)
      temp = temp + M(105, 101) * x(105)
      temp = temp + M(106, 101) * x(106)
      temp = temp + M(107, 101) * x(107)
      temp = temp + M(108, 101) * x(108)
      temp = temp + M(109, 101) * x(109)
      temp = temp + M(110, 101) * x(110)
      temp = temp + M(111, 101) * x(111)
      temp = temp + M(112, 101) * x(112)
      temp = temp + M(113, 101) * x(113)
      x(101) = ( x(101) - temp ) / M(101, 101)

      temp = M(101, 100) * x(101)
      temp = temp + M(102, 100) * x(102)
      temp = temp + M(103, 100) * x(103)
      temp = temp + M(104, 100) * x(104)
      temp = temp + M(105, 100) * x(105)
      temp = temp + M(106, 100) * x(106)
      temp = temp + M(107, 100) * x(107)
      temp = temp + M(108, 100) * x(108)
      temp = temp + M(109, 100) * x(109)
      temp = temp + M(110, 100) * x(110)
      temp = temp + M(111, 100) * x(111)
      temp = temp + M(112, 100) * x(112)
      temp = temp + M(113, 100) * x(113)
      x(100) = ( x(100) - temp ) / M(100, 100)

      temp = M(100, 99) * x(100)
      temp = temp + M(101, 99) * x(101)
      temp = temp + M(102, 99) * x(102)
      temp = temp + M(103, 99) * x(103)
      temp = temp + M(104, 99) * x(104)
      temp = temp + M(105, 99) * x(105)
      temp = temp + M(106, 99) * x(106)
      temp = temp + M(107, 99) * x(107)
      temp = temp + M(108, 99) * x(108)
      temp = temp + M(109, 99) * x(109)
      temp = temp + M(110, 99) * x(110)
      temp = temp + M(111, 99) * x(111)
      temp = temp + M(112, 99) * x(112)
      temp = temp + M(113, 99) * x(113)
      x(99) = ( x(99) - temp ) / M(99, 99)

      temp = M(100, 98) * x(100)
      temp = temp + M(101, 98) * x(101)
      temp = temp + M(102, 98) * x(102)
      temp = temp + M(104, 98) * x(104)
      temp = temp + M(105, 98) * x(105)
      temp = temp + M(106, 98) * x(106)
      temp = temp + M(108, 98) * x(108)
      temp = temp + M(109, 98) * x(109)
      temp = temp + M(110, 98) * x(110)
      temp = temp + M(111, 98) * x(111)
      temp = temp + M(112, 98) * x(112)
      x(98) = ( x(98) - temp ) / M(98, 98)

      temp = M(100, 97) * x(100)
      temp = temp + M(102, 97) * x(102)
      temp = temp + M(105, 97) * x(105)
      temp = temp + M(106, 97) * x(106)
      temp = temp + M(108, 97) * x(108)
      temp = temp + M(109, 97) * x(109)
      temp = temp + M(110, 97) * x(110)
      temp = temp + M(111, 97) * x(111)
      temp = temp + M(112, 97) * x(112)
      x(97) = ( x(97) - temp ) / M(97, 97)

      temp = M(111, 96) * x(111)
      temp = temp + M(112, 96) * x(112)
      x(96) = ( x(96) - temp ) / M(96, 96)

      temp = M(96, 95) * x(96)
      temp = temp + M(97, 95) * x(97)
      temp = temp + M(100, 95) * x(100)
      temp = temp + M(102, 95) * x(102)
      temp = temp + M(105, 95) * x(105)
      temp = temp + M(107, 95) * x(107)
      temp = temp + M(108, 95) * x(108)
      temp = temp + M(109, 95) * x(109)
      temp = temp + M(110, 95) * x(110)
      temp = temp + M(111, 95) * x(111)
      temp = temp + M(112, 95) * x(112)
      x(95) = ( x(95) - temp ) / M(95, 95)

      temp = M(109, 94) * x(109)
      temp = temp + M(110, 94) * x(110)
      temp = temp + M(112, 94) * x(112)
      x(94) = ( x(94) - temp ) / M(94, 94)

      temp = M(94, 93) * x(94)
      temp = temp + M(96, 93) * x(96)
      temp = temp + M(105, 93) * x(105)
      temp = temp + M(109, 93) * x(109)
      temp = temp + M(111, 93) * x(111)
      temp = temp + M(112, 93) * x(112)
      x(93) = ( x(93) - temp ) / M(93, 93)

      temp = M(93, 92) * x(93)
      temp = temp + M(94, 92) * x(94)
      temp = temp + M(96, 92) * x(96)
      temp = temp + M(97, 92) * x(97)
      temp = temp + M(100, 92) * x(100)
      temp = temp + M(101, 92) * x(101)
      temp = temp + M(102, 92) * x(102)
      temp = temp + M(105, 92) * x(105)
      temp = temp + M(106, 92) * x(106)
      temp = temp + M(107, 92) * x(107)
      temp = temp + M(108, 92) * x(108)
      temp = temp + M(109, 92) * x(109)
      temp = temp + M(110, 92) * x(110)
      temp = temp + M(111, 92) * x(111)
      temp = temp + M(112, 92) * x(112)
      x(92) = ( x(92) - temp ) / M(92, 92)

      temp = M(94, 91) * x(94)
      temp = temp + M(96, 91) * x(96)
      temp = temp + M(108, 91) * x(108)
      temp = temp + M(109, 91) * x(109)
      temp = temp + M(111, 91) * x(111)
      temp = temp + M(112, 91) * x(112)
      x(91) = ( x(91) - temp ) / M(91, 91)

      temp = M(91, 90) * x(91)
      temp = temp + M(100, 90) * x(100)
      temp = temp + M(102, 90) * x(102)
      temp = temp + M(105, 90) * x(105)
      temp = temp + M(106, 90) * x(106)
      temp = temp + M(108, 90) * x(108)
      temp = temp + M(109, 90) * x(109)
      temp = temp + M(110, 90) * x(110)
      temp = temp + M(111, 90) * x(111)
      x(90) = ( x(90) - temp ) / M(90, 90)

      temp = M(108, 89) * x(108)
      temp = temp + M(111, 89) * x(111)
      temp = temp + M(112, 89) * x(112)
      x(89) = ( x(89) - temp ) / M(89, 89)

      temp = M(89, 88) * x(89)
      temp = temp + M(97, 88) * x(97)
      temp = temp + M(100, 88) * x(100)
      temp = temp + M(102, 88) * x(102)
      temp = temp + M(105, 88) * x(105)
      temp = temp + M(106, 88) * x(106)
      temp = temp + M(107, 88) * x(107)
      temp = temp + M(108, 88) * x(108)
      temp = temp + M(109, 88) * x(109)
      temp = temp + M(110, 88) * x(110)
      temp = temp + M(111, 88) * x(111)
      temp = temp + M(112, 88) * x(112)
      x(88) = ( x(88) - temp ) / M(88, 88)

      temp = M(94, 87) * x(94)
      temp = temp + M(96, 87) * x(96)
      temp = temp + M(100, 87) * x(100)
      temp = temp + M(105, 87) * x(105)
      temp = temp + M(109, 87) * x(109)
      temp = temp + M(111, 87) * x(111)
      temp = temp + M(112, 87) * x(112)
      x(87) = ( x(87) - temp ) / M(87, 87)

      temp = M(87, 86) * x(87)
      temp = temp + M(89, 86) * x(89)
      temp = temp + M(91, 86) * x(91)
      temp = temp + M(93, 86) * x(93)
      temp = temp + M(96, 86) * x(96)
      temp = temp + M(97, 86) * x(97)
      temp = temp + M(100, 86) * x(100)
      temp = temp + M(101, 86) * x(101)
      temp = temp + M(102, 86) * x(102)
      temp = temp + M(103, 86) * x(103)
      temp = temp + M(104, 86) * x(104)
      temp = temp + M(105, 86) * x(105)
      temp = temp + M(106, 86) * x(106)
      temp = temp + M(107, 86) * x(107)
      temp = temp + M(108, 86) * x(108)
      temp = temp + M(109, 86) * x(109)
      temp = temp + M(110, 86) * x(110)
      temp = temp + M(111, 86) * x(111)
      temp = temp + M(112, 86) * x(112)
      temp = temp + M(113, 86) * x(113)
      x(86) = ( x(86) - temp ) / M(86, 86)

      temp = M(87, 85) * x(87)
      temp = temp + M(107, 85) * x(107)
      temp = temp + M(111, 85) * x(111)
      temp = temp + M(112, 85) * x(112)
      x(85) = ( x(85) - temp ) / M(85, 85)

      temp = M(85, 84) * x(85)
      temp = temp + M(89, 84) * x(89)
      temp = temp + M(91, 84) * x(91)
      temp = temp + M(93, 84) * x(93)
      temp = temp + M(96, 84) * x(96)
      temp = temp + M(97, 84) * x(97)
      temp = temp + M(100, 84) * x(100)
      temp = temp + M(102, 84) * x(102)
      temp = temp + M(103, 84) * x(103)
      temp = temp + M(105, 84) * x(105)
      temp = temp + M(106, 84) * x(106)
      temp = temp + M(107, 84) * x(107)
      temp = temp + M(108, 84) * x(108)
      temp = temp + M(109, 84) * x(109)
      temp = temp + M(110, 84) * x(110)
      temp = temp + M(111, 84) * x(111)
      x(84) = ( x(84) - temp ) / M(84, 84)

      temp = M(84, 83) * x(84)
      temp = temp + M(85, 83) * x(85)
      temp = temp + M(88, 83) * x(88)
      temp = temp + M(89, 83) * x(89)
      temp = temp + M(91, 83) * x(91)
      temp = temp + M(92, 83) * x(92)
      temp = temp + M(93, 83) * x(93)
      temp = temp + M(94, 83) * x(94)
      temp = temp + M(95, 83) * x(95)
      temp = temp + M(96, 83) * x(96)
      temp = temp + M(97, 83) * x(97)
      temp = temp + M(100, 83) * x(100)
      temp = temp + M(101, 83) * x(101)
      temp = temp + M(102, 83) * x(102)
      temp = temp + M(103, 83) * x(103)
      temp = temp + M(104, 83) * x(104)
      temp = temp + M(105, 83) * x(105)
      temp = temp + M(106, 83) * x(106)
      temp = temp + M(107, 83) * x(107)
      temp = temp + M(108, 83) * x(108)
      temp = temp + M(109, 83) * x(109)
      temp = temp + M(110, 83) * x(110)
      temp = temp + M(111, 83) * x(111)
      temp = temp + M(112, 83) * x(112)
      temp = temp + M(113, 83) * x(113)
      x(83) = ( x(83) - temp ) / M(83, 83)

      temp = M(83, 82) * x(83)
      temp = temp + M(100, 82) * x(100)
      temp = temp + M(102, 82) * x(102)
      temp = temp + M(105, 82) * x(105)
      temp = temp + M(106, 82) * x(106)
      temp = temp + M(108, 82) * x(108)
      temp = temp + M(109, 82) * x(109)
      temp = temp + M(110, 82) * x(110)
      temp = temp + M(111, 82) * x(111)
      x(82) = ( x(82) - temp ) / M(82, 82)

      temp = M(82, 81) * x(82)
      temp = temp + M(83, 81) * x(83)
      temp = temp + M(84, 81) * x(84)
      temp = temp + M(85, 81) * x(85)
      temp = temp + M(88, 81) * x(88)
      temp = temp + M(89, 81) * x(89)
      temp = temp + M(91, 81) * x(91)
      temp = temp + M(92, 81) * x(92)
      temp = temp + M(93, 81) * x(93)
      temp = temp + M(94, 81) * x(94)
      temp = temp + M(95, 81) * x(95)
      temp = temp + M(96, 81) * x(96)
      temp = temp + M(97, 81) * x(97)
      temp = temp + M(100, 81) * x(100)
      temp = temp + M(101, 81) * x(101)
      temp = temp + M(102, 81) * x(102)
      temp = temp + M(103, 81) * x(103)
      temp = temp + M(104, 81) * x(104)
      temp = temp + M(105, 81) * x(105)
      temp = temp + M(106, 81) * x(106)
      temp = temp + M(107, 81) * x(107)
      temp = temp + M(108, 81) * x(108)
      temp = temp + M(109, 81) * x(109)
      temp = temp + M(110, 81) * x(110)
      temp = temp + M(111, 81) * x(111)
      temp = temp + M(112, 81) * x(112)
      temp = temp + M(113, 81) * x(113)
      x(81) = ( x(81) - temp ) / M(81, 81)

      temp = M(81, 80) * x(81)
      temp = temp + M(84, 80) * x(84)
      temp = temp + M(91, 80) * x(91)
      temp = temp + M(93, 80) * x(93)
      temp = temp + M(96, 80) * x(96)
      temp = temp + M(100, 80) * x(100)
      temp = temp + M(101, 80) * x(101)
      temp = temp + M(103, 80) * x(103)
      temp = temp + M(105, 80) * x(105)
      temp = temp + M(107, 80) * x(107)
      temp = temp + M(108, 80) * x(108)
      temp = temp + M(109, 80) * x(109)
      temp = temp + M(111, 80) * x(111)
      temp = temp + M(112, 80) * x(112)
      temp = temp + M(113, 80) * x(113)
      x(80) = ( x(80) - temp ) / M(80, 80)

      temp = M(85, 79) * x(85)
      temp = temp + M(89, 79) * x(89)
      temp = temp + M(97, 79) * x(97)
      temp = temp + M(100, 79) * x(100)
      temp = temp + M(102, 79) * x(102)
      temp = temp + M(103, 79) * x(103)
      temp = temp + M(105, 79) * x(105)
      temp = temp + M(106, 79) * x(106)
      temp = temp + M(107, 79) * x(107)
      temp = temp + M(108, 79) * x(108)
      temp = temp + M(109, 79) * x(109)
      temp = temp + M(110, 79) * x(110)
      temp = temp + M(111, 79) * x(111)
      x(79) = ( x(79) - temp ) / M(79, 79)

      temp = M(79, 78) * x(79)
      temp = temp + M(81, 78) * x(81)
      temp = temp + M(93, 78) * x(93)
      temp = temp + M(96, 78) * x(96)
      temp = temp + M(97, 78) * x(97)
      temp = temp + M(100, 78) * x(100)
      temp = temp + M(101, 78) * x(101)
      temp = temp + M(105, 78) * x(105)
      temp = temp + M(108, 78) * x(108)
      temp = temp + M(111, 78) * x(111)
      temp = temp + M(112, 78) * x(112)
      x(78) = ( x(78) - temp ) / M(78, 78)

      temp = M(91, 77) * x(91)
      temp = temp + M(93, 77) * x(93)
      temp = temp + M(96, 77) * x(96)
      temp = temp + M(101, 77) * x(101)
      temp = temp + M(105, 77) * x(105)
      temp = temp + M(107, 77) * x(107)
      temp = temp + M(111, 77) * x(111)
      temp = temp + M(112, 77) * x(112)
      x(77) = ( x(77) - temp ) / M(77, 77)

      temp = M(93, 76) * x(93)
      temp = temp + M(105, 76) * x(105)
      temp = temp + M(108, 76) * x(108)
      temp = temp + M(111, 76) * x(111)
      temp = temp + M(112, 76) * x(112)
      x(76) = ( x(76) - temp ) / M(76, 76)

      temp = M(76, 75) * x(76)
      temp = temp + M(91, 75) * x(91)
      temp = temp + M(100, 75) * x(100)
      temp = temp + M(102, 75) * x(102)
      temp = temp + M(105, 75) * x(105)
      temp = temp + M(106, 75) * x(106)
      temp = temp + M(108, 75) * x(108)
      temp = temp + M(109, 75) * x(109)
      temp = temp + M(110, 75) * x(110)
      temp = temp + M(111, 75) * x(111)
      x(75) = ( x(75) - temp ) / M(75, 75)

      temp = M(100, 74) * x(100)
      temp = temp + M(101, 74) * x(101)
      temp = temp + M(105, 74) * x(105)
      temp = temp + M(108, 74) * x(108)
      temp = temp + M(112, 74) * x(112)
      x(74) = ( x(74) - temp ) / M(74, 74)

      temp = M(93, 73) * x(93)
      temp = temp + M(111, 73) * x(111)
      temp = temp + M(112, 73) * x(112)
      x(73) = ( x(73) - temp ) / M(73, 73)

      temp = M(85, 72) * x(85)
      temp = temp + M(89, 72) * x(89)
      temp = temp + M(97, 72) * x(97)
      temp = temp + M(100, 72) * x(100)
      temp = temp + M(102, 72) * x(102)
      temp = temp + M(103, 72) * x(103)
      temp = temp + M(105, 72) * x(105)
      temp = temp + M(106, 72) * x(106)
      temp = temp + M(107, 72) * x(107)
      temp = temp + M(108, 72) * x(108)
      temp = temp + M(109, 72) * x(109)
      temp = temp + M(110, 72) * x(110)
      temp = temp + M(111, 72) * x(111)
      x(72) = ( x(72) - temp ) / M(72, 72)

      temp = M(85, 71) * x(85)
      temp = temp + M(89, 71) * x(89)
      temp = temp + M(97, 71) * x(97)
      temp = temp + M(100, 71) * x(100)
      temp = temp + M(102, 71) * x(102)
      temp = temp + M(103, 71) * x(103)
      temp = temp + M(105, 71) * x(105)
      temp = temp + M(107, 71) * x(107)
      temp = temp + M(108, 71) * x(108)
      temp = temp + M(109, 71) * x(109)
      temp = temp + M(110, 71) * x(110)
      temp = temp + M(111, 71) * x(111)
      temp = temp + M(113, 71) * x(113)
      x(71) = ( x(71) - temp ) / M(71, 71)

      temp = M(71, 70) * x(71)
      temp = temp + M(85, 70) * x(85)
      temp = temp + M(89, 70) * x(89)
      temp = temp + M(97, 70) * x(97)
      temp = temp + M(100, 70) * x(100)
      temp = temp + M(102, 70) * x(102)
      temp = temp + M(103, 70) * x(103)
      temp = temp + M(105, 70) * x(105)
      temp = temp + M(107, 70) * x(107)
      temp = temp + M(108, 70) * x(108)
      temp = temp + M(109, 70) * x(109)
      temp = temp + M(110, 70) * x(110)
      temp = temp + M(111, 70) * x(111)
      temp = temp + M(113, 70) * x(113)
      x(70) = ( x(70) - temp ) / M(70, 70)

      temp = M(70, 69) * x(70)
      temp = temp + M(71, 69) * x(71)
      temp = temp + M(79, 69) * x(79)
      temp = temp + M(81, 69) * x(81)
      temp = temp + M(92, 69) * x(92)
      temp = temp + M(96, 69) * x(96)
      temp = temp + M(97, 69) * x(97)
      temp = temp + M(100, 69) * x(100)
      temp = temp + M(103, 69) * x(103)
      temp = temp + M(104, 69) * x(104)
      temp = temp + M(107, 69) * x(107)
      temp = temp + M(108, 69) * x(108)
      temp = temp + M(109, 69) * x(109)
      temp = temp + M(111, 69) * x(111)
      temp = temp + M(112, 69) * x(112)
      x(69) = ( x(69) - temp ) / M(69, 69)

      temp = M(85, 68) * x(85)
      temp = temp + M(89, 68) * x(89)
      temp = temp + M(93, 68) * x(93)
      temp = temp + M(97, 68) * x(97)
      temp = temp + M(100, 68) * x(100)
      temp = temp + M(101, 68) * x(101)
      temp = temp + M(102, 68) * x(102)
      temp = temp + M(105, 68) * x(105)
      temp = temp + M(106, 68) * x(106)
      temp = temp + M(107, 68) * x(107)
      temp = temp + M(108, 68) * x(108)
      temp = temp + M(109, 68) * x(109)
      temp = temp + M(110, 68) * x(110)
      temp = temp + M(111, 68) * x(111)
      x(68) = ( x(68) - temp ) / M(68, 68)

      temp = M(111, 67) * x(111)
      temp = temp + M(112, 67) * x(112)
      x(67) = ( x(67) - temp ) / M(67, 67)

      temp = M(67, 66) * x(67)
      temp = temp + M(68, 66) * x(68)
      temp = temp + M(80, 66) * x(80)
      temp = temp + M(81, 66) * x(81)
      temp = temp + M(93, 66) * x(93)
      temp = temp + M(95, 66) * x(95)
      temp = temp + M(96, 66) * x(96)
      temp = temp + M(100, 66) * x(100)
      temp = temp + M(101, 66) * x(101)
      temp = temp + M(105, 66) * x(105)
      temp = temp + M(108, 66) * x(108)
      temp = temp + M(111, 66) * x(111)
      temp = temp + M(112, 66) * x(112)
      x(66) = ( x(66) - temp ) / M(66, 66)

      temp = M(85, 65) * x(85)
      temp = temp + M(89, 65) * x(89)
      temp = temp + M(97, 65) * x(97)
      temp = temp + M(100, 65) * x(100)
      temp = temp + M(102, 65) * x(102)
      temp = temp + M(105, 65) * x(105)
      temp = temp + M(106, 65) * x(106)
      temp = temp + M(108, 65) * x(108)
      temp = temp + M(109, 65) * x(109)
      temp = temp + M(110, 65) * x(110)
      temp = temp + M(111, 65) * x(111)
      temp = temp + M(112, 65) * x(112)
      x(65) = ( x(65) - temp ) / M(65, 65)

      temp = M(77, 64) * x(77)
      temp = temp + M(85, 64) * x(85)
      temp = temp + M(89, 64) * x(89)
      temp = temp + M(97, 64) * x(97)
      temp = temp + M(100, 64) * x(100)
      temp = temp + M(102, 64) * x(102)
      temp = temp + M(105, 64) * x(105)
      temp = temp + M(106, 64) * x(106)
      temp = temp + M(108, 64) * x(108)
      temp = temp + M(109, 64) * x(109)
      temp = temp + M(110, 64) * x(110)
      temp = temp + M(111, 64) * x(111)
      x(64) = ( x(64) - temp ) / M(64, 64)

      temp = M(69, 63) * x(69)
      temp = temp + M(80, 63) * x(80)
      temp = temp + M(91, 63) * x(91)
      temp = temp + M(100, 63) * x(100)
      temp = temp + M(102, 63) * x(102)
      temp = temp + M(105, 63) * x(105)
      temp = temp + M(106, 63) * x(106)
      temp = temp + M(108, 63) * x(108)
      temp = temp + M(109, 63) * x(109)
      temp = temp + M(110, 63) * x(110)
      temp = temp + M(111, 63) * x(111)
      temp = temp + M(113, 63) * x(113)
      x(63) = ( x(63) - temp ) / M(63, 63)

      temp = M(85, 62) * x(85)
      temp = temp + M(89, 62) * x(89)
      temp = temp + M(97, 62) * x(97)
      temp = temp + M(100, 62) * x(100)
      temp = temp + M(101, 62) * x(101)
      temp = temp + M(102, 62) * x(102)
      temp = temp + M(103, 62) * x(103)
      temp = temp + M(104, 62) * x(104)
      temp = temp + M(105, 62) * x(105)
      temp = temp + M(106, 62) * x(106)
      temp = temp + M(107, 62) * x(107)
      temp = temp + M(108, 62) * x(108)
      temp = temp + M(109, 62) * x(109)
      temp = temp + M(110, 62) * x(110)
      temp = temp + M(111, 62) * x(111)
      temp = temp + M(113, 62) * x(113)
      x(62) = ( x(62) - temp ) / M(62, 62)

      temp = M(67, 61) * x(67)
      temp = temp + M(81, 61) * x(81)
      temp = temp + M(93, 61) * x(93)
      temp = temp + M(94, 61) * x(94)
      temp = temp + M(95, 61) * x(95)
      temp = temp + M(96, 61) * x(96)
      temp = temp + M(101, 61) * x(101)
      temp = temp + M(105, 61) * x(105)
      temp = temp + M(108, 61) * x(108)
      temp = temp + M(109, 61) * x(109)
      temp = temp + M(111, 61) * x(111)
      temp = temp + M(112, 61) * x(112)
      temp = temp + M(113, 61) * x(113)
      x(61) = ( x(61) - temp ) / M(61, 61)

      temp = M(61, 60) * x(61)
      temp = temp + M(65, 60) * x(65)
      temp = temp + M(69, 60) * x(69)
      temp = temp + M(85, 60) * x(85)
      temp = temp + M(89, 60) * x(89)
      temp = temp + M(97, 60) * x(97)
      temp = temp + M(100, 60) * x(100)
      temp = temp + M(102, 60) * x(102)
      temp = temp + M(103, 60) * x(103)
      temp = temp + M(105, 60) * x(105)
      temp = temp + M(106, 60) * x(106)
      temp = temp + M(108, 60) * x(108)
      temp = temp + M(109, 60) * x(109)
      temp = temp + M(110, 60) * x(110)
      temp = temp + M(111, 60) * x(111)
      temp = temp + M(112, 60) * x(112)
      temp = temp + M(113, 60) * x(113)
      x(60) = ( x(60) - temp ) / M(60, 60)

      temp = M(61, 59) * x(61)
      temp = temp + M(66, 59) * x(66)
      temp = temp + M(73, 59) * x(73)
      temp = temp + M(85, 59) * x(85)
      temp = temp + M(89, 59) * x(89)
      temp = temp + M(96, 59) * x(96)
      temp = temp + M(97, 59) * x(97)
      temp = temp + M(100, 59) * x(100)
      temp = temp + M(102, 59) * x(102)
      temp = temp + M(105, 59) * x(105)
      temp = temp + M(108, 59) * x(108)
      temp = temp + M(109, 59) * x(109)
      temp = temp + M(110, 59) * x(110)
      temp = temp + M(111, 59) * x(111)
      temp = temp + M(112, 59) * x(112)
      x(59) = ( x(59) - temp ) / M(59, 59)

      temp = M(65, 58) * x(65)
      temp = temp + M(100, 58) * x(100)
      temp = temp + M(105, 58) * x(105)
      temp = temp + M(112, 58) * x(112)
      x(58) = ( x(58) - temp ) / M(58, 58)

      temp = M(58, 57) * x(58)
      temp = temp + M(67, 57) * x(67)
      temp = temp + M(85, 57) * x(85)
      temp = temp + M(89, 57) * x(89)
      temp = temp + M(97, 57) * x(97)
      temp = temp + M(100, 57) * x(100)
      temp = temp + M(102, 57) * x(102)
      temp = temp + M(103, 57) * x(103)
      temp = temp + M(105, 57) * x(105)
      temp = temp + M(106, 57) * x(106)
      temp = temp + M(107, 57) * x(107)
      temp = temp + M(108, 57) * x(108)
      temp = temp + M(109, 57) * x(109)
      temp = temp + M(110, 57) * x(110)
      temp = temp + M(111, 57) * x(111)
      temp = temp + M(113, 57) * x(113)
      x(57) = ( x(57) - temp ) / M(57, 57)

      temp = M(91, 56) * x(91)
      temp = temp + M(93, 56) * x(93)
      temp = temp + M(96, 56) * x(96)
      temp = temp + M(101, 56) * x(101)
      temp = temp + M(105, 56) * x(105)
      temp = temp + M(107, 56) * x(107)
      temp = temp + M(111, 56) * x(111)
      temp = temp + M(112, 56) * x(112)
      x(56) = ( x(56) - temp ) / M(56, 56)

      temp = M(56, 55) * x(56)
      temp = temp + M(75, 55) * x(75)
      temp = temp + M(77, 55) * x(77)
      temp = temp + M(78, 55) * x(78)
      temp = temp + M(83, 55) * x(83)
      temp = temp + M(91, 55) * x(91)
      temp = temp + M(93, 55) * x(93)
      temp = temp + M(94, 55) * x(94)
      temp = temp + M(100, 55) * x(100)
      temp = temp + M(102, 55) * x(102)
      temp = temp + M(105, 55) * x(105)
      temp = temp + M(106, 55) * x(106)
      temp = temp + M(108, 55) * x(108)
      temp = temp + M(109, 55) * x(109)
      temp = temp + M(110, 55) * x(110)
      temp = temp + M(111, 55) * x(111)
      temp = temp + M(112, 55) * x(112)
      temp = temp + M(113, 55) * x(113)
      x(55) = ( x(55) - temp ) / M(55, 55)

      temp = M(100, 54) * x(100)
      temp = temp + M(102, 54) * x(102)
      temp = temp + M(105, 54) * x(105)
      temp = temp + M(108, 54) * x(108)
      temp = temp + M(109, 54) * x(109)
      temp = temp + M(110, 54) * x(110)
      temp = temp + M(111, 54) * x(111)
      temp = temp + M(113, 54) * x(113)
      x(54) = ( x(54) - temp ) / M(54, 54)

      temp = M(54, 53) * x(54)
      temp = temp + M(75, 53) * x(75)
      temp = temp + M(83, 53) * x(83)
      temp = temp + M(91, 53) * x(91)
      temp = temp + M(94, 53) * x(94)
      temp = temp + M(96, 53) * x(96)
      temp = temp + M(100, 53) * x(100)
      temp = temp + M(102, 53) * x(102)
      temp = temp + M(105, 53) * x(105)
      temp = temp + M(106, 53) * x(106)
      temp = temp + M(108, 53) * x(108)
      temp = temp + M(109, 53) * x(109)
      temp = temp + M(110, 53) * x(110)
      temp = temp + M(111, 53) * x(111)
      temp = temp + M(112, 53) * x(112)
      temp = temp + M(113, 53) * x(113)
      x(53) = ( x(53) - temp ) / M(53, 53)

      temp = M(53, 52) * x(53)
      temp = temp + M(100, 52) * x(100)
      temp = temp + M(102, 52) * x(102)
      temp = temp + M(105, 52) * x(105)
      temp = temp + M(108, 52) * x(108)
      temp = temp + M(109, 52) * x(109)
      temp = temp + M(110, 52) * x(110)
      temp = temp + M(111, 52) * x(111)
      x(52) = ( x(52) - temp ) / M(52, 52)

      temp = M(91, 51) * x(91)
      temp = temp + M(100, 51) * x(100)
      temp = temp + M(102, 51) * x(102)
      temp = temp + M(105, 51) * x(105)
      temp = temp + M(106, 51) * x(106)
      temp = temp + M(108, 51) * x(108)
      temp = temp + M(109, 51) * x(109)
      temp = temp + M(110, 51) * x(110)
      temp = temp + M(111, 51) * x(111)
      temp = temp + M(113, 51) * x(113)
      x(51) = ( x(51) - temp ) / M(51, 51)

      temp = M(53, 50) * x(53)
      temp = temp + M(100, 50) * x(100)
      temp = temp + M(102, 50) * x(102)
      temp = temp + M(105, 50) * x(105)
      temp = temp + M(108, 50) * x(108)
      temp = temp + M(109, 50) * x(109)
      temp = temp + M(110, 50) * x(110)
      temp = temp + M(111, 50) * x(111)
      x(50) = ( x(50) - temp ) / M(50, 50)

      temp = M(77, 49) * x(77)
      temp = temp + M(78, 49) * x(78)
      temp = temp + M(93, 49) * x(93)
      temp = temp + M(100, 49) * x(100)
      temp = temp + M(102, 49) * x(102)
      temp = temp + M(105, 49) * x(105)
      temp = temp + M(108, 49) * x(108)
      temp = temp + M(109, 49) * x(109)
      temp = temp + M(110, 49) * x(110)
      temp = temp + M(111, 49) * x(111)
      temp = temp + M(113, 49) * x(113)
      x(49) = ( x(49) - temp ) / M(49, 49)

      temp = M(51, 48) * x(51)
      temp = temp + M(75, 48) * x(75)
      temp = temp + M(83, 48) * x(83)
      temp = temp + M(94, 48) * x(94)
      temp = temp + M(109, 48) * x(109)
      temp = temp + M(110, 48) * x(110)
      temp = temp + M(111, 48) * x(111)
      temp = temp + M(112, 48) * x(112)
      temp = temp + M(113, 48) * x(113)
      x(48) = ( x(48) - temp ) / M(48, 48)

      temp = M(48, 47) * x(48)
      temp = temp + M(51, 47) * x(51)
      temp = temp + M(75, 47) * x(75)
      temp = temp + M(83, 47) * x(83)
      temp = temp + M(94, 47) * x(94)
      temp = temp + M(109, 47) * x(109)
      temp = temp + M(111, 47) * x(111)
      temp = temp + M(112, 47) * x(112)
      x(47) = ( x(47) - temp ) / M(47, 47)

      temp = M(110, 46) * x(110)
      temp = temp + M(113, 46) * x(113)
      x(46) = ( x(46) - temp ) / M(46, 46)

      temp = M(46, 45) * x(46)
      temp = temp + M(100, 45) * x(100)
      temp = temp + M(102, 45) * x(102)
      temp = temp + M(105, 45) * x(105)
      temp = temp + M(108, 45) * x(108)
      temp = temp + M(109, 45) * x(109)
      temp = temp + M(110, 45) * x(110)
      temp = temp + M(111, 45) * x(111)
      x(45) = ( x(45) - temp ) / M(45, 45)

      temp = M(81, 44) * x(81)
      temp = temp + M(102, 44) * x(102)
      temp = temp + M(109, 44) * x(109)
      temp = temp + M(110, 44) * x(110)
      x(44) = ( x(44) - temp ) / M(44, 44)

      temp = M(47, 43) * x(47)
      temp = temp + M(49, 43) * x(49)
      temp = temp + M(56, 43) * x(56)
      temp = temp + M(100, 43) * x(100)
      temp = temp + M(102, 43) * x(102)
      temp = temp + M(105, 43) * x(105)
      temp = temp + M(108, 43) * x(108)
      temp = temp + M(109, 43) * x(109)
      temp = temp + M(110, 43) * x(110)
      temp = temp + M(111, 43) * x(111)
      temp = temp + M(112, 43) * x(112)
      temp = temp + M(113, 43) * x(113)
      x(43) = ( x(43) - temp ) / M(43, 43)

      temp = M(77, 42) * x(77)
      temp = temp + M(93, 42) * x(93)
      temp = temp + M(100, 42) * x(100)
      temp = temp + M(102, 42) * x(102)
      temp = temp + M(105, 42) * x(105)
      temp = temp + M(108, 42) * x(108)
      temp = temp + M(109, 42) * x(109)
      temp = temp + M(110, 42) * x(110)
      temp = temp + M(111, 42) * x(111)
      temp = temp + M(113, 42) * x(113)
      x(42) = ( x(42) - temp ) / M(42, 42)

      temp = M(42, 41) * x(42)
      temp = temp + M(47, 41) * x(47)
      temp = temp + M(56, 41) * x(56)
      temp = temp + M(91, 41) * x(91)
      temp = temp + M(100, 41) * x(100)
      temp = temp + M(102, 41) * x(102)
      temp = temp + M(105, 41) * x(105)
      temp = temp + M(108, 41) * x(108)
      temp = temp + M(109, 41) * x(109)
      temp = temp + M(110, 41) * x(110)
      temp = temp + M(111, 41) * x(111)
      temp = temp + M(112, 41) * x(112)
      temp = temp + M(113, 41) * x(113)
      x(41) = ( x(41) - temp ) / M(41, 41)

      temp = M(73, 40) * x(73)
      temp = temp + M(95, 40) * x(95)
      temp = temp + M(109, 40) * x(109)
      temp = temp + M(110, 40) * x(110)
      temp = temp + M(112, 40) * x(112)
      x(40) = ( x(40) - temp ) / M(40, 40)

      temp = M(73, 39) * x(73)
      temp = temp + M(96, 39) * x(96)
      temp = temp + M(108, 39) * x(108)
      temp = temp + M(110, 39) * x(110)
      temp = temp + M(112, 39) * x(112)
      x(39) = ( x(39) - temp ) / M(39, 39)

      temp = M(111, 38) * x(111)
      temp = temp + M(112, 38) * x(112)
      x(38) = ( x(38) - temp ) / M(38, 38)

      temp = M(98, 37) * x(98)
      temp = temp + M(101, 37) * x(101)
      temp = temp + M(108, 37) * x(108)
      temp = temp + M(109, 37) * x(109)
      temp = temp + M(110, 37) * x(110)
      temp = temp + M(112, 37) * x(112)
      x(37) = ( x(37) - temp ) / M(37, 37)

      temp = M(109, 36) * x(109)
      temp = temp + M(110, 36) * x(110)
      temp = temp + M(111, 36) * x(111)
      temp = temp + M(112, 36) * x(112)
      x(36) = ( x(36) - temp ) / M(36, 36)

      temp = M(100, 35) * x(100)
      temp = temp + M(101, 35) * x(101)
      temp = temp + M(105, 35) * x(105)
      temp = temp + M(108, 35) * x(108)
      temp = temp + M(109, 35) * x(109)
      temp = temp + M(110, 35) * x(110)
      temp = temp + M(112, 35) * x(112)
      x(35) = ( x(35) - temp ) / M(35, 35)

      temp = M(100, 34) * x(100)
      temp = temp + M(108, 34) * x(108)
      temp = temp + M(111, 34) * x(111)
      temp = temp + M(112, 34) * x(112)
      x(34) = ( x(34) - temp ) / M(34, 34)

      temp = M(104, 33) * x(104)
      temp = temp + M(112, 33) * x(112)
      x(33) = ( x(33) - temp ) / M(33, 33)

      temp = M(100, 32) * x(100)
      temp = temp + M(112, 32) * x(112)
      x(32) = ( x(32) - temp ) / M(32, 32)

      temp = M(32, 31) * x(32)
      temp = temp + M(33, 31) * x(33)
      temp = temp + M(38, 31) * x(38)
      temp = temp + M(67, 31) * x(67)
      temp = temp + M(70, 31) * x(70)
      temp = temp + M(71, 31) * x(71)
      temp = temp + M(72, 31) * x(72)
      temp = temp + M(81, 31) * x(81)
      temp = temp + M(92, 31) * x(92)
      temp = temp + M(96, 31) * x(96)
      temp = temp + M(97, 31) * x(97)
      temp = temp + M(100, 31) * x(100)
      temp = temp + M(103, 31) * x(103)
      temp = temp + M(104, 31) * x(104)
      temp = temp + M(107, 31) * x(107)
      temp = temp + M(108, 31) * x(108)
      temp = temp + M(109, 31) * x(109)
      temp = temp + M(111, 31) * x(111)
      temp = temp + M(112, 31) * x(112)
      x(31) = ( x(31) - temp ) / M(31, 31)

      temp = M(64, 30) * x(64)
      temp = temp + M(100, 30) * x(100)
      temp = temp + M(104, 30) * x(104)
      temp = temp + M(105, 30) * x(105)
      temp = temp + M(112, 30) * x(112)
      x(30) = ( x(30) - temp ) / M(30, 30)

      temp = M(83, 29) * x(83)
      temp = temp + M(94, 29) * x(94)
      temp = temp + M(109, 29) * x(109)
      temp = temp + M(112, 29) * x(112)
      x(29) = ( x(29) - temp ) / M(29, 29)

      temp = M(95, 28) * x(95)
      temp = temp + M(112, 28) * x(112)
      x(28) = ( x(28) - temp ) / M(28, 28)

      temp = M(31, 27) * x(31)
      temp = temp + M(38, 27) * x(38)
      temp = temp + M(60, 27) * x(60)
      temp = temp + M(61, 27) * x(61)
      temp = temp + M(67, 27) * x(67)
      temp = temp + M(70, 27) * x(70)
      temp = temp + M(71, 27) * x(71)
      temp = temp + M(81, 27) * x(81)
      temp = temp + M(92, 27) * x(92)
      temp = temp + M(96, 27) * x(96)
      temp = temp + M(97, 27) * x(97)
      temp = temp + M(104, 27) * x(104)
      temp = temp + M(108, 27) * x(108)
      temp = temp + M(109, 27) * x(109)
      temp = temp + M(111, 27) * x(111)
      temp = temp + M(112, 27) * x(112)
      x(27) = ( x(27) - temp ) / M(27, 27)

      temp = M(38, 26) * x(38)
      temp = temp + M(39, 26) * x(39)
      temp = temp + M(59, 26) * x(59)
      temp = temp + M(61, 26) * x(61)
      temp = temp + M(66, 26) * x(66)
      temp = temp + M(67, 26) * x(67)
      temp = temp + M(81, 26) * x(81)
      temp = temp + M(95, 26) * x(95)
      temp = temp + M(96, 26) * x(96)
      temp = temp + M(100, 26) * x(100)
      temp = temp + M(105, 26) * x(105)
      temp = temp + M(108, 26) * x(108)
      temp = temp + M(109, 26) * x(109)
      temp = temp + M(111, 26) * x(111)
      temp = temp + M(112, 26) * x(112)
      x(26) = ( x(26) - temp ) / M(26, 26)

      temp = M(61, 25) * x(61)
      x(25) = ( x(25) - temp ) / M(25, 25)

      temp = M(107, 24) * x(107)
      temp = temp + M(111, 24) * x(111)
      temp = temp + M(112, 24) * x(112)
      x(24) = ( x(24) - temp ) / M(24, 24)

      temp = M(67, 23) * x(67)
      temp = temp + M(70, 23) * x(70)
      temp = temp + M(71, 23) * x(71)
      temp = temp + M(81, 23) * x(81)
      temp = temp + M(88, 23) * x(88)
      temp = temp + M(96, 23) * x(96)
      temp = temp + M(108, 23) * x(108)
      temp = temp + M(109, 23) * x(109)
      temp = temp + M(111, 23) * x(111)
      temp = temp + M(112, 23) * x(112)
      x(23) = ( x(23) - temp ) / M(23, 23)

      temp = M(81, 22) * x(81)
      temp = temp + M(91, 22) * x(91)
      temp = temp + M(94, 22) * x(94)
      temp = temp + M(96, 22) * x(96)
      temp = temp + M(101, 22) * x(101)
      temp = temp + M(107, 22) * x(107)
      temp = temp + M(109, 22) * x(109)
      temp = temp + M(110, 22) * x(110)
      temp = temp + M(111, 22) * x(111)
      temp = temp + M(112, 22) * x(112)
      x(22) = ( x(22) - temp ) / M(22, 22)

      temp = M(87, 21) * x(87)
      temp = temp + M(111, 21) * x(111)
      temp = temp + M(112, 21) * x(112)
      x(21) = ( x(21) - temp ) / M(21, 21)

      temp = M(31, 20) * x(31)
      temp = temp + M(38, 20) * x(38)
      temp = temp + M(44, 20) * x(44)
      temp = temp + M(61, 20) * x(61)
      temp = temp + M(67, 20) * x(67)
      temp = temp + M(70, 20) * x(70)
      temp = temp + M(71, 20) * x(71)
      temp = temp + M(79, 20) * x(79)
      temp = temp + M(81, 20) * x(81)
      temp = temp + M(92, 20) * x(92)
      temp = temp + M(96, 20) * x(96)
      temp = temp + M(100, 20) * x(100)
      temp = temp + M(101, 20) * x(101)
      temp = temp + M(105, 20) * x(105)
      temp = temp + M(108, 20) * x(108)
      temp = temp + M(109, 20) * x(109)
      temp = temp + M(111, 20) * x(111)
      temp = temp + M(112, 20) * x(112)
      x(20) = ( x(20) - temp ) / M(20, 20)

      temp = M(38, 19) * x(38)
      temp = temp + M(57, 19) * x(57)
      temp = temp + M(70, 19) * x(70)
      temp = temp + M(71, 19) * x(71)
      temp = temp + M(81, 19) * x(81)
      temp = temp + M(92, 19) * x(92)
      temp = temp + M(96, 19) * x(96)
      temp = temp + M(103, 19) * x(103)
      temp = temp + M(104, 19) * x(104)
      temp = temp + M(107, 19) * x(107)
      temp = temp + M(109, 19) * x(109)
      temp = temp + M(111, 19) * x(111)
      temp = temp + M(112, 19) * x(112)
      x(19) = ( x(19) - temp ) / M(19, 19)

      temp = M(29, 18) * x(29)
      temp = temp + M(48, 18) * x(48)
      temp = temp + M(51, 18) * x(51)
      temp = temp + M(75, 18) * x(75)
      temp = temp + M(94, 18) * x(94)
      temp = temp + M(109, 18) * x(109)
      temp = temp + M(111, 18) * x(111)
      temp = temp + M(112, 18) * x(112)
      x(18) = ( x(18) - temp ) / M(18, 18)

      temp = M(96, 17) * x(96)
      temp = temp + M(108, 17) * x(108)
      temp = temp + M(110, 17) * x(110)
      temp = temp + M(112, 17) * x(112)
      x(17) = ( x(17) - temp ) / M(17, 17)

      temp = M(94, 16) * x(94)
      temp = temp + M(109, 16) * x(109)
      temp = temp + M(110, 16) * x(110)
      x(16) = ( x(16) - temp ) / M(16, 16)

      temp = M(102, 15) * x(102)
      temp = temp + M(110, 15) * x(110)
      temp = temp + M(112, 15) * x(112)
      x(15) = ( x(15) - temp ) / M(15, 15)

      temp = M(22, 14) * x(22)
      temp = temp + M(47, 14) * x(47)
      temp = temp + M(49, 14) * x(49)
      temp = temp + M(55, 14) * x(55)
      temp = temp + M(56, 14) * x(56)
      temp = temp + M(111, 14) * x(111)
      temp = temp + M(112, 14) * x(112)
      x(14) = ( x(14) - temp ) / M(14, 14)

      temp = M(14, 13) * x(14)
      temp = temp + M(47, 13) * x(47)
      temp = temp + M(52, 13) * x(52)
      temp = temp + M(111, 13) * x(111)
      temp = temp + M(112, 13) * x(112)
      x(13) = ( x(13) - temp ) / M(13, 13)

      temp = M(22, 12) * x(22)
      temp = temp + M(43, 12) * x(43)
      temp = temp + M(47, 12) * x(47)
      temp = temp + M(49, 12) * x(49)
      temp = temp + M(56, 12) * x(56)
      temp = temp + M(111, 12) * x(111)
      temp = temp + M(112, 12) * x(112)
      x(12) = ( x(12) - temp ) / M(12, 12)

      temp = M(12, 11) * x(12)
      temp = temp + M(47, 11) * x(47)
      temp = temp + M(52, 11) * x(52)
      temp = temp + M(111, 11) * x(111)
      temp = temp + M(112, 11) * x(112)
      x(11) = ( x(11) - temp ) / M(11, 11)

      temp = M(22, 10) * x(22)
      temp = temp + M(41, 10) * x(41)
      temp = temp + M(42, 10) * x(42)
      temp = temp + M(47, 10) * x(47)
      temp = temp + M(56, 10) * x(56)
      temp = temp + M(111, 10) * x(111)
      temp = temp + M(112, 10) * x(112)
      x(10) = ( x(10) - temp ) / M(10, 10)

      temp = M(10, 9) * x(10)
      temp = temp + M(47, 9) * x(47)
      temp = temp + M(50, 9) * x(50)
      temp = temp + M(111, 9) * x(111)
      temp = temp + M(112, 9) * x(112)
      x(9) = ( x(9) - temp ) / M(9, 9)

      temp = M(62, 8) * x(62)
      temp = temp + M(76, 8) * x(76)
      temp = temp + M(107, 8) * x(107)
      temp = temp + M(111, 8) * x(111)
      temp = temp + M(112, 8) * x(112)
      x(8) = ( x(8) - temp ) / M(8, 8)

      temp = M(86, 7) * x(86)
      temp = temp + M(112, 7) * x(112)
      x(7) = ( x(7) - temp ) / M(7, 7)

      temp = M(99, 6) * x(99)
      temp = temp + M(112, 6) * x(112)
      x(6) = ( x(6) - temp ) / M(6, 6)

      temp = M(18, 5) * x(18)
      temp = temp + M(63, 5) * x(63)
      temp = temp + M(80, 5) * x(80)
      temp = temp + M(111, 5) * x(111)
      temp = temp + M(112, 5) * x(112)
      x(5) = ( x(5) - temp ) / M(5, 5)

      temp = M(67, 4) * x(67)
      temp = temp + M(91, 4) * x(91)
      temp = temp + M(96, 4) * x(96)
      temp = temp + M(111, 4) * x(111)
      temp = temp + M(112, 4) * x(112)
      x(4) = ( x(4) - temp ) / M(4, 4)

      x(3) = x(3) / M(3, 3)

      temp = M(3, 2) * x(3)
      temp = temp + M(111, 2) * x(111)
      temp = temp + M(112, 2) * x(112)
      x(2) = ( x(2) - temp ) / M(2, 2)

      temp = M(44, 1) * x(44)
      temp = temp + M(112, 1) * x(112)
      x(1) = ( x(1) - temp ) / M(1, 1)


      END
