C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C
C     This file is part of the air quality modeling system Polyphemus.
C
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C
C     Polyphemus is free software; you can redistribute i and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C------------------------------------------------------------------------
 
      subroutine jacdchemdc_radm(ns,nr,y,convers_factor,
     $                    convers_factor_jac,rk,JacC)
 
C------------------------------------------------------------------------
C
C     -- DESCRIPTION
C
C     This routine computes the Jacobian matrix for the gas-phase.
C     This routine is automatically generated by SPACK.
C     Mechanism: RADM                
C     Species: _ciRADM             
C
C------------------------------------------------------------------------
C
C     -- INPUT VARIABLES
C
C     Ns: chemical species number.
C     NR: reaction number.
C     Y: chemical concentrations.
C     RK: kinetic rates.
C     convers_factor: unity conversion factor of mug/m3 to molecules/cm3.
C     convers_factor_jac: Wmol(i)/Wmol(j) for JacC(i,j)
C
C     -- INPUT/OUTPUT VARIABLES
C
C     -- OUTPUT VARIABLES
C
C     JACC: Jacobian matrix.
C
C------------------------------------------------------------------------
C
C     -- REMARKS
C
C     The matrix JACC could be stored in a low-dimensional vector.
C
C------------------------------------------------------------------------
C
C     -- MODIFICATIONS
C
C------------------------------------------------------------------------
C
C     -- AUTHOR(S)
C
C     SPACK.
C
C------------------------------------------------------------------------
 
      implicit none
 
      integer i,j,nr,ns
      double precision dw(nr,ns),rk(nr),y(ns),JacC(ns,ns)
      double precision convers_factor(ns)
      double precision convers_factor_jac(ns,ns)
      double precision conc(ns)
 
      do j=1,ns
       do i=1,ns
        JacC(i,j)=0.d0
       enddo
      enddo
 
C     Conversion mug/m3 to molecules/cm3.
 
      do i = 1, ns
         conc(i) = y(i) * convers_factor(i)
      enddo
 
      call dratedc_radm(ns,nr,rk,conc,dw)
 
      JacC( 23, 55) = JacC( 23, 55) + dw(  1, 55)
      JacC( 55, 55) = JacC( 55, 55) - dw(  1, 55)
      JacC( 56, 55) = JacC( 56, 55) + dw(  1, 55)
      JacC(  8, 26) = JacC(  8, 26) + dw(  2, 26)
      JacC( 26, 26) = JacC( 26, 26) - dw(  2, 26)
      JacC( 23, 26) = JacC( 23, 26) + dw(  3, 26)
      JacC( 26, 26) = JacC( 26, 26) - dw(  3, 26)
      JacC( 12, 12) = JacC( 12, 12) - dw(  4, 12)
      JacC( 50, 12) = JacC( 50, 12) + dw(  4, 12)
      JacC( 56, 12) = JacC( 56, 12) + dw(  4, 12)
      JacC( 49, 49) = JacC( 49, 49) - dw(  5, 49)
      JacC( 50, 49) = JacC( 50, 49) + dw(  5, 49)
      JacC( 55, 49) = JacC( 55, 49) + dw(  5, 49)
      JacC( 24, 24) = JacC( 24, 24) - dw(  6, 24)
      JacC( 50, 24) = JacC( 50, 24)+ 0.3500000000000000D+00*dw(  6, 24)
      JacC( 51, 24) = JacC( 51, 24)+ 0.3500000000000000D+00*dw(  6, 24)
      JacC( 55, 24) = JacC( 55, 24)+ 0.6500000000000000D+00*dw(  6, 24)
      JacC( 57, 24) = JacC( 57, 24)+ 0.6500000000000000D+00*dw(  6, 24)
      JacC( 51, 51) = JacC( 51, 51) - dw(  7, 51)
      JacC( 56, 51) = JacC( 56, 51) + dw(  7, 51)
      JacC( 23, 51) = JacC( 23, 51) + dw(  8, 51)
      JacC( 51, 51) = JacC( 51, 51) - dw(  8, 51)
      JacC( 55, 51) = JacC( 55, 51) + dw(  8, 51)
      JacC( 10, 10) = JacC( 10, 10) - dw(  9, 10)
      JacC( 50, 10) = JacC( 50, 10)+ 0.2000000000000000D+01*dw(  9, 10)
      JacC( 48, 48) = JacC( 48, 48) - dw( 10, 48)
      JacC( 53, 48) = JacC( 53, 48) + dw( 10, 48)
      JacC( 48, 48) = JacC( 48, 48) - dw( 11, 48)
      JacC( 53, 48) = JacC( 53, 48) + dw( 11, 48)
      JacC( 57, 48) = JacC( 57, 48)+ 0.2000000000000000D+01*dw( 11, 48)
      JacC( 44, 44) = JacC( 44, 44) - dw( 12, 44)
      JacC( 46, 44) = JacC( 46, 44) + dw( 12, 44)
      JacC( 53, 44) = JacC( 53, 44) + dw( 12, 44)
      JacC( 57, 44) = JacC( 57, 44) + dw( 12, 44)
      JacC( 21, 21) = JacC( 21, 21) - dw( 13, 21)
      JacC( 48, 21) = JacC( 48, 21) + dw( 13, 21)
      JacC( 50, 21) = JacC( 50, 21) + dw( 13, 21)
      JacC( 57, 21) = JacC( 57, 21) + dw( 13, 21)
      JacC( 42, 42) = JacC( 42, 42) - dw( 14, 42)
      JacC( 44, 42) = JacC( 44, 42) + dw( 14, 42)
      JacC( 50, 42) = JacC( 50, 42) + dw( 14, 42)
      JacC( 57, 42) = JacC( 57, 42) + dw( 14, 42)
      JacC( 22, 22) = JacC( 22, 22) - dw( 15, 22)
      JacC( 46, 22) = JacC( 46, 22) + dw( 15, 22)
      JacC( 50, 22) = JacC( 50, 22) + dw( 15, 22)
      JacC( 38, 38) = JacC( 38, 38) - dw( 16, 38)
      JacC( 39, 38) = JacC( 39, 38) + dw( 16, 38)
      JacC( 58, 38) = JacC( 58, 38) + dw( 16, 38)
      JacC( 47, 47) = JacC( 47, 47) - dw( 17, 47)
      JacC( 48, 47) = JacC( 48, 47)+ 0.1300000000000000D+00*dw( 17, 47)
      JacC( 53, 47) = JacC( 53, 47)+ 0.1870000000000000D+01*dw( 17, 47)
      JacC( 47, 47) = JacC( 47, 47) - dw( 18, 47)
      JacC( 48, 47) = JacC( 48, 47)+ 0.4500000000000000D+00*dw( 18, 47)
      JacC( 53, 47) = JacC( 53, 47)+ 0.1550000000000000D+01*dw( 18, 47)
      JacC( 57, 47) = JacC( 57, 47)+ 0.8000000000000000D+00*dw( 18, 47)
      JacC( 52, 52) = JacC( 52, 52) - dw( 19, 52)
      JacC( 53, 52) = JacC( 53, 52) + dw( 19, 52)
      JacC( 57, 52) = JacC( 57, 52) + dw( 19, 52)
      JacC( 58, 52) = JacC( 58, 52) + dw( 19, 52)
      JacC( 33, 33) = JacC( 33, 33) - dw( 20, 33)
      JacC( 54, 33) = JacC( 54, 33) + dw( 20, 33)
      JacC( 57, 33) = JacC( 57, 33) + dw( 20, 33)
      JacC( 37, 37) = JacC( 37, 37) - dw( 21, 37)
      JacC( 38, 37) = JacC( 38, 37)+ 0.8000000000000000D+00*dw( 21, 37)
      JacC( 44, 37) = JacC( 44, 37)+ 0.2000000000000000D+00*dw( 21, 37)
      JacC( 55, 37) = JacC( 55, 37) + dw( 21, 37)
      JacC( 57, 37) = JacC( 57, 37) + dw( 21, 37)
      JacC( 23, 23) = JacC( 23, 23) - dw( 22, 23)
      JacC( 23, 55) = JacC( 23, 55) - dw( 22, 55)
      JacC( 55, 23) = JacC( 55, 23) - dw( 22, 23)
      JacC( 55, 55) = JacC( 55, 55) - dw( 22, 55)
      JacC( 56, 23) = JacC( 56, 23) + dw( 22, 23)
      JacC( 56, 55) = JacC( 56, 55) + dw( 22, 55)
      JacC(  8,  8) = JacC(  8,  8) - dw( 23,  8)
      JacC( 23,  8) = JacC( 23,  8) + dw( 23,  8)
      JacC(  8,  8) = JacC(  8,  8) - dw( 24,  8)
      JacC( 23,  8) = JacC( 23,  8) + dw( 24,  8)
      JacC(  8,  8) = JacC(  8,  8) - dw( 25,  8)
      JacC( 50,  8) = JacC( 50,  8)+ 0.2000000000000000D+01*dw( 25,  8)
      JacC( 26, 26) = JacC( 26, 26) - dw( 26, 26)
      JacC( 26, 56) = JacC( 26, 56) - dw( 26, 56)
      JacC( 55, 26) = JacC( 55, 26) + dw( 26, 26)
      JacC( 55, 56) = JacC( 55, 56) + dw( 26, 56)
      JacC( 56, 26) = JacC( 56, 26) - dw( 26, 26)
      JacC( 56, 56) = JacC( 56, 56) - dw( 26, 56)
      JacC( 26, 26) = JacC( 26, 26) - dw( 27, 26)
      JacC( 26, 50) = JacC( 26, 50) - dw( 27, 50)
      JacC( 50, 26) = JacC( 50, 26) - dw( 27, 26)
      JacC( 50, 50) = JacC( 50, 50) - dw( 27, 50)
      JacC( 57, 26) = JacC( 57, 26) + dw( 27, 26)
      JacC( 57, 50) = JacC( 57, 50) + dw( 27, 50)
      JacC( 26, 26) = JacC( 26, 26) - dw( 28, 26)
      JacC( 26, 57) = JacC( 26, 57) - dw( 28, 57)
      JacC( 50, 26) = JacC( 50, 26) + dw( 28, 26)
      JacC( 50, 57) = JacC( 50, 57) + dw( 28, 57)
      JacC( 57, 26) = JacC( 57, 26) - dw( 28, 26)
      JacC( 57, 57) = JacC( 57, 57) - dw( 28, 57)
      JacC( 50, 57) = JacC( 50, 57) + dw( 29, 57)
      JacC( 50, 56) = JacC( 50, 56) + dw( 29, 56)
      JacC( 55, 57) = JacC( 55, 57) + dw( 29, 57)
      JacC( 55, 56) = JacC( 55, 56) + dw( 29, 56)
      JacC( 56, 57) = JacC( 56, 57) - dw( 29, 57)
      JacC( 56, 56) = JacC( 56, 56) - dw( 29, 56)
      JacC( 57, 57) = JacC( 57, 57) - dw( 29, 57)
      JacC( 57, 56) = JacC( 57, 56) - dw( 29, 56)
      JacC( 10, 10) = JacC( 10, 10) - dw( 30, 10)
      JacC( 10, 50) = JacC( 10, 50) - dw( 30, 50)
      JacC( 50, 10) = JacC( 50, 10) - dw( 30, 10)
      JacC( 50, 50) = JacC( 50, 50) - dw( 30, 50)
      JacC( 57, 10) = JacC( 57, 10) + dw( 30, 10)
      JacC( 57, 50) = JacC( 57, 50) + dw( 30, 50)
      JacC( 55, 56) = JacC( 55, 56)+ 0.2000000000000000D+01*dw( 31, 56)
      JacC( 55, 56) = JacC( 55, 56)+ 0.2000000000000000D+01*dw( 31, 56)
      JacC( 56, 56) = JacC( 56, 56)- 0.2000000000000000D+01*dw( 31, 56)
      JacC( 56, 56) = JacC( 56, 56)- 0.2000000000000000D+01*dw( 31, 56)
      JacC( 26, 26) = JacC( 26, 26) - dw( 32, 26)
      JacC( 26, 55) = JacC( 26, 55) - dw( 32, 55)
      JacC( 51, 26) = JacC( 51, 26) + dw( 32, 26)
      JacC( 51, 55) = JacC( 51, 55) + dw( 32, 55)
      JacC( 55, 26) = JacC( 55, 26) - dw( 32, 26)
      JacC( 55, 55) = JacC( 55, 55) - dw( 32, 55)
      JacC( 51, 51) = JacC( 51, 51) - dw( 33, 51)
      JacC( 51, 56) = JacC( 51, 56) - dw( 33, 56)
      JacC( 55, 51) = JacC( 55, 51)+ 0.2000000000000000D+01*dw( 33, 51)
      JacC( 55, 56) = JacC( 55, 56)+ 0.2000000000000000D+01*dw( 33, 56)
      JacC( 56, 51) = JacC( 56, 51) - dw( 33, 51)
      JacC( 56, 56) = JacC( 56, 56) - dw( 33, 56)
      JacC( 51, 51) = JacC( 51, 51) - dw( 34, 51)
      JacC( 51, 55) = JacC( 51, 55) - dw( 34, 55)
      JacC( 56, 51) = JacC( 56, 51) + dw( 34, 51)
      JacC( 56, 55) = JacC( 56, 55) + dw( 34, 55)
      JacC( 49, 51) = JacC( 49, 51) + dw( 35, 51)
      JacC( 49, 57) = JacC( 49, 57) + dw( 35, 57)
      JacC( 51, 51) = JacC( 51, 51) - dw( 35, 51)
      JacC( 51, 57) = JacC( 51, 57) - dw( 35, 57)
      JacC( 57, 51) = JacC( 57, 51) - dw( 35, 51)
      JacC( 57, 57) = JacC( 57, 57) - dw( 35, 57)
      JacC( 11, 11) = JacC( 11, 11) - dw( 36, 11)
      JacC( 49, 11) = JacC( 49, 11)+ 0.2000000000000000D+01*dw( 36, 11)
      JacC( 24, 50) = JacC( 24, 50) - dw( 37, 50)
      JacC( 24, 24) = JacC( 24, 24) - dw( 37, 24)
      JacC( 50, 50) = JacC( 50, 50) - dw( 37, 50)
      JacC( 50, 24) = JacC( 50, 24) - dw( 37, 24)
      JacC( 55, 50) = JacC( 55, 50) + dw( 37, 50)
      JacC( 55, 24) = JacC( 55, 24) + dw( 37, 24)
      JacC( 50, 50) = JacC( 50, 50) - dw( 38, 50)
      JacC( 50, 57) = JacC( 50, 57) - dw( 38, 57)
      JacC( 57, 50) = JacC( 57, 50) - dw( 38, 50)
      JacC( 57, 57) = JacC( 57, 57) - dw( 38, 57)
      JacC( 17, 17) = JacC( 17, 17) - dw( 39, 17)
      JacC( 17, 50) = JacC( 17, 50) - dw( 39, 50)
      JacC( 46, 17) = JacC( 46, 17) + dw( 39, 17)
      JacC( 46, 50) = JacC( 46, 50) + dw( 39, 50)
      JacC( 50, 17) = JacC( 50, 17) - dw( 39, 17)
      JacC( 50, 50) = JacC( 50, 50) - dw( 39, 50)
      JacC(  2,  2) = JacC(  2,  2) - dw( 40,  2)
      JacC(  2, 50) = JacC(  2, 50) - dw( 40, 50)
      JacC( 39,  2) = JacC( 39,  2) + dw( 40,  2)
      JacC( 39, 50) = JacC( 39, 50) + dw( 40, 50)
      JacC( 50,  2) = JacC( 50,  2) - dw( 40,  2)
      JacC( 50, 50) = JacC( 50, 50) - dw( 40, 50)
      JacC(  3,  3) = JacC(  3,  3) - dw( 41,  3)
      JacC(  3, 50) = JacC(  3, 50) - dw( 41, 50)
      JacC( 38,  3) = JacC( 38,  3)+ 0.2500000000000000D-01*dw( 41,  3)
      JacC( 38, 50) = JacC( 38, 50)+ 0.2500000000000000D-01*dw( 41, 50)
      JacC( 43,  3) = JacC( 43,  3)+ 0.8300000000000000D+00*dw( 41,  3)
      JacC( 43, 50) = JacC( 43, 50)+ 0.8300000000000000D+00*dw( 41, 50)
      JacC( 44,  3) = JacC( 44,  3)+ 0.7500000000000000D-01*dw( 41,  3)
      JacC( 44, 50) = JacC( 44, 50)+ 0.7500000000000000D-01*dw( 41, 50)
      JacC( 48,  3) = JacC( 48,  3)+ 0.8999999999999999D-02*dw( 41,  3)
      JacC( 48, 50) = JacC( 48, 50)+ 0.8999999999999999D-02*dw( 41, 50)
      JacC( 50,  3) = JacC( 50,  3) - dw( 41,  3)
      JacC( 50, 50) = JacC( 50, 50) - dw( 41, 50)
      JacC( 57,  3) = JacC( 57,  3)+ 0.1700000000000000D+00*dw( 41,  3)
      JacC( 57, 50) = JacC( 57, 50)+ 0.1700000000000000D+00*dw( 41, 50)
      JacC(  4,  4) = JacC(  4,  4) - dw( 42,  4)
      JacC(  4, 50) = JacC(  4, 50) - dw( 42, 50)
      JacC( 27,  4) = JacC( 27,  4) + dw( 42,  4)
      JacC( 27, 50) = JacC( 27, 50) + dw( 42, 50)
      JacC( 45,  4) = JacC( 45,  4)+ 0.2500000000000000D+00*dw( 42,  4)
      JacC( 45, 50) = JacC( 45, 50)+ 0.2500000000000000D+00*dw( 42, 50)
      JacC( 50,  4) = JacC( 50,  4) - dw( 42,  4)
      JacC( 50, 50) = JacC( 50, 50) - dw( 42, 50)
      JacC(  5,  5) = JacC(  5,  5) - dw( 43,  5)
      JacC(  5, 50) = JacC(  5, 50) - dw( 43, 50)
      JacC( 28,  5) = JacC( 28,  5) + dw( 43,  5)
      JacC( 28, 50) = JacC( 28, 50) + dw( 43, 50)
      JacC( 45,  5) = JacC( 45,  5)+ 0.7500000000000000D+00*dw( 43,  5)
      JacC( 45, 50) = JacC( 45, 50)+ 0.7500000000000000D+00*dw( 43, 50)
      JacC( 50,  5) = JacC( 50,  5) - dw( 43,  5)
      JacC( 50, 50) = JacC( 50, 50) - dw( 43, 50)
      JacC( 25, 25) = JacC( 25, 25) - dw( 44, 25)
      JacC( 25, 50) = JacC( 25, 50) - dw( 44, 50)
      JacC( 34, 25) = JacC( 34, 25) + dw( 44, 25)
      JacC( 34, 50) = JacC( 34, 50) + dw( 44, 50)
      JacC( 50, 25) = JacC( 50, 25) - dw( 44, 25)
      JacC( 50, 50) = JacC( 50, 50) - dw( 44, 50)
      JacC( 15, 15) = JacC( 15, 15) - dw( 45, 15)
      JacC( 15, 50) = JacC( 15, 50) - dw( 45, 50)
      JacC( 29, 15) = JacC( 29, 15) + dw( 45, 15)
      JacC( 29, 50) = JacC( 29, 50) + dw( 45, 50)
      JacC( 50, 15) = JacC( 50, 15) - dw( 45, 15)
      JacC( 50, 50) = JacC( 50, 50) - dw( 45, 50)
      JacC( 16, 16) = JacC( 16, 16) - dw( 46, 16)
      JacC( 16, 50) = JacC( 16, 50) - dw( 46, 50)
      JacC( 30, 16) = JacC( 30, 16) + dw( 46, 16)
      JacC( 30, 50) = JacC( 30, 50) + dw( 46, 50)
      JacC( 50, 16) = JacC( 50, 16) - dw( 46, 16)
      JacC( 50, 50) = JacC( 50, 50) - dw( 46, 50)
      JacC(  6,  6) = JacC(  6,  6) - dw( 47,  6)
      JacC(  6, 50) = JacC(  6, 50) - dw( 47, 50)
      JacC( 13,  6) = JacC( 13,  6)+ 0.2500000000000000D+00*dw( 47,  6)
      JacC( 13, 50) = JacC( 13, 50)+ 0.2500000000000000D+00*dw( 47, 50)
      JacC( 31,  6) = JacC( 31,  6)+ 0.7500000000000000D+00*dw( 47,  6)
      JacC( 31, 50) = JacC( 31, 50)+ 0.7500000000000000D+00*dw( 47, 50)
      JacC( 50,  6) = JacC( 50,  6) - dw( 47,  6)
      JacC( 50, 50) = JacC( 50, 50) - dw( 47, 50)
      JacC( 57,  6) = JacC( 57,  6)+ 0.2500000000000000D+00*dw( 47,  6)
      JacC( 57, 50) = JacC( 57, 50)+ 0.2500000000000000D+00*dw( 47, 50)
      JacC(  7,  7) = JacC(  7,  7) - dw( 48,  7)
      JacC(  7, 50) = JacC(  7, 50) - dw( 48, 50)
      JacC( 13,  7) = JacC( 13,  7)+ 0.1700000000000000D+00*dw( 48,  7)
      JacC( 13, 50) = JacC( 13, 50)+ 0.1700000000000000D+00*dw( 48, 50)
      JacC( 32,  7) = JacC( 32,  7)+ 0.8300000000000000D+00*dw( 48,  7)
      JacC( 32, 50) = JacC( 32, 50)+ 0.8300000000000000D+00*dw( 48, 50)
      JacC( 50,  7) = JacC( 50,  7) - dw( 48,  7)
      JacC( 50, 50) = JacC( 50, 50) - dw( 48, 50)
      JacC( 57,  7) = JacC( 57,  7)+ 0.1700000000000000D+00*dw( 48,  7)
      JacC( 57, 50) = JacC( 57, 50)+ 0.1700000000000000D+00*dw( 48, 50)
      JacC( 13, 13) = JacC( 13, 13) - dw( 49, 13)
      JacC( 13, 50) = JacC( 13, 50) - dw( 49, 50)
      JacC( 45, 13) = JacC( 45, 13)+ 0.9000000000000000D+00*dw( 49, 13)
      JacC( 45, 50) = JacC( 45, 50)+ 0.9000000000000000D+00*dw( 49, 50)
      JacC( 50, 13) = JacC( 50, 13) - dw( 49, 13)
      JacC( 50, 50) = JacC( 50, 50) - dw( 49, 50)
      JacC( 54, 13) = JacC( 54, 13)+ 0.9000000000000000D+00*dw( 49, 13)
      JacC( 54, 50) = JacC( 54, 50)+ 0.9000000000000000D+00*dw( 49, 50)
      JacC( 57, 13) = JacC( 57, 13)+ 0.1000000000000000D+00*dw( 49, 13)
      JacC( 57, 50) = JacC( 57, 50)+ 0.1000000000000000D+00*dw( 49, 50)
      JacC( 48, 48) = JacC( 48, 48) - dw( 50, 48)
      JacC( 48, 50) = JacC( 48, 50) - dw( 50, 50)
      JacC( 50, 48) = JacC( 50, 48) - dw( 50, 48)
      JacC( 50, 50) = JacC( 50, 50) - dw( 50, 50)
      JacC( 53, 48) = JacC( 53, 48) + dw( 50, 48)
      JacC( 53, 50) = JacC( 53, 50) + dw( 50, 50)
      JacC( 57, 48) = JacC( 57, 48) + dw( 50, 48)
      JacC( 57, 50) = JacC( 57, 50) + dw( 50, 50)
      JacC( 44, 44) = JacC( 44, 44) - dw( 51, 44)
      JacC( 44, 50) = JacC( 44, 50) - dw( 51, 50)
      JacC( 50, 44) = JacC( 50, 44) - dw( 51, 44)
      JacC( 50, 50) = JacC( 50, 50) - dw( 51, 50)
      JacC( 58, 44) = JacC( 58, 44) + dw( 51, 44)
      JacC( 58, 50) = JacC( 58, 50) + dw( 51, 50)
      JacC( 38, 38) = JacC( 38, 38) - dw( 52, 38)
      JacC( 38, 50) = JacC( 38, 50) - dw( 52, 50)
      JacC( 40, 38) = JacC( 40, 38) + dw( 52, 38)
      JacC( 40, 50) = JacC( 40, 50) + dw( 52, 50)
      JacC( 50, 38) = JacC( 50, 38) - dw( 52, 38)
      JacC( 50, 50) = JacC( 50, 50) - dw( 52, 50)
      JacC( 47, 47) = JacC( 47, 47) - dw( 53, 47)
      JacC( 47, 50) = JacC( 47, 50) - dw( 53, 50)
      JacC( 50, 47) = JacC( 50, 47) - dw( 53, 47)
      JacC( 50, 50) = JacC( 50, 50) - dw( 53, 50)
      JacC( 53, 47) = JacC( 53, 47)+ 0.2000000000000000D+01*dw( 53, 47)
      JacC( 53, 50) = JacC( 53, 50)+ 0.2000000000000000D+01*dw( 53, 50)
      JacC( 57, 47) = JacC( 57, 47) + dw( 53, 47)
      JacC( 57, 50) = JacC( 57, 50) + dw( 53, 50)
      JacC( 50, 52) = JacC( 50, 52) - dw( 54, 52)
      JacC( 50, 50) = JacC( 50, 50) - dw( 54, 50)
      JacC( 52, 52) = JacC( 52, 52) - dw( 54, 52)
      JacC( 52, 50) = JacC( 52, 50) - dw( 54, 50)
      JacC( 53, 52) = JacC( 53, 52) + dw( 54, 52)
      JacC( 53, 50) = JacC( 53, 50) + dw( 54, 50)
      JacC( 58, 52) = JacC( 58, 52) + dw( 54, 52)
      JacC( 58, 50) = JacC( 58, 50) + dw( 54, 50)
      JacC( 33, 33) = JacC( 33, 33) - dw( 55, 33)
      JacC( 33, 50) = JacC( 33, 50) - dw( 55, 50)
      JacC( 50, 33) = JacC( 50, 33) - dw( 55, 33)
      JacC( 50, 50) = JacC( 50, 50) - dw( 55, 50)
      JacC( 54, 33) = JacC( 54, 33) + dw( 55, 33)
      JacC( 54, 50) = JacC( 54, 50) + dw( 55, 50)
      JacC( 21, 21) = JacC( 21, 21) - dw( 56, 21)
      JacC( 21, 50) = JacC( 21, 50) - dw( 56, 50)
      JacC( 46, 21) = JacC( 46, 21)+ 0.5000000000000000D+00*dw( 56, 21)
      JacC( 46, 50) = JacC( 46, 50)+ 0.5000000000000000D+00*dw( 56, 50)
      JacC( 48, 21) = JacC( 48, 21)+ 0.5000000000000000D+00*dw( 56, 21)
      JacC( 48, 50) = JacC( 48, 50)+ 0.5000000000000000D+00*dw( 56, 50)
      JacC( 50, 21) = JacC( 50, 21)- 0.5000000000000000D+00*dw( 56, 21)
      JacC( 50, 50) = JacC( 50, 50)- 0.5000000000000000D+00*dw( 56, 50)
      JacC( 42, 42) = JacC( 42, 42) - dw( 57, 42)
      JacC( 42, 50) = JacC( 42, 50) - dw( 57, 50)
      JacC( 43, 42) = JacC( 43, 42)+ 0.5000000000000000D+00*dw( 57, 42)
      JacC( 43, 50) = JacC( 43, 50)+ 0.5000000000000000D+00*dw( 57, 50)
      JacC( 44, 42) = JacC( 44, 42)+ 0.5000000000000000D+00*dw( 57, 42)
      JacC( 44, 50) = JacC( 44, 50)+ 0.5000000000000000D+00*dw( 57, 50)
      JacC( 50, 42) = JacC( 50, 42)- 0.5000000000000000D+00*dw( 57, 42)
      JacC( 50, 50) = JacC( 50, 50)- 0.5000000000000000D+00*dw( 57, 50)
      JacC( 22, 22) = JacC( 22, 22) - dw( 58, 22)
      JacC( 22, 50) = JacC( 22, 50) - dw( 58, 50)
      JacC( 50, 22) = JacC( 50, 22) - dw( 58, 22)
      JacC( 50, 50) = JacC( 50, 50) - dw( 58, 50)
      JacC( 58, 22) = JacC( 58, 22) + dw( 58, 22)
      JacC( 58, 50) = JacC( 58, 50) + dw( 58, 50)
      JacC( 20, 20) = JacC( 20, 20) - dw( 59, 20)
      JacC( 20, 50) = JacC( 20, 50) - dw( 59, 50)
      JacC( 45, 20) = JacC( 45, 20) + dw( 59, 20)
      JacC( 45, 50) = JacC( 45, 50) + dw( 59, 50)
      JacC( 48, 20) = JacC( 48, 20) + dw( 59, 20)
      JacC( 48, 50) = JacC( 48, 50) + dw( 59, 50)
      JacC( 50, 20) = JacC( 50, 20) - dw( 59, 20)
      JacC( 50, 50) = JacC( 50, 50) - dw( 59, 50)
      JacC( 51, 20) = JacC( 51, 20) + dw( 59, 20)
      JacC( 51, 50) = JacC( 51, 50) + dw( 59, 50)
      JacC( 37, 37) = JacC( 37, 37) - dw( 60, 37)
      JacC( 37, 50) = JacC( 37, 50) - dw( 60, 50)
      JacC( 43, 37) = JacC( 43, 37) + dw( 60, 37)
      JacC( 43, 50) = JacC( 43, 50) + dw( 60, 50)
      JacC( 50, 37) = JacC( 50, 37) - dw( 60, 37)
      JacC( 50, 50) = JacC( 50, 50) - dw( 60, 50)
      JacC( 55, 37) = JacC( 55, 37) + dw( 60, 37)
      JacC( 55, 50) = JacC( 55, 50) + dw( 60, 50)
      JacC( 18, 18) = JacC( 18, 18) - dw( 61, 18)
      JacC( 18, 50) = JacC( 18, 50) - dw( 61, 50)
      JacC( 29, 18) = JacC( 29, 18) + dw( 61, 18)
      JacC( 29, 50) = JacC( 29, 50) + dw( 61, 50)
      JacC( 50, 18) = JacC( 50, 18) - dw( 61, 18)
      JacC( 50, 50) = JacC( 50, 50) - dw( 61, 50)
      JacC( 20, 58) = JacC( 20, 58) + dw( 62, 58)
      JacC( 20, 55) = JacC( 20, 55) + dw( 62, 55)
      JacC( 55, 58) = JacC( 55, 58) - dw( 62, 58)
      JacC( 55, 55) = JacC( 55, 55) - dw( 62, 55)
      JacC( 58, 58) = JacC( 58, 58) - dw( 62, 58)
      JacC( 58, 55) = JacC( 58, 55) - dw( 62, 55)
      JacC( 20, 20) = JacC( 20, 20) - dw( 63, 20)
      JacC( 55, 20) = JacC( 55, 20) + dw( 63, 20)
      JacC( 58, 20) = JacC( 58, 20) + dw( 63, 20)
      JacC( 14, 54) = JacC( 14, 54) + dw( 64, 54)
      JacC( 14, 55) = JacC( 14, 55) + dw( 64, 55)
      JacC( 54, 54) = JacC( 54, 54) - dw( 64, 54)
      JacC( 54, 55) = JacC( 54, 55) - dw( 64, 55)
      JacC( 55, 54) = JacC( 55, 54) - dw( 64, 54)
      JacC( 55, 55) = JacC( 55, 55) - dw( 64, 55)
      JacC( 14, 14) = JacC( 14, 14) - dw( 65, 14)
      JacC( 54, 14) = JacC( 54, 14) + dw( 65, 14)
      JacC( 55, 14) = JacC( 55, 14) + dw( 65, 14)
      JacC( 46, 46) = JacC( 46, 46) - dw( 66, 46)
      JacC( 46, 56) = JacC( 46, 56) - dw( 66, 56)
      JacC( 48, 46) = JacC( 48, 46) + dw( 66, 46)
      JacC( 48, 56) = JacC( 48, 56) + dw( 66, 56)
      JacC( 55, 46) = JacC( 55, 46) + dw( 66, 46)
      JacC( 55, 56) = JacC( 55, 56) + dw( 66, 56)
      JacC( 56, 46) = JacC( 56, 46) - dw( 66, 46)
      JacC( 56, 56) = JacC( 56, 56) - dw( 66, 56)
      JacC( 57, 46) = JacC( 57, 46) + dw( 66, 46)
      JacC( 57, 56) = JacC( 57, 56) + dw( 66, 56)
      JacC( 37, 43) = JacC( 37, 43)+ 0.3600000000000000D-01*dw( 67, 43)
      JacC( 37, 56) = JacC( 37, 56)+ 0.3600000000000000D-01*dw( 67, 56)
      JacC( 38, 43) = JacC( 38, 43)+ 0.2500000000000000D+00*dw( 67, 43)
      JacC( 38, 56) = JacC( 38, 56)+ 0.2500000000000000D+00*dw( 67, 56)
      JacC( 43, 43) = JacC( 43, 43) - dw( 67, 43)
      JacC( 43, 56) = JacC( 43, 56) - dw( 67, 56)
      JacC( 44, 43) = JacC( 44, 43)+ 0.7500000000000000D+00*dw( 67, 43)
      JacC( 44, 56) = JacC( 44, 56)+ 0.7500000000000000D+00*dw( 67, 56)
      JacC( 48, 43) = JacC( 48, 43)+ 0.9000000000000000D-01*dw( 67, 43)
      JacC( 48, 56) = JacC( 48, 56)+ 0.9000000000000000D-01*dw( 67, 56)
      JacC( 55, 43) = JacC( 55, 43)+ 0.9640000000000000D+00*dw( 67, 43)
      JacC( 55, 56) = JacC( 55, 56)+ 0.9640000000000000D+00*dw( 67, 56)
      JacC( 56, 43) = JacC( 56, 43) - dw( 67, 43)
      JacC( 56, 56) = JacC( 56, 56) - dw( 67, 56)
      JacC( 57, 43) = JacC( 57, 43)+ 0.9640000000000000D+00*dw( 67, 43)
      JacC( 57, 56) = JacC( 57, 56)+ 0.9640000000000000D+00*dw( 67, 56)
      JacC( 27, 27) = JacC( 27, 27) - dw( 68, 27)
      JacC( 27, 56) = JacC( 27, 56) - dw( 68, 56)
      JacC( 37, 27) = JacC( 37, 27)+ 0.8000000000000000D-01*dw( 68, 27)
      JacC( 37, 56) = JacC( 37, 56)+ 0.8000000000000000D-01*dw( 68, 56)
      JacC( 38, 27) = JacC( 38, 27)+ 0.6899999999999999D+00*dw( 68, 27)
      JacC( 38, 56) = JacC( 38, 56)+ 0.6899999999999999D+00*dw( 68, 56)
      JacC( 44, 27) = JacC( 44, 27)+ 0.3800000000000000D+00*dw( 68, 27)
      JacC( 44, 56) = JacC( 44, 56)+ 0.3800000000000000D+00*dw( 68, 56)
      JacC( 55, 27) = JacC( 55, 27)+ 0.9200000000000000D+00*dw( 68, 27)
      JacC( 55, 56) = JacC( 55, 56)+ 0.9200000000000000D+00*dw( 68, 56)
      JacC( 56, 27) = JacC( 56, 27) - dw( 68, 27)
      JacC( 56, 56) = JacC( 56, 56) - dw( 68, 56)
      JacC( 57, 27) = JacC( 57, 27)+ 0.9200000000000000D+00*dw( 68, 27)
      JacC( 57, 56) = JacC( 57, 56)+ 0.9200000000000000D+00*dw( 68, 56)
      JacC( 28, 28) = JacC( 28, 28) - dw( 69, 28)
      JacC( 28, 56) = JacC( 28, 56) - dw( 69, 56)
      JacC( 37, 28) = JacC( 37, 28)+ 0.2400000000000000D+00*dw( 69, 28)
      JacC( 37, 56) = JacC( 37, 56)+ 0.2400000000000000D+00*dw( 69, 56)
      JacC( 38, 28) = JacC( 38, 28)+ 0.1060000000000000D+01*dw( 69, 28)
      JacC( 38, 56) = JacC( 38, 56)+ 0.1060000000000000D+01*dw( 69, 56)
      JacC( 44, 28) = JacC( 44, 28)+ 0.3500000000000000D+00*dw( 69, 28)
      JacC( 44, 56) = JacC( 44, 56)+ 0.3500000000000000D+00*dw( 69, 56)
      JacC( 48, 28) = JacC( 48, 28)+ 0.4000000000000000D-01*dw( 69, 28)
      JacC( 48, 56) = JacC( 48, 56)+ 0.4000000000000000D-01*dw( 69, 56)
      JacC( 55, 28) = JacC( 55, 28)+ 0.7600000000000000D+00*dw( 69, 28)
      JacC( 55, 56) = JacC( 55, 56)+ 0.7600000000000000D+00*dw( 69, 56)
      JacC( 56, 28) = JacC( 56, 28) - dw( 69, 28)
      JacC( 56, 56) = JacC( 56, 56) - dw( 69, 56)
      JacC( 57, 28) = JacC( 57, 28)+ 0.7600000000000000D+00*dw( 69, 28)
      JacC( 57, 56) = JacC( 57, 56)+ 0.7600000000000000D+00*dw( 69, 56)
      JacC( 34, 34) = JacC( 34, 34) - dw( 70, 34)
      JacC( 34, 56) = JacC( 34, 56) - dw( 70, 56)
      JacC( 44, 34) = JacC( 44, 34)+ 0.2000000000000000D+00*dw( 70, 34)
      JacC( 44, 56) = JacC( 44, 56)+ 0.2000000000000000D+00*dw( 70, 56)
      JacC( 48, 34) = JacC( 48, 34)+ 0.1600000000000000D+01*dw( 70, 34)
      JacC( 48, 56) = JacC( 48, 56)+ 0.1600000000000000D+01*dw( 70, 56)
      JacC( 55, 34) = JacC( 55, 34) + dw( 70, 34)
      JacC( 55, 56) = JacC( 55, 56) + dw( 70, 56)
      JacC( 56, 34) = JacC( 56, 34) - dw( 70, 34)
      JacC( 56, 56) = JacC( 56, 56) - dw( 70, 56)
      JacC( 57, 34) = JacC( 57, 34) + dw( 70, 34)
      JacC( 57, 56) = JacC( 57, 56) + dw( 70, 56)
      JacC( 29, 29) = JacC( 29, 29) - dw( 71, 29)
      JacC( 29, 56) = JacC( 29, 56) - dw( 71, 56)
      JacC( 44, 29) = JacC( 44, 29) + dw( 71, 29)
      JacC( 44, 56) = JacC( 44, 56) + dw( 71, 56)
      JacC( 48, 29) = JacC( 48, 29) + dw( 71, 29)
      JacC( 48, 56) = JacC( 48, 56) + dw( 71, 56)
      JacC( 55, 29) = JacC( 55, 29) + dw( 71, 29)
      JacC( 55, 56) = JacC( 55, 56) + dw( 71, 56)
      JacC( 56, 29) = JacC( 56, 29) - dw( 71, 29)
      JacC( 56, 56) = JacC( 56, 56) - dw( 71, 56)
      JacC( 57, 29) = JacC( 57, 29) + dw( 71, 29)
      JacC( 57, 56) = JacC( 57, 56) + dw( 71, 56)
      JacC( 30, 30) = JacC( 30, 30) - dw( 72, 30)
      JacC( 30, 56) = JacC( 30, 56) - dw( 72, 56)
      JacC( 38, 30) = JacC( 38, 30)+ 0.1000000000000000D+00*dw( 72, 30)
      JacC( 38, 56) = JacC( 38, 56)+ 0.1000000000000000D+00*dw( 72, 56)
      JacC( 44, 30) = JacC( 44, 30)+ 0.1450000000000000D+01*dw( 72, 30)
      JacC( 44, 56) = JacC( 44, 56)+ 0.1450000000000000D+01*dw( 72, 56)
      JacC( 48, 30) = JacC( 48, 30)+ 0.2800000000000000D+00*dw( 72, 30)
      JacC( 48, 56) = JacC( 48, 56)+ 0.2800000000000000D+00*dw( 72, 56)
      JacC( 55, 30) = JacC( 55, 30) + dw( 72, 30)
      JacC( 55, 56) = JacC( 55, 56) + dw( 72, 56)
      JacC( 56, 30) = JacC( 56, 30) - dw( 72, 30)
      JacC( 56, 56) = JacC( 56, 56) - dw( 72, 56)
      JacC( 57, 30) = JacC( 57, 30) + dw( 72, 30)
      JacC( 57, 56) = JacC( 57, 56) + dw( 72, 56)
      JacC( 46, 58) = JacC( 46, 58) + dw( 73, 58)
      JacC( 46, 56) = JacC( 46, 56) + dw( 73, 56)
      JacC( 55, 58) = JacC( 55, 58) + dw( 73, 58)
      JacC( 55, 56) = JacC( 55, 56) + dw( 73, 56)
      JacC( 56, 58) = JacC( 56, 58) - dw( 73, 58)
      JacC( 56, 56) = JacC( 56, 56) - dw( 73, 56)
      JacC( 58, 58) = JacC( 58, 58) - dw( 73, 58)
      JacC( 58, 56) = JacC( 58, 56) - dw( 73, 56)
      JacC( 45, 54) = JacC( 45, 54)+ 0.2000000000000000D+01*dw( 74, 54)
      JacC( 45, 56) = JacC( 45, 56)+ 0.2000000000000000D+01*dw( 74, 56)
      JacC( 47, 54) = JacC( 47, 54)+ 0.8900000000000000D+00*dw( 74, 54)
      JacC( 47, 56) = JacC( 47, 56)+ 0.8900000000000000D+00*dw( 74, 56)
      JacC( 52, 54) = JacC( 52, 54)+ 0.1100000000000000D+00*dw( 74, 54)
      JacC( 52, 56) = JacC( 52, 56)+ 0.1100000000000000D+00*dw( 74, 56)
      JacC( 53, 54) = JacC( 53, 54)+ 0.9500000000000000D+00*dw( 74, 54)
      JacC( 53, 56) = JacC( 53, 56)+ 0.9500000000000000D+00*dw( 74, 56)
      JacC( 54, 54) = JacC( 54, 54) - dw( 74, 54)
      JacC( 54, 56) = JacC( 54, 56) - dw( 74, 56)
      JacC( 55, 54) = JacC( 55, 54) + dw( 74, 54)
      JacC( 55, 56) = JacC( 55, 56) + dw( 74, 56)
      JacC( 56, 54) = JacC( 56, 54) - dw( 74, 54)
      JacC( 56, 56) = JacC( 56, 56) - dw( 74, 56)
      JacC( 57, 54) = JacC( 57, 54)+ 0.9200000000000000D+00*dw( 74, 54)
      JacC( 57, 56) = JacC( 57, 56)+ 0.9200000000000000D+00*dw( 74, 56)
      JacC( 58, 54) = JacC( 58, 54)+ 0.5000000000000000D-01*dw( 74, 54)
      JacC( 58, 56) = JacC( 58, 56)+ 0.5000000000000000D-01*dw( 74, 56)
      JacC( 31, 31) = JacC( 31, 31) - dw( 75, 31)
      JacC( 31, 56) = JacC( 31, 56) - dw( 75, 56)
      JacC( 33, 31) = JacC( 33, 31)+ 0.7000000000000000D+00*dw( 75, 31)
      JacC( 33, 56) = JacC( 33, 56)+ 0.7000000000000000D+00*dw( 75, 56)
      JacC( 47, 31) = JacC( 47, 31)+ 0.1600000000000000D+00*dw( 75, 31)
      JacC( 47, 56) = JacC( 47, 56)+ 0.1600000000000000D+00*dw( 75, 56)
      JacC( 52, 31) = JacC( 52, 31)+ 0.1700000000000000D+00*dw( 75, 31)
      JacC( 52, 56) = JacC( 52, 56)+ 0.1700000000000000D+00*dw( 75, 56)
      JacC( 55, 31) = JacC( 55, 31) + dw( 75, 31)
      JacC( 55, 56) = JacC( 55, 56) + dw( 75, 56)
      JacC( 56, 31) = JacC( 56, 31) - dw( 75, 31)
      JacC( 56, 56) = JacC( 56, 56) - dw( 75, 56)
      JacC( 57, 31) = JacC( 57, 31) + dw( 75, 31)
      JacC( 57, 56) = JacC( 57, 56) + dw( 75, 56)
      JacC( 32, 32) = JacC( 32, 32) - dw( 76, 32)
      JacC( 32, 56) = JacC( 32, 56) - dw( 76, 56)
      JacC( 33, 32) = JacC( 33, 32)+ 0.8060000000000000D+00*dw( 76, 32)
      JacC( 33, 56) = JacC( 33, 56)+ 0.8060000000000000D+00*dw( 76, 56)
      JacC( 52, 32) = JacC( 52, 32)+ 0.4500000000000000D+00*dw( 76, 32)
      JacC( 52, 56) = JacC( 52, 56)+ 0.4500000000000000D+00*dw( 76, 56)
      JacC( 55, 32) = JacC( 55, 32) + dw( 76, 32)
      JacC( 55, 56) = JacC( 55, 56) + dw( 76, 56)
      JacC( 56, 32) = JacC( 56, 32) - dw( 76, 32)
      JacC( 56, 56) = JacC( 56, 56) - dw( 76, 56)
      JacC( 57, 32) = JacC( 57, 32) + dw( 76, 32)
      JacC( 57, 56) = JacC( 57, 56) + dw( 76, 56)
      JacC( 39, 39) = JacC( 39, 39) - dw( 77, 39)
      JacC( 39, 56) = JacC( 39, 56) - dw( 77, 56)
      JacC( 44, 39) = JacC( 44, 39) + dw( 77, 39)
      JacC( 44, 56) = JacC( 44, 56) + dw( 77, 56)
      JacC( 55, 39) = JacC( 55, 39) + dw( 77, 39)
      JacC( 55, 56) = JacC( 55, 56) + dw( 77, 56)
      JacC( 56, 39) = JacC( 56, 39) - dw( 77, 39)
      JacC( 56, 56) = JacC( 56, 56) - dw( 77, 56)
      JacC( 57, 39) = JacC( 57, 39) + dw( 77, 39)
      JacC( 57, 56) = JacC( 57, 56) + dw( 77, 56)
      JacC( 40, 40) = JacC( 40, 40) - dw( 78, 40)
      JacC( 40, 56) = JacC( 40, 56) - dw( 78, 56)
      JacC( 52, 40) = JacC( 52, 40) + dw( 78, 40)
      JacC( 52, 56) = JacC( 52, 56) + dw( 78, 56)
      JacC( 55, 40) = JacC( 55, 40) + dw( 78, 40)
      JacC( 55, 56) = JacC( 55, 56) + dw( 78, 56)
      JacC( 56, 40) = JacC( 56, 40) - dw( 78, 40)
      JacC( 56, 56) = JacC( 56, 56) - dw( 78, 56)
      JacC( 57, 40) = JacC( 57, 40) + dw( 78, 40)
      JacC( 57, 56) = JacC( 57, 56) + dw( 78, 56)
      JacC( 35, 35) = JacC( 35, 35) - dw( 79, 35)
      JacC( 35, 56) = JacC( 35, 56) - dw( 79, 56)
      JacC( 44, 35) = JacC( 44, 35) + dw( 79, 35)
      JacC( 44, 56) = JacC( 44, 56) + dw( 79, 56)
      JacC( 48, 35) = JacC( 48, 35) + dw( 79, 35)
      JacC( 48, 56) = JacC( 48, 56) + dw( 79, 56)
      JacC( 55, 35) = JacC( 55, 35)+ 0.2000000000000000D+01*dw( 79, 35)
      JacC( 55, 56) = JacC( 55, 56)+ 0.2000000000000000D+01*dw( 79, 56)
      JacC( 56, 35) = JacC( 56, 35) - dw( 79, 35)
      JacC( 56, 56) = JacC( 56, 56) - dw( 79, 56)
      JacC( 48, 48) = JacC( 48, 48) - dw( 80, 48)
      JacC( 48, 51) = JacC( 48, 51) - dw( 80, 51)
      JacC( 49, 48) = JacC( 49, 48) + dw( 80, 48)
      JacC( 49, 51) = JacC( 49, 51) + dw( 80, 51)
      JacC( 51, 48) = JacC( 51, 48) - dw( 80, 48)
      JacC( 51, 51) = JacC( 51, 51) - dw( 80, 51)
      JacC( 53, 48) = JacC( 53, 48) + dw( 80, 48)
      JacC( 53, 51) = JacC( 53, 51) + dw( 80, 51)
      JacC( 57, 48) = JacC( 57, 48) + dw( 80, 48)
      JacC( 57, 51) = JacC( 57, 51) + dw( 80, 51)
      JacC( 44, 44) = JacC( 44, 44) - dw( 81, 44)
      JacC( 44, 51) = JacC( 44, 51) - dw( 81, 51)
      JacC( 49, 44) = JacC( 49, 44) + dw( 81, 44)
      JacC( 49, 51) = JacC( 49, 51) + dw( 81, 51)
      JacC( 51, 44) = JacC( 51, 44) - dw( 81, 44)
      JacC( 51, 51) = JacC( 51, 51) - dw( 81, 51)
      JacC( 58, 44) = JacC( 58, 44) + dw( 81, 44)
      JacC( 58, 51) = JacC( 58, 51) + dw( 81, 51)
      JacC( 47, 47) = JacC( 47, 47) - dw( 82, 47)
      JacC( 47, 51) = JacC( 47, 51) - dw( 82, 51)
      JacC( 49, 47) = JacC( 49, 47) + dw( 82, 47)
      JacC( 49, 51) = JacC( 49, 51) + dw( 82, 51)
      JacC( 51, 47) = JacC( 51, 47) - dw( 82, 47)
      JacC( 51, 51) = JacC( 51, 51) - dw( 82, 51)
      JacC( 53, 47) = JacC( 53, 47)+ 0.2000000000000000D+01*dw( 82, 47)
      JacC( 53, 51) = JacC( 53, 51)+ 0.2000000000000000D+01*dw( 82, 51)
      JacC( 57, 47) = JacC( 57, 47) + dw( 82, 47)
      JacC( 57, 51) = JacC( 57, 51) + dw( 82, 51)
      JacC( 49, 52) = JacC( 49, 52) + dw( 83, 52)
      JacC( 49, 51) = JacC( 49, 51) + dw( 83, 51)
      JacC( 51, 52) = JacC( 51, 52) - dw( 83, 52)
      JacC( 51, 51) = JacC( 51, 51) - dw( 83, 51)
      JacC( 52, 52) = JacC( 52, 52) - dw( 83, 52)
      JacC( 52, 51) = JacC( 52, 51) - dw( 83, 51)
      JacC( 53, 52) = JacC( 53, 52) + dw( 83, 52)
      JacC( 53, 51) = JacC( 53, 51) + dw( 83, 51)
      JacC( 58, 52) = JacC( 58, 52) + dw( 83, 52)
      JacC( 58, 51) = JacC( 58, 51) + dw( 83, 51)
      JacC( 33, 33) = JacC( 33, 33) - dw( 84, 33)
      JacC( 33, 51) = JacC( 33, 51) - dw( 84, 51)
      JacC( 49, 33) = JacC( 49, 33) + dw( 84, 33)
      JacC( 49, 51) = JacC( 49, 51) + dw( 84, 51)
      JacC( 51, 33) = JacC( 51, 33) - dw( 84, 33)
      JacC( 51, 51) = JacC( 51, 51) - dw( 84, 51)
      JacC( 54, 33) = JacC( 54, 33) + dw( 84, 33)
      JacC( 54, 51) = JacC( 54, 51) + dw( 84, 51)
      JacC( 13, 13) = JacC( 13, 13)- 0.5000000000000000D+00*dw( 85, 13)
      JacC( 13, 51) = JacC( 13, 51)- 0.5000000000000000D+00*dw( 85, 51)
      JacC( 36, 13) = JacC( 36, 13) + dw( 85, 13)
      JacC( 36, 51) = JacC( 36, 51) + dw( 85, 51)
      JacC( 49, 13) = JacC( 49, 13) + dw( 85, 13)
      JacC( 49, 51) = JacC( 49, 51) + dw( 85, 51)
      JacC( 51, 13) = JacC( 51, 13) - dw( 85, 13)
      JacC( 51, 51) = JacC( 51, 51) - dw( 85, 51)
      JacC( 25, 25) = JacC( 25, 25) - dw( 86, 25)
      JacC( 25, 51) = JacC( 25, 51) - dw( 86, 51)
      JacC( 35, 25) = JacC( 35, 25) + dw( 86, 25)
      JacC( 35, 51) = JacC( 35, 51) + dw( 86, 51)
      JacC( 51, 25) = JacC( 51, 25) - dw( 86, 25)
      JacC( 51, 51) = JacC( 51, 51) - dw( 86, 51)
      JacC( 15, 15) = JacC( 15, 15) - dw( 87, 15)
      JacC( 15, 51) = JacC( 15, 51) - dw( 87, 51)
      JacC( 35, 15) = JacC( 35, 15) + dw( 87, 15)
      JacC( 35, 51) = JacC( 35, 51) + dw( 87, 51)
      JacC( 51, 15) = JacC( 51, 15) - dw( 87, 15)
      JacC( 51, 51) = JacC( 51, 51) - dw( 87, 51)
      JacC( 16, 16) = JacC( 16, 16) - dw( 88, 16)
      JacC( 16, 51) = JacC( 16, 51) - dw( 88, 51)
      JacC( 35, 16) = JacC( 35, 16) + dw( 88, 16)
      JacC( 35, 51) = JacC( 35, 51) + dw( 88, 51)
      JacC( 51, 16) = JacC( 51, 16) - dw( 88, 16)
      JacC( 51, 51) = JacC( 51, 51) - dw( 88, 51)
      JacC( 18, 18) = JacC( 18, 18) - dw( 89, 18)
      JacC( 18, 51) = JacC( 18, 51) - dw( 89, 51)
      JacC( 35, 18) = JacC( 35, 18) + dw( 89, 18)
      JacC( 35, 51) = JacC( 35, 51) + dw( 89, 51)
      JacC( 51, 18) = JacC( 51, 18) - dw( 89, 18)
      JacC( 51, 51) = JacC( 51, 51) - dw( 89, 51)
      JacC( 19, 25) = JacC( 19, 25)+ 0.4000000000000000D+00*dw( 90, 25)
      JacC( 19, 26) = JacC( 19, 26)+ 0.4000000000000000D+00*dw( 90, 26)
      JacC( 25, 25) = JacC( 25, 25) - dw( 90, 25)
      JacC( 25, 26) = JacC( 25, 26) - dw( 90, 26)
      JacC( 26, 25) = JacC( 26, 25) - dw( 90, 25)
      JacC( 26, 26) = JacC( 26, 26) - dw( 90, 26)
      JacC( 48, 25) = JacC( 48, 25) + dw( 90, 25)
      JacC( 48, 26) = JacC( 48, 26) + dw( 90, 26)
      JacC( 53, 25) = JacC( 53, 25)+ 0.4200000000000000D+00*dw( 90, 25)
      JacC( 53, 26) = JacC( 53, 26)+ 0.4200000000000000D+00*dw( 90, 26)
      JacC( 57, 25) = JacC( 57, 25)+ 0.1200000000000000D+00*dw( 90, 25)
      JacC( 57, 26) = JacC( 57, 26)+ 0.1200000000000000D+00*dw( 90, 26)
      JacC( 15, 15) = JacC( 15, 15) - dw( 91, 15)
      JacC( 15, 26) = JacC( 15, 26) - dw( 91, 26)
      JacC( 17, 15) = JacC( 17, 15)+ 0.6000000000000000D-01*dw( 91, 15)
      JacC( 17, 26) = JacC( 17, 26)+ 0.6000000000000000D-01*dw( 91, 26)
      JacC( 19, 15) = JacC( 19, 15)+ 0.2000000000000000D+00*dw( 91, 15)
      JacC( 19, 26) = JacC( 19, 26)+ 0.2000000000000000D+00*dw( 91, 26)
      JacC( 26, 15) = JacC( 26, 15) - dw( 91, 15)
      JacC( 26, 26) = JacC( 26, 26) - dw( 91, 26)
      JacC( 41, 15) = JacC( 41, 15)+ 0.2000000000000000D+00*dw( 91, 15)
      JacC( 41, 26) = JacC( 41, 26)+ 0.2000000000000000D+00*dw( 91, 26)
      JacC( 44, 15) = JacC( 44, 15)+ 0.5000000000000000D+00*dw( 91, 15)
      JacC( 44, 26) = JacC( 44, 26)+ 0.5000000000000000D+00*dw( 91, 26)
      JacC( 46, 15) = JacC( 46, 15)+ 0.2200000000000000D+00*dw( 91, 15)
      JacC( 46, 26) = JacC( 46, 26)+ 0.2200000000000000D+00*dw( 91, 26)
      JacC( 48, 15) = JacC( 48, 15)+ 0.5300000000000000D+00*dw( 91, 15)
      JacC( 48, 26) = JacC( 48, 26)+ 0.5300000000000000D+00*dw( 91, 26)
      JacC( 50, 15) = JacC( 50, 15)+ 0.1000000000000000D+00*dw( 91, 15)
      JacC( 50, 26) = JacC( 50, 26)+ 0.1000000000000000D+00*dw( 91, 26)
      JacC( 53, 15) = JacC( 53, 15)+ 0.3300000000000000D+00*dw( 91, 15)
      JacC( 53, 26) = JacC( 53, 26)+ 0.3300000000000000D+00*dw( 91, 26)
      JacC( 57, 15) = JacC( 57, 15)+ 0.2300000000000000D+00*dw( 91, 15)
      JacC( 57, 26) = JacC( 57, 26)+ 0.2300000000000000D+00*dw( 91, 26)
      JacC( 16, 16) = JacC( 16, 16) - dw( 92, 16)
      JacC( 16, 26) = JacC( 16, 26) - dw( 92, 26)
      JacC( 17, 16) = JacC( 17, 16)+ 0.9000000000000000D-01*dw( 92, 16)
      JacC( 17, 26) = JacC( 17, 26)+ 0.9000000000000000D-01*dw( 92, 26)
      JacC( 19, 16) = JacC( 19, 16)+ 0.6000000000000000D-01*dw( 92, 16)
      JacC( 19, 26) = JacC( 19, 26)+ 0.6000000000000000D-01*dw( 92, 26)
      JacC( 26, 16) = JacC( 26, 16) - dw( 92, 16)
      JacC( 26, 26) = JacC( 26, 26) - dw( 92, 26)
      JacC( 38, 16) = JacC( 38, 16)+ 0.1000000000000000D+00*dw( 92, 16)
      JacC( 38, 26) = JacC( 38, 26)+ 0.1000000000000000D+00*dw( 92, 26)
      JacC( 41, 16) = JacC( 41, 16)+ 0.2900000000000000D+00*dw( 92, 16)
      JacC( 41, 26) = JacC( 41, 26)+ 0.2900000000000000D+00*dw( 92, 26)
      JacC( 44, 16) = JacC( 44, 16)+ 0.7200000000000000D+00*dw( 92, 16)
      JacC( 44, 26) = JacC( 44, 26)+ 0.7200000000000000D+00*dw( 92, 26)
      JacC( 46, 16) = JacC( 46, 16)+ 0.3100000000000000D+00*dw( 92, 16)
      JacC( 46, 26) = JacC( 46, 26)+ 0.3100000000000000D+00*dw( 92, 26)
      JacC( 48, 16) = JacC( 48, 16)+ 0.1800000000000000D+00*dw( 92, 16)
      JacC( 48, 26) = JacC( 48, 26)+ 0.1800000000000000D+00*dw( 92, 26)
      JacC( 50, 16) = JacC( 50, 16)+ 0.1400000000000000D+00*dw( 92, 16)
      JacC( 50, 26) = JacC( 50, 26)+ 0.1400000000000000D+00*dw( 92, 26)
      JacC( 53, 16) = JacC( 53, 16)+ 0.2300000000000000D+00*dw( 92, 16)
      JacC( 53, 26) = JacC( 53, 26)+ 0.2300000000000000D+00*dw( 92, 26)
      JacC( 57, 16) = JacC( 57, 16)+ 0.2600000000000000D+00*dw( 92, 16)
      JacC( 57, 26) = JacC( 57, 26)+ 0.2600000000000000D+00*dw( 92, 26)
      JacC( 18, 18) = JacC( 18, 18) - dw( 93, 18)
      JacC( 18, 26) = JacC( 18, 26) - dw( 93, 26)
      JacC( 19, 18) = JacC( 19, 18)+ 0.2000000000000000D+00*dw( 93, 18)
      JacC( 19, 26) = JacC( 19, 26)+ 0.2000000000000000D+00*dw( 93, 26)
      JacC( 26, 18) = JacC( 26, 18) - dw( 93, 18)
      JacC( 26, 26) = JacC( 26, 26) - dw( 93, 26)
      JacC( 41, 18) = JacC( 41, 18)+ 0.2000000000000000D+00*dw( 93, 18)
      JacC( 41, 26) = JacC( 41, 26)+ 0.2000000000000000D+00*dw( 93, 26)
      JacC( 44, 18) = JacC( 44, 18)+ 0.5000000000000000D+00*dw( 93, 18)
      JacC( 44, 26) = JacC( 44, 26)+ 0.5000000000000000D+00*dw( 93, 26)
      JacC( 46, 18) = JacC( 46, 18)+ 0.2200000000000000D+00*dw( 93, 18)
      JacC( 46, 26) = JacC( 46, 26)+ 0.2200000000000000D+00*dw( 93, 26)
      JacC( 48, 18) = JacC( 48, 18)+ 0.5300000000000000D+00*dw( 93, 18)
      JacC( 48, 26) = JacC( 48, 26)+ 0.5300000000000000D+00*dw( 93, 26)
      JacC( 50, 18) = JacC( 50, 18)+ 0.1000000000000000D+00*dw( 93, 18)
      JacC( 50, 26) = JacC( 50, 26)+ 0.1000000000000000D+00*dw( 93, 26)
      JacC( 53, 18) = JacC( 53, 18)+ 0.3300000000000000D+00*dw( 93, 18)
      JacC( 53, 26) = JacC( 53, 26)+ 0.3300000000000000D+00*dw( 93, 26)
      JacC( 57, 18) = JacC( 57, 18)+ 0.2300000000000000D+00*dw( 93, 18)
      JacC( 57, 26) = JacC( 57, 26)+ 0.2300000000000000D+00*dw( 93, 26)
      JacC( 21, 57) = JacC( 21, 57) + dw( 94, 57)
      JacC( 21, 46) = JacC( 21, 46) + dw( 94, 46)
      JacC( 46, 57) = JacC( 46, 57) - dw( 94, 57)
      JacC( 46, 46) = JacC( 46, 46) - dw( 94, 46)
      JacC( 57, 57) = JacC( 57, 57) - dw( 94, 57)
      JacC( 57, 46) = JacC( 57, 46) - dw( 94, 46)
      JacC( 39, 57) = JacC( 39, 57) - dw( 95, 57)
      JacC( 39, 39) = JacC( 39, 39) - dw( 95, 39)
      JacC( 42, 57) = JacC( 42, 57) + dw( 95, 57)
      JacC( 42, 39) = JacC( 42, 39) + dw( 95, 39)
      JacC( 57, 57) = JacC( 57, 57) - dw( 95, 57)
      JacC( 57, 39) = JacC( 57, 39) - dw( 95, 39)
      JacC( 42, 57) = JacC( 42, 57) + dw( 96, 57)
      JacC( 42, 43) = JacC( 42, 43) + dw( 96, 43)
      JacC( 43, 57) = JacC( 43, 57) - dw( 96, 57)
      JacC( 43, 43) = JacC( 43, 43) - dw( 96, 43)
      JacC( 57, 57) = JacC( 57, 57) - dw( 96, 57)
      JacC( 57, 43) = JacC( 57, 43) - dw( 96, 43)
      JacC( 27, 57) = JacC( 27, 57) - dw( 97, 57)
      JacC( 27, 27) = JacC( 27, 27) - dw( 97, 27)
      JacC( 42, 57) = JacC( 42, 57) + dw( 97, 57)
      JacC( 42, 27) = JacC( 42, 27) + dw( 97, 27)
      JacC( 57, 57) = JacC( 57, 57) - dw( 97, 57)
      JacC( 57, 27) = JacC( 57, 27) - dw( 97, 27)
      JacC( 28, 57) = JacC( 28, 57) - dw( 98, 57)
      JacC( 28, 28) = JacC( 28, 28) - dw( 98, 28)
      JacC( 42, 57) = JacC( 42, 57) + dw( 98, 57)
      JacC( 42, 28) = JacC( 42, 28) + dw( 98, 28)
      JacC( 57, 57) = JacC( 57, 57) - dw( 98, 57)
      JacC( 57, 28) = JacC( 57, 28) - dw( 98, 28)
      JacC( 34, 57) = JacC( 34, 57) - dw( 99, 57)
      JacC( 34, 34) = JacC( 34, 34) - dw( 99, 34)
      JacC( 42, 57) = JacC( 42, 57) + dw( 99, 57)
      JacC( 42, 34) = JacC( 42, 34) + dw( 99, 34)
      JacC( 57, 57) = JacC( 57, 57) - dw( 99, 57)
      JacC( 57, 34) = JacC( 57, 34) - dw( 99, 34)
      JacC( 29, 57) = JacC( 29, 57) - dw(100, 57)
      JacC( 29, 29) = JacC( 29, 29) - dw(100, 29)
      JacC( 42, 57) = JacC( 42, 57) + dw(100, 57)
      JacC( 42, 29) = JacC( 42, 29) + dw(100, 29)
      JacC( 57, 57) = JacC( 57, 57) - dw(100, 57)
      JacC( 57, 29) = JacC( 57, 29) - dw(100, 29)
      JacC( 30, 57) = JacC( 30, 57) - dw(101, 57)
      JacC( 30, 30) = JacC( 30, 30) - dw(101, 30)
      JacC( 42, 57) = JacC( 42, 57) + dw(101, 57)
      JacC( 42, 30) = JacC( 42, 30) + dw(101, 30)
      JacC( 57, 57) = JacC( 57, 57) - dw(101, 57)
      JacC( 57, 30) = JacC( 57, 30) - dw(101, 30)
      JacC( 40, 57) = JacC( 40, 57) - dw(102, 57)
      JacC( 40, 40) = JacC( 40, 40) - dw(102, 40)
      JacC( 42, 57) = JacC( 42, 57) + dw(102, 57)
      JacC( 42, 40) = JacC( 42, 40) + dw(102, 40)
      JacC( 57, 57) = JacC( 57, 57) - dw(102, 57)
      JacC( 57, 40) = JacC( 57, 40) - dw(102, 40)
      JacC( 22, 57) = JacC( 22, 57) + dw(103, 57)
      JacC( 22, 58) = JacC( 22, 58) + dw(103, 58)
      JacC( 57, 57) = JacC( 57, 57) - dw(103, 57)
      JacC( 57, 58) = JacC( 57, 58) - dw(103, 58)
      JacC( 58, 57) = JacC( 58, 57) - dw(103, 57)
      JacC( 58, 58) = JacC( 58, 58) - dw(103, 58)
      JacC( 31, 57) = JacC( 31, 57) - dw(104, 57)
      JacC( 31, 31) = JacC( 31, 31) - dw(104, 31)
      JacC( 42, 57) = JacC( 42, 57) + dw(104, 57)
      JacC( 42, 31) = JacC( 42, 31) + dw(104, 31)
      JacC( 57, 57) = JacC( 57, 57) - dw(104, 57)
      JacC( 57, 31) = JacC( 57, 31) - dw(104, 31)
      JacC( 32, 57) = JacC( 32, 57) - dw(105, 57)
      JacC( 32, 32) = JacC( 32, 32) - dw(105, 32)
      JacC( 42, 57) = JacC( 42, 57) + dw(105, 57)
      JacC( 42, 32) = JacC( 42, 32) + dw(105, 32)
      JacC( 57, 57) = JacC( 57, 57) - dw(105, 57)
      JacC( 57, 32) = JacC( 57, 32) - dw(105, 32)
      JacC( 42, 57) = JacC( 42, 57) + dw(106, 57)
      JacC( 42, 54) = JacC( 42, 54) + dw(106, 54)
      JacC( 54, 57) = JacC( 54, 57) - dw(106, 57)
      JacC( 54, 54) = JacC( 54, 54) - dw(106, 54)
      JacC( 57, 57) = JacC( 57, 57) - dw(106, 57)
      JacC( 57, 54) = JacC( 57, 54) - dw(106, 54)
      JacC( 35, 57) = JacC( 35, 57) - dw(107, 57)
      JacC( 35, 35) = JacC( 35, 35) - dw(107, 35)
      JacC( 37, 57) = JacC( 37, 57) + dw(107, 57)
      JacC( 37, 35) = JacC( 37, 35) + dw(107, 35)
      JacC( 57, 57) = JacC( 57, 57) - dw(107, 57)
      JacC( 57, 35) = JacC( 57, 35) - dw(107, 35)
      JacC( 46, 46) = JacC( 46, 46)- 0.2000000000000000D+01*dw(108, 46)
      JacC( 46, 46) = JacC( 46, 46)- 0.2000000000000000D+01*dw(108, 46)
      JacC( 48, 46) = JacC( 48, 46)+ 0.1500000000000000D+01*dw(108, 46)
      JacC( 48, 46) = JacC( 48, 46)+ 0.1500000000000000D+01*dw(108, 46)
      JacC( 57, 46) = JacC( 57, 46) + dw(108, 46)
      JacC( 57, 46) = JacC( 57, 46) + dw(108, 46)
      JacC( 39, 46) = JacC( 39, 46) - dw(109, 46)
      JacC( 39, 39) = JacC( 39, 39) - dw(109, 39)
      JacC( 44, 46) = JacC( 44, 46)+ 0.7500000000000000D+00*dw(109, 46)
      JacC( 44, 39) = JacC( 44, 39)+ 0.7500000000000000D+00*dw(109, 39)
      JacC( 46, 46) = JacC( 46, 46) - dw(109, 46)
      JacC( 46, 39) = JacC( 46, 39) - dw(109, 39)
      JacC( 48, 46) = JacC( 48, 46)+ 0.7500000000000000D+00*dw(109, 46)
      JacC( 48, 39) = JacC( 48, 39)+ 0.7500000000000000D+00*dw(109, 39)
      JacC( 57, 46) = JacC( 57, 46) + dw(109, 46)
      JacC( 57, 39) = JacC( 57, 39) + dw(109, 39)
      JacC( 38, 46) = JacC( 38, 46)+ 0.2600000000000000D+00*dw(110, 46)
      JacC( 38, 43) = JacC( 38, 43)+ 0.2600000000000000D+00*dw(110, 43)
      JacC( 43, 46) = JacC( 43, 46) - dw(110, 46)
      JacC( 43, 43) = JacC( 43, 43) - dw(110, 43)
      JacC( 44, 46) = JacC( 44, 46)+ 0.7700000000000000D+00*dw(110, 46)
      JacC( 44, 43) = JacC( 44, 43)+ 0.7700000000000000D+00*dw(110, 43)
      JacC( 46, 46) = JacC( 46, 46) - dw(110, 46)
      JacC( 46, 43) = JacC( 46, 43) - dw(110, 43)
      JacC( 48, 46) = JacC( 48, 46)+ 0.8400000000000000D+00*dw(110, 46)
      JacC( 48, 43) = JacC( 48, 43)+ 0.8400000000000000D+00*dw(110, 43)
      JacC( 57, 46) = JacC( 57, 46) + dw(110, 46)
      JacC( 57, 43) = JacC( 57, 43) + dw(110, 43)
      JacC( 27, 46) = JacC( 27, 46) - dw(111, 46)
      JacC( 27, 27) = JacC( 27, 27) - dw(111, 27)
      JacC( 38, 46) = JacC( 38, 46)+ 0.7500000000000000D+00*dw(111, 46)
      JacC( 38, 27) = JacC( 38, 27)+ 0.7500000000000000D+00*dw(111, 27)
      JacC( 44, 46) = JacC( 44, 46)+ 0.4100000000000000D+00*dw(111, 46)
      JacC( 44, 27) = JacC( 44, 27)+ 0.4100000000000000D+00*dw(111, 27)
      JacC( 46, 46) = JacC( 46, 46) - dw(111, 46)
      JacC( 46, 27) = JacC( 46, 27) - dw(111, 27)
      JacC( 48, 46) = JacC( 48, 46)+ 0.7700000000000000D+00*dw(111, 46)
      JacC( 48, 27) = JacC( 48, 27)+ 0.7700000000000000D+00*dw(111, 27)
      JacC( 57, 46) = JacC( 57, 46) + dw(111, 46)
      JacC( 57, 27) = JacC( 57, 27) + dw(111, 27)
      JacC( 28, 46) = JacC( 28, 46) - dw(112, 46)
      JacC( 28, 28) = JacC( 28, 28) - dw(112, 28)
      JacC( 38, 46) = JacC( 38, 46)+ 0.1390000000000000D+01*dw(112, 46)
      JacC( 38, 28) = JacC( 38, 28)+ 0.1390000000000000D+01*dw(112, 28)
      JacC( 44, 46) = JacC( 44, 46)+ 0.4600000000000000D+00*dw(112, 46)
      JacC( 44, 28) = JacC( 44, 28)+ 0.4600000000000000D+00*dw(112, 28)
      JacC( 46, 46) = JacC( 46, 46) - dw(112, 46)
      JacC( 46, 28) = JacC( 46, 28) - dw(112, 28)
      JacC( 48, 46) = JacC( 48, 46)+ 0.8000000000000000D+00*dw(112, 46)
      JacC( 48, 28) = JacC( 48, 28)+ 0.8000000000000000D+00*dw(112, 28)
      JacC( 57, 46) = JacC( 57, 46) + dw(112, 46)
      JacC( 57, 28) = JacC( 57, 28) + dw(112, 28)
      JacC( 34, 46) = JacC( 34, 46) - dw(113, 46)
      JacC( 34, 34) = JacC( 34, 34) - dw(113, 34)
      JacC( 44, 46) = JacC( 44, 46)+ 0.3500000000000000D+00*dw(113, 46)
      JacC( 44, 34) = JacC( 44, 34)+ 0.3500000000000000D+00*dw(113, 34)
      JacC( 46, 46) = JacC( 46, 46) - dw(113, 46)
      JacC( 46, 34) = JacC( 46, 34) - dw(113, 34)
      JacC( 48, 46) = JacC( 48, 46)+ 0.1550000000000000D+01*dw(113, 46)
      JacC( 48, 34) = JacC( 48, 34)+ 0.1550000000000000D+01*dw(113, 34)
      JacC( 57, 46) = JacC( 57, 46) + dw(113, 46)
      JacC( 57, 34) = JacC( 57, 34) + dw(113, 34)
      JacC( 29, 46) = JacC( 29, 46) - dw(114, 46)
      JacC( 29, 29) = JacC( 29, 29) - dw(114, 29)
      JacC( 44, 46) = JacC( 44, 46)+ 0.7500000000000000D+00*dw(114, 46)
      JacC( 44, 29) = JacC( 44, 29)+ 0.7500000000000000D+00*dw(114, 29)
      JacC( 46, 46) = JacC( 46, 46) - dw(114, 46)
      JacC( 46, 29) = JacC( 46, 29) - dw(114, 29)
      JacC( 48, 46) = JacC( 48, 46)+ 0.1250000000000000D+01*dw(114, 46)
      JacC( 48, 29) = JacC( 48, 29)+ 0.1250000000000000D+01*dw(114, 29)
      JacC( 57, 46) = JacC( 57, 46) + dw(114, 46)
      JacC( 57, 29) = JacC( 57, 29) + dw(114, 29)
      JacC( 30, 46) = JacC( 30, 46) - dw(115, 46)
      JacC( 30, 30) = JacC( 30, 30) - dw(115, 30)
      JacC( 38, 46) = JacC( 38, 46)+ 0.5500000000000000D+00*dw(115, 46)
      JacC( 38, 30) = JacC( 38, 30)+ 0.5500000000000000D+00*dw(115, 30)
      JacC( 44, 46) = JacC( 44, 46)+ 0.7250000000000000D+00*dw(115, 46)
      JacC( 44, 30) = JacC( 44, 30)+ 0.7250000000000000D+00*dw(115, 30)
      JacC( 46, 46) = JacC( 46, 46) - dw(115, 46)
      JacC( 46, 30) = JacC( 46, 30) - dw(115, 30)
      JacC( 48, 46) = JacC( 48, 46)+ 0.8900000000000000D+00*dw(115, 46)
      JacC( 48, 30) = JacC( 48, 30)+ 0.8900000000000000D+00*dw(115, 30)
      JacC( 57, 46) = JacC( 57, 46) + dw(115, 46)
      JacC( 57, 30) = JacC( 57, 30) + dw(115, 30)
      JacC( 40, 46) = JacC( 40, 46) - dw(116, 46)
      JacC( 40, 40) = JacC( 40, 40) - dw(116, 40)
      JacC( 46, 46) = JacC( 46, 46) - dw(116, 46)
      JacC( 46, 40) = JacC( 46, 40) - dw(116, 40)
      JacC( 48, 46) = JacC( 48, 46)+ 0.7500000000000000D+00*dw(116, 46)
      JacC( 48, 40) = JacC( 48, 40)+ 0.7500000000000000D+00*dw(116, 40)
      JacC( 52, 46) = JacC( 52, 46)+ 0.7500000000000000D+00*dw(116, 46)
      JacC( 52, 40) = JacC( 52, 40)+ 0.7500000000000000D+00*dw(116, 40)
      JacC( 57, 46) = JacC( 57, 46) + dw(116, 46)
      JacC( 57, 40) = JacC( 57, 40) + dw(116, 40)
      JacC( 41, 46) = JacC( 41, 46)+ 0.5000000000000000D+00*dw(117, 46)
      JacC( 41, 58) = JacC( 41, 58)+ 0.5000000000000000D+00*dw(117, 58)
      JacC( 46, 46) = JacC( 46, 46)- 0.5000000000000000D+00*dw(117, 46)
      JacC( 46, 58) = JacC( 46, 58)- 0.5000000000000000D+00*dw(117, 58)
      JacC( 48, 46) = JacC( 48, 46) + dw(117, 46)
      JacC( 48, 58) = JacC( 48, 58) + dw(117, 58)
      JacC( 57, 46) = JacC( 57, 46)+ 0.5000000000000000D+00*dw(117, 46)
      JacC( 57, 58) = JacC( 57, 58)+ 0.5000000000000000D+00*dw(117, 58)
      JacC( 58, 46) = JacC( 58, 46) - dw(117, 46)
      JacC( 58, 58) = JacC( 58, 58) - dw(117, 58)
      JacC( 31, 46) = JacC( 31, 46) - dw(118, 46)
      JacC( 31, 31) = JacC( 31, 31) - dw(118, 31)
      JacC( 33, 46) = JacC( 33, 46)+ 0.7000000000000000D+00*dw(118, 46)
      JacC( 33, 31) = JacC( 33, 31)+ 0.7000000000000000D+00*dw(118, 31)
      JacC( 46, 46) = JacC( 46, 46) - dw(118, 46)
      JacC( 46, 31) = JacC( 46, 31) - dw(118, 31)
      JacC( 47, 46) = JacC( 47, 46)+ 0.1600000000000000D+00*dw(118, 46)
      JacC( 47, 31) = JacC( 47, 31)+ 0.1600000000000000D+00*dw(118, 31)
      JacC( 48, 46) = JacC( 48, 46) + dw(118, 46)
      JacC( 48, 31) = JacC( 48, 31) + dw(118, 31)
      JacC( 52, 46) = JacC( 52, 46)+ 0.1700000000000000D+00*dw(118, 46)
      JacC( 52, 31) = JacC( 52, 31)+ 0.1700000000000000D+00*dw(118, 31)
      JacC( 57, 46) = JacC( 57, 46)+ 0.2000000000000000D+01*dw(118, 46)
      JacC( 57, 31) = JacC( 57, 31)+ 0.2000000000000000D+01*dw(118, 31)
      JacC( 32, 46) = JacC( 32, 46) - dw(119, 46)
      JacC( 32, 32) = JacC( 32, 32) - dw(119, 32)
      JacC( 33, 46) = JacC( 33, 46)+ 0.8060000000000000D+00*dw(119, 46)
      JacC( 33, 32) = JacC( 33, 32)+ 0.8060000000000000D+00*dw(119, 32)
      JacC( 46, 46) = JacC( 46, 46) - dw(119, 46)
      JacC( 46, 32) = JacC( 46, 32) - dw(119, 32)
      JacC( 48, 46) = JacC( 48, 46) + dw(119, 46)
      JacC( 48, 32) = JacC( 48, 32) + dw(119, 32)
      JacC( 52, 46) = JacC( 52, 46)+ 0.4500000000000000D+00*dw(119, 46)
      JacC( 52, 32) = JacC( 52, 32)+ 0.4500000000000000D+00*dw(119, 32)
      JacC( 57, 46) = JacC( 57, 46)+ 0.2000000000000000D+01*dw(119, 46)
      JacC( 57, 32) = JacC( 57, 32)+ 0.2000000000000000D+01*dw(119, 32)
      JacC( 41, 46) = JacC( 41, 46)+ 0.5000000000000000D+00*dw(120, 46)
      JacC( 41, 54) = JacC( 41, 54)+ 0.5000000000000000D+00*dw(120, 54)
      JacC( 45, 46) = JacC( 45, 46) + dw(120, 46)
      JacC( 45, 54) = JacC( 45, 54) + dw(120, 54)
      JacC( 46, 46) = JacC( 46, 46) - dw(120, 46)
      JacC( 46, 54) = JacC( 46, 54) - dw(120, 54)
      JacC( 47, 46) = JacC( 47, 46)+ 0.4450000000000000D+00*dw(120, 46)
      JacC( 47, 54) = JacC( 47, 54)+ 0.4450000000000000D+00*dw(120, 54)
      JacC( 48, 46) = JacC( 48, 46)+ 0.5000000000000000D+00*dw(120, 46)
      JacC( 48, 54) = JacC( 48, 54)+ 0.5000000000000000D+00*dw(120, 54)
      JacC( 52, 46) = JacC( 52, 46)+ 0.5500000000000000D-01*dw(120, 46)
      JacC( 52, 54) = JacC( 52, 54)+ 0.5500000000000000D-01*dw(120, 54)
      JacC( 53, 46) = JacC( 53, 46)+ 0.4750000000000000D+00*dw(120, 46)
      JacC( 53, 54) = JacC( 53, 54)+ 0.4750000000000000D+00*dw(120, 54)
      JacC( 54, 46) = JacC( 54, 46) - dw(120, 46)
      JacC( 54, 54) = JacC( 54, 54) - dw(120, 54)
      JacC( 57, 46) = JacC( 57, 46)+ 0.4600000000000000D+00*dw(120, 46)
      JacC( 57, 54) = JacC( 57, 54)+ 0.4600000000000000D+00*dw(120, 54)
      JacC( 58, 46) = JacC( 58, 46)+ 0.2500000000000000D-01*dw(120, 46)
      JacC( 58, 54) = JacC( 58, 54)+ 0.2500000000000000D-01*dw(120, 54)
      JacC( 35, 46) = JacC( 35, 46) - dw(121, 46)
      JacC( 35, 35) = JacC( 35, 35) - dw(121, 35)
      JacC( 44, 46) = JacC( 44, 46) + dw(121, 46)
      JacC( 44, 35) = JacC( 44, 35) + dw(121, 35)
      JacC( 46, 46) = JacC( 46, 46) - dw(121, 46)
      JacC( 46, 35) = JacC( 46, 35) - dw(121, 35)
      JacC( 48, 46) = JacC( 48, 46)+ 0.1750000000000000D+01*dw(121, 46)
      JacC( 48, 35) = JacC( 48, 35)+ 0.1750000000000000D+01*dw(121, 35)
      JacC( 55, 46) = JacC( 55, 46) + dw(121, 46)
      JacC( 55, 35) = JacC( 55, 35) + dw(121, 35)
      JacC( 57, 46) = JacC( 57, 46)+ 0.5000000000000000D+00*dw(121, 46)
      JacC( 57, 35) = JacC( 57, 35)+ 0.5000000000000000D+00*dw(121, 35)
      JacC( 39, 39) = JacC( 39, 39) - dw(122, 39)
      JacC( 39, 58) = JacC( 39, 58) - dw(122, 58)
      JacC( 41, 39) = JacC( 41, 39)+ 0.5000000000000000D+00*dw(122, 39)
      JacC( 41, 58) = JacC( 41, 58)+ 0.5000000000000000D+00*dw(122, 58)
      JacC( 44, 39) = JacC( 44, 39) + dw(122, 39)
      JacC( 44, 58) = JacC( 44, 58) + dw(122, 58)
      JacC( 46, 39) = JacC( 46, 39)+ 0.5000000000000000D+00*dw(122, 39)
      JacC( 46, 58) = JacC( 46, 58)+ 0.5000000000000000D+00*dw(122, 58)
      JacC( 57, 39) = JacC( 57, 39)+ 0.5000000000000000D+00*dw(122, 39)
      JacC( 57, 58) = JacC( 57, 58)+ 0.5000000000000000D+00*dw(122, 58)
      JacC( 58, 39) = JacC( 58, 39) - dw(122, 39)
      JacC( 58, 58) = JacC( 58, 58) - dw(122, 58)
      JacC( 38, 43) = JacC( 38, 43)+ 0.2600000000000000D+00*dw(123, 43)
      JacC( 38, 58) = JacC( 38, 58)+ 0.2600000000000000D+00*dw(123, 58)
      JacC( 41, 43) = JacC( 41, 43)+ 0.5000000000000000D+00*dw(123, 43)
      JacC( 41, 58) = JacC( 41, 58)+ 0.5000000000000000D+00*dw(123, 58)
      JacC( 43, 43) = JacC( 43, 43) - dw(123, 43)
      JacC( 43, 58) = JacC( 43, 58) - dw(123, 58)
      JacC( 44, 43) = JacC( 44, 43)+ 0.7700000000000000D+00*dw(123, 43)
      JacC( 44, 58) = JacC( 44, 58)+ 0.7700000000000000D+00*dw(123, 58)
      JacC( 46, 43) = JacC( 46, 43)+ 0.5000000000000000D+00*dw(123, 43)
      JacC( 46, 58) = JacC( 46, 58)+ 0.5000000000000000D+00*dw(123, 58)
      JacC( 57, 43) = JacC( 57, 43)+ 0.5000000000000000D+00*dw(123, 43)
      JacC( 57, 58) = JacC( 57, 58)+ 0.5000000000000000D+00*dw(123, 58)
      JacC( 58, 43) = JacC( 58, 43) - dw(123, 43)
      JacC( 58, 58) = JacC( 58, 58) - dw(123, 58)
      JacC( 27, 27) = JacC( 27, 27) - dw(124, 27)
      JacC( 27, 58) = JacC( 27, 58) - dw(124, 58)
      JacC( 38, 27) = JacC( 38, 27)+ 0.7500000000000000D+00*dw(124, 27)
      JacC( 38, 58) = JacC( 38, 58)+ 0.7500000000000000D+00*dw(124, 58)
      JacC( 41, 27) = JacC( 41, 27)+ 0.5000000000000000D+00*dw(124, 27)
      JacC( 41, 58) = JacC( 41, 58)+ 0.5000000000000000D+00*dw(124, 58)
      JacC( 44, 27) = JacC( 44, 27)+ 0.4100000000000000D+00*dw(124, 27)
      JacC( 44, 58) = JacC( 44, 58)+ 0.4100000000000000D+00*dw(124, 58)
      JacC( 46, 27) = JacC( 46, 27)+ 0.5000000000000000D+00*dw(124, 27)
      JacC( 46, 58) = JacC( 46, 58)+ 0.5000000000000000D+00*dw(124, 58)
      JacC( 57, 27) = JacC( 57, 27)+ 0.5000000000000000D+00*dw(124, 27)
      JacC( 57, 58) = JacC( 57, 58)+ 0.5000000000000000D+00*dw(124, 58)
      JacC( 58, 27) = JacC( 58, 27) - dw(124, 27)
      JacC( 58, 58) = JacC( 58, 58) - dw(124, 58)
      JacC( 28, 28) = JacC( 28, 28) - dw(125, 28)
      JacC( 28, 58) = JacC( 28, 58) - dw(125, 58)
      JacC( 38, 28) = JacC( 38, 28)+ 0.1390000000000000D+01*dw(125, 28)
      JacC( 38, 58) = JacC( 38, 58)+ 0.1390000000000000D+01*dw(125, 58)
      JacC( 41, 28) = JacC( 41, 28)+ 0.5000000000000000D+00*dw(125, 28)
      JacC( 41, 58) = JacC( 41, 58)+ 0.5000000000000000D+00*dw(125, 58)
      JacC( 44, 28) = JacC( 44, 28)+ 0.4600000000000000D+00*dw(125, 28)
      JacC( 44, 58) = JacC( 44, 58)+ 0.4600000000000000D+00*dw(125, 58)
      JacC( 46, 28) = JacC( 46, 28)+ 0.5000000000000000D+00*dw(125, 28)
      JacC( 46, 58) = JacC( 46, 58)+ 0.5000000000000000D+00*dw(125, 58)
      JacC( 57, 28) = JacC( 57, 28)+ 0.5000000000000000D+00*dw(125, 28)
      JacC( 57, 58) = JacC( 57, 58)+ 0.5000000000000000D+00*dw(125, 58)
      JacC( 58, 28) = JacC( 58, 28) - dw(125, 28)
      JacC( 58, 58) = JacC( 58, 58) - dw(125, 58)
      JacC( 34, 34) = JacC( 34, 34) - dw(126, 34)
      JacC( 34, 58) = JacC( 34, 58) - dw(126, 58)
      JacC( 41, 34) = JacC( 41, 34)+ 0.5000000000000000D+00*dw(126, 34)
      JacC( 41, 58) = JacC( 41, 58)+ 0.5000000000000000D+00*dw(126, 58)
      JacC( 44, 34) = JacC( 44, 34)+ 0.6000000000000000D+00*dw(126, 34)
      JacC( 44, 58) = JacC( 44, 58)+ 0.6000000000000000D+00*dw(126, 58)
      JacC( 46, 34) = JacC( 46, 34)+ 0.5000000000000000D+00*dw(126, 34)
      JacC( 46, 58) = JacC( 46, 58)+ 0.5000000000000000D+00*dw(126, 58)
      JacC( 48, 34) = JacC( 48, 34)+ 0.8000000000000000D+00*dw(126, 34)
      JacC( 48, 58) = JacC( 48, 58)+ 0.8000000000000000D+00*dw(126, 58)
      JacC( 57, 34) = JacC( 57, 34)+ 0.5000000000000000D+00*dw(126, 34)
      JacC( 57, 58) = JacC( 57, 58)+ 0.5000000000000000D+00*dw(126, 58)
      JacC( 58, 34) = JacC( 58, 34) - dw(126, 34)
      JacC( 58, 58) = JacC( 58, 58) - dw(126, 58)
      JacC( 29, 29) = JacC( 29, 29) - dw(127, 29)
      JacC( 29, 58) = JacC( 29, 58) - dw(127, 58)
      JacC( 41, 29) = JacC( 41, 29)+ 0.5000000000000000D+00*dw(127, 29)
      JacC( 41, 58) = JacC( 41, 58)+ 0.5000000000000000D+00*dw(127, 58)
      JacC( 44, 29) = JacC( 44, 29) + dw(127, 29)
      JacC( 44, 58) = JacC( 44, 58) + dw(127, 58)
      JacC( 46, 29) = JacC( 46, 29)+ 0.5000000000000000D+00*dw(127, 29)
      JacC( 46, 58) = JacC( 46, 58)+ 0.5000000000000000D+00*dw(127, 58)
      JacC( 48, 29) = JacC( 48, 29)+ 0.5000000000000000D+00*dw(127, 29)
      JacC( 48, 58) = JacC( 48, 58)+ 0.5000000000000000D+00*dw(127, 58)
      JacC( 57, 29) = JacC( 57, 29)+ 0.5000000000000000D+00*dw(127, 29)
      JacC( 57, 58) = JacC( 57, 58)+ 0.5000000000000000D+00*dw(127, 58)
      JacC( 58, 29) = JacC( 58, 29) - dw(127, 29)
      JacC( 58, 58) = JacC( 58, 58) - dw(127, 58)
      JacC( 30, 30) = JacC( 30, 30) - dw(128, 30)
      JacC( 30, 58) = JacC( 30, 58) - dw(128, 58)
      JacC( 38, 30) = JacC( 38, 30)+ 0.5500000000000000D+00*dw(128, 30)
      JacC( 38, 58) = JacC( 38, 58)+ 0.5500000000000000D+00*dw(128, 58)
      JacC( 41, 30) = JacC( 41, 30)+ 0.5000000000000000D+00*dw(128, 30)
      JacC( 41, 58) = JacC( 41, 58)+ 0.5000000000000000D+00*dw(128, 58)
      JacC( 44, 30) = JacC( 44, 30)+ 0.7250000000000000D+00*dw(128, 30)
      JacC( 44, 58) = JacC( 44, 58)+ 0.7250000000000000D+00*dw(128, 58)
      JacC( 46, 30) = JacC( 46, 30)+ 0.5000000000000000D+00*dw(128, 30)
      JacC( 46, 58) = JacC( 46, 58)+ 0.5000000000000000D+00*dw(128, 58)
      JacC( 48, 30) = JacC( 48, 30)+ 0.1400000000000000D+00*dw(128, 30)
      JacC( 48, 58) = JacC( 48, 58)+ 0.1400000000000000D+00*dw(128, 58)
      JacC( 57, 30) = JacC( 57, 30)+ 0.5000000000000000D+00*dw(128, 30)
      JacC( 57, 58) = JacC( 57, 58)+ 0.5000000000000000D+00*dw(128, 58)
      JacC( 58, 30) = JacC( 58, 30) - dw(128, 30)
      JacC( 58, 58) = JacC( 58, 58) - dw(128, 58)
      JacC( 40, 40) = JacC( 40, 40) - dw(129, 40)
      JacC( 40, 58) = JacC( 40, 58) - dw(129, 58)
      JacC( 41, 40) = JacC( 41, 40)+ 0.5000000000000000D+00*dw(129, 40)
      JacC( 41, 58) = JacC( 41, 58)+ 0.5000000000000000D+00*dw(129, 58)
      JacC( 46, 40) = JacC( 46, 40)+ 0.5000000000000000D+00*dw(129, 40)
      JacC( 46, 58) = JacC( 46, 58)+ 0.5000000000000000D+00*dw(129, 58)
      JacC( 52, 40) = JacC( 52, 40) + dw(129, 40)
      JacC( 52, 58) = JacC( 52, 58) + dw(129, 58)
      JacC( 57, 40) = JacC( 57, 40)+ 0.5000000000000000D+00*dw(129, 40)
      JacC( 57, 58) = JacC( 57, 58)+ 0.5000000000000000D+00*dw(129, 58)
      JacC( 58, 40) = JacC( 58, 40) - dw(129, 40)
      JacC( 58, 58) = JacC( 58, 58) - dw(129, 58)
      JacC( 46, 58) = JacC( 46, 58)+ 0.2000000000000000D+01*dw(130, 58)
      JacC( 46, 58) = JacC( 46, 58)+ 0.2000000000000000D+01*dw(130, 58)
      JacC( 58, 58) = JacC( 58, 58)- 0.2000000000000000D+01*dw(130, 58)
      JacC( 58, 58) = JacC( 58, 58)- 0.2000000000000000D+01*dw(130, 58)
      JacC( 31, 58) = JacC( 31, 58) - dw(131, 58)
      JacC( 31, 31) = JacC( 31, 31) - dw(131, 31)
      JacC( 33, 58) = JacC( 33, 58)+ 0.7000000000000000D+00*dw(131, 58)
      JacC( 33, 31) = JacC( 33, 31)+ 0.7000000000000000D+00*dw(131, 31)
      JacC( 46, 58) = JacC( 46, 58) + dw(131, 58)
      JacC( 46, 31) = JacC( 46, 31) + dw(131, 31)
      JacC( 47, 58) = JacC( 47, 58)+ 0.1600000000000000D+00*dw(131, 58)
      JacC( 47, 31) = JacC( 47, 31)+ 0.1600000000000000D+00*dw(131, 31)
      JacC( 52, 58) = JacC( 52, 58)+ 0.1700000000000000D+00*dw(131, 58)
      JacC( 52, 31) = JacC( 52, 31)+ 0.1700000000000000D+00*dw(131, 31)
      JacC( 57, 58) = JacC( 57, 58) + dw(131, 58)
      JacC( 57, 31) = JacC( 57, 31) + dw(131, 31)
      JacC( 58, 58) = JacC( 58, 58) - dw(131, 58)
      JacC( 58, 31) = JacC( 58, 31) - dw(131, 31)
      JacC( 32, 58) = JacC( 32, 58) - dw(132, 58)
      JacC( 32, 32) = JacC( 32, 32) - dw(132, 32)
      JacC( 33, 58) = JacC( 33, 58)+ 0.8060000000000000D+00*dw(132, 58)
      JacC( 33, 32) = JacC( 33, 32)+ 0.8060000000000000D+00*dw(132, 32)
      JacC( 46, 58) = JacC( 46, 58) + dw(132, 58)
      JacC( 46, 32) = JacC( 46, 32) + dw(132, 32)
      JacC( 52, 58) = JacC( 52, 58)+ 0.4500000000000000D+00*dw(132, 58)
      JacC( 52, 32) = JacC( 52, 32)+ 0.4500000000000000D+00*dw(132, 32)
      JacC( 57, 58) = JacC( 57, 58) + dw(132, 58)
      JacC( 57, 32) = JacC( 57, 32) + dw(132, 32)
      JacC( 58, 58) = JacC( 58, 58) - dw(132, 58)
      JacC( 58, 32) = JacC( 58, 32) - dw(132, 32)
      JacC( 45, 58) = JacC( 45, 58)+ 0.2000000000000000D+01*dw(133, 58)
      JacC( 45, 54) = JacC( 45, 54)+ 0.2000000000000000D+01*dw(133, 54)
      JacC( 46, 58) = JacC( 46, 58) + dw(133, 58)
      JacC( 46, 54) = JacC( 46, 54) + dw(133, 54)
      JacC( 47, 58) = JacC( 47, 58)+ 0.8900000000000000D+00*dw(133, 58)
      JacC( 47, 54) = JacC( 47, 54)+ 0.8900000000000000D+00*dw(133, 54)
      JacC( 52, 58) = JacC( 52, 58)+ 0.1100000000000000D+00*dw(133, 58)
      JacC( 52, 54) = JacC( 52, 54)+ 0.1100000000000000D+00*dw(133, 54)
      JacC( 53, 58) = JacC( 53, 58)+ 0.9500000000000000D+00*dw(133, 58)
      JacC( 53, 54) = JacC( 53, 54)+ 0.9500000000000000D+00*dw(133, 54)
      JacC( 54, 58) = JacC( 54, 58) - dw(133, 58)
      JacC( 54, 54) = JacC( 54, 54) - dw(133, 54)
      JacC( 57, 58) = JacC( 57, 58)+ 0.9200000000000000D+00*dw(133, 58)
      JacC( 57, 54) = JacC( 57, 54)+ 0.9200000000000000D+00*dw(133, 54)
      JacC( 58, 58) = JacC( 58, 58)- 0.9500000000000000D+00*dw(133, 58)
      JacC( 58, 54) = JacC( 58, 54)- 0.9500000000000000D+00*dw(133, 54)
      JacC( 35, 58) = JacC( 35, 58) - dw(134, 58)
      JacC( 35, 35) = JacC( 35, 35) - dw(134, 35)
      JacC( 41, 58) = JacC( 41, 58)+ 0.5000000000000000D+00*dw(134, 58)
      JacC( 41, 35) = JacC( 41, 35)+ 0.5000000000000000D+00*dw(134, 35)
      JacC( 44, 58) = JacC( 44, 58) + dw(134, 58)
      JacC( 44, 35) = JacC( 44, 35) + dw(134, 35)
      JacC( 46, 58) = JacC( 46, 58)+ 0.5000000000000000D+00*dw(134, 58)
      JacC( 46, 35) = JacC( 46, 35)+ 0.5000000000000000D+00*dw(134, 35)
      JacC( 48, 58) = JacC( 48, 58) + dw(134, 58)
      JacC( 48, 35) = JacC( 48, 35) + dw(134, 35)
      JacC( 55, 58) = JacC( 55, 58) + dw(134, 58)
      JacC( 55, 35) = JacC( 55, 35) + dw(134, 35)
      JacC( 58, 58) = JacC( 58, 58) - dw(134, 58)
      JacC( 58, 35) = JacC( 58, 35) - dw(134, 35)
      JacC( 35, 35) = JacC( 35, 35)- 0.2000000000000000D+01*dw(135, 35)
      JacC( 35, 35) = JacC( 35, 35)- 0.2000000000000000D+01*dw(135, 35)
      JacC( 44, 35) = JacC( 44, 35)+ 0.2000000000000000D+01*dw(135, 35)
      JacC( 44, 35) = JacC( 44, 35)+ 0.2000000000000000D+01*dw(135, 35)
      JacC( 48, 35) = JacC( 48, 35)+ 0.2000000000000000D+01*dw(135, 35)
      JacC( 48, 35) = JacC( 48, 35)+ 0.2000000000000000D+01*dw(135, 35)
      JacC( 55, 35) = JacC( 55, 35)+ 0.2000000000000000D+01*dw(135, 35)
      JacC( 55, 35) = JacC( 55, 35)+ 0.2000000000000000D+01*dw(135, 35)
      JacC( 42, 45) = JacC( 42, 45) + dw(136, 45)
      JacC( 42, 57) = JacC( 42, 57) + dw(136, 57)
      JacC( 45, 45) = JacC( 45, 45) - dw(136, 45)
      JacC( 45, 57) = JacC( 45, 57) - dw(136, 57)
      JacC( 57, 45) = JacC( 57, 45) - dw(136, 45)
      JacC( 57, 57) = JacC( 57, 57) - dw(136, 57)
      JacC( 45, 45) = JacC( 45, 45) - dw(137, 45)
      JacC( 45, 46) = JacC( 45, 46) - dw(137, 46)
      JacC( 46, 45) = JacC( 46, 45) - dw(137, 45)
      JacC( 46, 46) = JacC( 46, 46) - dw(137, 46)
      JacC( 48, 45) = JacC( 48, 45) + dw(137, 45)
      JacC( 48, 46) = JacC( 48, 46) + dw(137, 46)
      JacC( 57, 45) = JacC( 57, 45) + dw(137, 45)
      JacC( 57, 46) = JacC( 57, 46) + dw(137, 46)
      JacC( 45, 45) = JacC( 45, 45) - dw(138, 45)
      JacC( 45, 58) = JacC( 45, 58) - dw(138, 58)
      JacC( 46, 45) = JacC( 46, 45) + dw(138, 45)
      JacC( 46, 58) = JacC( 46, 58) + dw(138, 58)
      JacC( 58, 45) = JacC( 58, 45) - dw(138, 45)
      JacC( 58, 58) = JacC( 58, 58) - dw(138, 58)
      JacC( 45, 45) = JacC( 45, 45)- 0.2000000000000000D+01*dw(139, 45)
      JacC( 45, 45) = JacC( 45, 45)- 0.2000000000000000D+01*dw(139, 45)
      JacC( 45, 45) = JacC( 45, 45) - dw(140, 45)
      JacC( 45, 56) = JacC( 45, 56) - dw(140, 56)
      JacC( 55, 45) = JacC( 55, 45) + dw(140, 45)
      JacC( 55, 56) = JacC( 55, 56) + dw(140, 56)
      JacC( 56, 45) = JacC( 56, 45) - dw(140, 45)
      JacC( 56, 56) = JacC( 56, 56) - dw(140, 56)
      JacC( 36, 36) = JacC( 36, 36) - dw(141, 36)
      JacC( 36, 55) = JacC( 36, 55) - dw(141, 55)
      JacC( 37, 36) = JacC( 37, 36) + dw(141, 36)
      JacC( 37, 55) = JacC( 37, 55) + dw(141, 55)
      JacC( 55, 36) = JacC( 55, 36) - dw(141, 36)
      JacC( 55, 55) = JacC( 55, 55) - dw(141, 55)
      JacC( 36, 36) = JacC( 36, 36) - dw(142, 36)
      JacC( 36, 57) = JacC( 36, 57) - dw(142, 57)
      JacC( 42, 36) = JacC( 42, 36) + dw(142, 36)
      JacC( 42, 57) = JacC( 42, 57) + dw(142, 57)
      JacC( 57, 36) = JacC( 57, 36) - dw(142, 36)
      JacC( 57, 57) = JacC( 57, 57) - dw(142, 57)
      JacC( 36, 36) = JacC( 36, 36) - dw(143, 36)
      JacC( 36, 46) = JacC( 36, 46) - dw(143, 46)
      JacC( 46, 36) = JacC( 46, 36) - dw(143, 36)
      JacC( 46, 46) = JacC( 46, 46) - dw(143, 46)
      JacC( 48, 36) = JacC( 48, 36) + dw(143, 36)
      JacC( 48, 46) = JacC( 48, 46) + dw(143, 46)
      JacC( 57, 36) = JacC( 57, 36) + dw(143, 36)
      JacC( 57, 46) = JacC( 57, 46) + dw(143, 46)
      JacC( 36, 36) = JacC( 36, 36) - dw(144, 36)
      JacC( 36, 58) = JacC( 36, 58) - dw(144, 58)
      JacC( 46, 36) = JacC( 46, 36) + dw(144, 36)
      JacC( 46, 58) = JacC( 46, 58) + dw(144, 58)
      JacC( 58, 36) = JacC( 58, 36) - dw(144, 36)
      JacC( 58, 58) = JacC( 58, 58) - dw(144, 58)
      JacC( 36, 36) = JacC( 36, 36)- 0.2000000000000000D+01*dw(145, 36)
      JacC( 36, 36) = JacC( 36, 36)- 0.2000000000000000D+01*dw(145, 36)
      JacC( 24, 57) = JacC( 24, 57) + dw(146, 57)
      JacC( 24, 55) = JacC( 24, 55) + dw(146, 55)
      JacC( 55, 57) = JacC( 55, 57) - dw(146, 57)
      JacC( 55, 55) = JacC( 55, 55) - dw(146, 55)
      JacC( 57, 57) = JacC( 57, 57) - dw(146, 57)
      JacC( 57, 55) = JacC( 57, 55) - dw(146, 55)
      JacC( 12, 56) = JacC( 12, 56) + dw(147, 56)
      JacC( 12, 50) = JacC( 12, 50) + dw(147, 50)
      JacC( 50, 56) = JacC( 50, 56) - dw(147, 56)
      JacC( 50, 50) = JacC( 50, 50) - dw(147, 50)
      JacC( 56, 56) = JacC( 56, 56) - dw(147, 56)
      JacC( 56, 50) = JacC( 56, 50) - dw(147, 50)
      JacC( 11, 51) = JacC( 11, 51) + dw(148, 51)
      JacC( 11, 55) = JacC( 11, 55) + dw(148, 55)
      JacC( 51, 51) = JacC( 51, 51) - dw(148, 51)
      JacC( 51, 55) = JacC( 51, 55) - dw(148, 55)
      JacC( 55, 51) = JacC( 55, 51) - dw(148, 51)
      JacC( 55, 55) = JacC( 55, 55) - dw(148, 55)
      JacC( 49, 50) = JacC( 49, 50) + dw(149, 50)
      JacC( 49, 55) = JacC( 49, 55) + dw(149, 55)
      JacC( 50, 50) = JacC( 50, 50) - dw(149, 50)
      JacC( 50, 55) = JacC( 50, 55) - dw(149, 55)
      JacC( 55, 50) = JacC( 55, 50) - dw(149, 50)
      JacC( 55, 55) = JacC( 55, 55) - dw(149, 55)
      JacC(  1, 50) = JacC(  1, 50) - dw(150, 50)
      JacC(  1,  1) = JacC(  1,  1) - dw(150,  1)
      JacC(  9, 50) = JacC(  9, 50) + dw(150, 50)
      JacC(  9,  1) = JacC(  9,  1) + dw(150,  1)
      JacC( 50, 50) = JacC( 50, 50) - dw(150, 50)
      JacC( 50,  1) = JacC( 50,  1) - dw(150,  1)
      JacC( 57, 50) = JacC( 57, 50) + dw(150, 50)
      JacC( 57,  1) = JacC( 57,  1) + dw(150,  1)
      JacC( 24, 24) = JacC( 24, 24) - dw(151, 24)
      JacC( 55, 24) = JacC( 55, 24) + dw(151, 24)
      JacC( 57, 24) = JacC( 57, 24) + dw(151, 24)
      JacC( 11, 11) = JacC( 11, 11) - dw(152, 11)
      JacC( 51, 11) = JacC( 51, 11) + dw(152, 11)
      JacC( 55, 11) = JacC( 55, 11) + dw(152, 11)
      JacC( 23, 23) = JacC( 23, 23) - dw(153, 23)
      JacC( 26, 23) = JacC( 26, 23) + dw(153, 23)
      JacC( 10, 57) = JacC( 10, 57) + dw(154, 57)
      JacC( 10, 57) = JacC( 10, 57) + dw(154, 57)
      JacC( 57, 57) = JacC( 57, 57)- 0.2000000000000000D+01*dw(154, 57)
      JacC( 57, 57) = JacC( 57, 57)- 0.2000000000000000D+01*dw(154, 57)
      JacC( 10, 57) = JacC( 10, 57) + dw(155, 57)
      JacC( 10, 57) = JacC( 10, 57) + dw(155, 57)
      JacC( 57, 57) = JacC( 57, 57)- 0.2000000000000000D+01*dw(155, 57)
      JacC( 57, 57) = JacC( 57, 57)- 0.2000000000000000D+01*dw(155, 57)
      JacC( 49, 50) = JacC( 49, 50) - dw(156, 50)
      JacC( 49, 49) = JacC( 49, 49) - dw(156, 49)
      JacC( 50, 50) = JacC( 50, 50) - dw(156, 50)
      JacC( 50, 49) = JacC( 50, 49) - dw(156, 49)
      JacC( 51, 50) = JacC( 51, 50) + dw(156, 50)
      JacC( 51, 49) = JacC( 51, 49) + dw(156, 49)
      JacC( 50, 53) = JacC( 50, 53) - dw(157, 53)
      JacC( 50, 50) = JacC( 50, 50) - dw(157, 50)
      JacC( 53, 53) = JacC( 53, 53) - dw(157, 53)
      JacC( 53, 50) = JacC( 53, 50) - dw(157, 50)
      JacC( 57, 53) = JacC( 57, 53) + dw(157, 53)
      JacC( 57, 50) = JacC( 57, 50) + dw(157, 50)
 
      do j = 1, ns
         do i = 1, ns
            JacC(i,j) = JacC(i,j) * convers_factor_jac(i,j)
         enddo
      enddo
 
 
      RETURN
      END
 
