C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C
C     This file is part of the air quality modeling system Polyphemus.
C
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C
C     Polyphemus is free software; you can redistribute i and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C------------------------------------------------------------------------
 
      subroutine jacdchemdc(ns,nr,y,convers_factor,
     $                    convers_factor_jac,rk,JacC)
 
C------------------------------------------------------------------------
C
C     -- DESCRIPTION
C
C     This routine computes the Jacobian matrix for the gas-phase.
C     This routine is automatically generated by SPACK.
C     Mechanism: RACM2_AEC           
C     Species: _ciRACM2_AEC        
C
C------------------------------------------------------------------------
C
C     -- INPUT VARIABLES
C
C     Ns: chemical species number.
C     NR: reaction number.
C     Y: chemical concentrations.
C     RK: kinetic rates.
C     convers_factor: unity conversion factor of mug/m3 to molecules/cm3.
C     convers_factor_jac: Wmol(i)/Wmol(j) for JacC(i,j)
C
C     -- INPUT/OUTPUT VARIABLES
C
C     -- OUTPUT VARIABLES
C
C     JACC: Jacobian matrix.
C
C------------------------------------------------------------------------
C
C     -- REMARKS
C
C     The matrix JACC could be stored in a low-dimensional vector.
C
C------------------------------------------------------------------------
C
C     -- MODIFICATIONS
C
C------------------------------------------------------------------------
C
C     -- AUTHOR(S)
C
C     SPACK.
C
C------------------------------------------------------------------------
 
      implicit none
 
      integer i,j,nr,ns
      double precision dw(nr,ns),rk(nr),y(ns),JacC(ns,ns)
      double precision convers_factor(ns)
      double precision convers_factor_jac(ns,ns)
      double precision conc(ns)
 
      do j=1,ns
       do i=1,ns
        JacC(i,j)=0.d0
       enddo
      enddo
 
C     Conversion mug/m3 to molecules/cm3.
 
      do i = 1, ns
         conc(i) = y(i) * convers_factor(i)
      enddo
 
      call dratedc(ns,nr,rk,conc,dw)
 
      JacC( 48,124) = JacC( 48,124) + dw(  1,124)
      JacC(117,124) = JacC(117,124) + dw(  1,124)
      JacC(124,124) = JacC(124,124) - dw(  1,124)
      JacC(  3, 90) = JacC(  3, 90) + dw(  2, 90)
      JacC( 90, 90) = JacC( 90, 90) - dw(  2, 90)
      JacC( 48, 90) = JacC( 48, 90) + dw(  3, 90)
      JacC( 90, 90) = JacC( 90, 90) - dw(  3, 90)
      JacC( 23, 23) = JacC( 23, 23) - dw(  4, 23)
      JacC(117, 23) = JacC(117, 23) + dw(  4, 23)
      JacC(120, 23) = JacC(120, 23) + dw(  4, 23)
      JacC(103,103) = JacC(103,103) - dw(  5,103)
      JacC(120,103) = JacC(120,103) + dw(  5,103)
      JacC(124,103) = JacC(124,103) + dw(  5,103)
      JacC( 42, 42) = JacC( 42, 42) - dw(  6, 42)
      JacC(120, 42) = JacC(120, 42)+ 0.2000000000000000D+00*dw(  6, 42)
      JacC(121, 42) = JacC(121, 42)+ 0.2000000000000000D+00*dw(  6, 42)
      JacC(123, 42) = JacC(123, 42)+ 0.8000000000000000D+00*dw(  6, 42)
      JacC(124, 42) = JacC(124, 42)+ 0.8000000000000000D+00*dw(  6, 42)
      JacC(117,121) = JacC(117,121) + dw(  7,121)
      JacC(121,121) = JacC(121,121) - dw(  7,121)
      JacC( 48,121) = JacC( 48,121) + dw(  8,121)
      JacC(121,121) = JacC(121,121) - dw(  8,121)
      JacC(124,121) = JacC(124,121) + dw(  8,121)
      JacC( 49, 49) = JacC( 49, 49) - dw(  9, 49)
      JacC(120, 49) = JacC(120, 49)+ 0.2000000000000000D+01*dw(  9, 49)
      JacC(108,119) = JacC(108,119) + dw( 10,119)
      JacC(119,119) = JacC(119,119) - dw( 10,119)
      JacC(108,119) = JacC(108,119) + dw( 11,119)
      JacC(119,119) = JacC(119,119) - dw( 11,119)
      JacC(123,119) = JacC(123,119)+ 0.2000000000000000D+01*dw( 11,119)
      JacC(100,100) = JacC(100,100) - dw( 12,100)
      JacC(108,100) = JacC(108,100) + dw( 12,100)
      JacC(114,100) = JacC(114,100) + dw( 12,100)
      JacC(123,100) = JacC(123,100) + dw( 12,100)
      JacC(108,112) = JacC(108,112) + dw( 13,112)
      JacC(112,112) = JacC(112,112) - dw( 13,112)
      JacC(113,112) = JacC(113,112) + dw( 13,112)
      JacC(123,112) = JacC(123,112) + dw( 13,112)
      JacC( 73, 73) = JacC( 73, 73) - dw( 14, 73)
      JacC(114, 73) = JacC(114, 73) + dw( 14, 73)
      JacC(118, 73) = JacC(118, 73) + dw( 14, 73)
      JacC( 36, 36) = JacC( 36, 36) - dw( 15, 36)
      JacC(113, 36) = JacC(113, 36)+ 0.5000000000000000D+00*dw( 15, 36)
      JacC(114, 36) = JacC(114, 36)+ 0.5000000000000000D+00*dw( 15, 36)
      JacC(118, 36) = JacC(118, 36) + dw( 15, 36)
      JacC(109,109) = JacC(109,109) - dw( 16,109)
      JacC(113,109) = JacC(113,109) + dw( 16,109)
      JacC(118,109) = JacC(118,109) + dw( 16,109)
      JacC( 77, 77) = JacC( 77, 77) - dw( 17, 77)
      JacC(118, 77) = JacC(118, 77) + dw( 17, 77)
      JacC(119, 77) = JacC(119, 77) + dw( 17, 77)
      JacC(123, 77) = JacC(123, 77) + dw( 17, 77)
      JacC( 84, 84) = JacC( 84, 84) - dw( 18, 84)
      JacC(105, 84) = JacC(105, 84)+ 0.3300000000000000D+00*dw( 18, 84)
      JacC(108, 84) = JacC(108, 84)+ 0.6700000000000000D+00*dw( 18, 84)
      JacC(116, 84) = JacC(116, 84)+ 0.3400000000000000D+00*dw( 18, 84)
      JacC(118, 84) = JacC(118, 84)+ 0.6700000000000000D+00*dw( 18, 84)
      JacC(119, 84) = JacC(119, 84)+ 0.6700000000000000D+00*dw( 18, 84)
      JacC(120, 84) = JacC(120, 84)+ 0.3400000000000000D+00*dw( 18, 84)
      JacC(123, 84) = JacC(123, 84)+ 0.6600000000000000D+00*dw( 18, 84)
      JacC( 81, 81) = JacC( 81, 81) - dw( 19, 81)
      JacC( 87, 81) = JacC( 87, 81)+ 0.7000000000000000D+00*dw( 19, 81)
      JacC(105, 81) = JacC(105, 81)+ 0.3000000000000000D+00*dw( 19, 81)
      JacC(108, 81) = JacC(108, 81)+ 0.7000000000000000D+00*dw( 19, 81)
      JacC(114, 81) = JacC(114, 81)+ 0.3000000000000000D+00*dw( 19, 81)
      JacC( 87, 87) = JacC( 87, 87) - dw( 20, 87)
      JacC(108, 87) = JacC(108, 87)+ 0.1220000000000000D+01*dw( 20, 87)
      JacC(109, 87) = JacC(109, 87)+ 0.2160000000000000D+00*dw( 20, 87)
      JacC(112, 87) = JacC(112, 87)+ 0.4340000000000000D+00*dw( 20, 87)
      JacC(118, 87) = JacC(118, 87)+ 0.7840000000000000D+00*dw( 20, 87)
      JacC(119, 87) = JacC(119, 87)+ 0.3500000000000000D+00*dw( 20, 87)
      JacC(123, 87) = JacC(123, 87)+ 0.1220000000000000D+01*dw( 20, 87)
      JacC(104,104) = JacC(104,104) - dw( 21,104)
      JacC(108,104) = JacC(108,104)+ 0.2000000000000000D+01*dw( 21,104)
      JacC(123,104) = JacC(123,104)+ 0.2000000000000000D+01*dw( 21,104)
      JacC(104,104) = JacC(104,104) - dw( 22,104)
      JacC(108,104) = JacC(108,104)+ 0.2000000000000000D+01*dw( 22,104)
      JacC(104,104) = JacC(104,104) - dw( 23,104)
      JacC(108,104) = JacC(108,104)+ 0.2000000000000000D+01*dw( 23,104)
      JacC(119,104) = JacC(119,104) + dw( 23,104)
      JacC(102,102) = JacC(102,102) - dw( 24,102)
      JacC(108,102) = JacC(108,102) + dw( 24,102)
      JacC(118,102) = JacC(118,102) + dw( 24,102)
      JacC(123,102) = JacC(123,102) + dw( 24,102)
      JacC( 69, 69) = JacC( 69, 69) - dw( 25, 69)
      JacC(102, 69) = JacC(102, 69)+ 0.5000000000000000D+00*dw( 25, 69)
      JacC(104, 69) = JacC(104, 69)+ 0.5000000000000000D+00*dw( 25, 69)
      JacC(108, 69) = JacC(108, 69) + dw( 25, 69)
      JacC(116, 69) = JacC(116, 69)+ 0.2000000000000000D+01*dw( 25, 69)
      JacC(118, 69) = JacC(118, 69)+ 0.5000000000000000D+00*dw( 25, 69)
      JacC(123, 69) = JacC(123, 69)+ 0.1500000000000000D+01*dw( 25, 69)
      JacC( 65, 65) = JacC( 65, 65) - dw( 26, 65)
      JacC(102, 65) = JacC(102, 65)+ 0.5000000000000000D+00*dw( 26, 65)
      JacC(104, 65) = JacC(104, 65)+ 0.5000000000000000D+00*dw( 26, 65)
      JacC(108, 65) = JacC(108, 65) + dw( 26, 65)
      JacC(116, 65) = JacC(116, 65)+ 0.2000000000000000D+01*dw( 26, 65)
      JacC(118, 65) = JacC(118, 65)+ 0.5000000000000000D+00*dw( 26, 65)
      JacC(123, 65) = JacC(123, 65)+ 0.1500000000000000D+01*dw( 26, 65)
      JacC( 91, 91) = JacC( 91, 91) - dw( 27, 91)
      JacC( 92, 91) = JacC( 92, 91) + dw( 27, 91)
      JacC(108, 91) = JacC(108, 91) + dw( 27, 91)
      JacC(118, 91) = JacC(118, 91) + dw( 27, 91)
      JacC(123, 91) = JacC(123, 91) + dw( 27, 91)
      JacC( 60, 63) = JacC( 60, 63) + dw( 28, 63)
      JacC( 63, 63) = JacC( 63, 63) - dw( 28, 63)
      JacC(108, 63) = JacC(108, 63) + dw( 28, 63)
      JacC(123, 63) = JacC(123, 63) + dw( 28, 63)
      JacC( 39, 39) = JacC( 39, 39) - dw( 29, 39)
      JacC(119, 39) = JacC(119, 39) + dw( 29, 39)
      JacC(120, 39) = JacC(120, 39) + dw( 29, 39)
      JacC(123, 39) = JacC(123, 39) + dw( 29, 39)
      JacC(112,115) = JacC(112,115) + dw( 30,115)
      JacC(115,115) = JacC(115,115) - dw( 30,115)
      JacC(120,115) = JacC(120,115) + dw( 30,115)
      JacC(123,115) = JacC(123,115) + dw( 30,115)
      JacC( 71, 71) = JacC( 71, 71) - dw( 31, 71)
      JacC(114, 71) = JacC(114, 71) + dw( 31, 71)
      JacC(120, 71) = JacC(120, 71) + dw( 31, 71)
      JacC(109,111) = JacC(109,111)+ 0.8000000000000000D+00*dw( 32,111)
      JacC(111,111) = JacC(111,111) - dw( 32,111)
      JacC(112,111) = JacC(112,111)+ 0.2000000000000000D+00*dw( 32,111)
      JacC(123,111) = JacC(123,111) + dw( 32,111)
      JacC(124,111) = JacC(124,111) + dw( 32,111)
      JacC( 40, 40) = JacC( 40, 40) - dw( 33, 40)
      JacC(118, 40) = JacC(118, 40) + dw( 33, 40)
      JacC(124, 40) = JacC(124, 40) + dw( 33, 40)
      JacC( 40, 40) = JacC( 40, 40) - dw( 34, 40)
      JacC(114, 40) = JacC(114, 40) + dw( 34, 40)
      JacC(121, 40) = JacC(121, 40) + dw( 34, 40)
      JacC( 48, 48) = JacC( 48, 48) - dw( 35, 48)
      JacC( 90, 48) = JacC( 90, 48) + dw( 35, 48)
      JacC( 48, 48) = JacC( 48, 48) - dw( 36, 48)
      JacC( 48, 90) = JacC( 48, 90) - dw( 36, 90)
      JacC( 90, 48) = JacC( 90, 48) - dw( 36, 48)
      JacC( 90, 90) = JacC( 90, 90) - dw( 36, 90)
      JacC(  3,  3) = JacC(  3,  3) - dw( 37,  3)
      JacC( 48,  3) = JacC( 48,  3) + dw( 37,  3)
      JacC(  3,  3) = JacC(  3,  3) - dw( 38,  3)
      JacC( 48,  3) = JacC( 48,  3) + dw( 38,  3)
      JacC(  3,  3) = JacC(  3,  3) - dw( 39,  3)
      JacC(120,  3) = JacC(120,  3)+ 0.2000000000000000D+01*dw( 39,  3)
      JacC( 90, 90) = JacC( 90, 90) - dw( 40, 90)
      JacC( 90,120) = JacC( 90,120) - dw( 40,120)
      JacC(120, 90) = JacC(120, 90) - dw( 40, 90)
      JacC(120,120) = JacC(120,120) - dw( 40,120)
      JacC(123, 90) = JacC(123, 90) + dw( 40, 90)
      JacC(123,120) = JacC(123,120) + dw( 40,120)
      JacC( 90, 90) = JacC( 90, 90) - dw( 41, 90)
      JacC( 90,123) = JacC( 90,123) - dw( 41,123)
      JacC(120, 90) = JacC(120, 90) + dw( 41, 90)
      JacC(120,123) = JacC(120,123) + dw( 41,123)
      JacC(123, 90) = JacC(123, 90) - dw( 41, 90)
      JacC(123,123) = JacC(123,123) - dw( 41,123)
      JacC(120,120) = JacC(120,120) - dw( 42,120)
      JacC(120,123) = JacC(120,123) - dw( 42,123)
      JacC(123,120) = JacC(123,120) - dw( 42,120)
      JacC(123,123) = JacC(123,123) - dw( 42,123)
      JacC( 49, 49) = JacC( 49, 49) - dw( 43, 49)
      JacC( 49,120) = JacC( 49,120) - dw( 43,120)
      JacC(120, 49) = JacC(120, 49) - dw( 43, 49)
      JacC(120,120) = JacC(120,120) - dw( 43,120)
      JacC(123, 49) = JacC(123, 49) + dw( 43, 49)
      JacC(123,120) = JacC(123,120) + dw( 43,120)
      JacC( 49,123) = JacC( 49,123) + dw( 44,123)
      JacC( 49,123) = JacC( 49,123) + dw( 44,123)
      JacC(123,123) = JacC(123,123)- 0.2000000000000000D+01*dw( 44,123)
      JacC(123,123) = JacC(123,123)- 0.2000000000000000D+01*dw( 44,123)
      JacC( 49,123) = JacC( 49,123) + dw( 45,123)
      JacC( 49,123) = JacC( 49,123) + dw( 45,123)
      JacC(123,123) = JacC(123,123)- 0.2000000000000000D+01*dw( 45,123)
      JacC(123,123) = JacC(123,123)- 0.2000000000000000D+01*dw( 45,123)
      JacC( 48, 48) = JacC( 48, 48) - dw( 46, 48)
      JacC( 48,117) = JacC( 48,117) - dw( 46,117)
      JacC(117, 48) = JacC(117, 48) - dw( 46, 48)
      JacC(117,117) = JacC(117,117) - dw( 46,117)
      JacC(124, 48) = JacC(124, 48) + dw( 46, 48)
      JacC(124,117) = JacC(124,117) + dw( 46,117)
      JacC( 48, 48) = JacC( 48, 48) - dw( 47, 48)
      JacC( 48,124) = JacC( 48,124) - dw( 47,124)
      JacC(117, 48) = JacC(117, 48) + dw( 47, 48)
      JacC(117,124) = JacC(117,124) + dw( 47,124)
      JacC(124, 48) = JacC(124, 48) - dw( 47, 48)
      JacC(124,124) = JacC(124,124) - dw( 47,124)
      JacC( 48, 48) = JacC( 48, 48) - dw( 48, 48)
      JacC( 48,124) = JacC( 48,124) - dw( 48,124)
      JacC(121, 48) = JacC(121, 48) + dw( 48, 48)
      JacC(121,124) = JacC(121,124) + dw( 48,124)
      JacC(124, 48) = JacC(124, 48) - dw( 48, 48)
      JacC(124,124) = JacC(124,124) - dw( 48,124)
      JacC( 23,120) = JacC( 23,120) + dw( 49,120)
      JacC( 23,117) = JacC( 23,117) + dw( 49,117)
      JacC(117,120) = JacC(117,120) - dw( 49,120)
      JacC(117,117) = JacC(117,117) - dw( 49,117)
      JacC(120,120) = JacC(120,120) - dw( 49,120)
      JacC(120,117) = JacC(120,117) - dw( 49,117)
      JacC(103,120) = JacC(103,120) + dw( 50,120)
      JacC(103,124) = JacC(103,124) + dw( 50,124)
      JacC(120,120) = JacC(120,120) - dw( 50,120)
      JacC(120,124) = JacC(120,124) - dw( 50,124)
      JacC(124,120) = JacC(124,120) - dw( 50,120)
      JacC(124,124) = JacC(124,124) - dw( 50,124)
      JacC(120,120) = JacC(120,120) - dw( 51,120)
      JacC(120,121) = JacC(120,121) - dw( 51,121)
      JacC(121,120) = JacC(121,120) - dw( 51,120)
      JacC(121,121) = JacC(121,121) - dw( 51,121)
      JacC(123,120) = JacC(123,120) + dw( 51,120)
      JacC(123,121) = JacC(123,121) + dw( 51,121)
      JacC(124,120) = JacC(124,120) + dw( 51,120)
      JacC(124,121) = JacC(124,121) + dw( 51,121)
      JacC(117,123) = JacC(117,123) - dw( 52,123)
      JacC(117,117) = JacC(117,117) - dw( 52,117)
      JacC(120,123) = JacC(120,123) + dw( 52,123)
      JacC(120,117) = JacC(120,117) + dw( 52,117)
      JacC(123,123) = JacC(123,123) - dw( 52,123)
      JacC(123,117) = JacC(123,117) - dw( 52,117)
      JacC(124,123) = JacC(124,123) + dw( 52,123)
      JacC(124,117) = JacC(124,117) + dw( 52,117)
      JacC( 42,123) = JacC( 42,123) + dw( 53,123)
      JacC( 42,124) = JacC( 42,124) + dw( 53,124)
      JacC(123,123) = JacC(123,123) - dw( 53,123)
      JacC(123,124) = JacC(123,124) - dw( 53,124)
      JacC(124,123) = JacC(124,123) - dw( 53,123)
      JacC(124,124) = JacC(124,124) - dw( 53,124)
      JacC( 42, 42) = JacC( 42, 42) - dw( 54, 42)
      JacC(123, 42) = JacC(123, 42) + dw( 54, 42)
      JacC(124, 42) = JacC(124, 42) + dw( 54, 42)
      JacC(103,123) = JacC(103,123)+ 0.3000000000000000D+00*dw( 55,123)
      JacC(103,121) = JacC(103,121)+ 0.3000000000000000D+00*dw( 55,121)
      JacC(120,123) = JacC(120,123)+ 0.7000000000000000D+00*dw( 55,123)
      JacC(120,121) = JacC(120,121)+ 0.7000000000000000D+00*dw( 55,121)
      JacC(121,123) = JacC(121,123) - dw( 55,123)
      JacC(121,121) = JacC(121,121) - dw( 55,121)
      JacC(123,123) = JacC(123,123) - dw( 55,123)
      JacC(123,121) = JacC(123,121) - dw( 55,121)
      JacC(124,123) = JacC(124,123)+ 0.7000000000000000D+00*dw( 55,123)
      JacC(124,121) = JacC(124,121)+ 0.7000000000000000D+00*dw( 55,121)
      JacC( 23,120) = JacC( 23,120) - dw( 56,120)
      JacC( 23, 23) = JacC( 23, 23) - dw( 56, 23)
      JacC(120,120) = JacC(120,120) - dw( 56,120)
      JacC(120, 23) = JacC(120, 23) - dw( 56, 23)
      JacC(124,120) = JacC(124,120) + dw( 56,120)
      JacC(124, 23) = JacC(124, 23) + dw( 56, 23)
      JacC(103,120) = JacC(103,120) - dw( 57,120)
      JacC(103,103) = JacC(103,103) - dw( 57,103)
      JacC(120,120) = JacC(120,120) - dw( 57,120)
      JacC(120,103) = JacC(120,103) - dw( 57,103)
      JacC(121,120) = JacC(121,120) + dw( 57,120)
      JacC(121,103) = JacC(121,103) + dw( 57,103)
      JacC( 42,120) = JacC( 42,120) - dw( 58,120)
      JacC( 42, 42) = JacC( 42, 42) - dw( 58, 42)
      JacC(120,120) = JacC(120,120) - dw( 58,120)
      JacC(120, 42) = JacC(120, 42) - dw( 58, 42)
      JacC(124,120) = JacC(124,120) + dw( 58,120)
      JacC(124, 42) = JacC(124, 42) + dw( 58, 42)
      JacC( 90, 90) = JacC( 90, 90) - dw( 59, 90)
      JacC( 90,117) = JacC( 90,117) - dw( 59,117)
      JacC(117, 90) = JacC(117, 90) - dw( 59, 90)
      JacC(117,117) = JacC(117,117) - dw( 59,117)
      JacC(124, 90) = JacC(124, 90) + dw( 59, 90)
      JacC(124,117) = JacC(124,117) + dw( 59,117)
      JacC( 90, 90) = JacC( 90, 90) - dw( 60, 90)
      JacC( 90,124) = JacC( 90,124) - dw( 60,124)
      JacC(121, 90) = JacC(121, 90) + dw( 60, 90)
      JacC(121,124) = JacC(121,124) + dw( 60,124)
      JacC(124, 90) = JacC(124, 90) - dw( 60, 90)
      JacC(124,124) = JacC(124,124) - dw( 60,124)
      JacC(117,117) = JacC(117,117)- 0.2000000000000000D+01*dw( 61,117)
      JacC(117,117) = JacC(117,117)- 0.2000000000000000D+01*dw( 61,117)
      JacC(124,117) = JacC(124,117)+ 0.2000000000000000D+01*dw( 61,117)
      JacC(124,117) = JacC(124,117)+ 0.2000000000000000D+01*dw( 61,117)
      JacC(117,121) = JacC(117,121) - dw( 62,121)
      JacC(117,117) = JacC(117,117) - dw( 62,117)
      JacC(121,121) = JacC(121,121) - dw( 62,121)
      JacC(121,117) = JacC(121,117) - dw( 62,117)
      JacC(124,121) = JacC(124,121)+ 0.2000000000000000D+01*dw( 62,121)
      JacC(124,117) = JacC(124,117)+ 0.2000000000000000D+01*dw( 62,117)
      JacC(117,121) = JacC(117,121) + dw( 63,121)
      JacC(117,124) = JacC(117,124) + dw( 63,124)
      JacC(121,121) = JacC(121,121) - dw( 63,121)
      JacC(121,124) = JacC(121,124) - dw( 63,124)
      JacC( 17,121) = JacC( 17,121) + dw( 64,121)
      JacC( 17,124) = JacC( 17,124) + dw( 64,124)
      JacC(121,121) = JacC(121,121) - dw( 64,121)
      JacC(121,124) = JacC(121,124) - dw( 64,124)
      JacC(124,121) = JacC(124,121) - dw( 64,121)
      JacC(124,124) = JacC(124,124) - dw( 64,124)
      JacC( 17, 17) = JacC( 17, 17) - dw( 65, 17)
      JacC(121, 17) = JacC(121, 17) + dw( 65, 17)
      JacC(124, 17) = JacC(124, 17) + dw( 65, 17)
      JacC( 17, 17) = JacC( 17, 17) - dw( 66, 17)
      JacC(103, 17) = JacC(103, 17)+ 0.2000000000000000D+01*dw( 66, 17)
      JacC(121,121) = JacC(121,121)- 0.2000000000000000D+01*dw( 67,121)
      JacC(121,121) = JacC(121,121)- 0.2000000000000000D+01*dw( 67,121)
      JacC(124,121) = JacC(124,121)+ 0.2000000000000000D+01*dw( 67,121)
      JacC(124,121) = JacC(124,121)+ 0.2000000000000000D+01*dw( 67,121)
      JacC(120,120) = JacC(120,120) - dw( 68,120)
      JacC(123,120) = JacC(123,120) + dw( 68,120)
      JacC(  4,120) = JacC(  4,120) - dw( 69,120)
      JacC(  4,  4) = JacC(  4,  4) - dw( 69,  4)
      JacC(  5,120) = JacC(  5,120) + dw( 69,120)
      JacC(  5,  4) = JacC(  5,  4) + dw( 69,  4)
      JacC(120,120) = JacC(120,120) - dw( 69,120)
      JacC(120,  4) = JacC(120,  4) - dw( 69,  4)
      JacC(123,120) = JacC(123,120) + dw( 69,120)
      JacC(123,  4) = JacC(123,  4) + dw( 69,  4)
      JacC(108,108) = JacC(108,108) - dw( 70,108)
      JacC(108,120) = JacC(108,120) - dw( 70,120)
      JacC(120,108) = JacC(120,108) - dw( 70,108)
      JacC(120,120) = JacC(120,120) - dw( 70,120)
      JacC(123,108) = JacC(123,108) + dw( 70,108)
      JacC(123,120) = JacC(123,120) + dw( 70,120)
      JacC( 45, 45) = JacC( 45, 45) - dw( 71, 45)
      JacC( 45,120) = JacC( 45,120) - dw( 71,120)
      JacC(114, 45) = JacC(114, 45) + dw( 71, 45)
      JacC(114,120) = JacC(114,120) + dw( 71,120)
      JacC(120, 45) = JacC(120, 45) - dw( 71, 45)
      JacC(120,120) = JacC(120,120) - dw( 71,120)
      JacC( 38, 38) = JacC( 38, 38) - dw( 72, 38)
      JacC( 38,120) = JacC( 38,120) - dw( 72,120)
      JacC(113, 38) = JacC(113, 38) + dw( 72, 38)
      JacC(113,120) = JacC(113,120) + dw( 72,120)
      JacC(120, 38) = JacC(120, 38) - dw( 72, 38)
      JacC(120,120) = JacC(120,120) - dw( 72,120)
      JacC( 99, 99) = JacC( 99, 99) - dw( 73, 99)
      JacC( 99,120) = JacC( 99,120) - dw( 73,120)
      JacC(119, 99) = JacC(119, 99) + dw( 73, 99)
      JacC(119,120) = JacC(119,120) + dw( 73,120)
      JacC(120, 99) = JacC(120, 99) - dw( 73, 99)
      JacC(120,120) = JacC(120,120) - dw( 73,120)
      JacC(123, 99) = JacC(123, 99) + dw( 73, 99)
      JacC(123,120) = JacC(123,120) + dw( 73,120)
      JacC( 25, 25) = JacC( 25, 25) - dw( 74, 25)
      JacC( 25,120) = JacC( 25,120) - dw( 74,120)
      JacC(100, 25) = JacC(100, 25) + dw( 74, 25)
      JacC(100,120) = JacC(100,120) + dw( 74,120)
      JacC(120, 25) = JacC(120, 25) - dw( 74, 25)
      JacC(120,120) = JacC(120,120) - dw( 74,120)
      JacC(123, 25) = JacC(123, 25) + dw( 74, 25)
      JacC(123,120) = JacC(123,120) + dw( 74,120)
      JacC( 95, 95) = JacC( 95, 95) - dw( 75, 95)
      JacC( 95,120) = JacC( 95,120) - dw( 75,120)
      JacC(100, 95) = JacC(100, 95)+ 0.1840000000000000D+00*dw( 75, 95)
      JacC(100,120) = JacC(100,120)+ 0.1840000000000000D+00*dw( 75,120)
      JacC(112, 95) = JacC(112, 95)+ 0.7190000000000000D+00*dw( 75, 95)
      JacC(112,120) = JacC(112,120)+ 0.7190000000000000D+00*dw( 75,120)
      JacC(120, 95) = JacC(120, 95) - dw( 75, 95)
      JacC(120,120) = JacC(120,120) - dw( 75,120)
      JacC(123, 95) = JacC(123, 95) + dw( 75, 95)
      JacC(123,120) = JacC(123,120) + dw( 75,120)
      JacC(  6,  6) = JacC(  6,  6) - dw( 76,  6)
      JacC(  6,120) = JacC(  6,120) - dw( 76,120)
      JacC( 82,  6) = JacC( 82,  6)+ 0.3500000000000000D+00*dw( 76,  6)
      JacC( 82,120) = JacC( 82,120)+ 0.3500000000000000D+00*dw( 76,120)
      JacC(104,  6) = JacC(104,  6)+ 0.6500000000000000D+00*dw( 76,  6)
      JacC(104,120) = JacC(104,120)+ 0.6500000000000000D+00*dw( 76,120)
      JacC(108,  6) = JacC(108,  6)+ 0.3500000000000000D+00*dw( 76,  6)
      JacC(108,120) = JacC(108,120)+ 0.3500000000000000D+00*dw( 76,120)
      JacC(120,  6) = JacC(120,  6)- 0.3500000000000000D+00*dw( 76,  6)
      JacC(120,120) = JacC(120,120)- 0.3500000000000000D+00*dw( 76,120)
      JacC(123,  6) = JacC(123,  6)+ 0.3500000000000000D+00*dw( 76,  6)
      JacC(123,120) = JacC(123,120)+ 0.3500000000000000D+00*dw( 76,120)
      JacC(  8,  8) = JacC(  8,  8) - dw( 77,  8)
      JacC(  8,120) = JacC(  8,120) - dw( 77,120)
      JacC(110,  8) = JacC(110,  8) + dw( 77,  8)
      JacC(110,120) = JacC(110,120) + dw( 77,120)
      JacC(120,  8) = JacC(120,  8) - dw( 77,  8)
      JacC(120,120) = JacC(120,120) - dw( 77,120)
      JacC(  9,  9) = JacC(  9,  9) - dw( 78,  9)
      JacC(  9,120) = JacC(  9,120) - dw( 78,120)
      JacC( 72,  9) = JacC( 72,  9) + dw( 78,  9)
      JacC( 72,120) = JacC( 72,120) + dw( 78,120)
      JacC(120,  9) = JacC(120,  9) - dw( 78,  9)
      JacC(120,120) = JacC(120,120) - dw( 78,120)
      JacC( 10, 10) = JacC( 10, 10) - dw( 79, 10)
      JacC( 10,120) = JacC( 10,120) - dw( 79,120)
      JacC( 66, 10) = JacC( 66, 10)+ 0.4800000000000000D-01*dw( 79, 10)
      JacC( 66,120) = JacC( 66,120)+ 0.4800000000000000D-01*dw( 79,120)
      JacC( 75, 10) = JacC( 75, 10)+ 0.9510000000000000D+00*dw( 79, 10)
      JacC( 75,120) = JacC( 75,120)+ 0.9510000000000000D+00*dw( 79,120)
      JacC( 77, 10) = JacC( 77, 10)+ 0.2400000000000000D-01*dw( 79, 10)
      JacC( 77,120) = JacC( 77,120)+ 0.2400000000000000D-01*dw( 79,120)
      JacC(112, 10) = JacC(112, 10)+ 0.2500000000000000D-01*dw( 79, 10)
      JacC(112,120) = JacC(112,120)+ 0.2500000000000000D-01*dw( 79,120)
      JacC(120, 10) = JacC(120, 10) - dw( 79, 10)
      JacC(120,120) = JacC(120,120) - dw( 79,120)
      JacC(123, 10) = JacC(123, 10)+ 0.4900000000000000D-01*dw( 79, 10)
      JacC(123,120) = JacC(123,120)+ 0.4900000000000000D-01*dw( 79,120)
      JacC( 27, 27) = JacC( 27, 27) - dw( 80, 27)
      JacC( 27,120) = JacC( 27,120) - dw( 80,120)
      JacC( 85, 27) = JacC( 85, 27) + dw( 80, 27)
      JacC( 85,120) = JacC( 85,120) + dw( 80,120)
      JacC(120, 27) = JacC(120, 27) - dw( 80, 27)
      JacC(120,120) = JacC(120,120) - dw( 80,120)
      JacC( 37, 37) = JacC( 37, 37) - dw( 81, 37)
      JacC( 37,120) = JacC( 37,120) - dw( 81,120)
      JacC( 66, 37) = JacC( 66, 37)+ 0.1600000000000000D-02*dw( 81, 37)
      JacC( 66,120) = JacC( 66,120)+ 0.1600000000000000D-02*dw( 81,120)
      JacC( 70, 37) = JacC( 70, 37) + dw( 81, 37)
      JacC( 70,120) = JacC( 70,120) + dw( 81,120)
      JacC(120, 37) = JacC(120, 37) - dw( 81, 37)
      JacC(120,120) = JacC(120,120) - dw( 81,120)
      JacC( 66, 89) = JacC( 66, 89)+ 0.3000000000000000D-02*dw( 82, 89)
      JacC( 66,120) = JacC( 66,120)+ 0.3000000000000000D-02*dw( 82,120)
      JacC( 89, 89) = JacC( 89, 89) - dw( 82, 89)
      JacC( 89,120) = JacC( 89,120) - dw( 82,120)
      JacC( 92, 89) = JacC( 92, 89) + dw( 82, 89)
      JacC( 92,120) = JacC( 92,120) + dw( 82,120)
      JacC(120, 89) = JacC(120, 89) - dw( 82, 89)
      JacC(120,120) = JacC(120,120) - dw( 82,120)
      JacC( 24, 24) = JacC( 24, 24) - dw( 83, 24)
      JacC( 24,120) = JacC( 24,120) - dw( 83,120)
      JacC( 92, 24) = JacC( 92, 24) + dw( 83, 24)
      JacC( 92,120) = JacC( 92,120) + dw( 83,120)
      JacC(120, 24) = JacC(120, 24) - dw( 83, 24)
      JacC(120,120) = JacC(120,120) - dw( 83,120)
      JacC( 20, 30) = JacC( 20, 30)+ 0.2320000000000000D+00*dw( 84, 30)
      JacC( 20,120) = JacC( 20,120)+ 0.2320000000000000D+00*dw( 84,120)
      JacC( 21, 30) = JacC( 21, 30)+ 0.2880000000000000D-01*dw( 84, 30)
      JacC( 21,120) = JacC( 21,120)+ 0.2880000000000000D-01*dw( 84,120)
      JacC( 30, 30) = JacC( 30, 30) - dw( 84, 30)
      JacC( 30,120) = JacC( 30,120) - dw( 84,120)
      JacC( 80, 30) = JacC( 80, 30) + dw( 84, 30)
      JacC( 80,120) = JacC( 80,120) + dw( 84,120)
      JacC(120, 30) = JacC(120, 30) - dw( 84, 30)
      JacC(120,120) = JacC(120,120) - dw( 84,120)
      JacC( 22, 22) = JacC( 22, 22) - dw( 85, 22)
      JacC( 22,120) = JacC( 22,120) - dw( 85,120)
      JacC( 32, 22) = JacC( 32, 22)+ 0.7600000000000000D-01*dw( 85, 22)
      JacC( 32,120) = JacC( 32,120)+ 0.7600000000000000D-01*dw( 85,120)
      JacC( 43, 22) = JacC( 43, 22)+ 0.1640000000000000D+00*dw( 85, 22)
      JacC( 43,120) = JacC( 43,120)+ 0.1640000000000000D+00*dw( 85,120)
      JacC( 44, 22) = JacC( 44, 22)+ 0.1170000000000000D+00*dw( 85, 22)
      JacC( 44,120) = JacC( 44,120)+ 0.1170000000000000D+00*dw( 85,120)
      JacC( 74, 22) = JacC( 74, 22) + dw( 85, 22)
      JacC( 74,120) = JacC( 74,120) + dw( 85,120)
      JacC(120, 22) = JacC(120, 22) - dw( 85, 22)
      JacC(120,120) = JacC(120,120) - dw( 85,120)
      JacC( 31, 31) = JacC( 31, 31) - dw( 86, 31)
      JacC( 31,120) = JacC( 31,120) - dw( 86,120)
      JacC( 32, 31) = JacC( 32, 31)+ 0.3000000000000000D-02*dw( 86, 31)
      JacC( 32,120) = JacC( 32,120)+ 0.3000000000000000D-02*dw( 86,120)
      JacC( 33, 31) = JacC( 33, 31)+ 0.2400000000000000D-01*dw( 86, 31)
      JacC( 33,120) = JacC( 33,120)+ 0.2400000000000000D-01*dw( 86,120)
      JacC( 43, 31) = JacC( 43, 31)+ 0.4070000000000000D+00*dw( 86, 31)
      JacC( 43,120) = JacC( 43,120)+ 0.4070000000000000D+00*dw( 86,120)
      JacC( 44, 31) = JacC( 44, 31)+ 0.1730000000000000D+00*dw( 86, 31)
      JacC( 44,120) = JacC( 44,120)+ 0.1730000000000000D+00*dw( 86,120)
      JacC( 79, 31) = JacC( 79, 31) + dw( 86, 31)
      JacC( 79,120) = JacC( 79,120) + dw( 86,120)
      JacC(120, 31) = JacC(120, 31) - dw( 86, 31)
      JacC(120,120) = JacC(120,120) - dw( 86,120)
      JacC( 29, 29) = JacC( 29, 29) - dw( 87, 29)
      JacC( 29,120) = JacC( 29,120) - dw( 87,120)
      JacC( 84, 29) = JacC( 84, 29) + dw( 87, 29)
      JacC( 84,120) = JacC( 84,120) + dw( 87,120)
      JacC( 18, 46) = JacC( 18, 46) + dw( 88, 46)
      JacC( 18,120) = JacC( 18,120) + dw( 88,120)
      JacC( 46, 46) = JacC( 46, 46) - dw( 88, 46)
      JacC( 46,120) = JacC( 46,120) - dw( 88,120)
      JacC( 76, 46) = JacC( 76, 46) + dw( 88, 46)
      JacC( 76,120) = JacC( 76,120) + dw( 88,120)
      JacC(120, 46) = JacC(120, 46) - dw( 88, 46)
      JacC(120,120) = JacC(120,120) - dw( 88,120)
      JacC( 34, 34) = JacC( 34, 34) - dw( 89, 34)
      JacC( 34,120) = JacC( 34,120) - dw( 89,120)
      JacC(105, 34) = JacC(105, 34) + dw( 89, 34)
      JacC(105,120) = JacC(105,120) + dw( 89,120)
      JacC(120, 34) = JacC(120, 34) - dw( 89, 34)
      JacC(120,120) = JacC(120,120) - dw( 89,120)
      JacC( 76, 76) = JacC( 76, 76) - dw( 90, 76)
      JacC( 76,120) = JacC( 76,120) - dw( 90,120)
      JacC(102, 76) = JacC(102, 76) + dw( 90, 76)
      JacC(102,120) = JacC(102,120) + dw( 90,120)
      JacC(120, 76) = JacC(120, 76) - dw( 90, 76)
      JacC(120,120) = JacC(120,120) - dw( 90,120)
      JacC(123, 76) = JacC(123, 76) + dw( 90, 76)
      JacC(123,120) = JacC(123,120) + dw( 90,120)
      JacC( 18, 18) = JacC( 18, 18) - dw( 91, 18)
      JacC( 18,120) = JacC( 18,120) - dw( 91,120)
      JacC(108, 18) = JacC(108, 18) + dw( 91, 18)
      JacC(108,120) = JacC(108,120) + dw( 91,120)
      JacC(119, 18) = JacC(119, 18) + dw( 91, 18)
      JacC(119,120) = JacC(119,120) + dw( 91,120)
      JacC(120, 18) = JacC(120, 18) - dw( 91, 18)
      JacC(120,120) = JacC(120,120) - dw( 91,120)
      JacC(124, 18) = JacC(124, 18) + dw( 91, 18)
      JacC(124,120) = JacC(124,120) + dw( 91,120)
      JacC( 28, 28) = JacC( 28, 28) - dw( 92, 28)
      JacC( 28,120) = JacC( 28,120) - dw( 92,120)
      JacC(112, 28) = JacC(112, 28) + dw( 92, 28)
      JacC(112,120) = JacC(112,120) + dw( 92,120)
      JacC(120, 28) = JacC(120, 28) - dw( 92, 28)
      JacC(120,120) = JacC(120,120) - dw( 92,120)
      JacC(123, 28) = JacC(123, 28) + dw( 92, 28)
      JacC(123,120) = JacC(123,120) + dw( 92,120)
      JacC(  7,  7) = JacC(  7,  7) - dw( 93,  7)
      JacC(  7,120) = JacC(  7,120) - dw( 93,120)
      JacC( 19,  7) = JacC( 19,  7)+ 0.5300000000000000D+00*dw( 93,  7)
      JacC( 19,120) = JacC( 19,120)+ 0.5300000000000000D+00*dw( 93,120)
      JacC( 86,  7) = JacC( 86,  7)+ 0.3520000000000000D+00*dw( 93,  7)
      JacC( 86,120) = JacC( 86,120)+ 0.3520000000000000D+00*dw( 93,120)
      JacC( 87,  7) = JacC( 87,  7)+ 0.1180000000000000D+00*dw( 93,  7)
      JacC( 87,120) = JacC( 87,120)+ 0.1180000000000000D+00*dw( 93,120)
      JacC(120,  7) = JacC(120,  7) - dw( 93,  7)
      JacC(120,120) = JacC(120,120) - dw( 93,120)
      JacC(123,  7) = JacC(123,  7)+ 0.6480000000000000D+00*dw( 93,  7)
      JacC(123,120) = JacC(123,120)+ 0.6480000000000000D+00*dw( 93,120)
      JacC( 11, 11) = JacC( 11, 11) - dw( 94, 11)
      JacC( 11,120) = JacC( 11,120) - dw( 94,120)
      JacC( 12, 11) = JacC( 12, 11)+ 0.8900000000000000D+00*dw( 94, 11)
      JacC( 12,120) = JacC( 12,120)+ 0.8900000000000000D+00*dw( 94,120)
      JacC( 53, 11) = JacC( 53, 11)+ 0.6000000000000000D-01*dw( 94, 11)
      JacC( 53,120) = JacC( 53,120)+ 0.6000000000000000D-01*dw( 94,120)
      JacC( 58, 11) = JacC( 58, 11)+ 0.5000000000000000D-01*dw( 94, 11)
      JacC( 58,120) = JacC( 58,120)+ 0.5000000000000000D-01*dw( 94,120)
      JacC(120, 11) = JacC(120, 11) - dw( 94, 11)
      JacC(120,120) = JacC(120,120) - dw( 94,120)
      JacC(123, 11) = JacC(123, 11)+ 0.5000000000000000D-01*dw( 94, 11)
      JacC(123,120) = JacC(123,120)+ 0.5000000000000000D-01*dw( 94,120)
      JacC( 53, 53) = JacC( 53, 53) - dw( 95, 53)
      JacC( 53,117) = JacC( 53,117) - dw( 95,117)
      JacC( 63, 53) = JacC( 63, 53) + dw( 95, 53)
      JacC( 63,117) = JacC( 63,117) + dw( 95,117)
      JacC(117, 53) = JacC(117, 53) - dw( 95, 53)
      JacC(117,117) = JacC(117,117) - dw( 95,117)
      JacC(124, 53) = JacC(124, 53) + dw( 95, 53)
      JacC(124,117) = JacC(124,117) + dw( 95,117)
      JacC( 12, 12) = JacC( 12, 12) - dw( 96, 12)
      JacC( 26, 12) = JacC( 26, 12)+ 0.2800000000000000D+00*dw( 96, 12)
      JacC( 52, 12) = JacC( 52, 12)+ 0.1500000000000000D+00*dw( 96, 12)
      JacC( 54, 12) = JacC( 54, 12)+ 0.2800000000000000D+00*dw( 96, 12)
      JacC( 58, 12) = JacC( 58, 12)+ 0.1000000000000000D-01*dw( 96, 12)
      JacC( 65, 12) = JacC( 65, 12)+ 0.2800000000000000D+00*dw( 96, 12)
      JacC(120, 12) = JacC(120, 12)+ 0.2800000000000000D+00*dw( 96, 12)
      JacC(123, 12) = JacC(123, 12)+ 0.2900000000000000D+00*dw( 96, 12)
      JacC( 52, 54) = JacC( 52, 54)+ 0.5000000000000000D+00*dw( 97, 54)
      JacC( 54, 54) = JacC( 54, 54) - dw( 97, 54)
      JacC( 58, 54) = JacC( 58, 54)+ 0.1000000000000000D-01*dw( 97, 54)
      JacC( 65, 54) = JacC( 65, 54)+ 0.4900000000000000D+00*dw( 97, 54)
      JacC(120, 54) = JacC(120, 54)+ 0.4900000000000000D+00*dw( 97, 54)
      JacC(123, 54) = JacC(123, 54)+ 0.1000000000000000D-01*dw( 97, 54)
      JacC( 54, 54) = JacC( 54, 54) - dw( 98, 54)
      JacC( 54,117) = JacC( 54,117) - dw( 98,117)
      JacC( 59, 54) = JacC( 59, 54)+ 0.3360000000000000D+00*dw( 98, 54)
      JacC( 59,117) = JacC( 59,117)+ 0.3360000000000000D+00*dw( 98,117)
      JacC( 65, 54) = JacC( 65, 54)+ 0.9500000000000000D+00*dw( 98, 54)
      JacC( 65,117) = JacC( 65,117)+ 0.9500000000000000D+00*dw( 98,117)
      JacC( 66, 54) = JacC( 66, 54)+ 0.5300000000000000D-01*dw( 98, 54)
      JacC( 66,117) = JacC( 66,117)+ 0.5300000000000000D-01*dw( 98,117)
      JacC(111, 54) = JacC(111, 54)+ 0.5000000000000000D-01*dw( 98, 54)
      JacC(111,117) = JacC(111,117)+ 0.5000000000000000D-01*dw( 98,117)
      JacC(117, 54) = JacC(117, 54) - dw( 98, 54)
      JacC(117,117) = JacC(117,117) - dw( 98,117)
      JacC(123, 54) = JacC(123, 54)+ 0.9500000000000000D+00*dw( 98, 54)
      JacC(123,117) = JacC(123,117)+ 0.9500000000000000D+00*dw( 98,117)
      JacC(124, 54) = JacC(124, 54)+ 0.9500000000000000D+00*dw( 98, 54)
      JacC(124,117) = JacC(124,117)+ 0.9500000000000000D+00*dw( 98,117)
      JacC( 52, 52) = JacC( 52, 52) - dw( 99, 52)
      JacC( 52,117) = JacC( 52,117) - dw( 99,117)
      JacC( 69, 52) = JacC( 69, 52)+ 0.9500000000000000D+00*dw( 99, 52)
      JacC( 69,117) = JacC( 69,117)+ 0.9500000000000000D+00*dw( 99,117)
      JacC(102, 52) = JacC(102, 52)+ 0.9500000000000000D+00*dw( 99, 52)
      JacC(102,117) = JacC(102,117)+ 0.9500000000000000D+00*dw( 99,117)
      JacC(111, 52) = JacC(111, 52)+ 0.5000000000000000D-01*dw( 99, 52)
      JacC(111,117) = JacC(111,117)+ 0.5000000000000000D-01*dw( 99,117)
      JacC(117, 52) = JacC(117, 52) - dw( 99, 52)
      JacC(117,117) = JacC(117,117) - dw( 99,117)
      JacC(123, 52) = JacC(123, 52)+ 0.9500000000000000D+00*dw( 99, 52)
      JacC(123,117) = JacC(123,117)+ 0.9500000000000000D+00*dw( 99,117)
      JacC(124, 52) = JacC(124, 52)+ 0.9500000000000000D+00*dw( 99, 52)
      JacC(124,117) = JacC(124,117)+ 0.9500000000000000D+00*dw( 99,117)
      JacC( 15, 15) = JacC( 15, 15) - dw(100, 15)
      JacC( 15,120) = JacC( 15,120) - dw(100,120)
      JacC( 16, 15) = JacC( 16, 15)+ 0.8900000000000000D+00*dw(100, 15)
      JacC( 16,120) = JacC( 16,120)+ 0.8900000000000000D+00*dw(100,120)
      JacC( 55, 15) = JacC( 55, 15)+ 0.6000000000000000D-01*dw(100, 15)
      JacC( 55,120) = JacC( 55,120)+ 0.6000000000000000D-01*dw(100,120)
      JacC( 58, 15) = JacC( 58, 15)+ 0.5000000000000000D-01*dw(100, 15)
      JacC( 58,120) = JacC( 58,120)+ 0.5000000000000000D-01*dw(100,120)
      JacC(120, 15) = JacC(120, 15) - dw(100, 15)
      JacC(120,120) = JacC(120,120) - dw(100,120)
      JacC(123, 15) = JacC(123, 15)+ 0.5000000000000000D-01*dw(100, 15)
      JacC(123,120) = JacC(123,120)+ 0.5000000000000000D-01*dw(100,120)
      JacC( 13, 13) = JacC( 13, 13) - dw(101, 13)
      JacC( 13,120) = JacC( 13,120) - dw(101,120)
      JacC( 14, 13) = JacC( 14, 13)+ 0.8900000000000000D+00*dw(101, 13)
      JacC( 14,120) = JacC( 14,120)+ 0.8900000000000000D+00*dw(101,120)
      JacC( 55, 13) = JacC( 55, 13)+ 0.6000000000000000D-01*dw(101, 13)
      JacC( 55,120) = JacC( 55,120)+ 0.6000000000000000D-01*dw(101,120)
      JacC( 58, 13) = JacC( 58, 13)+ 0.5000000000000000D-01*dw(101, 13)
      JacC( 58,120) = JacC( 58,120)+ 0.5000000000000000D-01*dw(101,120)
      JacC(120, 13) = JacC(120, 13) - dw(101, 13)
      JacC(120,120) = JacC(120,120) - dw(101,120)
      JacC(123, 13) = JacC(123, 13)+ 0.5000000000000000D-01*dw(101, 13)
      JacC(123,120) = JacC(123,120)+ 0.5000000000000000D-01*dw(101,120)
      JacC( 55, 55) = JacC( 55, 55) - dw(102, 55)
      JacC( 55,117) = JacC( 55,117) - dw(102,117)
      JacC( 63, 55) = JacC( 63, 55) + dw(102, 55)
      JacC( 63,117) = JacC( 63,117) + dw(102,117)
      JacC(117, 55) = JacC(117, 55) - dw(102, 55)
      JacC(117,117) = JacC(117,117) - dw(102,117)
      JacC(124, 55) = JacC(124, 55) + dw(102, 55)
      JacC(124,117) = JacC(124,117) + dw(102,117)
      JacC( 14, 14) = JacC( 14, 14) - dw(103, 14)
      JacC( 26, 14) = JacC( 26, 14)+ 0.8400000000000000D+00*dw(103, 14)
      JacC( 56, 14) = JacC( 56, 14)+ 0.3080000000000000D+00*dw(103, 14)
      JacC( 58, 14) = JacC( 58, 14)+ 0.1000000000000000D-01*dw(103, 14)
      JacC( 62, 14) = JacC( 62, 14)+ 0.1500000000000000D+00*dw(103, 14)
      JacC( 65, 14) = JacC( 65, 14)+ 0.2240000000000000D+00*dw(103, 14)
      JacC(120, 14) = JacC(120, 14)+ 0.3080000000000000D+00*dw(103, 14)
      JacC(123, 14) = JacC(123, 14)+ 0.3080000000000000D+00*dw(103, 14)
      JacC( 16, 16) = JacC( 16, 16) - dw(104, 16)
      JacC( 26, 16) = JacC( 26, 16)+ 0.8400000000000000D+00*dw(104, 16)
      JacC( 58, 16) = JacC( 58, 16)+ 0.1000000000000000D-01*dw(104, 16)
      JacC( 62, 16) = JacC( 62, 16)+ 0.1500000000000000D+00*dw(104, 16)
      JacC( 64, 16) = JacC( 64, 16)+ 0.3080000000000000D+00*dw(104, 16)
      JacC( 65, 16) = JacC( 65, 16)+ 0.2240000000000000D+00*dw(104, 16)
      JacC(120, 16) = JacC(120, 16)+ 0.3080000000000000D+00*dw(104, 16)
      JacC(123, 16) = JacC(123, 16)+ 0.3080000000000000D+00*dw(104, 16)
      JacC( 56, 56) = JacC( 56, 56) - dw(105, 56)
      JacC( 58, 56) = JacC( 58, 56)+ 0.1000000000000000D-01*dw(105, 56)
      JacC( 62, 56) = JacC( 62, 56)+ 0.5000000000000000D+00*dw(105, 56)
      JacC( 65, 56) = JacC( 65, 56)+ 0.4900000000000000D+00*dw(105, 56)
      JacC(120, 56) = JacC(120, 56)+ 0.4900000000000000D+00*dw(105, 56)
      JacC(123, 56) = JacC(123, 56)+ 0.1000000000000000D-01*dw(105, 56)
      JacC( 58, 64) = JacC( 58, 64)+ 0.1000000000000000D-01*dw(106, 64)
      JacC( 62, 64) = JacC( 62, 64)+ 0.5000000000000000D+00*dw(106, 64)
      JacC( 64, 64) = JacC( 64, 64) - dw(106, 64)
      JacC( 65, 64) = JacC( 65, 64)+ 0.4900000000000000D+00*dw(106, 64)
      JacC(120, 64) = JacC(120, 64)+ 0.4900000000000000D+00*dw(106, 64)
      JacC(123, 64) = JacC(123, 64)+ 0.1000000000000000D-01*dw(106, 64)
      JacC( 56, 56) = JacC( 56, 56) - dw(107, 56)
      JacC( 56,117) = JacC( 56,117) - dw(107,117)
      JacC( 59, 56) = JacC( 59, 56)+ 0.3200000000000000D+00*dw(107, 56)
      JacC( 59,117) = JacC( 59,117)+ 0.3200000000000000D+00*dw(107,117)
      JacC( 65, 56) = JacC( 65, 56)+ 0.9500000000000000D+00*dw(107, 56)
      JacC( 65,117) = JacC( 65,117)+ 0.9500000000000000D+00*dw(107,117)
      JacC( 66, 56) = JacC( 66, 56)+ 0.2300000000000000D-01*dw(107, 56)
      JacC( 66,117) = JacC( 66,117)+ 0.2300000000000000D-01*dw(107,117)
      JacC(111, 56) = JacC(111, 56)+ 0.5000000000000000D-01*dw(107, 56)
      JacC(111,117) = JacC(111,117)+ 0.5000000000000000D-01*dw(107,117)
      JacC(117, 56) = JacC(117, 56) - dw(107, 56)
      JacC(117,117) = JacC(117,117) - dw(107,117)
      JacC(123, 56) = JacC(123, 56)+ 0.9500000000000000D+00*dw(107, 56)
      JacC(123,117) = JacC(123,117)+ 0.9500000000000000D+00*dw(107,117)
      JacC(124, 56) = JacC(124, 56)+ 0.9500000000000000D+00*dw(107, 56)
      JacC(124,117) = JacC(124,117)+ 0.9500000000000000D+00*dw(107,117)
      JacC( 62, 62) = JacC( 62, 62) - dw(108, 62)
      JacC( 62,117) = JacC( 62,117) - dw(108,117)
      JacC( 69, 62) = JacC( 69, 62)+ 0.9500000000000000D+00*dw(108, 62)
      JacC( 69,117) = JacC( 69,117)+ 0.9500000000000000D+00*dw(108,117)
      JacC( 91, 62) = JacC( 91, 62)+ 0.1950000000000000D+01*dw(108, 62)
      JacC( 91,117) = JacC( 91,117)+ 0.1950000000000000D+01*dw(108,117)
      JacC(102, 62) = JacC(102, 62)+ 0.9500000000000000D+00*dw(108, 62)
      JacC(102,117) = JacC(102,117)+ 0.9500000000000000D+00*dw(108,117)
      JacC(111, 62) = JacC(111, 62)+ 0.5000000000000000D-01*dw(108, 62)
      JacC(111,117) = JacC(111,117)+ 0.5000000000000000D-01*dw(108,117)
      JacC(117, 62) = JacC(117, 62) - dw(108, 62)
      JacC(117,117) = JacC(117,117) - dw(108,117)
      JacC(123, 62) = JacC(123, 62)+ 0.9500000000000000D+00*dw(108, 62)
      JacC(123,117) = JacC(123,117)+ 0.9500000000000000D+00*dw(108,117)
      JacC(124, 62) = JacC(124, 62)+ 0.9500000000000000D+00*dw(108, 62)
      JacC(124,117) = JacC(124,117)+ 0.9500000000000000D+00*dw(108,117)
      JacC( 63, 63) = JacC( 63, 63) - dw(109, 63)
      JacC( 63,120) = JacC( 63,120) - dw(109,120)
      JacC( 67, 63) = JacC( 67, 63) + dw(109, 63)
      JacC( 67,120) = JacC( 67,120) + dw(109,120)
      JacC(120, 63) = JacC(120, 63) - dw(109, 63)
      JacC(120,120) = JacC(120,120) - dw(109,120)
      JacC( 50, 67) = JacC( 50, 67) + dw(110, 67)
      JacC( 50,117) = JacC( 50,117) + dw(110,117)
      JacC( 67, 67) = JacC( 67, 67) - dw(110, 67)
      JacC( 67,117) = JacC( 67,117) - dw(110,117)
      JacC(117, 67) = JacC(117, 67) - dw(110, 67)
      JacC(117,117) = JacC(117,117) - dw(110,117)
      JacC(124, 67) = JacC(124, 67) + dw(110, 67)
      JacC(124,117) = JacC(124,117) + dw(110,117)
      JacC( 50, 50) = JacC( 50, 50) - dw(111, 50)
      JacC( 50,117) = JacC( 50,117) - dw(111,117)
      JacC( 51, 50) = JacC( 51, 50) + dw(111, 50)
      JacC( 51,117) = JacC( 51,117) + dw(111,117)
      JacC(117, 50) = JacC(117, 50) - dw(111, 50)
      JacC(117,117) = JacC(117,117) - dw(111,117)
      JacC(124, 50) = JacC(124, 50) + dw(111, 50)
      JacC(124,117) = JacC(124,117) + dw(111,117)
      JacC( 51, 51) = JacC( 51, 51) - dw(112, 51)
      JacC( 51,124) = JacC( 51,124) - dw(112,124)
      JacC(111, 51) = JacC(111, 51) + dw(112, 51)
      JacC(111,124) = JacC(111,124) + dw(112,124)
      JacC(124, 51) = JacC(124, 51) - dw(112, 51)
      JacC(124,124) = JacC(124,124) - dw(112,124)
      JacC( 19, 19) = JacC( 19, 19) - dw(113, 19)
      JacC( 19,120) = JacC( 19,120) - dw(113,120)
      JacC( 35, 19) = JacC( 35, 19)+ 0.7300000000000000D+00*dw(113, 19)
      JacC( 35,120) = JacC( 35,120)+ 0.7300000000000000D+00*dw(113,120)
      JacC( 59, 19) = JacC( 59, 19)+ 0.9000000000000000D-01*dw(113, 19)
      JacC( 59,120) = JacC( 59,120)+ 0.9000000000000000D-01*dw(113,120)
      JacC( 60, 19) = JacC( 60, 19)+ 0.7000000000000001D-01*dw(113, 19)
      JacC( 60,120) = JacC( 60,120)+ 0.7000000000000001D-01*dw(113,120)
      JacC( 66, 19) = JacC( 66, 19)+ 0.1400000000000000D-01*dw(113, 19)
      JacC( 66,120) = JacC( 66,120)+ 0.1400000000000000D-01*dw(113,120)
      JacC( 78, 19) = JacC( 78, 19)+ 0.2000000000000000D+00*dw(113, 19)
      JacC( 78,120) = JacC( 78,120)+ 0.2000000000000000D+00*dw(113,120)
      JacC(120, 19) = JacC(120, 19) - dw(113, 19)
      JacC(120,120) = JacC(120,120) - dw(113,120)
      JacC(123, 19) = JacC(123, 19)+ 0.7300000000000000D+00*dw(113, 19)
      JacC(123,120) = JacC(123,120)+ 0.7300000000000000D+00*dw(113,120)
      JacC( 35, 58) = JacC( 35, 58)+ 0.7300000000000000D+00*dw(114, 58)
      JacC( 35,120) = JacC( 35,120)+ 0.7300000000000000D+00*dw(114,120)
      JacC( 58, 58) = JacC( 58, 58) - dw(114, 58)
      JacC( 58,120) = JacC( 58,120) - dw(114,120)
      JacC( 59, 58) = JacC( 59, 58)+ 0.9000000000000000D-01*dw(114, 58)
      JacC( 59,120) = JacC( 59,120)+ 0.9000000000000000D-01*dw(114,120)
      JacC( 60, 58) = JacC( 60, 58)+ 0.7000000000000001D-01*dw(114, 58)
      JacC( 60,120) = JacC( 60,120)+ 0.7000000000000001D-01*dw(114,120)
      JacC( 66, 58) = JacC( 66, 58)+ 0.1400000000000000D-01*dw(114, 58)
      JacC( 66,120) = JacC( 66,120)+ 0.1400000000000000D-01*dw(114,120)
      JacC( 78, 58) = JacC( 78, 58)+ 0.2000000000000000D+00*dw(114, 58)
      JacC( 78,120) = JacC( 78,120)+ 0.2000000000000000D+00*dw(114,120)
      JacC(120, 58) = JacC(120, 58) - dw(114, 58)
      JacC(120,120) = JacC(120,120) - dw(114,120)
      JacC(123, 58) = JacC(123, 58)+ 0.7300000000000000D+00*dw(114, 58)
      JacC(123,120) = JacC(123,120)+ 0.7300000000000000D+00*dw(114,120)
      JacC( 35, 35) = JacC( 35, 35) - dw(115, 35)
      JacC( 35,120) = JacC( 35,120) - dw(115,120)
      JacC( 97, 35) = JacC( 97, 35) + dw(115, 35)
      JacC( 97,120) = JacC( 97,120) + dw(115,120)
      JacC(120, 35) = JacC(120, 35) - dw(115, 35)
      JacC(120,120) = JacC(120,120) - dw(115,120)
      JacC( 35, 35) = JacC( 35, 35) - dw(116, 35)
      JacC( 35,121) = JacC( 35,121) - dw(116,121)
      JacC( 97, 35) = JacC( 97, 35) + dw(116, 35)
      JacC( 97,121) = JacC( 97,121) + dw(116,121)
      JacC(103, 35) = JacC(103, 35) + dw(116, 35)
      JacC(103,121) = JacC(103,121) + dw(116,121)
      JacC(121, 35) = JacC(121, 35) - dw(116, 35)
      JacC(121,121) = JacC(121,121) - dw(116,121)
      JacC( 90, 97) = JacC( 90, 97) - dw(117, 97)
      JacC( 90, 90) = JacC( 90, 90) - dw(117, 90)
      JacC( 96, 97) = JacC( 96, 97) + dw(117, 97)
      JacC( 96, 90) = JacC( 96, 90) + dw(117, 90)
      JacC( 97, 97) = JacC( 97, 97) - dw(117, 97)
      JacC( 97, 90) = JacC( 97, 90) - dw(117, 90)
      JacC( 97, 97) = JacC( 97, 97) - dw(118, 97)
      JacC( 97,124) = JacC( 97,124) - dw(118,124)
      JacC(111, 97) = JacC(111, 97) + dw(118, 97)
      JacC(111,124) = JacC(111,124) + dw(118,124)
      JacC(124, 97) = JacC(124, 97) - dw(118, 97)
      JacC(124,124) = JacC(124,124) - dw(118,124)
      JacC( 96, 96) = JacC( 96, 96) - dw(119, 96)
      JacC( 96,117) = JacC( 96,117) - dw(119,117)
      JacC( 97, 96) = JacC( 97, 96) + dw(119, 96)
      JacC( 97,117) = JacC( 97,117) + dw(119,117)
      JacC(117, 96) = JacC(117, 96) - dw(119, 96)
      JacC(117,117) = JacC(117,117) - dw(119,117)
      JacC(124, 96) = JacC(124, 96) + dw(119, 96)
      JacC(124,117) = JacC(124,117) + dw(119,117)
      JacC( 96, 96) = JacC( 96, 96) - dw(120, 96)
      JacC( 96,114) = JacC( 96,114) - dw(120,114)
      JacC( 97, 96) = JacC( 97, 96) + dw(120, 96)
      JacC( 97,114) = JacC( 97,114) + dw(120,114)
      JacC(114, 96) = JacC(114, 96) - dw(120, 96)
      JacC(114,114) = JacC(114,114) - dw(120,114)
      JacC(119, 96) = JacC(119, 96) + dw(120, 96)
      JacC(119,114) = JacC(119,114) + dw(120,114)
      JacC(123, 96) = JacC(123, 96) + dw(120, 96)
      JacC(123,114) = JacC(123,114) + dw(120,114)
      JacC( 96, 96) = JacC( 96, 96) - dw(121, 96)
      JacC( 96,118) = JacC( 96,118) - dw(121,118)
      JacC( 97, 96) = JacC( 97, 96) + dw(121, 96)
      JacC( 97,118) = JacC( 97,118) + dw(121,118)
      JacC(114, 96) = JacC(114, 96) + dw(121, 96)
      JacC(114,118) = JacC(114,118) + dw(121,118)
      JacC(118, 96) = JacC(118, 96) - dw(121, 96)
      JacC(118,118) = JacC(118,118) - dw(121,118)
      JacC(123, 96) = JacC(123, 96) + dw(121, 96)
      JacC(123,118) = JacC(123,118) + dw(121,118)
      JacC( 96, 96) = JacC( 96, 96) - dw(122, 96)
      JacC( 96,123) = JacC( 96,123) - dw(122,123)
      JacC(115, 96) = JacC(115, 96) + dw(122, 96)
      JacC(115,123) = JacC(115,123) + dw(122,123)
      JacC(123, 96) = JacC(123, 96) - dw(122, 96)
      JacC(123,123) = JacC(123,123) - dw(122,123)
      JacC( 96, 96) = JacC( 96, 96) - dw(123, 96)
      JacC( 96,121) = JacC( 96,121) - dw(123,121)
      JacC( 97, 96) = JacC( 97, 96) + dw(123, 96)
      JacC( 97,121) = JacC( 97,121) + dw(123,121)
      JacC(121, 96) = JacC(121, 96) - dw(123, 96)
      JacC(121,121) = JacC(121,121) - dw(123,121)
      JacC(124, 96) = JacC(124, 96) + dw(123, 96)
      JacC(124,121) = JacC(124,121) + dw(123,121)
      JacC(108,119) = JacC(108,119) + dw(124,119)
      JacC(108,120) = JacC(108,120) + dw(124,120)
      JacC(119,119) = JacC(119,119) - dw(124,119)
      JacC(119,120) = JacC(119,120) - dw(124,120)
      JacC(120,119) = JacC(120,119) - dw(124,119)
      JacC(120,120) = JacC(120,120) - dw(124,120)
      JacC(123,119) = JacC(123,119) + dw(124,119)
      JacC(123,120) = JacC(123,120) + dw(124,120)
      JacC(100,100) = JacC(100,100) - dw(125,100)
      JacC(100,120) = JacC(100,120) - dw(125,120)
      JacC(118,100) = JacC(118,100) + dw(125,100)
      JacC(118,120) = JacC(118,120) + dw(125,120)
      JacC(120,100) = JacC(120,100) - dw(125,100)
      JacC(120,120) = JacC(120,120) - dw(125,120)
      JacC(112,112) = JacC(112,112) - dw(126,112)
      JacC(112,120) = JacC(112,120) - dw(126,120)
      JacC(120,112) = JacC(120,112) - dw(126,112)
      JacC(120,120) = JacC(120,120) - dw(126,120)
      JacC(122,112) = JacC(122,112) + dw(126,112)
      JacC(122,120) = JacC(122,120) + dw(126,120)
      JacC( 73, 73) = JacC( 73, 73) - dw(127, 73)
      JacC( 73,120) = JacC( 73,120) - dw(127,120)
      JacC( 98, 73) = JacC( 98, 73) + dw(127, 73)
      JacC( 98,120) = JacC( 98,120) + dw(127,120)
      JacC(120, 73) = JacC(120, 73) - dw(127, 73)
      JacC(120,120) = JacC(120,120) - dw(127,120)
      JacC( 36, 36) = JacC( 36, 36) - dw(128, 36)
      JacC( 36,120) = JacC( 36,120) - dw(128,120)
      JacC( 68, 36) = JacC( 68, 36) + dw(128, 36)
      JacC( 68,120) = JacC( 68,120) + dw(128,120)
      JacC(120, 36) = JacC(120, 36) - dw(128, 36)
      JacC(120,120) = JacC(120,120) - dw(128,120)
      JacC(101,109) = JacC(101,109) + dw(129,109)
      JacC(101,120) = JacC(101,120) + dw(129,120)
      JacC(109,109) = JacC(109,109) - dw(129,109)
      JacC(109,120) = JacC(109,120) - dw(129,120)
      JacC(120,109) = JacC(120,109) - dw(129,109)
      JacC(120,120) = JacC(120,120) - dw(129,120)
      JacC( 77, 77) = JacC( 77, 77) - dw(130, 77)
      JacC( 77,120) = JacC( 77,120) - dw(130,120)
      JacC(102, 77) = JacC(102, 77) + dw(130, 77)
      JacC(102,120) = JacC(102,120) + dw(130,120)
      JacC(120, 77) = JacC(120, 77) - dw(130, 77)
      JacC(120,120) = JacC(120,120) - dw(130,120)
      JacC(123, 77) = JacC(123, 77) + dw(130, 77)
      JacC(123,120) = JacC(123,120) + dw(130,120)
      JacC(104,104) = JacC(104,104) - dw(131,104)
      JacC(104,120) = JacC(104,120) - dw(131,120)
      JacC(108,104) = JacC(108,104)+ 0.2000000000000000D+01*dw(131,104)
      JacC(108,120) = JacC(108,120)+ 0.2000000000000000D+01*dw(131,120)
      JacC(120,104) = JacC(120,104) - dw(131,104)
      JacC(120,120) = JacC(120,120) - dw(131,120)
      JacC(123,104) = JacC(123,104) + dw(131,104)
      JacC(123,120) = JacC(123,120) + dw(131,120)
      JacC(102,102) = JacC(102,102) - dw(132,102)
      JacC(102,120) = JacC(102,120) - dw(132,120)
      JacC(108,102) = JacC(108,102) + dw(132,102)
      JacC(108,120) = JacC(108,120) + dw(132,120)
      JacC(118,102) = JacC(118,102) + dw(132,102)
      JacC(118,120) = JacC(118,120) + dw(132,120)
      JacC(120,102) = JacC(120,102) - dw(132,102)
      JacC(120,120) = JacC(120,120) - dw(132,120)
      JacC( 84, 84) = JacC( 84, 84) - dw(133, 84)
      JacC( 84,120) = JacC( 84,120) - dw(133,120)
      JacC(105, 84) = JacC(105, 84) + dw(133, 84)
      JacC(105,120) = JacC(105,120) + dw(133,120)
      JacC(120, 84) = JacC(120, 84) - dw(133, 84)
      JacC(120,120) = JacC(120,120) - dw(133,120)
      JacC( 81, 81) = JacC( 81, 81) - dw(134, 81)
      JacC( 81,120) = JacC( 81,120) - dw(134,120)
      JacC( 83, 81) = JacC( 83, 81) + dw(134, 81)
      JacC( 83,120) = JacC( 83,120) + dw(134,120)
      JacC(120, 81) = JacC(120, 81) - dw(134, 81)
      JacC(120,120) = JacC(120,120) - dw(134,120)
      JacC( 87, 87) = JacC( 87, 87) - dw(135, 87)
      JacC( 87,120) = JacC( 87,120) - dw(135,120)
      JacC( 88, 87) = JacC( 88, 87)+ 0.6870000000000001D+00*dw(135, 87)
      JacC( 88,120) = JacC( 88,120)+ 0.6870000000000001D+00*dw(135,120)
      JacC(118, 87) = JacC(118, 87)+ 0.3130000000000000D+00*dw(135, 87)
      JacC(118,120) = JacC(118,120)+ 0.3130000000000000D+00*dw(135,120)
      JacC(120, 87) = JacC(120, 87) - dw(135, 87)
      JacC(120,120) = JacC(120,120) - dw(135,120)
      JacC( 26, 26) = JacC( 26, 26) - dw(136, 26)
      JacC( 26,120) = JacC( 26,120) - dw(136,120)
      JacC(108, 26) = JacC(108, 26) + dw(136, 26)
      JacC(108,120) = JacC(108,120) + dw(136,120)
      JacC(112, 26) = JacC(112, 26) + dw(136, 26)
      JacC(112,120) = JacC(112,120) + dw(136,120)
      JacC(116, 26) = JacC(116, 26) + dw(136, 26)
      JacC(116,120) = JacC(116,120) + dw(136,120)
      JacC(120, 26) = JacC(120, 26) - dw(136, 26)
      JacC(120,120) = JacC(120,120) - dw(136,120)
      JacC(123, 26) = JacC(123, 26) + dw(136, 26)
      JacC(123,120) = JacC(123,120) + dw(136,120)
      JacC( 65, 65) = JacC( 65, 65) - dw(137, 65)
      JacC( 65,120) = JacC( 65,120) - dw(137,120)
      JacC(112, 65) = JacC(112, 65) + dw(137, 65)
      JacC(112,120) = JacC(112,120) + dw(137,120)
      JacC(116, 65) = JacC(116, 65) + dw(137, 65)
      JacC(116,120) = JacC(116,120) + dw(137,120)
      JacC(118, 65) = JacC(118, 65) + dw(137, 65)
      JacC(118,120) = JacC(118,120) + dw(137,120)
      JacC(120, 65) = JacC(120, 65) - dw(137, 65)
      JacC(120,120) = JacC(120,120) - dw(137,120)
      JacC( 69, 69) = JacC( 69, 69) - dw(138, 69)
      JacC( 69,120) = JacC( 69,120) - dw(138,120)
      JacC(112, 69) = JacC(112, 69) + dw(138, 69)
      JacC(112,120) = JacC(112,120) + dw(138,120)
      JacC(116, 69) = JacC(116, 69) + dw(138, 69)
      JacC(116,120) = JacC(116,120) + dw(138,120)
      JacC(118, 69) = JacC(118, 69) + dw(138, 69)
      JacC(118,120) = JacC(118,120) + dw(138,120)
      JacC(120, 69) = JacC(120, 69) - dw(138, 69)
      JacC(120,120) = JacC(120,120) - dw(138,120)
      JacC( 91, 91) = JacC( 91, 91) - dw(139, 91)
      JacC( 91,120) = JacC( 91,120) - dw(139,120)
      JacC(108, 91) = JacC(108, 91) + dw(139, 91)
      JacC(108,120) = JacC(108,120) + dw(139,120)
      JacC(118, 91) = JacC(118, 91) + dw(139, 91)
      JacC(118,120) = JacC(118,120) + dw(139,120)
      JacC(120, 91) = JacC(120, 91) - dw(139, 91)
      JacC(120,120) = JacC(120,120) - dw(139,120)
      JacC( 39, 39) = JacC( 39, 39) - dw(140, 39)
      JacC( 39,120) = JacC( 39,120) - dw(140,120)
      JacC(114, 39) = JacC(114, 39)+ 0.6500000000000000D+00*dw(140, 39)
      JacC(114,120) = JacC(114,120)+ 0.6500000000000000D+00*dw(140,120)
      JacC(119, 39) = JacC(119, 39)+ 0.3500000000000000D+00*dw(140, 39)
      JacC(119,120) = JacC(119,120)+ 0.3500000000000000D+00*dw(140,120)
      JacC(120, 39) = JacC(120, 39)- 0.6500000000000000D+00*dw(140, 39)
      JacC(120,120) = JacC(120,120)- 0.6500000000000000D+00*dw(140,120)
      JacC(109,115) = JacC(109,115)+ 0.4100000000000000D+00*dw(141,115)
      JacC(109,120) = JacC(109,120)+ 0.4100000000000000D+00*dw(141,120)
      JacC(110,115) = JacC(110,115)+ 0.4400000000000000D+00*dw(141,115)
      JacC(110,120) = JacC(110,120)+ 0.4400000000000000D+00*dw(141,120)
      JacC(112,115) = JacC(112,115)+ 0.8000000000000000D-01*dw(141,115)
      JacC(112,120) = JacC(112,120)+ 0.8000000000000000D-01*dw(141,120)
      JacC(115,115) = JacC(115,115) - dw(141,115)
      JacC(115,120) = JacC(115,120) - dw(141,120)
      JacC(116,115) = JacC(116,115)+ 0.7000000000000001D-01*dw(141,115)
      JacC(116,120) = JacC(116,120)+ 0.7000000000000001D-01*dw(141,120)
      JacC(120,115) = JacC(120,115)- 0.5100000000000000D+00*dw(141,115)
      JacC(120,120) = JacC(120,120)- 0.5100000000000000D+00*dw(141,120)
      JacC( 71, 71) = JacC( 71, 71) - dw(142, 71)
      JacC( 71,120) = JacC( 71,120) - dw(142,120)
      JacC(116, 71) = JacC(116, 71)+ 0.3500000000000000D+00*dw(142, 71)
      JacC(116,120) = JacC(116,120)+ 0.3500000000000000D+00*dw(142,120)
      JacC(118, 71) = JacC(118, 71)+ 0.6500000000000000D+00*dw(142, 71)
      JacC(118,120) = JacC(118,120)+ 0.6500000000000000D+00*dw(142,120)
      JacC(119, 71) = JacC(119, 71)+ 0.3500000000000000D+00*dw(142, 71)
      JacC(119,120) = JacC(119,120)+ 0.3500000000000000D+00*dw(142,120)
      JacC(120, 71) = JacC(120, 71)- 0.6500000000000000D+00*dw(142, 71)
      JacC(120,120) = JacC(120,120)- 0.6500000000000000D+00*dw(142,120)
      JacC( 40, 40) = JacC( 40, 40) - dw(143, 40)
      JacC( 40,120) = JacC( 40,120) - dw(143,120)
      JacC(116, 40) = JacC(116, 40) + dw(143, 40)
      JacC(116,120) = JacC(116,120) + dw(143,120)
      JacC(119, 40) = JacC(119, 40) + dw(143, 40)
      JacC(119,120) = JacC(119,120) + dw(143,120)
      JacC(120, 40) = JacC(120, 40) - dw(143, 40)
      JacC(120,120) = JacC(120,120) - dw(143,120)
      JacC(121, 40) = JacC(121, 40) + dw(143, 40)
      JacC(121,120) = JacC(121,120) + dw(143,120)
      JacC( 41, 41) = JacC( 41, 41) - dw(144, 41)
      JacC( 41,120) = JacC( 41,120) - dw(144,120)
      JacC(116, 41) = JacC(116, 41) + dw(144, 41)
      JacC(116,120) = JacC(116,120) + dw(144,120)
      JacC(119, 41) = JacC(119, 41) + dw(144, 41)
      JacC(119,120) = JacC(119,120) + dw(144,120)
      JacC(120, 41) = JacC(120, 41) - dw(144, 41)
      JacC(120,120) = JacC(120,120) - dw(144,120)
      JacC(121, 41) = JacC(121, 41) + dw(144, 41)
      JacC(121,120) = JacC(121,120) + dw(144,120)
      JacC( 47, 47) = JacC( 47, 47) - dw(145, 47)
      JacC( 47,120) = JacC( 47,120) - dw(145,120)
      JacC( 76, 47) = JacC( 76, 47) + dw(145, 47)
      JacC( 76,120) = JacC( 76,120) + dw(145,120)
      JacC(120, 47) = JacC(120, 47) - dw(145, 47)
      JacC(120,120) = JacC(120,120) - dw(145,120)
      JacC(124, 47) = JacC(124, 47) + dw(145, 47)
      JacC(124,120) = JacC(124,120) + dw(145,120)
      JacC(110,111) = JacC(110,111) + dw(146,111)
      JacC(110,120) = JacC(110,120) + dw(146,120)
      JacC(111,111) = JacC(111,111) - dw(146,111)
      JacC(111,120) = JacC(111,120) - dw(146,120)
      JacC(120,111) = JacC(120,111) - dw(146,111)
      JacC(120,120) = JacC(120,120) - dw(146,120)
      JacC(124,111) = JacC(124,111) + dw(146,111)
      JacC(124,120) = JacC(124,120) + dw(146,120)
      JacC( 82, 82) = JacC( 82, 82) - dw(147, 82)
      JacC( 82,120) = JacC( 82,120) - dw(147,120)
      JacC(120, 82) = JacC(120, 82) - dw(147, 82)
      JacC(120,120) = JacC(120,120) - dw(147,120)
      JacC(123, 82) = JacC(123, 82) + dw(147, 82)
      JacC(123,120) = JacC(123,120) + dw(147,120)
      JacC(106,106) = JacC(106,106) - dw(148,106)
      JacC(106,120) = JacC(106,120) - dw(148,120)
      JacC(107,106) = JacC(107,106)+ 0.3600000000000000D+00*dw(148,106)
      JacC(107,120) = JacC(107,120)+ 0.3600000000000000D+00*dw(148,120)
      JacC(114,106) = JacC(114,106)+ 0.6400000000000000D+00*dw(148,106)
      JacC(114,120) = JacC(114,120)+ 0.6400000000000000D+00*dw(148,120)
      JacC(120,106) = JacC(120,106) - dw(148,106)
      JacC(120,120) = JacC(120,120) - dw(148,120)
      JacC(103,119) = JacC(103,119) + dw(149,119)
      JacC(103,121) = JacC(103,121) + dw(149,121)
      JacC(108,119) = JacC(108,119) + dw(149,119)
      JacC(108,121) = JacC(108,121) + dw(149,121)
      JacC(119,119) = JacC(119,119) - dw(149,119)
      JacC(119,121) = JacC(119,121) - dw(149,121)
      JacC(121,119) = JacC(121,119) - dw(149,119)
      JacC(121,121) = JacC(121,121) - dw(149,121)
      JacC(123,119) = JacC(123,119) + dw(149,119)
      JacC(123,121) = JacC(123,121) + dw(149,121)
      JacC(100,100) = JacC(100,100) - dw(150,100)
      JacC(100,121) = JacC(100,121) - dw(150,121)
      JacC(103,100) = JacC(103,100) + dw(150,100)
      JacC(103,121) = JacC(103,121) + dw(150,121)
      JacC(118,100) = JacC(118,100) + dw(150,100)
      JacC(118,121) = JacC(118,121) + dw(150,121)
      JacC(121,100) = JacC(121,100) - dw(150,100)
      JacC(121,121) = JacC(121,121) - dw(150,121)
      JacC(103,112) = JacC(103,112) + dw(151,112)
      JacC(103,121) = JacC(103,121) + dw(151,121)
      JacC(112,112) = JacC(112,112) - dw(151,112)
      JacC(112,121) = JacC(112,121) - dw(151,121)
      JacC(121,112) = JacC(121,112) - dw(151,112)
      JacC(121,121) = JacC(121,121) - dw(151,121)
      JacC(122,112) = JacC(122,112) + dw(151,112)
      JacC(122,121) = JacC(122,121) + dw(151,121)
      JacC(103,104) = JacC(103,104) + dw(152,104)
      JacC(103,121) = JacC(103,121) + dw(152,121)
      JacC(104,104) = JacC(104,104) - dw(152,104)
      JacC(104,121) = JacC(104,121) - dw(152,121)
      JacC(108,104) = JacC(108,104)+ 0.2000000000000000D+01*dw(152,104)
      JacC(108,121) = JacC(108,121)+ 0.2000000000000000D+01*dw(152,121)
      JacC(121,104) = JacC(121,104) - dw(152,104)
      JacC(121,121) = JacC(121,121) - dw(152,121)
      JacC(123,104) = JacC(123,104) + dw(152,104)
      JacC(123,121) = JacC(123,121) + dw(152,121)
      JacC(102,102) = JacC(102,102) - dw(153,102)
      JacC(102,121) = JacC(102,121) - dw(153,121)
      JacC(103,102) = JacC(103,102) + dw(153,102)
      JacC(103,121) = JacC(103,121) + dw(153,121)
      JacC(108,102) = JacC(108,102) + dw(153,102)
      JacC(108,121) = JacC(108,121) + dw(153,121)
      JacC(118,102) = JacC(118,102) + dw(153,102)
      JacC(118,121) = JacC(118,121) + dw(153,121)
      JacC(121,102) = JacC(121,102) - dw(153,102)
      JacC(121,121) = JacC(121,121) - dw(153,121)
      JacC( 26, 26) = JacC( 26, 26) - dw(154, 26)
      JacC( 26,121) = JacC( 26,121) - dw(154,121)
      JacC(103, 26) = JacC(103, 26)+ 0.5000000000000000D+00*dw(154, 26)
      JacC(103,121) = JacC(103,121)+ 0.5000000000000000D+00*dw(154,121)
      JacC(104, 26) = JacC(104, 26) + dw(154, 26)
      JacC(104,121) = JacC(104,121) + dw(154,121)
      JacC(108, 26) = JacC(108, 26)+ 0.1500000000000000D+01*dw(154, 26)
      JacC(108,121) = JacC(108,121)+ 0.1500000000000000D+01*dw(154,121)
      JacC(120, 26) = JacC(120, 26)+ 0.5000000000000000D+00*dw(154, 26)
      JacC(120,121) = JacC(120,121)+ 0.5000000000000000D+00*dw(154,121)
      JacC(121, 26) = JacC(121, 26) - dw(154, 26)
      JacC(121,121) = JacC(121,121) - dw(154,121)
      JacC(123, 26) = JacC(123, 26)+ 0.1500000000000000D+01*dw(154, 26)
      JacC(123,121) = JacC(123,121)+ 0.1500000000000000D+01*dw(154,121)
      JacC(124, 26) = JacC(124, 26)+ 0.5000000000000000D+00*dw(154, 26)
      JacC(124,121) = JacC(124,121)+ 0.5000000000000000D+00*dw(154,121)
      JacC( 19, 19) = JacC( 19, 19) - dw(155, 19)
      JacC( 19,121) = JacC( 19,121) - dw(155,121)
      JacC( 59, 19) = JacC( 59, 19)+ 0.1200000000000000D+00*dw(155, 19)
      JacC( 59,121) = JacC( 59,121)+ 0.1200000000000000D+00*dw(155,121)
      JacC( 60, 19) = JacC( 60, 19)+ 0.4000000000000000D+00*dw(155, 19)
      JacC( 60,121) = JacC( 60,121)+ 0.4000000000000000D+00*dw(155,121)
      JacC( 61, 19) = JacC( 61, 19)+ 0.5000000000000000D+00*dw(155, 19)
      JacC( 61,121) = JacC( 61,121)+ 0.5000000000000000D+00*dw(155,121)
      JacC( 66, 19) = JacC( 66, 19)+ 0.4000000000000000D-01*dw(155, 19)
      JacC( 66,121) = JacC( 66,121)+ 0.4000000000000000D-01*dw(155,121)
      JacC( 78, 19) = JacC( 78, 19)+ 0.1000000000000000D+00*dw(155, 19)
      JacC( 78,121) = JacC( 78,121)+ 0.1000000000000000D+00*dw(155,121)
      JacC(103, 19) = JacC(103, 19)+ 0.5000000000000000D+00*dw(155, 19)
      JacC(103,121) = JacC(103,121)+ 0.5000000000000000D+00*dw(155,121)
      JacC(121, 19) = JacC(121, 19) - dw(155, 19)
      JacC(121,121) = JacC(121,121) - dw(155,121)
      JacC( 58, 58) = JacC( 58, 58) - dw(156, 58)
      JacC( 58,121) = JacC( 58,121) - dw(156,121)
      JacC( 59, 58) = JacC( 59, 58)+ 0.1200000000000000D+00*dw(156, 58)
      JacC( 59,121) = JacC( 59,121)+ 0.1200000000000000D+00*dw(156,121)
      JacC( 60, 58) = JacC( 60, 58)+ 0.4000000000000000D+00*dw(156, 58)
      JacC( 60,121) = JacC( 60,121)+ 0.4000000000000000D+00*dw(156,121)
      JacC( 61, 58) = JacC( 61, 58)+ 0.5000000000000000D+00*dw(156, 58)
      JacC( 61,121) = JacC( 61,121)+ 0.5000000000000000D+00*dw(156,121)
      JacC( 66, 58) = JacC( 66, 58)+ 0.4000000000000000D-01*dw(156, 58)
      JacC( 66,121) = JacC( 66,121)+ 0.4000000000000000D-01*dw(156,121)
      JacC( 78, 58) = JacC( 78, 58)+ 0.1000000000000000D+00*dw(156, 58)
      JacC( 78,121) = JacC( 78,121)+ 0.1000000000000000D+00*dw(156,121)
      JacC(103, 58) = JacC(103, 58)+ 0.5000000000000000D+00*dw(156, 58)
      JacC(103,121) = JacC(103,121)+ 0.5000000000000000D+00*dw(156,121)
      JacC(121, 58) = JacC(121, 58) - dw(156, 58)
      JacC(121,121) = JacC(121,121) - dw(156,121)
      JacC( 61, 61) = JacC( 61, 61) - dw(157, 61)
      JacC( 61,117) = JacC( 61,117) - dw(157,117)
      JacC(104, 61) = JacC(104, 61) + dw(157, 61)
      JacC(104,117) = JacC(104,117) + dw(157,117)
      JacC(115, 61) = JacC(115, 61) + dw(157, 61)
      JacC(115,117) = JacC(115,117) + dw(157,117)
      JacC(117, 61) = JacC(117, 61) - dw(157, 61)
      JacC(117,117) = JacC(117,117) - dw(157,117)
      JacC(124, 61) = JacC(124, 61)+ 0.2000000000000000D+01*dw(157, 61)
      JacC(124,117) = JacC(124,117)+ 0.2000000000000000D+01*dw(157,117)
      JacC( 61, 61) = JacC( 61, 61) - dw(158, 61)
      JacC( 61,121) = JacC( 61,121) - dw(158,121)
      JacC(104, 61) = JacC(104, 61) + dw(158, 61)
      JacC(104,121) = JacC(104,121) + dw(158,121)
      JacC(115, 61) = JacC(115, 61) + dw(158, 61)
      JacC(115,121) = JacC(115,121) + dw(158,121)
      JacC(121, 61) = JacC(121, 61) - dw(158, 61)
      JacC(121,121) = JacC(121,121) - dw(158,121)
      JacC(124, 61) = JacC(124, 61)+ 0.2000000000000000D+01*dw(158, 61)
      JacC(124,121) = JacC(124,121)+ 0.2000000000000000D+01*dw(158,121)
      JacC( 61, 61) = JacC( 61, 61) - dw(159, 61)
      JacC( 61,114) = JacC( 61,114) - dw(159,114)
      JacC(104, 61) = JacC(104, 61)+ 0.7000000000000000D+00*dw(159, 61)
      JacC(104,114) = JacC(104,114)+ 0.7000000000000000D+00*dw(159,114)
      JacC(111, 61) = JacC(111, 61)+ 0.3000000000000000D+00*dw(159, 61)
      JacC(111,114) = JacC(111,114)+ 0.3000000000000000D+00*dw(159,114)
      JacC(114, 61) = JacC(114, 61) - dw(159, 61)
      JacC(114,114) = JacC(114,114) - dw(159,114)
      JacC(115, 61) = JacC(115, 61)+ 0.7000000000000000D+00*dw(159, 61)
      JacC(115,114) = JacC(115,114)+ 0.7000000000000000D+00*dw(159,114)
      JacC(119, 61) = JacC(119, 61) + dw(159, 61)
      JacC(119,114) = JacC(119,114) + dw(159,114)
      JacC(123, 61) = JacC(123, 61) + dw(159, 61)
      JacC(123,114) = JacC(123,114) + dw(159,114)
      JacC(124, 61) = JacC(124, 61)+ 0.7000000000000000D+00*dw(159, 61)
      JacC(124,114) = JacC(124,114)+ 0.7000000000000000D+00*dw(159,114)
      JacC( 61, 61) = JacC( 61, 61) - dw(160, 61)
      JacC( 61,118) = JacC( 61,118) - dw(160,118)
      JacC(104, 61) = JacC(104, 61)+ 0.7000000000000000D+00*dw(160, 61)
      JacC(104,118) = JacC(104,118)+ 0.7000000000000000D+00*dw(160,118)
      JacC(111, 61) = JacC(111, 61)+ 0.3000000000000000D+00*dw(160, 61)
      JacC(111,118) = JacC(111,118)+ 0.3000000000000000D+00*dw(160,118)
      JacC(114, 61) = JacC(114, 61) + dw(160, 61)
      JacC(114,118) = JacC(114,118) + dw(160,118)
      JacC(115, 61) = JacC(115, 61)+ 0.7000000000000000D+00*dw(160, 61)
      JacC(115,118) = JacC(115,118)+ 0.7000000000000000D+00*dw(160,118)
      JacC(118, 61) = JacC(118, 61) - dw(160, 61)
      JacC(118,118) = JacC(118,118) - dw(160,118)
      JacC(123, 61) = JacC(123, 61) + dw(160, 61)
      JacC(123,118) = JacC(123,118) + dw(160,118)
      JacC(124, 61) = JacC(124, 61)+ 0.7000000000000000D+00*dw(160, 61)
      JacC(124,118) = JacC(124,118)+ 0.7000000000000000D+00*dw(160,118)
      JacC( 61, 61) = JacC( 61, 61) - dw(161, 61)
      JacC( 61,123) = JacC( 61,123) - dw(161,123)
      JacC(115, 61) = JacC(115, 61) + dw(161, 61)
      JacC(115,123) = JacC(115,123) + dw(161,123)
      JacC(123, 61) = JacC(123, 61) - dw(161, 61)
      JacC(123,123) = JacC(123,123) - dw(161,123)
      JacC( 27, 27) = JacC( 27, 27) - dw(162, 27)
      JacC( 27,121) = JacC( 27,121) - dw(162,121)
      JacC( 93, 27) = JacC( 93, 27)+ 0.8000000000000000D+00*dw(162, 27)
      JacC( 93,121) = JacC( 93,121)+ 0.8000000000000000D+00*dw(162,121)
      JacC( 94, 27) = JacC( 94, 27)+ 0.2000000000000000D+00*dw(162, 27)
      JacC( 94,121) = JacC( 94,121)+ 0.2000000000000000D+00*dw(162,121)
      JacC(121, 27) = JacC(121, 27) - dw(162, 27)
      JacC(121,121) = JacC(121,121) - dw(162,121)
      JacC( 37, 37) = JacC( 37, 37) - dw(163, 37)
      JacC( 37,121) = JacC( 37,121) - dw(163,121)
      JacC( 66, 37) = JacC( 66, 37)+ 0.1600000000000000D-02*dw(163, 37)
      JacC( 66,121) = JacC( 66,121)+ 0.1600000000000000D-02*dw(163,121)
      JacC( 93, 37) = JacC( 93, 37)+ 0.4300000000000000D+00*dw(163, 37)
      JacC( 93,121) = JacC( 93,121)+ 0.4300000000000000D+00*dw(163,121)
      JacC( 94, 37) = JacC( 94, 37)+ 0.5700000000000000D+00*dw(163, 37)
      JacC( 94,121) = JacC( 94,121)+ 0.5700000000000000D+00*dw(163,121)
      JacC(121, 37) = JacC(121, 37) - dw(163, 37)
      JacC(121,121) = JacC(121,121) - dw(163,121)
      JacC( 66, 89) = JacC( 66, 89)+ 0.3000000000000000D-02*dw(164, 89)
      JacC( 66,121) = JacC( 66,121)+ 0.3000000000000000D-02*dw(164,121)
      JacC( 89, 89) = JacC( 89, 89) - dw(164, 89)
      JacC( 89,121) = JacC( 89,121) - dw(164,121)
      JacC( 93, 89) = JacC( 93, 89)+ 0.1100000000000000D+00*dw(164, 89)
      JacC( 93,121) = JacC( 93,121)+ 0.1100000000000000D+00*dw(164,121)
      JacC( 94, 89) = JacC( 94, 89)+ 0.8900000000000000D+00*dw(164, 89)
      JacC( 94,121) = JacC( 94,121)+ 0.8900000000000000D+00*dw(164,121)
      JacC(121, 89) = JacC(121, 89) - dw(164, 89)
      JacC(121,121) = JacC(121,121) - dw(164,121)
      JacC( 24, 24) = JacC( 24, 24) - dw(165, 24)
      JacC( 24,121) = JacC( 24,121) - dw(165,121)
      JacC( 84, 24) = JacC( 84, 24)+ 0.9000000000000000D+00*dw(165, 24)
      JacC( 84,121) = JacC( 84,121)+ 0.9000000000000000D+00*dw(165,121)
      JacC( 93, 24) = JacC( 93, 24)+ 0.9000000000000000D+00*dw(165, 24)
      JacC( 93,121) = JacC( 93,121)+ 0.9000000000000000D+00*dw(165,121)
      JacC( 94, 24) = JacC( 94, 24)+ 0.1000000000000000D+00*dw(165, 24)
      JacC( 94,121) = JacC( 94,121)+ 0.1000000000000000D+00*dw(165,121)
      JacC(121, 24) = JacC(121, 24) - dw(165, 24)
      JacC(121,121) = JacC(121,121) - dw(165,121)
      JacC( 30, 30) = JacC( 30, 30) - dw(166, 30)
      JacC( 30,121) = JacC( 30,121) - dw(166,121)
      JacC( 46, 30) = JacC( 46, 30) + dw(166, 30)
      JacC( 46,121) = JacC( 46,121) + dw(166,121)
      JacC(121, 30) = JacC(121, 30) - dw(166, 30)
      JacC(121,121) = JacC(121,121) - dw(166,121)
      JacC( 84, 84) = JacC( 84, 84) - dw(167, 84)
      JacC( 84,121) = JacC( 84,121) - dw(167,121)
      JacC(103, 84) = JacC(103, 84)+ 0.5000000000000000D+00*dw(167, 84)
      JacC(103,121) = JacC(103,121)+ 0.5000000000000000D+00*dw(167,121)
      JacC(105, 84) = JacC(105, 84)+ 0.5000000000000000D+00*dw(167, 84)
      JacC(105,121) = JacC(105,121)+ 0.5000000000000000D+00*dw(167,121)
      JacC(108, 84) = JacC(108, 84)+ 0.5000000000000000D+00*dw(167, 84)
      JacC(108,121) = JacC(108,121)+ 0.5000000000000000D+00*dw(167,121)
      JacC(111, 84) = JacC(111, 84)+ 0.5000000000000000D+00*dw(167, 84)
      JacC(111,121) = JacC(111,121)+ 0.5000000000000000D+00*dw(167,121)
      JacC(116, 84) = JacC(116, 84)+ 0.5000000000000000D+00*dw(167, 84)
      JacC(116,121) = JacC(116,121)+ 0.5000000000000000D+00*dw(167,121)
      JacC(121, 84) = JacC(121, 84) - dw(167, 84)
      JacC(121,121) = JacC(121,121) - dw(167,121)
      JacC(123, 84) = JacC(123, 84)+ 0.5000000000000000D+00*dw(167, 84)
      JacC(123,121) = JacC(123,121)+ 0.5000000000000000D+00*dw(167,121)
      JacC( 87, 87) = JacC( 87, 87) - dw(168, 87)
      JacC( 87,121) = JacC( 87,121) - dw(168,121)
      JacC(108, 87) = JacC(108, 87)+ 0.6680000000000000D+00*dw(168, 87)
      JacC(108,121) = JacC(108,121)+ 0.6680000000000000D+00*dw(168,121)
      JacC(111, 87) = JacC(111, 87) + dw(168, 87)
      JacC(111,121) = JacC(111,121) + dw(168,121)
      JacC(112, 87) = JacC(112, 87)+ 0.3320000000000000D+00*dw(168, 87)
      JacC(112,121) = JacC(112,121)+ 0.3320000000000000D+00*dw(168,121)
      JacC(116, 87) = JacC(116, 87) + dw(168, 87)
      JacC(116,121) = JacC(116,121) + dw(168,121)
      JacC(119, 87) = JacC(119, 87)+ 0.3320000000000000D+00*dw(168, 87)
      JacC(119,121) = JacC(119,121)+ 0.3320000000000000D+00*dw(168,121)
      JacC(121, 87) = JacC(121, 87) - dw(168, 87)
      JacC(121,121) = JacC(121,121) - dw(168,121)
      JacC(123, 87) = JacC(123, 87) + dw(168, 87)
      JacC(123,121) = JacC(123,121) + dw(168,121)
      JacC( 22, 22) = JacC( 22, 22) - dw(169, 22)
      JacC( 22,121) = JacC( 22,121) - dw(169,121)
      JacC( 33, 22) = JacC( 33, 22)+ 0.8000000000000000D+00*dw(169, 22)
      JacC( 33,121) = JacC( 33,121)+ 0.8000000000000000D+00*dw(169,121)
      JacC( 93, 22) = JacC( 93, 22)+ 0.1000000000000000D+00*dw(169, 22)
      JacC( 93,121) = JacC( 93,121)+ 0.1000000000000000D+00*dw(169,121)
      JacC( 94, 22) = JacC( 94, 22)+ 0.9000000000000000D+00*dw(169, 22)
      JacC( 94,121) = JacC( 94,121)+ 0.9000000000000000D+00*dw(169,121)
      JacC(121, 22) = JacC(121, 22) - dw(169, 22)
      JacC(121,121) = JacC(121,121) - dw(169,121)
      JacC( 31, 31) = JacC( 31, 31) - dw(170, 31)
      JacC( 31,121) = JacC( 31,121) - dw(170,121)
      JacC( 43, 31) = JacC( 43, 31)+ 0.3090000000000000D+00*dw(170, 31)
      JacC( 43,121) = JacC( 43,121)+ 0.3090000000000000D+00*dw(170,121)
      JacC( 44, 31) = JacC( 44, 31)+ 0.2000000000000000D-01*dw(170, 31)
      JacC( 44,121) = JacC( 44,121)+ 0.2000000000000000D-01*dw(170,121)
      JacC( 93, 31) = JacC( 93, 31)+ 0.1300000000000000D+00*dw(170, 31)
      JacC( 93,121) = JacC( 93,121)+ 0.1300000000000000D+00*dw(170,121)
      JacC( 94, 31) = JacC( 94, 31)+ 0.8700000000000000D+00*dw(170, 31)
      JacC( 94,121) = JacC( 94,121)+ 0.8700000000000000D+00*dw(170,121)
      JacC(121, 31) = JacC(121, 31) - dw(170, 31)
      JacC(121,121) = JacC(121,121) - dw(170,121)
      JacC( 47, 47) = JacC( 47, 47) - dw(171, 47)
      JacC( 47,121) = JacC( 47,121) - dw(171,121)
      JacC(105, 47) = JacC(105, 47) + dw(171, 47)
      JacC(105,121) = JacC(105,121) + dw(171,121)
      JacC(121, 47) = JacC(121, 47) - dw(171, 47)
      JacC(121,121) = JacC(121,121) - dw(171,121)
      JacC(124, 47) = JacC(124, 47) + dw(171, 47)
      JacC(124,121) = JacC(124,121) + dw(171,121)
      JacC( 27, 27) = JacC( 27, 27) - dw(172, 27)
      JacC( 27, 90) = JacC( 27, 90) - dw(172, 90)
      JacC( 82, 27) = JacC( 82, 27)+ 0.3700000000000000D+00*dw(172, 27)
      JacC( 82, 90) = JacC( 82, 90)+ 0.3700000000000000D+00*dw(172, 90)
      JacC( 90, 27) = JacC( 90, 27) - dw(172, 27)
      JacC( 90, 90) = JacC( 90, 90) - dw(172, 90)
      JacC(108, 27) = JacC(108, 27)+ 0.4300000000000000D+00*dw(172, 27)
      JacC(108, 90) = JacC(108, 90)+ 0.4300000000000000D+00*dw(172, 90)
      JacC(119, 27) = JacC(119, 27) + dw(172, 27)
      JacC(119, 90) = JacC(119, 90) + dw(172, 90)
      JacC(120, 27) = JacC(120, 27)+ 0.1200000000000000D+00*dw(172, 27)
      JacC(120, 90) = JacC(120, 90)+ 0.1200000000000000D+00*dw(172, 90)
      JacC(123, 27) = JacC(123, 27)+ 0.2600000000000000D+00*dw(172, 27)
      JacC(123, 90) = JacC(123, 90)+ 0.2600000000000000D+00*dw(172, 90)
      JacC( 37, 37) = JacC( 37, 37) - dw(173, 37)
      JacC( 37, 90) = JacC( 37, 90) - dw(173, 90)
      JacC( 38, 37) = JacC( 38, 37)+ 0.3000000000000000D-01*dw(173, 37)
      JacC( 38, 90) = JacC( 38, 90)+ 0.3000000000000000D-01*dw(173, 90)
      JacC( 45, 37) = JacC( 45, 37)+ 0.6000000000000000D-01*dw(173, 37)
      JacC( 45, 90) = JacC( 45, 90)+ 0.6000000000000000D-01*dw(173, 90)
      JacC( 49, 37) = JacC( 49, 37)+ 0.6000000000000000D-02*dw(173, 37)
      JacC( 49, 90) = JacC( 49, 90)+ 0.6000000000000000D-02*dw(173, 90)
      JacC( 66, 37) = JacC( 66, 37)+ 0.1600000000000000D-02*dw(173, 37)
      JacC( 66, 90) = JacC( 66, 90)+ 0.1600000000000000D-02*dw(173, 90)
      JacC( 82, 37) = JacC( 82, 37)+ 0.1400000000000000D+00*dw(173, 37)
      JacC( 82, 90) = JacC( 82, 90)+ 0.1400000000000000D+00*dw(173, 90)
      JacC( 90, 37) = JacC( 90, 37) - dw(173, 37)
      JacC( 90, 90) = JacC( 90, 90) - dw(173, 90)
      JacC(101, 37) = JacC(101, 37)+ 0.3000000000000000D-01*dw(173, 37)
      JacC(101, 90) = JacC(101, 90)+ 0.3000000000000000D-01*dw(173, 90)
      JacC(106, 37) = JacC(106, 37)+ 0.1000000000000000D+00*dw(173, 37)
      JacC(106, 90) = JacC(106, 90)+ 0.1000000000000000D+00*dw(173, 90)
      JacC(108, 37) = JacC(108, 37)+ 0.3700000000000000D+00*dw(173, 37)
      JacC(108, 90) = JacC(108, 90)+ 0.3700000000000000D+00*dw(173, 90)
      JacC(109, 37) = JacC(109, 37)+ 0.3000000000000000D-01*dw(173, 37)
      JacC(109, 90) = JacC(109, 90)+ 0.3000000000000000D-01*dw(173, 90)
      JacC(112, 37) = JacC(112, 37)+ 0.4400000000000000D+00*dw(173, 37)
      JacC(112, 90) = JacC(112, 90)+ 0.4400000000000000D+00*dw(173, 90)
      JacC(113, 37) = JacC(113, 37)+ 0.1000000000000000D+00*dw(173, 37)
      JacC(113, 90) = JacC(113, 90)+ 0.1000000000000000D+00*dw(173, 90)
      JacC(114, 37) = JacC(114, 37)+ 0.1900000000000000D+00*dw(173, 37)
      JacC(114, 90) = JacC(114, 90)+ 0.1900000000000000D+00*dw(173, 90)
      JacC(119, 37) = JacC(119, 37)+ 0.6400000000000000D+00*dw(173, 37)
      JacC(119, 90) = JacC(119, 90)+ 0.6400000000000000D+00*dw(173, 90)
      JacC(120, 37) = JacC(120, 37)+ 0.4000000000000000D+00*dw(173, 37)
      JacC(120, 90) = JacC(120, 90)+ 0.4000000000000000D+00*dw(173, 90)
      JacC(123, 37) = JacC(123, 37)+ 0.2500000000000000D+00*dw(173, 37)
      JacC(123, 90) = JacC(123, 90)+ 0.2500000000000000D+00*dw(173, 90)
      JacC( 38, 89) = JacC( 38, 89)+ 0.6000000000000000D-01*dw(174, 89)
      JacC( 38, 90) = JacC( 38, 90)+ 0.6000000000000000D-01*dw(174, 90)
      JacC( 45, 89) = JacC( 45, 89)+ 0.7000000000000001D-01*dw(174, 89)
      JacC( 45, 90) = JacC( 45, 90)+ 0.7000000000000001D-01*dw(174, 90)
      JacC( 49, 89) = JacC( 49, 89)+ 0.1100000000000000D-01*dw(174, 89)
      JacC( 49, 90) = JacC( 49, 90)+ 0.1100000000000000D-01*dw(174, 90)
      JacC( 66, 89) = JacC( 66, 89)+ 0.3000000000000000D-02*dw(174, 89)
      JacC( 66, 90) = JacC( 66, 90)+ 0.3000000000000000D-02*dw(174, 90)
      JacC( 89, 89) = JacC( 89, 89) - dw(174, 89)
      JacC( 89, 90) = JacC( 89, 90) - dw(174, 90)
      JacC( 90, 89) = JacC( 90, 89) - dw(174, 89)
      JacC( 90, 90) = JacC( 90, 90) - dw(174, 90)
      JacC(101, 89) = JacC(101, 89)+ 0.1200000000000000D+00*dw(174, 89)
      JacC(101, 90) = JacC(101, 90)+ 0.1200000000000000D+00*dw(174, 90)
      JacC(106, 89) = JacC(106, 89)+ 0.1400000000000000D+00*dw(174, 89)
      JacC(106, 90) = JacC(106, 90)+ 0.1400000000000000D+00*dw(174, 90)
      JacC(108, 89) = JacC(108, 89)+ 0.3000000000000000D+00*dw(174, 89)
      JacC(108, 90) = JacC(108, 90)+ 0.3000000000000000D+00*dw(174, 90)
      JacC(109, 89) = JacC(109, 89)+ 0.1600000000000000D+00*dw(174, 89)
      JacC(109, 90) = JacC(109, 90)+ 0.1600000000000000D+00*dw(174, 90)
      JacC(112, 89) = JacC(112, 89)+ 0.9900000000000000D+00*dw(174, 89)
      JacC(112, 90) = JacC(112, 90)+ 0.9900000000000000D+00*dw(174, 90)
      JacC(113, 89) = JacC(113, 89)+ 0.1800000000000000D+00*dw(174, 89)
      JacC(113, 90) = JacC(113, 90)+ 0.1800000000000000D+00*dw(174, 90)
      JacC(114, 89) = JacC(114, 89)+ 0.2300000000000000D+00*dw(174, 89)
      JacC(114, 90) = JacC(114, 90)+ 0.2300000000000000D+00*dw(174, 90)
      JacC(119, 89) = JacC(119, 89)+ 0.2000000000000000D-01*dw(174, 89)
      JacC(119, 90) = JacC(119, 90)+ 0.2000000000000000D-01*dw(174, 90)
      JacC(120, 89) = JacC(120, 89)+ 0.6300000000000000D+00*dw(174, 89)
      JacC(120, 90) = JacC(120, 90)+ 0.6300000000000000D+00*dw(174, 90)
      JacC(123, 89) = JacC(123, 89)+ 0.2200000000000000D+00*dw(174, 89)
      JacC(123, 90) = JacC(123, 90)+ 0.2200000000000000D+00*dw(174, 90)
      JacC( 24, 24) = JacC( 24, 24) - dw(175, 24)
      JacC( 24, 90) = JacC( 24, 90) - dw(175, 90)
      JacC( 37, 24) = JacC( 37, 24)+ 0.3500000000000000D+00*dw(175, 24)
      JacC( 37, 90) = JacC( 37, 90)+ 0.3500000000000000D+00*dw(175, 90)
      JacC( 48, 24) = JacC( 48, 24)+ 0.9000000000000000D-01*dw(175, 24)
      JacC( 48, 90) = JacC( 48, 90)+ 0.9000000000000000D-01*dw(175, 90)
      JacC( 49, 24) = JacC( 49, 24)+ 0.1000000000000000D-02*dw(175, 24)
      JacC( 49, 90) = JacC( 49, 90)+ 0.1000000000000000D-02*dw(175, 90)
      JacC( 82, 24) = JacC( 82, 24)+ 0.1500000000000000D+00*dw(175, 24)
      JacC( 82, 90) = JacC( 82, 90)+ 0.1500000000000000D+00*dw(175, 90)
      JacC( 84, 24) = JacC( 84, 24)+ 0.3900000000000000D+00*dw(175, 24)
      JacC( 84, 90) = JacC( 84, 90)+ 0.3900000000000000D+00*dw(175, 90)
      JacC( 90, 24) = JacC( 90, 24) - dw(175, 24)
      JacC( 90, 90) = JacC( 90, 90) - dw(175, 90)
      JacC(101, 24) = JacC(101, 24)+ 0.2000000000000000D-01*dw(175, 24)
      JacC(101, 90) = JacC(101, 90)+ 0.2000000000000000D-01*dw(175, 90)
      JacC(108, 24) = JacC(108, 24)+ 0.3600000000000000D+00*dw(175, 24)
      JacC(108, 90) = JacC(108, 90)+ 0.3600000000000000D+00*dw(175, 90)
      JacC(114, 24) = JacC(114, 24)+ 0.3000000000000000D-01*dw(175, 24)
      JacC(114, 90) = JacC(114, 90)+ 0.3000000000000000D-01*dw(175, 90)
      JacC(116, 24) = JacC(116, 24)+ 0.1300000000000000D+00*dw(175, 24)
      JacC(116, 90) = JacC(116, 90)+ 0.1300000000000000D+00*dw(175, 90)
      JacC(118, 24) = JacC(118, 24)+ 0.1500000000000000D+00*dw(175, 24)
      JacC(118, 90) = JacC(118, 90)+ 0.1500000000000000D+00*dw(175, 90)
      JacC(119, 24) = JacC(119, 24)+ 0.9000000000000000D+00*dw(175, 24)
      JacC(119, 90) = JacC(119, 90)+ 0.9000000000000000D+00*dw(175, 90)
      JacC(120, 24) = JacC(120, 24)+ 0.2800000000000000D+00*dw(175, 24)
      JacC(120, 90) = JacC(120, 90)+ 0.2800000000000000D+00*dw(175, 90)
      JacC(123, 24) = JacC(123, 24)+ 0.3000000000000000D+00*dw(175, 24)
      JacC(123, 90) = JacC(123, 90)+ 0.3000000000000000D+00*dw(175, 90)
      JacC( 30, 30) = JacC( 30, 30) - dw(176, 30)
      JacC( 30, 90) = JacC( 30, 90) - dw(176, 90)
      JacC( 49, 30) = JacC( 49, 30)+ 0.9000000000000000D-01*dw(176, 30)
      JacC( 49, 90) = JacC( 49, 90)+ 0.9000000000000000D-01*dw(176, 90)
      JacC( 81, 30) = JacC( 81, 30)+ 0.1890000000000000D+00*dw(176, 30)
      JacC( 81, 90) = JacC( 81, 90)+ 0.1890000000000000D+00*dw(176, 90)
      JacC( 82, 30) = JacC( 82, 30)+ 0.2800000000000000D+00*dw(176, 30)
      JacC( 82, 90) = JacC( 82, 90)+ 0.2800000000000000D+00*dw(176, 90)
      JacC( 84, 30) = JacC( 84, 30)+ 0.4610000000000000D+00*dw(176, 30)
      JacC( 84, 90) = JacC( 84, 90)+ 0.4610000000000000D+00*dw(176, 90)
      JacC( 90, 30) = JacC( 90, 30) - dw(176, 30)
      JacC( 90, 90) = JacC( 90, 90) - dw(176, 90)
      JacC(105, 30) = JacC(105, 30)+ 0.1000000000000000D+00*dw(176, 30)
      JacC(105, 90) = JacC(105, 90)+ 0.1000000000000000D+00*dw(176, 90)
      JacC(108, 30) = JacC(108, 30)+ 0.1400000000000000D+00*dw(176, 30)
      JacC(108, 90) = JacC(108, 90)+ 0.1400000000000000D+00*dw(176, 90)
      JacC(114, 30) = JacC(114, 30)+ 0.8000000000000000D-01*dw(176, 30)
      JacC(114, 90) = JacC(114, 90)+ 0.8000000000000000D-01*dw(176, 90)
      JacC(118, 30) = JacC(118, 30)+ 0.1000000000000000D+00*dw(176, 30)
      JacC(118, 90) = JacC(118, 90)+ 0.1000000000000000D+00*dw(176, 90)
      JacC(119, 30) = JacC(119, 30)+ 0.5800000000000000D+00*dw(176, 30)
      JacC(119, 90) = JacC(119, 90)+ 0.5800000000000000D+00*dw(176, 90)
      JacC(120, 30) = JacC(120, 30)+ 0.2500000000000000D+00*dw(176, 30)
      JacC(120, 90) = JacC(120, 90)+ 0.2500000000000000D+00*dw(176, 90)
      JacC(123, 30) = JacC(123, 30)+ 0.2500000000000000D+00*dw(176, 30)
      JacC(123, 90) = JacC(123, 90)+ 0.2500000000000000D+00*dw(176, 90)
      JacC( 82, 84) = JacC( 82, 84)+ 0.4500000000000000D+00*dw(177, 84)
      JacC( 82, 90) = JacC( 82, 90)+ 0.4500000000000000D+00*dw(177, 90)
      JacC( 84, 84) = JacC( 84, 84) - dw(177, 84)
      JacC( 84, 90) = JacC( 84, 90) - dw(177, 90)
      JacC( 90, 84) = JacC( 90, 84) - dw(177, 84)
      JacC( 90, 90) = JacC( 90, 90) - dw(177, 90)
      JacC(102, 84) = JacC(102, 84)+ 0.9000000000000000D+00*dw(177, 84)
      JacC(102, 90) = JacC(102, 90)+ 0.9000000000000000D+00*dw(177, 90)
      JacC(108, 84) = JacC(108, 84)+ 0.2200000000000000D+00*dw(177, 84)
      JacC(108, 90) = JacC(108, 90)+ 0.2200000000000000D+00*dw(177, 90)
      JacC(118, 84) = JacC(118, 84)+ 0.1000000000000000D+00*dw(177, 84)
      JacC(118, 90) = JacC(118, 90)+ 0.1000000000000000D+00*dw(177, 90)
      JacC(120, 84) = JacC(120, 84)+ 0.1900000000000000D+00*dw(177, 84)
      JacC(120, 90) = JacC(120, 90)+ 0.1900000000000000D+00*dw(177, 90)
      JacC(123, 84) = JacC(123, 84)+ 0.3200000000000000D+00*dw(177, 84)
      JacC(123, 90) = JacC(123, 90)+ 0.3200000000000000D+00*dw(177, 90)
      JacC( 81, 81) = JacC( 81, 81) - dw(178, 81)
      JacC( 81, 90) = JacC( 81, 90) - dw(178, 90)
      JacC( 82, 81) = JacC( 82, 81)+ 0.6700000000000000D+00*dw(178, 81)
      JacC( 82, 90) = JacC( 82, 90)+ 0.6700000000000000D+00*dw(178, 90)
      JacC( 90, 81) = JacC( 90, 81) - dw(178, 81)
      JacC( 90, 90) = JacC( 90, 90) - dw(178, 90)
      JacC(102, 81) = JacC(102, 81)+ 0.9500000000000000D+00*dw(178, 81)
      JacC(102, 90) = JacC(102, 90)+ 0.9500000000000000D+00*dw(178, 90)
      JacC(108, 81) = JacC(108, 81)+ 0.1100000000000000D+00*dw(178, 81)
      JacC(108, 90) = JacC(108, 90)+ 0.1100000000000000D+00*dw(178, 90)
      JacC(116, 81) = JacC(116, 81)+ 0.5000000000000000D-01*dw(178, 81)
      JacC(116, 90) = JacC(116, 90)+ 0.5000000000000000D-01*dw(178, 90)
      JacC(118, 81) = JacC(118, 81)+ 0.5000000000000000D-01*dw(178, 81)
      JacC(118, 90) = JacC(118, 90)+ 0.5000000000000000D-01*dw(178, 90)
      JacC(119, 81) = JacC(119, 81)+ 0.1000000000000000D+00*dw(178, 81)
      JacC(119, 90) = JacC(119, 90)+ 0.1000000000000000D+00*dw(178, 90)
      JacC(120, 81) = JacC(120, 81)+ 0.1600000000000000D+00*dw(178, 81)
      JacC(120, 90) = JacC(120, 90)+ 0.1600000000000000D+00*dw(178, 90)
      JacC(123, 81) = JacC(123, 81)+ 0.1100000000000000D+00*dw(178, 81)
      JacC(123, 90) = JacC(123, 90)+ 0.1100000000000000D+00*dw(178, 90)
      JacC( 82, 87) = JacC( 82, 87)+ 0.4400000000000000D-01*dw(179, 87)
      JacC( 82, 90) = JacC( 82, 90)+ 0.4400000000000000D-01*dw(179, 90)
      JacC( 87, 87) = JacC( 87, 87) - dw(179, 87)
      JacC( 87, 90) = JacC( 87, 90) - dw(179, 90)
      JacC( 90, 87) = JacC( 90, 87) - dw(179, 87)
      JacC( 90, 90) = JacC( 90, 90) - dw(179, 90)
      JacC(102, 87) = JacC(102, 87)+ 0.6530000000000000D+00*dw(179, 87)
      JacC(102, 90) = JacC(102, 90)+ 0.6530000000000000D+00*dw(179, 90)
      JacC(104, 87) = JacC(104, 87)+ 0.3100000000000000D-01*dw(179, 87)
      JacC(104, 90) = JacC(104, 90)+ 0.3100000000000000D-01*dw(179, 90)
      JacC(108, 87) = JacC(108, 87)+ 0.2430000000000000D+00*dw(179, 87)
      JacC(108, 90) = JacC(108, 90)+ 0.2430000000000000D+00*dw(179, 90)
      JacC(109, 87) = JacC(109, 87)+ 0.2780000000000000D+00*dw(179, 87)
      JacC(109, 90) = JacC(109, 90)+ 0.2780000000000000D+00*dw(179, 90)
      JacC(112, 87) = JacC(112, 87)+ 0.6200000000000000D-01*dw(179, 87)
      JacC(112, 90) = JacC(112, 90)+ 0.6200000000000000D-01*dw(179, 90)
      JacC(114, 87) = JacC(114, 87)+ 0.1680000000000000D+00*dw(179, 87)
      JacC(114, 90) = JacC(114, 90)+ 0.1680000000000000D+00*dw(179, 90)
      JacC(116, 87) = JacC(116, 87)+ 0.1000000000000000D+00*dw(179, 87)
      JacC(116, 90) = JacC(116, 90)+ 0.1000000000000000D+00*dw(179, 90)
      JacC(118, 87) = JacC(118, 87)+ 0.2370000000000000D+00*dw(179, 87)
      JacC(118, 90) = JacC(118, 90)+ 0.2370000000000000D+00*dw(179, 90)
      JacC(119, 87) = JacC(119, 87)+ 0.2180000000000000D+00*dw(179, 87)
      JacC(119, 90) = JacC(119, 90)+ 0.2180000000000000D+00*dw(179, 90)
      JacC(120, 87) = JacC(120, 87)+ 0.4760000000000000D+00*dw(179, 87)
      JacC(120, 90) = JacC(120, 90)+ 0.4760000000000000D+00*dw(179, 90)
      JacC(123, 87) = JacC(123, 87)+ 0.7199999999999999D-01*dw(179, 87)
      JacC(123, 90) = JacC(123, 90)+ 0.7199999999999999D-01*dw(179, 90)
      JacC( 22, 22) = JacC( 22, 22) - dw(180, 22)
      JacC( 22, 90) = JacC( 22, 90) - dw(180, 90)
      JacC( 32, 22) = JacC( 32, 22)+ 0.4400000000000000D-01*dw(180, 22)
      JacC( 32, 90) = JacC( 32, 90)+ 0.4400000000000000D-01*dw(180, 90)
      JacC( 43, 22) = JacC( 43, 22)+ 0.1270000000000000D+00*dw(180, 22)
      JacC( 43, 90) = JacC( 43, 90)+ 0.1270000000000000D+00*dw(180, 90)
      JacC( 44, 22) = JacC( 44, 22)+ 0.1420000000000000D+00*dw(180, 22)
      JacC( 44, 90) = JacC( 44, 90)+ 0.1420000000000000D+00*dw(180, 90)
      JacC( 49, 22) = JacC( 49, 22)+ 0.2000000000000000D-01*dw(180, 22)
      JacC( 49, 90) = JacC( 49, 90)+ 0.2000000000000000D-01*dw(180, 90)
      JacC( 90, 22) = JacC( 90, 22) - dw(180, 22)
      JacC( 90, 90) = JacC( 90, 90) - dw(180, 90)
      JacC(101, 22) = JacC(101, 22)+ 0.4200000000000000D+00*dw(180, 22)
      JacC(101, 90) = JacC(101, 90)+ 0.4200000000000000D+00*dw(180, 90)
      JacC(108, 22) = JacC(108, 22)+ 0.1400000000000000D+00*dw(180, 22)
      JacC(108, 90) = JacC(108, 90)+ 0.1400000000000000D+00*dw(180, 90)
      JacC(109, 22) = JacC(109, 22)+ 0.5300000000000000D+00*dw(180, 22)
      JacC(109, 90) = JacC(109, 90)+ 0.5300000000000000D+00*dw(180, 90)
      JacC(112, 22) = JacC(112, 22)+ 0.6500000000000000D+00*dw(180, 22)
      JacC(112, 90) = JacC(112, 90)+ 0.6500000000000000D+00*dw(180, 90)
      JacC(113, 22) = JacC(113, 22)+ 0.2000000000000000D+00*dw(180, 22)
      JacC(113, 90) = JacC(113, 90)+ 0.2000000000000000D+00*dw(180, 90)
      JacC(120, 22) = JacC(120, 22)+ 0.8500000000000000D+00*dw(180, 22)
      JacC(120, 90) = JacC(120, 90)+ 0.8500000000000000D+00*dw(180, 90)
      JacC(123, 22) = JacC(123, 22)+ 0.1000000000000000D+00*dw(180, 22)
      JacC(123, 90) = JacC(123, 90)+ 0.1000000000000000D+00*dw(180, 90)
      JacC( 31, 31) = JacC( 31, 31) - dw(181, 31)
      JacC( 31, 90) = JacC( 31, 90) - dw(181, 90)
      JacC( 37, 31) = JacC( 37, 31)+ 0.4600000000000000D+00*dw(181, 31)
      JacC( 37, 90) = JacC( 37, 90)+ 0.4600000000000000D+00*dw(181, 90)
      JacC( 43, 31) = JacC( 43, 31)+ 0.1970000000000000D+00*dw(181, 31)
      JacC( 43, 90) = JacC( 43, 90)+ 0.1970000000000000D+00*dw(181, 90)
      JacC( 44, 31) = JacC( 44, 31)+ 0.9400000000000000D-01*dw(181, 31)
      JacC( 44, 90) = JacC( 44, 90)+ 0.9400000000000000D-01*dw(181, 90)
      JacC( 49, 31) = JacC( 49, 31)+ 0.2000000000000000D-01*dw(181, 31)
      JacC( 49, 90) = JacC( 49, 90)+ 0.2000000000000000D-01*dw(181, 90)
      JacC( 82, 31) = JacC( 82, 31)+ 0.1000000000000000D-01*dw(181, 31)
      JacC( 82, 90) = JacC( 82, 90)+ 0.1000000000000000D-01*dw(181, 90)
      JacC( 84, 31) = JacC( 84, 31)+ 0.7900000000000000D+00*dw(181, 31)
      JacC( 84, 90) = JacC( 84, 90)+ 0.7900000000000000D+00*dw(181, 90)
      JacC( 90, 31) = JacC( 90, 31) - dw(181, 31)
      JacC( 90, 90) = JacC( 90, 90) - dw(181, 90)
      JacC(101, 31) = JacC(101, 31)+ 0.4200000000000000D+00*dw(181, 31)
      JacC(101, 90) = JacC(101, 90)+ 0.4200000000000000D+00*dw(181, 90)
      JacC(106, 31) = JacC(106, 31)+ 0.7000000000000001D-01*dw(181, 31)
      JacC(106, 90) = JacC(106, 90)+ 0.7000000000000001D-01*dw(181, 90)
      JacC(108, 31) = JacC(108, 31)+ 0.1400000000000000D+00*dw(181, 31)
      JacC(108, 90) = JacC(108, 90)+ 0.1400000000000000D+00*dw(181, 90)
      JacC(113, 31) = JacC(113, 31)+ 0.1600000000000000D+00*dw(181, 31)
      JacC(113, 90) = JacC(113, 90)+ 0.1600000000000000D+00*dw(181, 90)
      JacC(119, 31) = JacC(119, 31)+ 0.4000000000000000D-01*dw(181, 31)
      JacC(119, 90) = JacC(119, 90)+ 0.4000000000000000D-01*dw(181, 90)
      JacC(120, 31) = JacC(120, 31)+ 0.8500000000000000D+00*dw(181, 31)
      JacC(120, 90) = JacC(120, 90)+ 0.8500000000000000D+00*dw(181, 90)
      JacC(123, 31) = JacC(123, 31)+ 0.1000000000000000D+00*dw(181, 31)
      JacC(123, 90) = JacC(123, 90)+ 0.1000000000000000D+00*dw(181, 90)
      JacC( 26, 26) = JacC( 26, 26) - dw(182, 26)
      JacC( 26, 90) = JacC( 26, 90) - dw(182, 90)
      JacC( 90, 26) = JacC( 90, 26) - dw(182, 26)
      JacC( 90, 90) = JacC( 90, 90) - dw(182, 90)
      JacC(104, 26) = JacC(104, 26) + dw(182, 26)
      JacC(104, 90) = JacC(104, 90) + dw(182, 90)
      JacC(108, 26) = JacC(108, 26)+ 0.1500000000000000D+01*dw(182, 26)
      JacC(108, 90) = JacC(108, 90)+ 0.1500000000000000D+01*dw(182, 90)
      JacC(120, 26) = JacC(120, 26)+ 0.5000000000000000D+00*dw(182, 26)
      JacC(120, 90) = JacC(120, 90)+ 0.5000000000000000D+00*dw(182, 90)
      JacC(123, 26) = JacC(123, 26)+ 0.1500000000000000D+01*dw(182, 26)
      JacC(123, 90) = JacC(123, 90)+ 0.1500000000000000D+01*dw(182, 90)
      JacC( 71, 91) = JacC( 71, 91)+ 0.1100000000000000D+00*dw(183, 91)
      JacC( 71, 90) = JacC( 71, 90)+ 0.1100000000000000D+00*dw(183, 90)
      JacC( 82, 91) = JacC( 82, 91)+ 0.2500000000000000D+00*dw(183, 91)
      JacC( 82, 90) = JacC( 82, 90)+ 0.2500000000000000D+00*dw(183, 90)
      JacC( 90, 91) = JacC( 90, 91) - dw(183, 91)
      JacC( 90, 90) = JacC( 90, 90) - dw(183, 90)
      JacC( 91, 91) = JacC( 91, 91) - dw(183, 91)
      JacC( 91, 90) = JacC( 91, 90) - dw(183, 90)
      JacC(102, 91) = JacC(102, 91)+ 0.2480000000000000D+01*dw(183, 91)
      JacC(102, 90) = JacC(102, 90)+ 0.2480000000000000D+01*dw(183, 90)
      JacC(106, 91) = JacC(106, 91)+ 0.2500000000000000D+00*dw(183, 91)
      JacC(106, 90) = JacC(106, 90)+ 0.2500000000000000D+00*dw(183, 90)
      JacC(108, 91) = JacC(108, 91)+ 0.1500000000000000D+01*dw(183, 91)
      JacC(108, 90) = JacC(108, 90)+ 0.1500000000000000D+01*dw(183, 90)
      JacC(120, 91) = JacC(120, 91)+ 0.5000000000000000D+00*dw(183, 91)
      JacC(120, 90) = JacC(120, 90)+ 0.5000000000000000D+00*dw(183, 90)
      JacC(123, 91) = JacC(123, 91) + dw(183, 91)
      JacC(123, 90) = JacC(123, 90) + dw(183, 90)
      JacC( 60, 60) = JacC( 60, 60) - dw(184, 60)
      JacC( 60,124) = JacC( 60,124) - dw(184,124)
      JacC(111, 60) = JacC(111, 60) + dw(184, 60)
      JacC(111,124) = JacC(111,124) + dw(184,124)
      JacC(124, 60) = JacC(124, 60) - dw(184, 60)
      JacC(124,124) = JacC(124,124) - dw(184,124)
      JacC( 40,118) = JacC( 40,118) + dw(185,118)
      JacC( 40,124) = JacC( 40,124) + dw(185,124)
      JacC(118,118) = JacC(118,118) - dw(185,118)
      JacC(118,124) = JacC(118,124) - dw(185,124)
      JacC(124,118) = JacC(124,118) - dw(185,118)
      JacC(124,124) = JacC(124,124) - dw(185,124)
      JacC( 41,122) = JacC( 41,122) + dw(186,122)
      JacC( 41,124) = JacC( 41,124) + dw(186,124)
      JacC(122,122) = JacC(122,122) - dw(186,122)
      JacC(122,124) = JacC(122,124) - dw(186,124)
      JacC(124,122) = JacC(124,122) - dw(186,122)
      JacC(124,124) = JacC(124,124) - dw(186,124)
      JacC( 40, 40) = JacC( 40, 40) - dw(187, 40)
      JacC(118, 40) = JacC(118, 40) + dw(187, 40)
      JacC(124, 40) = JacC(124, 40) + dw(187, 40)
      JacC( 41, 41) = JacC( 41, 41) - dw(188, 41)
      JacC(122, 41) = JacC(122, 41) + dw(188, 41)
      JacC(124, 41) = JacC(124, 41) + dw(188, 41)
      JacC( 47,105) = JacC( 47,105) + dw(189,105)
      JacC( 47,124) = JacC( 47,124) + dw(189,124)
      JacC(105,105) = JacC(105,105) - dw(189,105)
      JacC(105,124) = JacC(105,124) - dw(189,124)
      JacC(124,105) = JacC(124,105) - dw(189,105)
      JacC(124,124) = JacC(124,124) - dw(189,124)
      JacC( 47, 47) = JacC( 47, 47) - dw(190, 47)
      JacC(105, 47) = JacC(105, 47) + dw(190, 47)
      JacC(124, 47) = JacC(124, 47) + dw(190, 47)
      JacC(114,114) = JacC(114,114) - dw(191,114)
      JacC(114,117) = JacC(114,117) - dw(191,117)
      JacC(117,114) = JacC(117,114) - dw(191,114)
      JacC(117,117) = JacC(117,117) - dw(191,117)
      JacC(119,114) = JacC(119,114) + dw(191,114)
      JacC(119,117) = JacC(119,117) + dw(191,117)
      JacC(123,114) = JacC(123,114) + dw(191,114)
      JacC(123,117) = JacC(123,117) + dw(191,117)
      JacC(124,114) = JacC(124,114) + dw(191,114)
      JacC(124,117) = JacC(124,117) + dw(191,117)
      JacC(100,113) = JacC(100,113) + dw(192,113)
      JacC(100,117) = JacC(100,117) + dw(192,117)
      JacC(113,113) = JacC(113,113) - dw(192,113)
      JacC(113,117) = JacC(113,117) - dw(192,117)
      JacC(117,113) = JacC(117,113) - dw(192,113)
      JacC(117,117) = JacC(117,117) - dw(192,117)
      JacC(123,113) = JacC(123,113) + dw(192,113)
      JacC(123,117) = JacC(123,117) + dw(192,117)
      JacC(124,113) = JacC(124,113) + dw(192,113)
      JacC(124,117) = JacC(124,117) + dw(192,117)
      JacC( 73,110) = JacC( 73,110)+ 0.6230000000000000D+00*dw(193,110)
      JacC( 73,117) = JacC( 73,117)+ 0.6230000000000000D+00*dw(193,117)
      JacC(104,110) = JacC(104,110)+ 0.6300000000000000D-01*dw(193,110)
      JacC(104,117) = JacC(104,117)+ 0.6300000000000000D-01*dw(193,117)
      JacC(110,110) = JacC(110,110) - dw(193,110)
      JacC(110,117) = JacC(110,117) - dw(193,117)
      JacC(111,110) = JacC(111,110)+ 0.5900000000000000D-01*dw(193,110)
      JacC(111,117) = JacC(111,117)+ 0.5900000000000000D-01*dw(193,117)
      JacC(112,110) = JacC(112,110)+ 0.2330000000000000D+00*dw(193,110)
      JacC(112,117) = JacC(112,117)+ 0.2330000000000000D+00*dw(193,117)
      JacC(113,110) = JacC(113,110)+ 0.4800000000000000D-01*dw(193,110)
      JacC(113,117) = JacC(113,117)+ 0.4800000000000000D-01*dw(193,117)
      JacC(114,110) = JacC(114,110)+ 0.1500000000000000D+00*dw(193,110)
      JacC(114,117) = JacC(114,117)+ 0.1500000000000000D+00*dw(193,117)
      JacC(116,110) = JacC(116,110)+ 0.4800000000000000D-01*dw(193,110)
      JacC(116,117) = JacC(116,117)+ 0.4800000000000000D-01*dw(193,117)
      JacC(117,110) = JacC(117,110) - dw(193,110)
      JacC(117,117) = JacC(117,117) - dw(193,117)
      JacC(119,110) = JacC(119,110)+ 0.4700000000000000D-01*dw(193,110)
      JacC(119,117) = JacC(119,117)+ 0.4700000000000000D-01*dw(193,117)
      JacC(123,110) = JacC(123,110)+ 0.7420000000000000D+00*dw(193,110)
      JacC(123,117) = JacC(123,117)+ 0.7420000000000000D+00*dw(193,117)
      JacC(124,110) = JacC(124,110)+ 0.9409999999999999D+00*dw(193,110)
      JacC(124,117) = JacC(124,117)+ 0.9409999999999999D+00*dw(193,117)
      JacC( 36, 72) = JacC( 36, 72)+ 0.1220000000000000D+00*dw(194, 72)
      JacC( 36,117) = JacC( 36,117)+ 0.1220000000000000D+00*dw(194,117)
      JacC( 72, 72) = JacC( 72, 72) - dw(194, 72)
      JacC( 72,117) = JacC( 72,117) - dw(194,117)
      JacC( 73, 72) = JacC( 73, 72)+ 0.1000000000000000D+00*dw(194, 72)
      JacC( 73,117) = JacC( 73,117)+ 0.1000000000000000D+00*dw(194,117)
      JacC(109, 72) = JacC(109, 72)+ 0.5000000000000000D+00*dw(194, 72)
      JacC(109,117) = JacC(109,117)+ 0.5000000000000000D+00*dw(194,117)
      JacC(111, 72) = JacC(111, 72)+ 0.1240000000000000D+00*dw(194, 72)
      JacC(111,117) = JacC(111,117)+ 0.1240000000000000D+00*dw(194,117)
      JacC(112, 72) = JacC(112, 72)+ 0.2110000000000000D+00*dw(194, 72)
      JacC(112,117) = JacC(112,117)+ 0.2110000000000000D+00*dw(194,117)
      JacC(113, 72) = JacC(113, 72)+ 0.2450000000000000D+00*dw(194, 72)
      JacC(113,117) = JacC(113,117)+ 0.2450000000000000D+00*dw(194,117)
      JacC(114, 72) = JacC(114, 72)+ 0.3100000000000000D-01*dw(194, 72)
      JacC(114,117) = JacC(114,117)+ 0.3100000000000000D-01*dw(194,117)
      JacC(116, 72) = JacC(116, 72)+ 0.3340000000000000D+00*dw(194, 72)
      JacC(116,117) = JacC(116,117)+ 0.3340000000000000D+00*dw(194,117)
      JacC(117, 72) = JacC(117, 72) - dw(194, 72)
      JacC(117,117) = JacC(117,117) - dw(194,117)
      JacC(119, 72) = JacC(119, 72)+ 0.2100000000000000D-01*dw(194, 72)
      JacC(119,117) = JacC(119,117)+ 0.2100000000000000D-01*dw(194,117)
      JacC(123, 72) = JacC(123, 72)+ 0.5990000000000000D+00*dw(194, 72)
      JacC(123,117) = JacC(123,117)+ 0.5990000000000000D+00*dw(194,117)
      JacC(124, 72) = JacC(124, 72)+ 0.8760000000000000D+00*dw(194, 72)
      JacC(124,117) = JacC(124,117)+ 0.8760000000000000D+00*dw(194,117)
      JacC( 75, 75) = JacC( 75, 75) - dw(195, 75)
      JacC( 75,117) = JacC( 75,117) - dw(195,117)
      JacC(109, 75) = JacC(109, 75)+ 0.6420000000000000D+00*dw(195, 75)
      JacC(109,117) = JacC(109,117)+ 0.6420000000000000D+00*dw(195,117)
      JacC(111, 75) = JacC(111, 75)+ 0.2610000000000000D+00*dw(195, 75)
      JacC(111,117) = JacC(111,117)+ 0.2610000000000000D+00*dw(195,117)
      JacC(112, 75) = JacC(112, 75)+ 0.1500000000000000D+00*dw(195, 75)
      JacC(112,117) = JacC(112,117)+ 0.1500000000000000D+00*dw(195,117)
      JacC(113, 75) = JacC(113, 75)+ 0.1330000000000000D+00*dw(195, 75)
      JacC(113,117) = JacC(113,117)+ 0.1330000000000000D+00*dw(195,117)
      JacC(116, 75) = JacC(116, 75)+ 0.4160000000000000D+00*dw(195, 75)
      JacC(116,117) = JacC(116,117)+ 0.4160000000000000D+00*dw(195,117)
      JacC(117, 75) = JacC(117, 75) - dw(195, 75)
      JacC(117,117) = JacC(117,117) - dw(195,117)
      JacC(123, 75) = JacC(123, 75)+ 0.6060000000000000D+00*dw(195, 75)
      JacC(123,117) = JacC(123,117)+ 0.6060000000000000D+00*dw(195,117)
      JacC(124, 75) = JacC(124, 75)+ 0.7390000000000000D+00*dw(195, 75)
      JacC(124,117) = JacC(124,117)+ 0.7390000000000000D+00*dw(195,117)
      JacC( 85, 85) = JacC( 85, 85) - dw(196, 85)
      JacC( 85,117) = JacC( 85,117) - dw(196,117)
      JacC(112, 85) = JacC(112, 85)+ 0.2000000000000000D+00*dw(196, 85)
      JacC(112,117) = JacC(112,117)+ 0.2000000000000000D+00*dw(196,117)
      JacC(117, 85) = JacC(117, 85) - dw(196, 85)
      JacC(117,117) = JacC(117,117) - dw(196,117)
      JacC(119, 85) = JacC(119, 85)+ 0.1600000000000000D+01*dw(196, 85)
      JacC(119,117) = JacC(119,117)+ 0.1600000000000000D+01*dw(196,117)
      JacC(123, 85) = JacC(123, 85) + dw(196, 85)
      JacC(123,117) = JacC(123,117) + dw(196,117)
      JacC(124, 85) = JacC(124, 85) + dw(196, 85)
      JacC(124,117) = JacC(124,117) + dw(196,117)
      JacC( 70, 70) = JacC( 70, 70) - dw(197, 70)
      JacC( 70,117) = JacC( 70,117) - dw(197,117)
      JacC(109, 70) = JacC(109, 70)+ 0.6000000000000000D-01*dw(197, 70)
      JacC(109,117) = JacC(109,117)+ 0.6000000000000000D-01*dw(197,117)
      JacC(112, 70) = JacC(112, 70)+ 0.9399999999999999D+00*dw(197, 70)
      JacC(112,117) = JacC(112,117)+ 0.9399999999999999D+00*dw(197,117)
      JacC(117, 70) = JacC(117, 70) - dw(197, 70)
      JacC(117,117) = JacC(117,117) - dw(197,117)
      JacC(119, 70) = JacC(119, 70) + dw(197, 70)
      JacC(119,117) = JacC(119,117) + dw(197,117)
      JacC(123, 70) = JacC(123, 70) + dw(197, 70)
      JacC(123,117) = JacC(123,117) + dw(197,117)
      JacC(124, 70) = JacC(124, 70) + dw(197, 70)
      JacC(124,117) = JacC(124,117) + dw(197,117)
      JacC( 92, 92) = JacC( 92, 92) - dw(198, 92)
      JacC( 92,117) = JacC( 92,117) - dw(198,117)
      JacC(109, 92) = JacC(109, 92)+ 0.2900000000000000D+00*dw(198, 92)
      JacC(109,117) = JacC(109,117)+ 0.2900000000000000D+00*dw(198,117)
      JacC(112, 92) = JacC(112, 92)+ 0.1710000000000000D+01*dw(198, 92)
      JacC(112,117) = JacC(112,117)+ 0.1710000000000000D+01*dw(198,117)
      JacC(117, 92) = JacC(117, 92) - dw(198, 92)
      JacC(117,117) = JacC(117,117) - dw(198,117)
      JacC(123, 92) = JacC(123, 92) + dw(198, 92)
      JacC(123,117) = JacC(123,117) + dw(198,117)
      JacC(124, 92) = JacC(124, 92) + dw(198, 92)
      JacC(124,117) = JacC(124,117) + dw(198,117)
      JacC( 46, 80) = JacC( 46, 80)+ 0.4600000000000000D-01*dw(199, 80)
      JacC( 46,117) = JacC( 46,117)+ 0.4600000000000000D-01*dw(199,117)
      JacC( 80, 80) = JacC( 80, 80) - dw(199, 80)
      JacC( 80,117) = JacC( 80,117) - dw(199,117)
      JacC( 81, 80) = JacC( 81, 80)+ 0.5820000000000000D+00*dw(199, 80)
      JacC( 81,117) = JacC( 81,117)+ 0.5820000000000000D+00*dw(199,117)
      JacC( 84, 80) = JacC( 84, 80)+ 0.4180000000000000D+00*dw(199, 80)
      JacC( 84,117) = JacC( 84,117)+ 0.4180000000000000D+00*dw(199,117)
      JacC(117, 80) = JacC(117, 80) - dw(199, 80)
      JacC(117,117) = JacC(117,117) - dw(199,117)
      JacC(119, 80) = JacC(119, 80) + dw(199, 80)
      JacC(119,117) = JacC(119,117) + dw(199,117)
      JacC(123, 80) = JacC(123, 80)+ 0.9540000000000000D+00*dw(199, 80)
      JacC(123,117) = JacC(123,117)+ 0.9540000000000000D+00*dw(199,117)
      JacC(124, 80) = JacC(124, 80)+ 0.9540000000000000D+00*dw(199, 80)
      JacC(124,117) = JacC(124,117)+ 0.9540000000000000D+00*dw(199,117)
      JacC( 76,105) = JacC( 76,105)+ 0.2500000000000000D+00*dw(200,105)
      JacC( 76,117) = JacC( 76,117)+ 0.2500000000000000D+00*dw(200,117)
      JacC(102,105) = JacC(102,105)+ 0.5000000000000000D+00*dw(200,105)
      JacC(102,117) = JacC(102,117)+ 0.5000000000000000D+00*dw(200,117)
      JacC(105,105) = JacC(105,105) - dw(200,105)
      JacC(105,117) = JacC(105,117) - dw(200,117)
      JacC(108,105) = JacC(108,105)+ 0.2500000000000000D+00*dw(200,105)
      JacC(108,117) = JacC(108,117)+ 0.2500000000000000D+00*dw(200,117)
      JacC(117,105) = JacC(117,105) - dw(200,105)
      JacC(117,117) = JacC(117,117) - dw(200,117)
      JacC(118,105) = JacC(118,105)+ 0.2500000000000000D+00*dw(200,105)
      JacC(118,117) = JacC(118,117)+ 0.2500000000000000D+00*dw(200,117)
      JacC(119,105) = JacC(119,105)+ 0.7500000000000000D+00*dw(200,105)
      JacC(119,117) = JacC(119,117)+ 0.7500000000000000D+00*dw(200,117)
      JacC(123,105) = JacC(123,105)+ 0.7500000000000000D+00*dw(200,105)
      JacC(123,117) = JacC(123,117)+ 0.7500000000000000D+00*dw(200,117)
      JacC(124,105) = JacC(124,105) + dw(200,105)
      JacC(124,117) = JacC(124,117) + dw(200,117)
      JacC( 83, 83) = JacC( 83, 83) - dw(201, 83)
      JacC( 83,117) = JacC( 83,117) - dw(201,117)
      JacC(102, 83) = JacC(102, 83)+ 0.3000000000000000D+00*dw(201, 83)
      JacC(102,117) = JacC(102,117)+ 0.3000000000000000D+00*dw(201,117)
      JacC(112, 83) = JacC(112, 83)+ 0.7000000000000000D+00*dw(201, 83)
      JacC(112,117) = JacC(112,117)+ 0.7000000000000000D+00*dw(201,117)
      JacC(116, 83) = JacC(116, 83)+ 0.7000000000000000D+00*dw(201, 83)
      JacC(116,117) = JacC(116,117)+ 0.7000000000000000D+00*dw(201,117)
      JacC(117, 83) = JacC(117, 83) - dw(201, 83)
      JacC(117,117) = JacC(117,117) - dw(201,117)
      JacC(118, 83) = JacC(118, 83)+ 0.7000000000000000D+00*dw(201, 83)
      JacC(118,117) = JacC(118,117)+ 0.7000000000000000D+00*dw(201,117)
      JacC(119, 83) = JacC(119, 83)+ 0.3000000000000000D+00*dw(201, 83)
      JacC(119,117) = JacC(119,117)+ 0.3000000000000000D+00*dw(201,117)
      JacC(123, 83) = JacC(123, 83)+ 0.3000000000000000D+00*dw(201, 83)
      JacC(123,117) = JacC(123,117)+ 0.3000000000000000D+00*dw(201,117)
      JacC(124, 83) = JacC(124, 83) + dw(201, 83)
      JacC(124,117) = JacC(124,117) + dw(201,117)
      JacC( 68, 68) = JacC( 68, 68) - dw(202, 68)
      JacC( 68,117) = JacC( 68,117) - dw(202,117)
      JacC( 69, 68) = JacC( 69, 68)+ 0.6700000000000000D+00*dw(202, 68)
      JacC( 69,117) = JacC( 69,117)+ 0.6700000000000000D+00*dw(202,117)
      JacC(117, 68) = JacC(117, 68) - dw(202, 68)
      JacC(117,117) = JacC(117,117) - dw(202,117)
      JacC(119, 68) = JacC(119, 68)+ 0.3300000000000000D+00*dw(202, 68)
      JacC(119,117) = JacC(119,117)+ 0.3300000000000000D+00*dw(202,117)
      JacC(123, 68) = JacC(123, 68)+ 0.6700000000000000D+00*dw(202, 68)
      JacC(123,117) = JacC(123,117)+ 0.6700000000000000D+00*dw(202,117)
      JacC(124, 68) = JacC(124, 68) + dw(202, 68)
      JacC(124,117) = JacC(124,117) + dw(202,117)
      JacC( 88, 88) = JacC( 88, 88) - dw(203, 88)
      JacC( 88,117) = JacC( 88,117) - dw(203,117)
      JacC(102, 88) = JacC(102, 88)+ 0.2100000000000000D+00*dw(203, 88)
      JacC(102,117) = JacC(102,117)+ 0.2100000000000000D+00*dw(203,117)
      JacC(104, 88) = JacC(104, 88)+ 0.1800000000000000D+00*dw(203, 88)
      JacC(104,117) = JacC(104,117)+ 0.1800000000000000D+00*dw(203,117)
      JacC(108, 88) = JacC(108, 88)+ 0.6100000000000000D+00*dw(203, 88)
      JacC(108,117) = JacC(108,117)+ 0.6100000000000000D+00*dw(203,117)
      JacC(109, 88) = JacC(109, 88)+ 0.7000000000000000D+00*dw(203, 88)
      JacC(109,117) = JacC(109,117)+ 0.7000000000000000D+00*dw(203,117)
      JacC(112, 88) = JacC(112, 88)+ 0.2700000000000000D+00*dw(203, 88)
      JacC(112,117) = JacC(112,117)+ 0.2700000000000000D+00*dw(203,117)
      JacC(117, 88) = JacC(117, 88) - dw(203, 88)
      JacC(117,117) = JacC(117,117) - dw(203,117)
      JacC(119, 88) = JacC(119, 88)+ 0.3000000000000000D-01*dw(203, 88)
      JacC(119,117) = JacC(119,117)+ 0.3000000000000000D-01*dw(203,117)
      JacC(123, 88) = JacC(123, 88) + dw(203, 88)
      JacC(123,117) = JacC(123,117) + dw(203,117)
      JacC(124, 88) = JacC(124, 88) + dw(203, 88)
      JacC(124,117) = JacC(124,117) + dw(203,117)
      JacC( 73, 74) = JacC( 73, 74)+ 0.1100000000000000D+00*dw(204, 74)
      JacC( 73,117) = JacC( 73,117)+ 0.1100000000000000D+00*dw(204,117)
      JacC( 74, 74) = JacC( 74, 74) - dw(204, 74)
      JacC( 74,117) = JacC( 74,117) - dw(204,117)
      JacC( 82, 74) = JacC( 82, 74)+ 0.7000000000000001D-01*dw(204, 74)
      JacC( 82,117) = JacC( 82,117)+ 0.7000000000000001D-01*dw(204,117)
      JacC(109, 74) = JacC(109, 74)+ 0.4400000000000000D+00*dw(204, 74)
      JacC(109,117) = JacC(109,117)+ 0.4400000000000000D+00*dw(204,117)
      JacC(111, 74) = JacC(111, 74)+ 0.1800000000000000D+00*dw(204, 74)
      JacC(111,117) = JacC(111,117)+ 0.1800000000000000D+00*dw(204,117)
      JacC(112, 74) = JacC(112, 74)+ 0.4300000000000000D+00*dw(204, 74)
      JacC(112,117) = JacC(112,117)+ 0.4300000000000000D+00*dw(204,117)
      JacC(117, 74) = JacC(117, 74) - dw(204, 74)
      JacC(117,117) = JacC(117,117) - dw(204,117)
      JacC(119, 74) = JacC(119, 74)+ 0.2300000000000000D+00*dw(204, 74)
      JacC(119,117) = JacC(119,117)+ 0.2300000000000000D+00*dw(204,117)
      JacC(123, 74) = JacC(123, 74)+ 0.8200000000000000D+00*dw(204, 74)
      JacC(123,117) = JacC(123,117)+ 0.8200000000000000D+00*dw(204,117)
      JacC(124, 74) = JacC(124, 74)+ 0.8200000000000000D+00*dw(204, 74)
      JacC(124,117) = JacC(124,117)+ 0.8200000000000000D+00*dw(204,117)
      JacC( 73, 79) = JacC( 73, 79)+ 0.3000000000000000D-01*dw(205, 79)
      JacC( 73,117) = JacC( 73,117)+ 0.3000000000000000D-01*dw(205,117)
      JacC( 79, 79) = JacC( 79, 79) - dw(205, 79)
      JacC( 79,117) = JacC( 79,117) - dw(205,117)
      JacC( 84, 79) = JacC( 84, 79)+ 0.2500000000000000D+00*dw(205, 79)
      JacC( 84,117) = JacC( 84,117)+ 0.2500000000000000D+00*dw(205,117)
      JacC(109, 79) = JacC(109, 79)+ 0.2500000000000000D+00*dw(205, 79)
      JacC(109,117) = JacC(109,117)+ 0.2500000000000000D+00*dw(205,117)
      JacC(111, 79) = JacC(111, 79)+ 0.1000000000000000D+00*dw(205, 79)
      JacC(111,117) = JacC(111,117)+ 0.1000000000000000D+00*dw(205,117)
      JacC(117, 79) = JacC(117, 79) - dw(205, 79)
      JacC(117,117) = JacC(117,117) - dw(205,117)
      JacC(123, 79) = JacC(123, 79)+ 0.9000000000000000D+00*dw(205, 79)
      JacC(123,117) = JacC(123,117)+ 0.9000000000000000D+00*dw(205,117)
      JacC(124, 79) = JacC(124, 79)+ 0.9000000000000000D+00*dw(205, 79)
      JacC(124,117) = JacC(124,117)+ 0.9000000000000000D+00*dw(205,117)
      JacC( 86, 86) = JacC( 86, 86) - dw(206, 86)
      JacC( 86,117) = JacC( 86,117) - dw(206,117)
      JacC( 87, 86) = JacC( 87, 86)+ 0.4590000000000000D+00*dw(206, 86)
      JacC( 87,117) = JacC( 87,117)+ 0.4590000000000000D+00*dw(206,117)
      JacC( 89, 86) = JacC( 89, 86)+ 0.4590000000000000D+00*dw(206, 86)
      JacC( 89,117) = JacC( 89,117)+ 0.4590000000000000D+00*dw(206,117)
      JacC(104, 86) = JacC(104, 86)+ 0.9180000000000000D+00*dw(206, 86)
      JacC(104,117) = JacC(104,117)+ 0.9180000000000000D+00*dw(206,117)
      JacC(111, 86) = JacC(111, 86)+ 0.8200000000000000D-01*dw(206, 86)
      JacC(111,117) = JacC(111,117)+ 0.8200000000000000D-01*dw(206,117)
      JacC(117, 86) = JacC(117, 86) - dw(206, 86)
      JacC(117,117) = JacC(117,117) - dw(206,117)
      JacC(123, 86) = JacC(123, 86)+ 0.9180000000000000D+00*dw(206, 86)
      JacC(123,117) = JacC(123,117)+ 0.9180000000000000D+00*dw(206,117)
      JacC(124, 86) = JacC(124, 86)+ 0.9180000000000000D+00*dw(206, 86)
      JacC(124,117) = JacC(124,117)+ 0.9180000000000000D+00*dw(206,117)
      JacC( 59, 64) = JacC( 59, 64)+ 0.3200000000000000D+00*dw(207, 64)
      JacC( 59,117) = JacC( 59,117)+ 0.3200000000000000D+00*dw(207,117)
      JacC( 64, 64) = JacC( 64, 64) - dw(207, 64)
      JacC( 64,117) = JacC( 64,117) - dw(207,117)
      JacC( 65, 64) = JacC( 65, 64)+ 0.7300000000000000D-01*dw(207, 64)
      JacC( 65,117) = JacC( 65,117)+ 0.7300000000000000D-01*dw(207,117)
      JacC( 66, 64) = JacC( 66, 64)+ 0.2300000000000000D-01*dw(207, 64)
      JacC( 66,117) = JacC( 66,117)+ 0.2300000000000000D-01*dw(207,117)
      JacC( 69, 64) = JacC( 69, 64)+ 0.7000000000000000D+00*dw(207, 64)
      JacC( 69,117) = JacC( 69,117)+ 0.7000000000000000D+00*dw(207,117)
      JacC( 91, 64) = JacC( 91, 64)+ 0.1770000000000000D+00*dw(207, 64)
      JacC( 91,117) = JacC( 91,117)+ 0.1770000000000000D+00*dw(207,117)
      JacC(102, 64) = JacC(102, 64)+ 0.6000000000000000D+00*dw(207, 64)
      JacC(102,117) = JacC(102,117)+ 0.6000000000000000D+00*dw(207,117)
      JacC(104, 64) = JacC(104, 64)+ 0.3500000000000000D+00*dw(207, 64)
      JacC(104,117) = JacC(104,117)+ 0.3500000000000000D+00*dw(207,117)
      JacC(111, 64) = JacC(111, 64)+ 0.5000000000000000D-01*dw(207, 64)
      JacC(111,117) = JacC(111,117)+ 0.5000000000000000D-01*dw(207,117)
      JacC(117, 64) = JacC(117, 64) - dw(207, 64)
      JacC(117,117) = JacC(117,117) - dw(207,117)
      JacC(123, 64) = JacC(123, 64)+ 0.9500000000000000D+00*dw(207, 64)
      JacC(123,117) = JacC(123,117)+ 0.9500000000000000D+00*dw(207,117)
      JacC(124, 64) = JacC(124, 64)+ 0.9500000000000000D+00*dw(207, 64)
      JacC(124,117) = JacC(124,117)+ 0.9500000000000000D+00*dw(207,117)
      JacC( 77, 78) = JacC( 77, 78)+ 0.3200000000000000D+00*dw(208, 78)
      JacC( 77,117) = JacC( 77,117)+ 0.3200000000000000D+00*dw(208,117)
      JacC( 78, 78) = JacC( 78, 78) - dw(208, 78)
      JacC( 78,117) = JacC( 78,117) - dw(208,117)
      JacC(104, 78) = JacC(104, 78)+ 0.6800000000000000D+00*dw(208, 78)
      JacC(104,117) = JacC(104,117)+ 0.6800000000000000D+00*dw(208,117)
      JacC(115, 78) = JacC(115, 78)+ 0.6800000000000000D+00*dw(208, 78)
      JacC(115,117) = JacC(115,117)+ 0.6800000000000000D+00*dw(208,117)
      JacC(117, 78) = JacC(117, 78) - dw(208, 78)
      JacC(117,117) = JacC(117,117) - dw(208,117)
      JacC(123, 78) = JacC(123, 78) + dw(208, 78)
      JacC(123,117) = JacC(123,117) + dw(208,117)
      JacC(124, 78) = JacC(124, 78) + dw(208, 78)
      JacC(124,117) = JacC(124,117) + dw(208,117)
      JacC(114,118) = JacC(114,118) + dw(209,118)
      JacC(114,117) = JacC(114,117) + dw(209,117)
      JacC(117,118) = JacC(117,118) - dw(209,118)
      JacC(117,117) = JacC(117,117) - dw(209,117)
      JacC(118,118) = JacC(118,118) - dw(209,118)
      JacC(118,117) = JacC(118,117) - dw(209,117)
      JacC(124,118) = JacC(124,118) + dw(209,118)
      JacC(124,117) = JacC(124,117) + dw(209,117)
      JacC(113,122) = JacC(113,122) + dw(210,122)
      JacC(113,117) = JacC(113,117) + dw(210,117)
      JacC(117,122) = JacC(117,122) - dw(210,122)
      JacC(117,117) = JacC(117,117) - dw(210,117)
      JacC(122,122) = JacC(122,122) - dw(210,122)
      JacC(122,117) = JacC(122,117) - dw(210,117)
      JacC(124,122) = JacC(124,122) + dw(210,122)
      JacC(124,117) = JacC(124,117) + dw(210,117)
      JacC(101,101) = JacC(101,101) - dw(211,101)
      JacC(101,117) = JacC(101,117) - dw(211,117)
      JacC(102,101) = JacC(102,101)+ 0.5400000000000000D+00*dw(211,101)
      JacC(102,117) = JacC(102,117)+ 0.5400000000000000D+00*dw(211,117)
      JacC(112,101) = JacC(112,101)+ 0.4600000000000000D+00*dw(211,101)
      JacC(112,117) = JacC(112,117)+ 0.4600000000000000D+00*dw(211,117)
      JacC(116,101) = JacC(116,101)+ 0.1600000000000000D+00*dw(211,101)
      JacC(116,117) = JacC(116,117)+ 0.1600000000000000D+00*dw(211,117)
      JacC(117,101) = JacC(117,101) - dw(211,101)
      JacC(117,117) = JacC(117,117) - dw(211,117)
      JacC(118,101) = JacC(118,101)+ 0.2300000000000000D+00*dw(211,101)
      JacC(118,117) = JacC(118,117)+ 0.2300000000000000D+00*dw(211,117)
      JacC(123,101) = JacC(123,101)+ 0.7700000000000000D+00*dw(211,101)
      JacC(123,117) = JacC(123,117)+ 0.7700000000000000D+00*dw(211,117)
      JacC(124,101) = JacC(124,101) + dw(211,101)
      JacC(124,117) = JacC(124,117) + dw(211,117)
      JacC( 98, 98) = JacC( 98, 98) - dw(212, 98)
      JacC( 98,117) = JacC( 98,117) - dw(212,117)
      JacC(117, 98) = JacC(117, 98) - dw(212, 98)
      JacC(117,117) = JacC(117,117) - dw(212,117)
      JacC(118, 98) = JacC(118, 98) + dw(212, 98)
      JacC(118,117) = JacC(118,117) + dw(212,117)
      JacC(119, 98) = JacC(119, 98) + dw(212, 98)
      JacC(119,117) = JacC(119,117) + dw(212,117)
      JacC(124, 98) = JacC(124, 98) + dw(212, 98)
      JacC(124,117) = JacC(124,117) + dw(212,117)
      JacC( 93, 93) = JacC( 93, 93) - dw(213, 93)
      JacC( 93,117) = JacC( 93,117) - dw(213,117)
      JacC(111, 93) = JacC(111, 93) + dw(213, 93)
      JacC(111,117) = JacC(111,117) + dw(213,117)
      JacC(117, 93) = JacC(117, 93) - dw(213, 93)
      JacC(117,117) = JacC(117,117) - dw(213,117)
      JacC(123, 93) = JacC(123, 93) + dw(213, 93)
      JacC(123,117) = JacC(123,117) + dw(213,117)
      JacC(124, 93) = JacC(124, 93) + dw(213, 93)
      JacC(124,117) = JacC(124,117) + dw(213,117)
      JacC( 94, 94) = JacC( 94, 94) - dw(214, 94)
      JacC( 94,117) = JacC( 94,117) - dw(214,117)
      JacC(109, 94) = JacC(109, 94)+ 0.4640000000000000D+00*dw(214, 94)
      JacC(109,117) = JacC(109,117)+ 0.4640000000000000D+00*dw(214,117)
      JacC(112, 94) = JacC(112, 94)+ 0.1240000000000000D+01*dw(214, 94)
      JacC(112,117) = JacC(112,117)+ 0.1240000000000000D+01*dw(214,117)
      JacC(117, 94) = JacC(117, 94) - dw(214, 94)
      JacC(117,117) = JacC(117,117) - dw(214,117)
      JacC(119, 94) = JacC(119, 94)+ 0.2870000000000000D+00*dw(214, 94)
      JacC(119,117) = JacC(119,117)+ 0.2870000000000000D+00*dw(214,117)
      JacC(124, 94) = JacC(124, 94)+ 0.2000000000000000D+01*dw(214, 94)
      JacC(124,117) = JacC(124,117)+ 0.2000000000000000D+01*dw(214,117)
      JacC( 39,114) = JacC( 39,114) + dw(215,114)
      JacC( 39,123) = JacC( 39,123) + dw(215,123)
      JacC(114,114) = JacC(114,114) - dw(215,114)
      JacC(114,123) = JacC(114,123) - dw(215,123)
      JacC(123,114) = JacC(123,114) - dw(215,114)
      JacC(123,123) = JacC(123,123) - dw(215,123)
      JacC(113,113) = JacC(113,113) - dw(216,113)
      JacC(113,123) = JacC(113,123) - dw(216,123)
      JacC(115,113) = JacC(115,113) + dw(216,113)
      JacC(115,123) = JacC(115,123) + dw(216,123)
      JacC(123,113) = JacC(123,113) - dw(216,113)
      JacC(123,123) = JacC(123,123) - dw(216,123)
      JacC(110,110) = JacC(110,110) - dw(217,110)
      JacC(110,123) = JacC(110,123) - dw(217,123)
      JacC(115,110) = JacC(115,110) + dw(217,110)
      JacC(115,123) = JacC(115,123) + dw(217,123)
      JacC(123,110) = JacC(123,110) - dw(217,110)
      JacC(123,123) = JacC(123,123) - dw(217,123)
      JacC( 72, 72) = JacC( 72, 72) - dw(218, 72)
      JacC( 72,123) = JacC( 72,123) - dw(218,123)
      JacC(115, 72) = JacC(115, 72) + dw(218, 72)
      JacC(115,123) = JacC(115,123) + dw(218,123)
      JacC(123, 72) = JacC(123, 72) - dw(218, 72)
      JacC(123,123) = JacC(123,123) - dw(218,123)
      JacC( 75, 75) = JacC( 75, 75) - dw(219, 75)
      JacC( 75,123) = JacC( 75,123) - dw(219,123)
      JacC(115, 75) = JacC(115, 75) + dw(219, 75)
      JacC(115,123) = JacC(115,123) + dw(219,123)
      JacC(123, 75) = JacC(123, 75) - dw(219, 75)
      JacC(123,123) = JacC(123,123) - dw(219,123)
      JacC( 85, 85) = JacC( 85, 85) - dw(220, 85)
      JacC( 85,123) = JacC( 85,123) - dw(220,123)
      JacC(115, 85) = JacC(115, 85) + dw(220, 85)
      JacC(115,123) = JacC(115,123) + dw(220,123)
      JacC(123, 85) = JacC(123, 85) - dw(220, 85)
      JacC(123,123) = JacC(123,123) - dw(220,123)
      JacC( 70, 70) = JacC( 70, 70) - dw(221, 70)
      JacC( 70,123) = JacC( 70,123) - dw(221,123)
      JacC(115, 70) = JacC(115, 70) + dw(221, 70)
      JacC(115,123) = JacC(115,123) + dw(221,123)
      JacC(123, 70) = JacC(123, 70) - dw(221, 70)
      JacC(123,123) = JacC(123,123) - dw(221,123)
      JacC( 92, 92) = JacC( 92, 92) - dw(222, 92)
      JacC( 92,123) = JacC( 92,123) - dw(222,123)
      JacC(115, 92) = JacC(115, 92) + dw(222, 92)
      JacC(115,123) = JacC(115,123) + dw(222,123)
      JacC(123, 92) = JacC(123, 92) - dw(222, 92)
      JacC(123,123) = JacC(123,123) - dw(222,123)
      JacC( 29, 80) = JacC( 29, 80) + dw(223, 80)
      JacC( 29,123) = JacC( 29,123) + dw(223,123)
      JacC( 80, 80) = JacC( 80, 80) - dw(223, 80)
      JacC( 80,123) = JacC( 80,123) - dw(223,123)
      JacC(123, 80) = JacC(123, 80) - dw(223, 80)
      JacC(123,123) = JacC(123,123) - dw(223,123)
      JacC( 34,105) = JacC( 34,105) + dw(224,105)
      JacC( 34,123) = JacC( 34,123) + dw(224,123)
      JacC(105,105) = JacC(105,105) - dw(224,105)
      JacC(105,123) = JacC(105,123) - dw(224,123)
      JacC(123,105) = JacC(123,105) - dw(224,105)
      JacC(123,123) = JacC(123,123) - dw(224,123)
      JacC( 83, 83) = JacC( 83, 83) - dw(225, 83)
      JacC( 83,123) = JacC( 83,123) - dw(225,123)
      JacC(115, 83) = JacC(115, 83) + dw(225, 83)
      JacC(115,123) = JacC(115,123) + dw(225,123)
      JacC(123, 83) = JacC(123, 83) - dw(225, 83)
      JacC(123,123) = JacC(123,123) - dw(225,123)
      JacC( 88, 88) = JacC( 88, 88) - dw(226, 88)
      JacC( 88,123) = JacC( 88,123) - dw(226,123)
      JacC(115, 88) = JacC(115, 88) + dw(226, 88)
      JacC(115,123) = JacC(115,123) + dw(226,123)
      JacC(123, 88) = JacC(123, 88) - dw(226, 88)
      JacC(123,123) = JacC(123,123) - dw(226,123)
      JacC( 74, 74) = JacC( 74, 74) - dw(227, 74)
      JacC( 74,123) = JacC( 74,123) - dw(227,123)
      JacC(115, 74) = JacC(115, 74) + dw(227, 74)
      JacC(115,123) = JacC(115,123) + dw(227,123)
      JacC(123, 74) = JacC(123, 74) - dw(227, 74)
      JacC(123,123) = JacC(123,123) - dw(227,123)
      JacC( 79, 79) = JacC( 79, 79) - dw(228, 79)
      JacC( 79,123) = JacC( 79,123) - dw(228,123)
      JacC(115, 79) = JacC(115, 79) + dw(228, 79)
      JacC(115,123) = JacC(115,123) + dw(228,123)
      JacC(123, 79) = JacC(123, 79) - dw(228, 79)
      JacC(123,123) = JacC(123,123) - dw(228,123)
      JacC( 86, 86) = JacC( 86, 86) - dw(229, 86)
      JacC( 86,123) = JacC( 86,123) - dw(229,123)
      JacC(115, 86) = JacC(115, 86) + dw(229, 86)
      JacC(115,123) = JacC(115,123) + dw(229,123)
      JacC(123, 86) = JacC(123, 86) - dw(229, 86)
      JacC(123,123) = JacC(123,123) - dw(229,123)
      JacC( 54, 54) = JacC( 54, 54) - dw(230, 54)
      JacC( 54,123) = JacC( 54,123) - dw(230,123)
      JacC( 57, 54) = JacC( 57, 54)+ 0.7800000000000000D+00*dw(230, 54)
      JacC( 57,123) = JacC( 57,123)+ 0.7800000000000000D+00*dw(230,123)
      JacC(115, 54) = JacC(115, 54) + dw(230, 54)
      JacC(115,123) = JacC(115,123) + dw(230,123)
      JacC(123, 54) = JacC(123, 54) - dw(230, 54)
      JacC(123,123) = JacC(123,123) - dw(230,123)
      JacC( 56, 56) = JacC( 56, 56) - dw(231, 56)
      JacC( 56,123) = JacC( 56,123) - dw(231,123)
      JacC( 57, 56) = JacC( 57, 56)+ 0.7100000000000000D+00*dw(231, 56)
      JacC( 57,123) = JacC( 57,123)+ 0.7100000000000000D+00*dw(231,123)
      JacC(115, 56) = JacC(115, 56) + dw(231, 56)
      JacC(115,123) = JacC(115,123) + dw(231,123)
      JacC(123, 56) = JacC(123, 56) - dw(231, 56)
      JacC(123,123) = JacC(123,123) - dw(231,123)
      JacC( 57, 64) = JacC( 57, 64)+ 0.7100000000000000D+00*dw(232, 64)
      JacC( 57,123) = JacC( 57,123)+ 0.7100000000000000D+00*dw(232,123)
      JacC( 64, 64) = JacC( 64, 64) - dw(232, 64)
      JacC( 64,123) = JacC( 64,123) - dw(232,123)
      JacC(115, 64) = JacC(115, 64) + dw(232, 64)
      JacC(115,123) = JacC(115,123) + dw(232,123)
      JacC(123, 64) = JacC(123, 64) - dw(232, 64)
      JacC(123,123) = JacC(123,123) - dw(232,123)
      JacC( 78, 78) = JacC( 78, 78) - dw(233, 78)
      JacC( 78,123) = JacC( 78,123) - dw(233,123)
      JacC(115, 78) = JacC(115, 78) + dw(233, 78)
      JacC(115,123) = JacC(115,123) + dw(233,123)
      JacC(123, 78) = JacC(123, 78) - dw(233, 78)
      JacC(123,123) = JacC(123,123) - dw(233,123)
      JacC( 58, 60) = JacC( 58, 60) + dw(234, 60)
      JacC( 58,123) = JacC( 58,123) + dw(234,123)
      JacC( 60, 60) = JacC( 60, 60) - dw(234, 60)
      JacC( 60,123) = JacC( 60,123) - dw(234,123)
      JacC(123, 60) = JacC(123, 60) - dw(234, 60)
      JacC(123,123) = JacC(123,123) - dw(234,123)
      JacC( 71,118) = JacC( 71,118)+ 0.4000000000000000D+00*dw(235,118)
      JacC( 71,123) = JacC( 71,123)+ 0.4000000000000000D+00*dw(235,123)
      JacC(106,118) = JacC(106,118)+ 0.2000000000000000D+00*dw(235,118)
      JacC(106,123) = JacC(106,123)+ 0.2000000000000000D+00*dw(235,123)
      JacC(114,118) = JacC(114,118)+ 0.4000000000000000D+00*dw(235,118)
      JacC(114,123) = JacC(114,123)+ 0.4000000000000000D+00*dw(235,123)
      JacC(118,118) = JacC(118,118) - dw(235,118)
      JacC(118,123) = JacC(118,123) - dw(235,123)
      JacC(120,118) = JacC(120,118)+ 0.4000000000000000D+00*dw(235,118)
      JacC(120,123) = JacC(120,123)+ 0.4000000000000000D+00*dw(235,123)
      JacC(123,118) = JacC(123,118) - dw(235,118)
      JacC(123,123) = JacC(123,123) - dw(235,123)
      JacC( 71,122) = JacC( 71,122)+ 0.4000000000000000D+00*dw(236,122)
      JacC( 71,123) = JacC( 71,123)+ 0.4000000000000000D+00*dw(236,123)
      JacC(106,122) = JacC(106,122)+ 0.2000000000000000D+00*dw(236,122)
      JacC(106,123) = JacC(106,123)+ 0.2000000000000000D+00*dw(236,123)
      JacC(113,122) = JacC(113,122)+ 0.4000000000000000D+00*dw(236,122)
      JacC(113,123) = JacC(113,123)+ 0.4000000000000000D+00*dw(236,123)
      JacC(120,122) = JacC(120,122)+ 0.4000000000000000D+00*dw(236,122)
      JacC(120,123) = JacC(120,123)+ 0.4000000000000000D+00*dw(236,123)
      JacC(122,122) = JacC(122,122) - dw(236,122)
      JacC(122,123) = JacC(122,123) - dw(236,123)
      JacC(123,122) = JacC(123,122) - dw(236,122)
      JacC(123,123) = JacC(123,123) - dw(236,123)
      JacC( 98, 98) = JacC( 98, 98) - dw(237, 98)
      JacC( 98,123) = JacC( 98,123) - dw(237,123)
      JacC(115, 98) = JacC(115, 98)+ 0.3300000000000000D+00*dw(237, 98)
      JacC(115,123) = JacC(115,123)+ 0.3300000000000000D+00*dw(237,123)
      JacC(118, 98) = JacC(118, 98)+ 0.6700000000000000D+00*dw(237, 98)
      JacC(118,123) = JacC(118,123)+ 0.6700000000000000D+00*dw(237,123)
      JacC(119, 98) = JacC(119, 98)+ 0.6700000000000000D+00*dw(237, 98)
      JacC(119,123) = JacC(119,123)+ 0.6700000000000000D+00*dw(237,123)
      JacC(120, 98) = JacC(120, 98)+ 0.6700000000000000D+00*dw(237, 98)
      JacC(120,123) = JacC(120,123)+ 0.6700000000000000D+00*dw(237,123)
      JacC(123, 98) = JacC(123, 98) - dw(237, 98)
      JacC(123,123) = JacC(123,123) - dw(237,123)
      JacC( 68, 68) = JacC( 68, 68) - dw(238, 68)
      JacC( 68,123) = JacC( 68,123) - dw(238,123)
      JacC(115, 68) = JacC(115, 68) + dw(238, 68)
      JacC(115,123) = JacC(115,123) + dw(238,123)
      JacC(123, 68) = JacC(123, 68) - dw(238, 68)
      JacC(123,123) = JacC(123,123) - dw(238,123)
      JacC(101,101) = JacC(101,101) - dw(239,101)
      JacC(101,123) = JacC(101,123) - dw(239,123)
      JacC(115,101) = JacC(115,101) + dw(239,101)
      JacC(115,123) = JacC(115,123) + dw(239,123)
      JacC(123,101) = JacC(123,101) - dw(239,101)
      JacC(123,123) = JacC(123,123) - dw(239,123)
      JacC( 93, 93) = JacC( 93, 93) - dw(240, 93)
      JacC( 93,123) = JacC( 93,123) - dw(240,123)
      JacC(111, 93) = JacC(111, 93) + dw(240, 93)
      JacC(111,123) = JacC(111,123) + dw(240,123)
      JacC(123, 93) = JacC(123, 93) - dw(240, 93)
      JacC(123,123) = JacC(123,123) - dw(240,123)
      JacC( 94, 94) = JacC( 94, 94) - dw(241, 94)
      JacC( 94,123) = JacC( 94,123) - dw(241,123)
      JacC(111, 94) = JacC(111, 94) + dw(241, 94)
      JacC(111,123) = JacC(111,123) + dw(241,123)
      JacC(123, 94) = JacC(123, 94) - dw(241, 94)
      JacC(123,123) = JacC(123,123) - dw(241,123)
      JacC( 99,114) = JacC( 99,114)+ 0.6300000000000000D+00*dw(242,114)
      JacC( 99,114) = JacC( 99,114)+ 0.6300000000000000D+00*dw(242,114)
      JacC(114,114) = JacC(114,114)- 0.2000000000000000D+01*dw(242,114)
      JacC(114,114) = JacC(114,114)- 0.2000000000000000D+01*dw(242,114)
      JacC(119,114) = JacC(119,114)+ 0.1370000000000000D+01*dw(242,114)
      JacC(119,114) = JacC(119,114)+ 0.1370000000000000D+01*dw(242,114)
      JacC(123,114) = JacC(123,114)+ 0.7400000000000000D+00*dw(242,114)
      JacC(123,114) = JacC(123,114)+ 0.7400000000000000D+00*dw(242,114)
      JacC( 25,113) = JacC( 25,113)+ 0.2500000000000000D+00*dw(243,113)
      JacC( 25,114) = JacC( 25,114)+ 0.2500000000000000D+00*dw(243,114)
      JacC( 99,113) = JacC( 99,113)+ 0.2500000000000000D+00*dw(243,113)
      JacC( 99,114) = JacC( 99,114)+ 0.2500000000000000D+00*dw(243,114)
      JacC(100,113) = JacC(100,113)+ 0.7500000000000000D+00*dw(243,113)
      JacC(100,114) = JacC(100,114)+ 0.7500000000000000D+00*dw(243,114)
      JacC(113,113) = JacC(113,113) - dw(243,113)
      JacC(113,114) = JacC(113,114) - dw(243,114)
      JacC(114,113) = JacC(114,113) - dw(243,113)
      JacC(114,114) = JacC(114,114) - dw(243,114)
      JacC(119,113) = JacC(119,113)+ 0.7500000000000000D+00*dw(243,113)
      JacC(119,114) = JacC(119,114)+ 0.7500000000000000D+00*dw(243,114)
      JacC(123,113) = JacC(123,113) + dw(243,113)
      JacC(123,114) = JacC(123,114) + dw(243,114)
      JacC( 95,110) = JacC( 95,110)+ 0.2500000000000000D+00*dw(244,110)
      JacC( 95,114) = JacC( 95,114)+ 0.2500000000000000D+00*dw(244,114)
      JacC( 99,110) = JacC( 99,110)+ 0.2500000000000000D+00*dw(244,110)
      JacC( 99,114) = JacC( 99,114)+ 0.2500000000000000D+00*dw(244,114)
      JacC(104,110) = JacC(104,110)+ 0.5000000000000000D-01*dw(244,110)
      JacC(104,114) = JacC(104,114)+ 0.5000000000000000D-01*dw(244,114)
      JacC(109,110) = JacC(109,110)+ 0.4970000000000000D+00*dw(244,110)
      JacC(109,114) = JacC(109,114)+ 0.4970000000000000D+00*dw(244,114)
      JacC(110,110) = JacC(110,110) - dw(244,110)
      JacC(110,114) = JacC(110,114) - dw(244,114)
      JacC(112,110) = JacC(112,110)+ 0.1980000000000000D+00*dw(244,110)
      JacC(112,114) = JacC(112,114)+ 0.1980000000000000D+00*dw(244,114)
      JacC(113,110) = JacC(113,110)+ 0.2600000000000000D-01*dw(244,110)
      JacC(113,114) = JacC(113,114)+ 0.2600000000000000D-01*dw(244,114)
      JacC(114,110) = JacC(114,110)- 0.9200000000000000D+00*dw(244,110)
      JacC(114,114) = JacC(114,114)- 0.9200000000000000D+00*dw(244,114)
      JacC(116,110) = JacC(116,110)+ 0.2600000000000000D-01*dw(244,110)
      JacC(116,114) = JacC(116,114)+ 0.2600000000000000D-01*dw(244,114)
      JacC(119,110) = JacC(119,110)+ 0.8270000000000000D+00*dw(244,110)
      JacC(119,114) = JacC(119,114)+ 0.8270000000000000D+00*dw(244,114)
      JacC(123,110) = JacC(123,110)+ 0.8940000000000000D+00*dw(244,110)
      JacC(123,114) = JacC(123,114)+ 0.8940000000000000D+00*dw(244,114)
      JacC( 72, 72) = JacC( 72, 72) - dw(245, 72)
      JacC( 72,114) = JacC( 72,114) - dw(245,114)
      JacC( 95, 72) = JacC( 95, 72)+ 0.2500000000000000D+00*dw(245, 72)
      JacC( 95,114) = JacC( 95,114)+ 0.2500000000000000D+00*dw(245,114)
      JacC( 99, 72) = JacC( 99, 72)+ 0.2500000000000000D+00*dw(245, 72)
      JacC( 99,114) = JacC( 99,114)+ 0.2500000000000000D+00*dw(245,114)
      JacC(109, 72) = JacC(109, 72)+ 0.6180000000000000D+00*dw(245, 72)
      JacC(109,114) = JacC(109,114)+ 0.6180000000000000D+00*dw(245,114)
      JacC(112, 72) = JacC(112, 72)+ 0.2510000000000000D+00*dw(245, 72)
      JacC(112,114) = JacC(112,114)+ 0.2510000000000000D+00*dw(245,114)
      JacC(113, 72) = JacC(113, 72)+ 0.1400000000000000D+00*dw(245, 72)
      JacC(113,114) = JacC(113,114)+ 0.1400000000000000D+00*dw(245,114)
      JacC(114, 72) = JacC(114, 72)- 0.9820000000000000D+00*dw(245, 72)
      JacC(114,114) = JacC(114,114)- 0.9820000000000000D+00*dw(245,114)
      JacC(116, 72) = JacC(116, 72)+ 0.1910000000000000D+00*dw(245, 72)
      JacC(116,114) = JacC(116,114)+ 0.1910000000000000D+00*dw(245,114)
      JacC(119, 72) = JacC(119, 72)+ 0.7770000000000000D+00*dw(245, 72)
      JacC(119,114) = JacC(119,114)+ 0.7770000000000000D+00*dw(245,114)
      JacC(123, 72) = JacC(123, 72)+ 0.8420000000000000D+00*dw(245, 72)
      JacC(123,114) = JacC(123,114)+ 0.8420000000000000D+00*dw(245,114)
      JacC( 75, 75) = JacC( 75, 75) - dw(246, 75)
      JacC( 75,114) = JacC( 75,114) - dw(246,114)
      JacC( 95, 75) = JacC( 95, 75)+ 0.2500000000000000D+00*dw(246, 75)
      JacC( 95,114) = JacC( 95,114)+ 0.2500000000000000D+00*dw(246,114)
      JacC( 99, 75) = JacC( 99, 75)+ 0.2500000000000000D+00*dw(246, 75)
      JacC( 99,114) = JacC( 99,114)+ 0.2500000000000000D+00*dw(246,114)
      JacC(109, 75) = JacC(109, 75)+ 0.6520000000000000D+00*dw(246, 75)
      JacC(109,114) = JacC(109,114)+ 0.6520000000000000D+00*dw(246,114)
      JacC(112, 75) = JacC(112, 75)+ 0.1970000000000000D+00*dw(246, 75)
      JacC(112,114) = JacC(112,114)+ 0.1970000000000000D+00*dw(246,114)
      JacC(113, 75) = JacC(113, 75)+ 0.9000000000000000D-01*dw(246, 75)
      JacC(113,114) = JacC(113,114)+ 0.9000000000000000D-01*dw(246,114)
      JacC(114, 75) = JacC(114, 75) - dw(246, 75)
      JacC(114,114) = JacC(114,114) - dw(246,114)
      JacC(116, 75) = JacC(116, 75)+ 0.2810000000000000D+00*dw(246, 75)
      JacC(116,114) = JacC(116,114)+ 0.2810000000000000D+00*dw(246,114)
      JacC(119, 75) = JacC(119, 75)+ 0.7500000000000000D+00*dw(246, 75)
      JacC(119,114) = JacC(119,114)+ 0.7500000000000000D+00*dw(246,114)
      JacC(123, 75) = JacC(123, 75)+ 0.9100000000000000D+00*dw(246, 75)
      JacC(123,114) = JacC(123,114)+ 0.9100000000000000D+00*dw(246,114)
      JacC( 28, 85) = JacC( 28, 85)+ 0.2500000000000000D+00*dw(247, 85)
      JacC( 28,114) = JacC( 28,114)+ 0.2500000000000000D+00*dw(247,114)
      JacC( 85, 85) = JacC( 85, 85) - dw(247, 85)
      JacC( 85,114) = JacC( 85,114) - dw(247,114)
      JacC( 99, 85) = JacC( 99, 85)+ 0.2500000000000000D+00*dw(247, 85)
      JacC( 99,114) = JacC( 99,114)+ 0.2500000000000000D+00*dw(247,114)
      JacC(112, 85) = JacC(112, 85)+ 0.1500000000000000D+00*dw(247, 85)
      JacC(112,114) = JacC(112,114)+ 0.1500000000000000D+00*dw(247,114)
      JacC(114, 85) = JacC(114, 85) - dw(247, 85)
      JacC(114,114) = JacC(114,114) - dw(247,114)
      JacC(119, 85) = JacC(119, 85)+ 0.1950000000000000D+01*dw(247, 85)
      JacC(119,114) = JacC(119,114)+ 0.1950000000000000D+01*dw(247,114)
      JacC(123, 85) = JacC(123, 85) + dw(247, 85)
      JacC(123,114) = JacC(123,114) + dw(247,114)
      JacC( 70, 70) = JacC( 70, 70) - dw(248, 70)
      JacC( 70,114) = JacC( 70,114) - dw(248,114)
      JacC( 95, 70) = JacC( 95, 70)+ 0.2500000000000000D+00*dw(248, 70)
      JacC( 95,114) = JacC( 95,114)+ 0.2500000000000000D+00*dw(248,114)
      JacC( 99, 70) = JacC( 99, 70)+ 0.2500000000000000D+00*dw(248, 70)
      JacC( 99,114) = JacC( 99,114)+ 0.2500000000000000D+00*dw(248,114)
      JacC(109, 70) = JacC(109, 70)+ 0.4500000000000000D-01*dw(248, 70)
      JacC(109,114) = JacC(109,114)+ 0.4500000000000000D-01*dw(248,114)
      JacC(112, 70) = JacC(112, 70)+ 0.7050000000000000D+00*dw(248, 70)
      JacC(112,114) = JacC(112,114)+ 0.7050000000000000D+00*dw(248,114)
      JacC(114, 70) = JacC(114, 70) - dw(248, 70)
      JacC(114,114) = JacC(114,114) - dw(248,114)
      JacC(119, 70) = JacC(119, 70)+ 0.1500000000000000D+01*dw(248, 70)
      JacC(119,114) = JacC(119,114)+ 0.1500000000000000D+01*dw(248,114)
      JacC(123, 70) = JacC(123, 70) + dw(248, 70)
      JacC(123,114) = JacC(123,114) + dw(248,114)
      JacC( 92, 92) = JacC( 92, 92) - dw(249, 92)
      JacC( 92,114) = JacC( 92,114) - dw(249,114)
      JacC( 95, 92) = JacC( 95, 92)+ 0.2500000000000000D+00*dw(249, 92)
      JacC( 95,114) = JacC( 95,114)+ 0.2500000000000000D+00*dw(249,114)
      JacC( 99, 92) = JacC( 99, 92)+ 0.2500000000000000D+00*dw(249, 92)
      JacC( 99,114) = JacC( 99,114)+ 0.2500000000000000D+00*dw(249,114)
      JacC(109, 92) = JacC(109, 92)+ 0.2180000000000000D+00*dw(249, 92)
      JacC(109,114) = JacC(109,114)+ 0.2180000000000000D+00*dw(249,114)
      JacC(112, 92) = JacC(112, 92)+ 0.1280000000000000D+01*dw(249, 92)
      JacC(112,114) = JacC(112,114)+ 0.1280000000000000D+01*dw(249,114)
      JacC(114, 92) = JacC(114, 92) - dw(249, 92)
      JacC(114,114) = JacC(114,114) - dw(249,114)
      JacC(119, 92) = JacC(119, 92)+ 0.7500000000000000D+00*dw(249, 92)
      JacC(119,114) = JacC(119,114)+ 0.7500000000000000D+00*dw(249,114)
      JacC(123, 92) = JacC(123, 92) + dw(249, 92)
      JacC(123,114) = JacC(123,114) + dw(249,114)
      JacC( 80, 80) = JacC( 80, 80) - dw(250, 80)
      JacC( 80,114) = JacC( 80,114) - dw(250,114)
      JacC( 81, 80) = JacC( 81, 80)+ 0.3050000000000000D+00*dw(250, 80)
      JacC( 81,114) = JacC( 81,114)+ 0.3050000000000000D+00*dw(250,114)
      JacC( 84, 80) = JacC( 84, 80)+ 0.2190000000000000D+00*dw(250, 80)
      JacC( 84,114) = JacC( 84,114)+ 0.2190000000000000D+00*dw(250,114)
      JacC( 95, 80) = JacC( 95, 80)+ 0.2500000000000000D+00*dw(250, 80)
      JacC( 95,114) = JacC( 95,114)+ 0.2500000000000000D+00*dw(250,114)
      JacC( 99, 80) = JacC( 99, 80)+ 0.2500000000000000D+00*dw(250, 80)
      JacC( 99,114) = JacC( 99,114)+ 0.2500000000000000D+00*dw(250,114)
      JacC(114, 80) = JacC(114, 80) - dw(250, 80)
      JacC(114,114) = JacC(114,114) - dw(250,114)
      JacC(119, 80) = JacC(119, 80)+ 0.1540000000000000D+01*dw(250, 80)
      JacC(119,114) = JacC(119,114)+ 0.1540000000000000D+01*dw(250,114)
      JacC(123, 80) = JacC(123, 80) + dw(250, 80)
      JacC(123,114) = JacC(123,114) + dw(250,114)
      JacC( 76,105) = JacC( 76,105)+ 0.1670000000000000D+00*dw(251,105)
      JacC( 76,114) = JacC( 76,114)+ 0.1670000000000000D+00*dw(251,114)
      JacC( 95,105) = JacC( 95,105)+ 0.2500000000000000D+00*dw(251,105)
      JacC( 95,114) = JacC( 95,114)+ 0.2500000000000000D+00*dw(251,114)
      JacC( 99,105) = JacC( 99,105)+ 0.2500000000000000D+00*dw(251,105)
      JacC( 99,114) = JacC( 99,114)+ 0.2500000000000000D+00*dw(251,114)
      JacC(102,105) = JacC(102,105)+ 0.3330000000000000D+00*dw(251,105)
      JacC(102,114) = JacC(102,114)+ 0.3330000000000000D+00*dw(251,114)
      JacC(105,105) = JacC(105,105) - dw(251,105)
      JacC(105,114) = JacC(105,114) - dw(251,114)
      JacC(106,105) = JacC(106,105)+ 0.4200000000000000D-01*dw(251,105)
      JacC(106,114) = JacC(106,114)+ 0.4200000000000000D-01*dw(251,114)
      JacC(108,105) = JacC(108,105)+ 0.1670000000000000D+00*dw(251,105)
      JacC(108,114) = JacC(108,114)+ 0.1670000000000000D+00*dw(251,114)
      JacC(114,105) = JacC(114,105) - dw(251,105)
      JacC(114,114) = JacC(114,114) - dw(251,114)
      JacC(118,105) = JacC(118,105)+ 0.1670000000000000D+00*dw(251,105)
      JacC(118,114) = JacC(118,114)+ 0.1670000000000000D+00*dw(251,114)
      JacC(119,105) = JacC(119,105)+ 0.1500000000000000D+01*dw(251,105)
      JacC(119,114) = JacC(119,114)+ 0.1500000000000000D+01*dw(251,114)
      JacC(123,105) = JacC(123,105) + dw(251,105)
      JacC(123,114) = JacC(123,114) + dw(251,114)
      JacC( 83, 83) = JacC( 83, 83) - dw(252, 83)
      JacC( 83,114) = JacC( 83,114) - dw(252,114)
      JacC( 95, 83) = JacC( 95, 83)+ 0.2500000000000000D+00*dw(252, 83)
      JacC( 95,114) = JacC( 95,114)+ 0.2500000000000000D+00*dw(252,114)
      JacC( 99, 83) = JacC( 99, 83)+ 0.2500000000000000D+00*dw(252, 83)
      JacC( 99,114) = JacC( 99,114)+ 0.2500000000000000D+00*dw(252,114)
      JacC(102, 83) = JacC(102, 83)+ 0.5000000000000000D+00*dw(252, 83)
      JacC(102,114) = JacC(102,114)+ 0.5000000000000000D+00*dw(252,114)
      JacC(106, 83) = JacC(106, 83)+ 0.2920000000000000D+00*dw(252, 83)
      JacC(106,114) = JacC(106,114)+ 0.2920000000000000D+00*dw(252,114)
      JacC(112, 83) = JacC(112, 83)+ 0.1750000000000000D+01*dw(252, 83)
      JacC(112,114) = JacC(112,114)+ 0.1750000000000000D+01*dw(252,114)
      JacC(114, 83) = JacC(114, 83) - dw(252, 83)
      JacC(114,114) = JacC(114,114) - dw(252,114)
      JacC(116, 83) = JacC(116, 83)+ 0.1160000000000000D+01*dw(252, 83)
      JacC(116,114) = JacC(116,114)+ 0.1160000000000000D+01*dw(252,114)
      JacC(118, 83) = JacC(118, 83)+ 0.1160000000000000D+01*dw(252, 83)
      JacC(118,114) = JacC(118,114)+ 0.1160000000000000D+01*dw(252,114)
      JacC(119, 83) = JacC(119, 83)+ 0.1500000000000000D+01*dw(252, 83)
      JacC(119,114) = JacC(119,114)+ 0.1500000000000000D+01*dw(252,114)
      JacC(123, 83) = JacC(123, 83) + dw(252, 83)
      JacC(123,114) = JacC(123,114) + dw(252,114)
      JacC( 88, 88) = JacC( 88, 88) - dw(253, 88)
      JacC( 88,114) = JacC( 88,114) - dw(253,114)
      JacC( 95, 88) = JacC( 95, 88)+ 0.2500000000000000D+00*dw(253, 88)
      JacC( 95,114) = JacC( 95,114)+ 0.2500000000000000D+00*dw(253,114)
      JacC( 99, 88) = JacC( 99, 88)+ 0.2500000000000000D+00*dw(253, 88)
      JacC( 99,114) = JacC( 99,114)+ 0.2500000000000000D+00*dw(253,114)
      JacC(102, 88) = JacC(102, 88)+ 0.1050000000000000D+00*dw(253, 88)
      JacC(102,114) = JacC(102,114)+ 0.1050000000000000D+00*dw(253,114)
      JacC(104, 88) = JacC(104, 88)+ 0.1350000000000000D+00*dw(253, 88)
      JacC(104,114) = JacC(104,114)+ 0.1350000000000000D+00*dw(253,114)
      JacC(108, 88) = JacC(108, 88)+ 0.3050000000000000D+00*dw(253, 88)
      JacC(108,114) = JacC(108,114)+ 0.3050000000000000D+00*dw(253,114)
      JacC(109, 88) = JacC(109, 88)+ 0.5250000000000000D+00*dw(253, 88)
      JacC(109,114) = JacC(109,114)+ 0.5250000000000000D+00*dw(253,114)
      JacC(112, 88) = JacC(112, 88)+ 0.2030000000000000D+00*dw(253, 88)
      JacC(112,114) = JacC(112,114)+ 0.2030000000000000D+00*dw(253,114)
      JacC(114, 88) = JacC(114, 88) - dw(253, 88)
      JacC(114,114) = JacC(114,114) - dw(253,114)
      JacC(119, 88) = JacC(119, 88)+ 0.7730000000000000D+00*dw(253, 88)
      JacC(119,114) = JacC(119,114)+ 0.7730000000000000D+00*dw(253,114)
      JacC(123, 88) = JacC(123, 88) + dw(253, 88)
      JacC(123,114) = JacC(123,114) + dw(253,114)
      JacC( 74, 74) = JacC( 74, 74) - dw(254, 74)
      JacC( 74,114) = JacC( 74,114) - dw(254,114)
      JacC( 95, 74) = JacC( 95, 74)+ 0.2500000000000000D+00*dw(254, 74)
      JacC( 95,114) = JacC( 95,114)+ 0.2500000000000000D+00*dw(254,114)
      JacC( 99, 74) = JacC( 99, 74)+ 0.2500000000000000D+00*dw(254, 74)
      JacC( 99,114) = JacC( 99,114)+ 0.2500000000000000D+00*dw(254,114)
      JacC(109, 74) = JacC(109, 74)+ 0.7500000000000000D+00*dw(254, 74)
      JacC(109,114) = JacC(109,114)+ 0.7500000000000000D+00*dw(254,114)
      JacC(112, 74) = JacC(112, 74)+ 0.7500000000000000D+00*dw(254, 74)
      JacC(112,114) = JacC(112,114)+ 0.7500000000000000D+00*dw(254,114)
      JacC(114, 74) = JacC(114, 74) - dw(254, 74)
      JacC(114,114) = JacC(114,114) - dw(254,114)
      JacC(119, 74) = JacC(119, 74)+ 0.7500000000000000D+00*dw(254, 74)
      JacC(119,114) = JacC(119,114)+ 0.7500000000000000D+00*dw(254,114)
      JacC(123, 74) = JacC(123, 74) + dw(254, 74)
      JacC(123,114) = JacC(123,114) + dw(254,114)
      JacC( 79, 79) = JacC( 79, 79) - dw(255, 79)
      JacC( 79,114) = JacC( 79,114) - dw(255,114)
      JacC( 84, 79) = JacC( 84, 79)+ 0.3080000000000000D+00*dw(255, 79)
      JacC( 84,114) = JacC( 84,114)+ 0.3080000000000000D+00*dw(255,114)
      JacC( 89, 79) = JacC( 89, 79)+ 0.1920000000000000D+00*dw(255, 79)
      JacC( 89,114) = JacC( 89,114)+ 0.1920000000000000D+00*dw(255,114)
      JacC( 95, 79) = JacC( 95, 79)+ 0.2500000000000000D+00*dw(255, 79)
      JacC( 95,114) = JacC( 95,114)+ 0.2500000000000000D+00*dw(255,114)
      JacC( 99, 79) = JacC( 99, 79)+ 0.2500000000000000D+00*dw(255, 79)
      JacC( 99,114) = JacC( 99,114)+ 0.2500000000000000D+00*dw(255,114)
      JacC(114, 79) = JacC(114, 79) - dw(255, 79)
      JacC(114,114) = JacC(114,114) - dw(255,114)
      JacC(119, 79) = JacC(119, 79)+ 0.1040000000000000D+01*dw(255, 79)
      JacC(119,114) = JacC(119,114)+ 0.1040000000000000D+01*dw(255,114)
      JacC(123, 79) = JacC(123, 79) + dw(255, 79)
      JacC(123,114) = JacC(123,114) + dw(255,114)
      JacC( 86, 86) = JacC( 86, 86) - dw(256, 86)
      JacC( 86,114) = JacC( 86,114) - dw(256,114)
      JacC( 87, 86) = JacC( 87, 86)+ 0.7000000000000000D+00*dw(256, 86)
      JacC( 87,114) = JacC( 87,114)+ 0.7000000000000000D+00*dw(256,114)
      JacC( 89, 86) = JacC( 89, 86)+ 0.3000000000000000D+00*dw(256, 86)
      JacC( 89,114) = JacC( 89,114)+ 0.3000000000000000D+00*dw(256,114)
      JacC(104, 86) = JacC(104, 86)+ 0.6000000000000000D+00*dw(256, 86)
      JacC(104,114) = JacC(104,114)+ 0.6000000000000000D+00*dw(256,114)
      JacC(114, 86) = JacC(114, 86) - dw(256, 86)
      JacC(114,114) = JacC(114,114) - dw(256,114)
      JacC(119, 86) = JacC(119, 86) + dw(256, 86)
      JacC(119,114) = JacC(119,114) + dw(256,114)
      JacC(123, 86) = JacC(123, 86)+ 0.2600000000000000D+01*dw(256, 86)
      JacC(123,114) = JacC(123,114)+ 0.2600000000000000D+01*dw(256,114)
      JacC( 54, 54) = JacC( 54, 54) - dw(257, 54)
      JacC( 54,114) = JacC( 54,114) - dw(257,114)
      JacC( 57, 54) = JacC( 57, 54)+ 0.7800000000000000D+00*dw(257, 54)
      JacC( 57,114) = JacC( 57,114)+ 0.7800000000000000D+00*dw(257,114)
      JacC( 65, 54) = JacC( 65, 54) + dw(257, 54)
      JacC( 65,114) = JacC( 65,114) + dw(257,114)
      JacC(104, 54) = JacC(104, 54)+ 0.2710000000000000D+00*dw(257, 54)
      JacC(104,114) = JacC(104,114)+ 0.2710000000000000D+00*dw(257,114)
      JacC(114, 54) = JacC(114, 54) - dw(257, 54)
      JacC(114,114) = JacC(114,114) - dw(257,114)
      JacC(119, 54) = JacC(119, 54) + dw(257, 54)
      JacC(119,114) = JacC(119,114) + dw(257,114)
      JacC(123, 54) = JacC(123, 54)+ 0.2000000000000000D+01*dw(257, 54)
      JacC(123,114) = JacC(123,114)+ 0.2000000000000000D+01*dw(257,114)
      JacC( 53, 53) = JacC( 53, 53) - dw(258, 53)
      JacC( 53,114) = JacC( 53,114) - dw(258,114)
      JacC( 63, 53) = JacC( 63, 53) + dw(258, 53)
      JacC( 63,114) = JacC( 63,114) + dw(258,114)
      JacC(114, 53) = JacC(114, 53) - dw(258, 53)
      JacC(114,114) = JacC(114,114) - dw(258,114)
      JacC(119, 53) = JacC(119, 53) + dw(258, 53)
      JacC(119,114) = JacC(119,114) + dw(258,114)
      JacC(123, 53) = JacC(123, 53) + dw(258, 53)
      JacC(123,114) = JacC(123,114) + dw(258,114)
      JacC( 52, 52) = JacC( 52, 52) - dw(259, 52)
      JacC( 52,114) = JacC( 52,114) - dw(259,114)
      JacC( 69, 52) = JacC( 69, 52) + dw(259, 52)
      JacC( 69,114) = JacC( 69,114) + dw(259,114)
      JacC(102, 52) = JacC(102, 52) + dw(259, 52)
      JacC(102,114) = JacC(102,114) + dw(259,114)
      JacC(114, 52) = JacC(114, 52) - dw(259, 52)
      JacC(114,114) = JacC(114,114) - dw(259,114)
      JacC(119, 52) = JacC(119, 52) + dw(259, 52)
      JacC(119,114) = JacC(119,114) + dw(259,114)
      JacC(123, 52) = JacC(123, 52)+ 0.2000000000000000D+01*dw(259, 52)
      JacC(123,114) = JacC(123,114)+ 0.2000000000000000D+01*dw(259,114)
      JacC( 57, 64) = JacC( 57, 64)+ 0.7100000000000000D+00*dw(260, 64)
      JacC( 57,114) = JacC( 57,114)+ 0.7100000000000000D+00*dw(260,114)
      JacC( 64, 64) = JacC( 64, 64) - dw(260, 64)
      JacC( 64,114) = JacC( 64,114) - dw(260,114)
      JacC( 65, 64) = JacC( 65, 64)+ 0.7700000000000000D-01*dw(260, 64)
      JacC( 65,114) = JacC( 65,114)+ 0.7700000000000000D-01*dw(260,114)
      JacC( 69, 64) = JacC( 69, 64)+ 0.7370000000000000D+00*dw(260, 64)
      JacC( 69,114) = JacC( 69,114)+ 0.7370000000000000D+00*dw(260,114)
      JacC( 91, 64) = JacC( 91, 64)+ 0.1860000000000000D+00*dw(260, 64)
      JacC( 91,114) = JacC( 91,114)+ 0.1860000000000000D+00*dw(260,114)
      JacC(102, 64) = JacC(102, 64)+ 0.6320000000000000D+00*dw(260, 64)
      JacC(102,114) = JacC(102,114)+ 0.6320000000000000D+00*dw(260,114)
      JacC(104, 64) = JacC(104, 64)+ 0.3680000000000000D+00*dw(260, 64)
      JacC(104,114) = JacC(104,114)+ 0.3680000000000000D+00*dw(260,114)
      JacC(114, 64) = JacC(114, 64) - dw(260, 64)
      JacC(114,114) = JacC(114,114) - dw(260,114)
      JacC(119, 64) = JacC(119, 64) + dw(260, 64)
      JacC(119,114) = JacC(119,114) + dw(260,114)
      JacC(123, 64) = JacC(123, 64)+ 0.2000000000000000D+01*dw(260, 64)
      JacC(123,114) = JacC(123,114)+ 0.2000000000000000D+01*dw(260,114)
      JacC( 55, 55) = JacC( 55, 55) - dw(261, 55)
      JacC( 55,114) = JacC( 55,114) - dw(261,114)
      JacC( 63, 55) = JacC( 63, 55) + dw(261, 55)
      JacC( 63,114) = JacC( 63,114) + dw(261,114)
      JacC(114, 55) = JacC(114, 55) - dw(261, 55)
      JacC(114,114) = JacC(114,114) - dw(261,114)
      JacC(119, 55) = JacC(119, 55) + dw(261, 55)
      JacC(119,114) = JacC(119,114) + dw(261,114)
      JacC(123, 55) = JacC(123, 55) + dw(261, 55)
      JacC(123,114) = JacC(123,114) + dw(261,114)
      JacC( 56, 56) = JacC( 56, 56) - dw(262, 56)
      JacC( 56,114) = JacC( 56,114) - dw(262,114)
      JacC( 57, 56) = JacC( 57, 56)+ 0.7100000000000000D+00*dw(262, 56)
      JacC( 57,114) = JacC( 57,114)+ 0.7100000000000000D+00*dw(262,114)
      JacC( 65, 56) = JacC( 65, 56) + dw(262, 56)
      JacC( 65,114) = JacC( 65,114) + dw(262,114)
      JacC(114, 56) = JacC(114, 56) - dw(262, 56)
      JacC(114,114) = JacC(114,114) - dw(262,114)
      JacC(119, 56) = JacC(119, 56) + dw(262, 56)
      JacC(119,114) = JacC(119,114) + dw(262,114)
      JacC(123, 56) = JacC(123, 56)+ 0.2000000000000000D+01*dw(262, 56)
      JacC(123,114) = JacC(123,114)+ 0.2000000000000000D+01*dw(262,114)
      JacC( 62, 62) = JacC( 62, 62) - dw(263, 62)
      JacC( 62,114) = JacC( 62,114) - dw(263,114)
      JacC( 69, 62) = JacC( 69, 62) + dw(263, 62)
      JacC( 69,114) = JacC( 69,114) + dw(263,114)
      JacC( 91, 62) = JacC( 91, 62)+ 0.2050000000000000D+01*dw(263, 62)
      JacC( 91,114) = JacC( 91,114)+ 0.2050000000000000D+01*dw(263,114)
      JacC(102, 62) = JacC(102, 62) + dw(263, 62)
      JacC(102,114) = JacC(102,114) + dw(263,114)
      JacC(114, 62) = JacC(114, 62) - dw(263, 62)
      JacC(114,114) = JacC(114,114) - dw(263,114)
      JacC(119, 62) = JacC(119, 62) + dw(263, 62)
      JacC(119,114) = JacC(119,114) + dw(263,114)
      JacC(123, 62) = JacC(123, 62)+ 0.2000000000000000D+01*dw(263, 62)
      JacC(123,114) = JacC(123,114)+ 0.2000000000000000D+01*dw(263,114)
      JacC( 50, 67) = JacC( 50, 67) + dw(264, 67)
      JacC( 50,114) = JacC( 50,114) + dw(264,114)
      JacC( 67, 67) = JacC( 67, 67) - dw(264, 67)
      JacC( 67,114) = JacC( 67,114) - dw(264,114)
      JacC(114, 67) = JacC(114, 67) - dw(264, 67)
      JacC(114,114) = JacC(114,114) - dw(264,114)
      JacC(119, 67) = JacC(119, 67) + dw(264, 67)
      JacC(119,114) = JacC(119,114) + dw(264,114)
      JacC(123, 67) = JacC(123, 67) + dw(264, 67)
      JacC(123,114) = JacC(123,114) + dw(264,114)
      JacC( 50, 50) = JacC( 50, 50) - dw(265, 50)
      JacC( 50,114) = JacC( 50,114) - dw(265,114)
      JacC( 51, 50) = JacC( 51, 50) + dw(265, 50)
      JacC( 51,114) = JacC( 51,114) + dw(265,114)
      JacC(114, 50) = JacC(114, 50) - dw(265, 50)
      JacC(114,114) = JacC(114,114) - dw(265,114)
      JacC(119, 50) = JacC(119, 50) + dw(265, 50)
      JacC(119,114) = JacC(119,114) + dw(265,114)
      JacC(123, 50) = JacC(123, 50) + dw(265, 50)
      JacC(123,114) = JacC(123,114) + dw(265,114)
      JacC( 77, 78) = JacC( 77, 78)+ 0.3200000000000000D+00*dw(266, 78)
      JacC( 77,114) = JacC( 77,114)+ 0.3200000000000000D+00*dw(266,114)
      JacC( 78, 78) = JacC( 78, 78) - dw(266, 78)
      JacC( 78,114) = JacC( 78,114) - dw(266,114)
      JacC(104, 78) = JacC(104, 78)+ 0.6800000000000000D+00*dw(266, 78)
      JacC(104,114) = JacC(104,114)+ 0.6800000000000000D+00*dw(266,114)
      JacC(114, 78) = JacC(114, 78) - dw(266, 78)
      JacC(114,114) = JacC(114,114) - dw(266,114)
      JacC(115, 78) = JacC(115, 78)+ 0.6800000000000000D+00*dw(266, 78)
      JacC(115,114) = JacC(115,114)+ 0.6800000000000000D+00*dw(266,114)
      JacC(119, 78) = JacC(119, 78) + dw(266, 78)
      JacC(119,114) = JacC(119,114) + dw(266,114)
      JacC(123, 78) = JacC(123, 78)+ 0.2000000000000000D+01*dw(266, 78)
      JacC(123,114) = JacC(123,114)+ 0.2000000000000000D+01*dw(266,114)
      JacC(106,118) = JacC(106,118)+ 0.1000000000000000D+00*dw(267,118)
      JacC(106,114) = JacC(106,114)+ 0.1000000000000000D+00*dw(267,114)
      JacC(114,118) = JacC(114,118)- 0.9999999999999998D-01*dw(267,118)
      JacC(114,114) = JacC(114,114)- 0.9999999999999998D-01*dw(267,114)
      JacC(118,118) = JacC(118,118) - dw(267,118)
      JacC(118,114) = JacC(118,114) - dw(267,114)
      JacC(119,118) = JacC(119,118) + dw(267,118)
      JacC(119,114) = JacC(119,114) + dw(267,114)
      JacC(123,118) = JacC(123,118)+ 0.9000000000000000D+00*dw(267,118)
      JacC(123,114) = JacC(123,114)+ 0.9000000000000000D+00*dw(267,114)
      JacC(106,122) = JacC(106,122)+ 0.1000000000000000D+00*dw(268,122)
      JacC(106,114) = JacC(106,114)+ 0.1000000000000000D+00*dw(268,114)
      JacC(114,122) = JacC(114,122)- 0.9999999999999998D-01*dw(268,122)
      JacC(114,114) = JacC(114,114)- 0.9999999999999998D-01*dw(268,114)
      JacC(119,122) = JacC(119,122) + dw(268,122)
      JacC(119,114) = JacC(119,114) + dw(268,114)
      JacC(122,122) = JacC(122,122) - dw(268,122)
      JacC(122,114) = JacC(122,114) - dw(268,114)
      JacC(123,122) = JacC(123,122)+ 0.9000000000000000D+00*dw(268,122)
      JacC(123,114) = JacC(123,114)+ 0.9000000000000000D+00*dw(268,114)
      JacC( 95, 98) = JacC( 95, 98)+ 0.2500000000000000D+00*dw(269, 98)
      JacC( 95,114) = JacC( 95,114)+ 0.2500000000000000D+00*dw(269,114)
      JacC( 98, 98) = JacC( 98, 98) - dw(269, 98)
      JacC( 98,114) = JacC( 98,114) - dw(269,114)
      JacC( 99, 98) = JacC( 99, 98)+ 0.2500000000000000D+00*dw(269, 98)
      JacC( 99,114) = JacC( 99,114)+ 0.2500000000000000D+00*dw(269,114)
      JacC(106, 98) = JacC(106, 98)+ 0.1250000000000000D+00*dw(269, 98)
      JacC(106,114) = JacC(106,114)+ 0.1250000000000000D+00*dw(269,114)
      JacC(114, 98) = JacC(114, 98) - dw(269, 98)
      JacC(114,114) = JacC(114,114) - dw(269,114)
      JacC(118, 98) = JacC(118, 98)+ 0.5000000000000000D+00*dw(269, 98)
      JacC(118,114) = JacC(118,114)+ 0.5000000000000000D+00*dw(269,114)
      JacC(119, 98) = JacC(119, 98)+ 0.1500000000000000D+01*dw(269, 98)
      JacC(119,114) = JacC(119,114)+ 0.1500000000000000D+01*dw(269,114)
      JacC(123, 98) = JacC(123, 98)+ 0.5000000000000000D+00*dw(269, 98)
      JacC(123,114) = JacC(123,114)+ 0.5000000000000000D+00*dw(269,114)
      JacC( 68, 68) = JacC( 68, 68) - dw(270, 68)
      JacC( 68,114) = JacC( 68,114) - dw(270,114)
      JacC( 69, 68) = JacC( 69, 68)+ 0.3340000000000000D+00*dw(270, 68)
      JacC( 69,114) = JacC( 69,114)+ 0.3340000000000000D+00*dw(270,114)
      JacC( 95, 68) = JacC( 95, 68)+ 0.2500000000000000D+00*dw(270, 68)
      JacC( 95,114) = JacC( 95,114)+ 0.2500000000000000D+00*dw(270,114)
      JacC( 99, 68) = JacC( 99, 68)+ 0.2500000000000000D+00*dw(270, 68)
      JacC( 99,114) = JacC( 99,114)+ 0.2500000000000000D+00*dw(270,114)
      JacC(114, 68) = JacC(114, 68) - dw(270, 68)
      JacC(114,114) = JacC(114,114) - dw(270,114)
      JacC(119, 68) = JacC(119, 68) + dw(270, 68)
      JacC(119,114) = JacC(119,114) + dw(270,114)
      JacC(123, 68) = JacC(123, 68)+ 0.8340000000000000D+00*dw(270, 68)
      JacC(123,114) = JacC(123,114)+ 0.8340000000000000D+00*dw(270,114)
      JacC( 69,101) = JacC( 69,101)+ 0.5000000000000000D+00*dw(271,101)
      JacC( 69,114) = JacC( 69,114)+ 0.5000000000000000D+00*dw(271,114)
      JacC( 95,101) = JacC( 95,101)+ 0.2500000000000000D+00*dw(271,101)
      JacC( 95,114) = JacC( 95,114)+ 0.2500000000000000D+00*dw(271,114)
      JacC( 99,101) = JacC( 99,101)+ 0.2500000000000000D+00*dw(271,101)
      JacC( 99,114) = JacC( 99,114)+ 0.2500000000000000D+00*dw(271,114)
      JacC(101,101) = JacC(101,101) - dw(271,101)
      JacC(101,114) = JacC(101,114) - dw(271,114)
      JacC(114,101) = JacC(114,101) - dw(271,101)
      JacC(114,114) = JacC(114,114) - dw(271,114)
      JacC(119,101) = JacC(119,101)+ 0.7500000000000000D+00*dw(271,101)
      JacC(119,114) = JacC(119,114)+ 0.7500000000000000D+00*dw(271,114)
      JacC(123,101) = JacC(123,101) + dw(271,101)
      JacC(123,114) = JacC(123,114) + dw(271,114)
      JacC( 93, 93) = JacC( 93, 93) - dw(272, 93)
      JacC( 93,114) = JacC( 93,114) - dw(272,114)
      JacC(111, 93) = JacC(111, 93) + dw(272, 93)
      JacC(111,114) = JacC(111,114) + dw(272,114)
      JacC(114, 93) = JacC(114, 93) - dw(272, 93)
      JacC(114,114) = JacC(114,114) - dw(272,114)
      JacC(119, 93) = JacC(119, 93) + dw(272, 93)
      JacC(119,114) = JacC(119,114) + dw(272,114)
      JacC(123, 93) = JacC(123, 93)+ 0.2000000000000000D+01*dw(272, 93)
      JacC(123,114) = JacC(123,114)+ 0.2000000000000000D+01*dw(272,114)
      JacC( 94, 94) = JacC( 94, 94) - dw(273, 94)
      JacC( 94,114) = JacC( 94,114) - dw(273,114)
      JacC( 95, 94) = JacC( 95, 94)+ 0.2500000000000000D+00*dw(273, 94)
      JacC( 95,114) = JacC( 95,114)+ 0.2500000000000000D+00*dw(273,114)
      JacC( 99, 94) = JacC( 99, 94)+ 0.2500000000000000D+00*dw(273, 94)
      JacC( 99,114) = JacC( 99,114)+ 0.2500000000000000D+00*dw(273,114)
      JacC(109, 94) = JacC(109, 94)+ 0.3480000000000000D+00*dw(273, 94)
      JacC(109,114) = JacC(109,114)+ 0.3480000000000000D+00*dw(273,114)
      JacC(111, 94) = JacC(111, 94)+ 0.5000000000000000D+00*dw(273, 94)
      JacC(111,114) = JacC(111,114)+ 0.5000000000000000D+00*dw(273,114)
      JacC(112, 94) = JacC(112, 94)+ 0.9300000000000000D+00*dw(273, 94)
      JacC(112,114) = JacC(112,114)+ 0.9300000000000000D+00*dw(273,114)
      JacC(114, 94) = JacC(114, 94) - dw(273, 94)
      JacC(114,114) = JacC(114,114) - dw(273,114)
      JacC(119, 94) = JacC(119, 94)+ 0.9650000000000000D+00*dw(273, 94)
      JacC(119,114) = JacC(119,114)+ 0.9650000000000000D+00*dw(273,114)
      JacC(123, 94) = JacC(123, 94)+ 0.5000000000000000D+00*dw(273, 94)
      JacC(123,114) = JacC(123,114)+ 0.5000000000000000D+00*dw(273,114)
      JacC(124, 94) = JacC(124, 94)+ 0.5000000000000000D+00*dw(273, 94)
      JacC(124,114) = JacC(124,114)+ 0.5000000000000000D+00*dw(273,114)
      JacC(100,113) = JacC(100,113) + dw(274,113)
      JacC(100,118) = JacC(100,118) + dw(274,118)
      JacC(106,113) = JacC(106,113)+ 0.5000000000000000D+00*dw(274,113)
      JacC(106,118) = JacC(106,118)+ 0.5000000000000000D+00*dw(274,118)
      JacC(113,113) = JacC(113,113) - dw(274,113)
      JacC(113,118) = JacC(113,118) - dw(274,118)
      JacC(114,113) = JacC(114,113)+ 0.5000000000000000D+00*dw(274,113)
      JacC(114,118) = JacC(114,118)+ 0.5000000000000000D+00*dw(274,118)
      JacC(118,113) = JacC(118,113) - dw(274,113)
      JacC(118,118) = JacC(118,118) - dw(274,118)
      JacC(123,113) = JacC(123,113)+ 0.5000000000000000D+00*dw(274,113)
      JacC(123,118) = JacC(123,118)+ 0.5000000000000000D+00*dw(274,118)
      JacC(104,110) = JacC(104,110)+ 0.6700000000000000D-01*dw(275,110)
      JacC(104,118) = JacC(104,118)+ 0.6700000000000000D-01*dw(275,118)
      JacC(106,110) = JacC(106,110)+ 0.5000000000000000D+00*dw(275,110)
      JacC(106,118) = JacC(106,118)+ 0.5000000000000000D+00*dw(275,118)
      JacC(109,110) = JacC(109,110)+ 0.6620000000000000D+00*dw(275,110)
      JacC(109,118) = JacC(109,118)+ 0.6620000000000000D+00*dw(275,118)
      JacC(110,110) = JacC(110,110) - dw(275,110)
      JacC(110,118) = JacC(110,118) - dw(275,118)
      JacC(112,110) = JacC(112,110)+ 0.2730000000000000D+00*dw(275,110)
      JacC(112,118) = JacC(112,118)+ 0.2730000000000000D+00*dw(275,118)
      JacC(113,110) = JacC(113,110)+ 0.2600000000000000D-01*dw(275,110)
      JacC(113,118) = JacC(113,118)+ 0.2600000000000000D-01*dw(275,118)
      JacC(114,110) = JacC(114,110)+ 0.5800000000000000D+00*dw(275,110)
      JacC(114,118) = JacC(114,118)+ 0.5800000000000000D+00*dw(275,118)
      JacC(116,110) = JacC(116,110)+ 0.2600000000000000D-01*dw(275,110)
      JacC(116,118) = JacC(116,118)+ 0.2600000000000000D-01*dw(275,118)
      JacC(118,110) = JacC(118,110) - dw(275,110)
      JacC(118,118) = JacC(118,118) - dw(275,118)
      JacC(119,110) = JacC(119,110)+ 0.1300000000000000D+00*dw(275,110)
      JacC(119,118) = JacC(119,118)+ 0.1300000000000000D+00*dw(275,118)
      JacC(123,110) = JacC(123,110)+ 0.3940000000000000D+00*dw(275,110)
      JacC(123,118) = JacC(123,118)+ 0.3940000000000000D+00*dw(275,118)
      JacC( 72, 72) = JacC( 72, 72) - dw(276, 72)
      JacC( 72,118) = JacC( 72,118) - dw(276,118)
      JacC(106, 72) = JacC(106, 72)+ 0.5000000000000000D+00*dw(276, 72)
      JacC(106,118) = JacC(106,118)+ 0.5000000000000000D+00*dw(276,118)
      JacC(109, 72) = JacC(109, 72)+ 0.8240000000000000D+00*dw(276, 72)
      JacC(109,118) = JacC(109,118)+ 0.8240000000000000D+00*dw(276,118)
      JacC(112, 72) = JacC(112, 72)+ 0.3810000000000000D+00*dw(276, 72)
      JacC(112,118) = JacC(112,118)+ 0.3810000000000000D+00*dw(276,118)
      JacC(113, 72) = JacC(113, 72)+ 0.1400000000000000D+00*dw(276, 72)
      JacC(113,118) = JacC(113,118)+ 0.1400000000000000D+00*dw(276,118)
      JacC(114, 72) = JacC(114, 72)+ 0.5180000000000000D+00*dw(276, 72)
      JacC(114,118) = JacC(114,118)+ 0.5180000000000000D+00*dw(276,118)
      JacC(116, 72) = JacC(116, 72)+ 0.1910000000000000D+00*dw(276, 72)
      JacC(116,118) = JacC(116,118)+ 0.1910000000000000D+00*dw(276,118)
      JacC(118, 72) = JacC(118, 72) - dw(276, 72)
      JacC(118,118) = JacC(118,118) - dw(276,118)
      JacC(119, 72) = JacC(119, 72)+ 0.4200000000000000D-01*dw(276, 72)
      JacC(119,118) = JacC(119,118)+ 0.4200000000000000D-01*dw(276,118)
      JacC(123, 72) = JacC(123, 72)+ 0.3420000000000000D+00*dw(276, 72)
      JacC(123,118) = JacC(123,118)+ 0.3420000000000000D+00*dw(276,118)
      JacC( 75, 75) = JacC( 75, 75) - dw(277, 75)
      JacC( 75,118) = JacC( 75,118) - dw(277,118)
      JacC(106, 75) = JacC(106, 75)+ 0.4950000000000000D+00*dw(277, 75)
      JacC(106,118) = JacC(106,118)+ 0.4950000000000000D+00*dw(277,118)
      JacC(109, 75) = JacC(109, 75)+ 0.6420000000000000D+00*dw(277, 75)
      JacC(109,118) = JacC(109,118)+ 0.6420000000000000D+00*dw(277,118)
      JacC(112, 75) = JacC(112, 75)+ 0.2170000000000000D+00*dw(277, 75)
      JacC(112,118) = JacC(112,118)+ 0.2170000000000000D+00*dw(277,118)
      JacC(113, 75) = JacC(113, 75)+ 0.6700000000000000D-01*dw(277, 75)
      JacC(113,118) = JacC(113,118)+ 0.6700000000000000D-01*dw(277,118)
      JacC(114, 75) = JacC(114, 75)+ 0.5000000000000000D+00*dw(277, 75)
      JacC(114,118) = JacC(114,118)+ 0.5000000000000000D+00*dw(277,118)
      JacC(116, 75) = JacC(116, 75)+ 0.2080000000000000D+00*dw(277, 75)
      JacC(116,118) = JacC(116,118)+ 0.2080000000000000D+00*dw(277,118)
      JacC(118, 75) = JacC(118, 75) - dw(277, 75)
      JacC(118,118) = JacC(118,118) - dw(277,118)
      JacC(123, 75) = JacC(123, 75)+ 0.3030000000000000D+00*dw(277, 75)
      JacC(123,118) = JacC(123,118)+ 0.3030000000000000D+00*dw(277,118)
      JacC( 85, 85) = JacC( 85, 85) - dw(278, 85)
      JacC( 85,118) = JacC( 85,118) - dw(278,118)
      JacC(106, 85) = JacC(106, 85)+ 0.5000000000000000D+00*dw(278, 85)
      JacC(106,118) = JacC(106,118)+ 0.5000000000000000D+00*dw(278,118)
      JacC(112, 85) = JacC(112, 85)+ 0.2000000000000000D+00*dw(278, 85)
      JacC(112,118) = JacC(112,118)+ 0.2000000000000000D+00*dw(278,118)
      JacC(114, 85) = JacC(114, 85)+ 0.5000000000000000D+00*dw(278, 85)
      JacC(114,118) = JacC(114,118)+ 0.5000000000000000D+00*dw(278,118)
      JacC(118, 85) = JacC(118, 85) - dw(278, 85)
      JacC(118,118) = JacC(118,118) - dw(278,118)
      JacC(119, 85) = JacC(119, 85)+ 0.1600000000000000D+01*dw(278, 85)
      JacC(119,118) = JacC(119,118)+ 0.1600000000000000D+01*dw(278,118)
      JacC(123, 85) = JacC(123, 85)+ 0.5000000000000000D+00*dw(278, 85)
      JacC(123,118) = JacC(123,118)+ 0.5000000000000000D+00*dw(278,118)
      JacC( 70, 70) = JacC( 70, 70) - dw(279, 70)
      JacC( 70,118) = JacC( 70,118) - dw(279,118)
      JacC(106, 70) = JacC(106, 70)+ 0.5000000000000000D+00*dw(279, 70)
      JacC(106,118) = JacC(106,118)+ 0.5000000000000000D+00*dw(279,118)
      JacC(109, 70) = JacC(109, 70)+ 0.6000000000000000D-01*dw(279, 70)
      JacC(109,118) = JacC(109,118)+ 0.6000000000000000D-01*dw(279,118)
      JacC(112, 70) = JacC(112, 70)+ 0.9399999999999999D+00*dw(279, 70)
      JacC(112,118) = JacC(112,118)+ 0.9399999999999999D+00*dw(279,118)
      JacC(114, 70) = JacC(114, 70)+ 0.5000000000000000D+00*dw(279, 70)
      JacC(114,118) = JacC(114,118)+ 0.5000000000000000D+00*dw(279,118)
      JacC(118, 70) = JacC(118, 70) - dw(279, 70)
      JacC(118,118) = JacC(118,118) - dw(279,118)
      JacC(119, 70) = JacC(119, 70) + dw(279, 70)
      JacC(119,118) = JacC(119,118) + dw(279,118)
      JacC(123, 70) = JacC(123, 70)+ 0.5000000000000000D+00*dw(279, 70)
      JacC(123,118) = JacC(123,118)+ 0.5000000000000000D+00*dw(279,118)
      JacC( 92, 92) = JacC( 92, 92) - dw(280, 92)
      JacC( 92,118) = JacC( 92,118) - dw(280,118)
      JacC(106, 92) = JacC(106, 92)+ 0.5000000000000000D+00*dw(280, 92)
      JacC(106,118) = JacC(106,118)+ 0.5000000000000000D+00*dw(280,118)
      JacC(109, 92) = JacC(109, 92)+ 0.2900000000000000D+00*dw(280, 92)
      JacC(109,118) = JacC(109,118)+ 0.2900000000000000D+00*dw(280,118)
      JacC(112, 92) = JacC(112, 92)+ 0.1710000000000000D+01*dw(280, 92)
      JacC(112,118) = JacC(112,118)+ 0.1710000000000000D+01*dw(280,118)
      JacC(114, 92) = JacC(114, 92)+ 0.5000000000000000D+00*dw(280, 92)
      JacC(114,118) = JacC(114,118)+ 0.5000000000000000D+00*dw(280,118)
      JacC(118, 92) = JacC(118, 92) - dw(280, 92)
      JacC(118,118) = JacC(118,118) - dw(280,118)
      JacC(123, 92) = JacC(123, 92)+ 0.5000000000000000D+00*dw(280, 92)
      JacC(123,118) = JacC(123,118)+ 0.5000000000000000D+00*dw(280,118)
      JacC( 80, 80) = JacC( 80, 80) - dw(281, 80)
      JacC( 80,118) = JacC( 80,118) - dw(281,118)
      JacC( 81, 80) = JacC( 81, 80)+ 0.3050000000000000D+00*dw(281, 80)
      JacC( 81,118) = JacC( 81,118)+ 0.3050000000000000D+00*dw(281,118)
      JacC( 84, 80) = JacC( 84, 80)+ 0.2190000000000000D+00*dw(281, 80)
      JacC( 84,118) = JacC( 84,118)+ 0.2190000000000000D+00*dw(281,118)
      JacC(106, 80) = JacC(106, 80)+ 0.5000000000000000D+00*dw(281, 80)
      JacC(106,118) = JacC(106,118)+ 0.5000000000000000D+00*dw(281,118)
      JacC(114, 80) = JacC(114, 80)+ 0.5000000000000000D+00*dw(281, 80)
      JacC(114,118) = JacC(114,118)+ 0.5000000000000000D+00*dw(281,118)
      JacC(118, 80) = JacC(118, 80) - dw(281, 80)
      JacC(118,118) = JacC(118,118) - dw(281,118)
      JacC(119, 80) = JacC(119, 80)+ 0.1048000000000000D+01*dw(281, 80)
      JacC(119,118) = JacC(119,118)+ 0.1048000000000000D+01*dw(281,118)
      JacC(123, 80) = JacC(123, 80)+ 0.5000000000000000D+00*dw(281, 80)
      JacC(123,118) = JacC(123,118)+ 0.5000000000000000D+00*dw(281,118)
      JacC( 76,105) = JacC( 76,105)+ 0.1670000000000000D+00*dw(282,105)
      JacC( 76,118) = JacC( 76,118)+ 0.1670000000000000D+00*dw(282,118)
      JacC(102,105) = JacC(102,105)+ 0.3300000000000000D+00*dw(282,105)
      JacC(102,118) = JacC(102,118)+ 0.3300000000000000D+00*dw(282,118)
      JacC(105,105) = JacC(105,105) - dw(282,105)
      JacC(105,118) = JacC(105,118) - dw(282,118)
      JacC(106,105) = JacC(106,105)+ 0.5830000000000000D+00*dw(282,105)
      JacC(106,118) = JacC(106,118)+ 0.5830000000000000D+00*dw(282,118)
      JacC(108,105) = JacC(108,105)+ 0.1670000000000000D+00*dw(282,105)
      JacC(108,118) = JacC(108,118)+ 0.1670000000000000D+00*dw(282,118)
      JacC(114,105) = JacC(114,105)+ 0.5000000000000000D+00*dw(282,105)
      JacC(114,118) = JacC(114,118)+ 0.5000000000000000D+00*dw(282,118)
      JacC(118,105) = JacC(118,105)- 0.8330000000000000D+00*dw(282,105)
      JacC(118,118) = JacC(118,118)- 0.8330000000000000D+00*dw(282,118)
      JacC(119,105) = JacC(119,105) + dw(282,105)
      JacC(119,118) = JacC(119,118) + dw(282,118)
      JacC(123,105) = JacC(123,105)+ 0.5000000000000000D+00*dw(282,105)
      JacC(123,118) = JacC(123,118)+ 0.5000000000000000D+00*dw(282,118)
      JacC( 83, 83) = JacC( 83, 83) - dw(283, 83)
      JacC( 83,118) = JacC( 83,118) - dw(283,118)
      JacC(102, 83) = JacC(102, 83)+ 0.5000000000000000D+00*dw(283, 83)
      JacC(102,118) = JacC(102,118)+ 0.5000000000000000D+00*dw(283,118)
      JacC(106, 83) = JacC(106, 83)+ 0.1083000000000000D+01*dw(283, 83)
      JacC(106,118) = JacC(106,118)+ 0.1083000000000000D+01*dw(283,118)
      JacC(112, 83) = JacC(112, 83)+ 0.2300000000000000D+01*dw(283, 83)
      JacC(112,118) = JacC(112,118)+ 0.2300000000000000D+01*dw(283,118)
      JacC(114, 83) = JacC(114, 83)+ 0.5000000000000000D+00*dw(283, 83)
      JacC(114,118) = JacC(114,118)+ 0.5000000000000000D+00*dw(283,118)
      JacC(116, 83) = JacC(116, 83)+ 0.1160000000000000D+01*dw(283, 83)
      JacC(116,118) = JacC(116,118)+ 0.1160000000000000D+01*dw(283,118)
      JacC(118, 83) = JacC(118, 83)+ 0.1599999999999999D+00*dw(283, 83)
      JacC(118,118) = JacC(118,118)+ 0.1599999999999999D+00*dw(283,118)
      JacC(119, 83) = JacC(119, 83) + dw(283, 83)
      JacC(119,118) = JacC(119,118) + dw(283,118)
      JacC(123, 83) = JacC(123, 83)+ 0.5000000000000000D+00*dw(283, 83)
      JacC(123,118) = JacC(123,118)+ 0.5000000000000000D+00*dw(283,118)
      JacC( 88, 88) = JacC( 88, 88) - dw(284, 88)
      JacC( 88,118) = JacC( 88,118) - dw(284,118)
      JacC(102, 88) = JacC(102, 88)+ 0.1050000000000000D+00*dw(284, 88)
      JacC(102,118) = JacC(102,118)+ 0.1050000000000000D+00*dw(284,118)
      JacC(104, 88) = JacC(104, 88)+ 0.1800000000000000D+00*dw(284, 88)
      JacC(104,118) = JacC(104,118)+ 0.1800000000000000D+00*dw(284,118)
      JacC(106, 88) = JacC(106, 88)+ 0.5000000000000000D+00*dw(284, 88)
      JacC(106,118) = JacC(106,118)+ 0.5000000000000000D+00*dw(284,118)
      JacC(108, 88) = JacC(108, 88)+ 0.5000000000000000D+00*dw(284, 88)
      JacC(108,118) = JacC(108,118)+ 0.5000000000000000D+00*dw(284,118)
      JacC(109, 88) = JacC(109, 88)+ 0.7000000000000000D+00*dw(284, 88)
      JacC(109,118) = JacC(109,118)+ 0.7000000000000000D+00*dw(284,118)
      JacC(112, 88) = JacC(112, 88)+ 0.2700000000000000D+00*dw(284, 88)
      JacC(112,118) = JacC(112,118)+ 0.2700000000000000D+00*dw(284,118)
      JacC(114, 88) = JacC(114, 88)+ 0.5000000000000000D+00*dw(284, 88)
      JacC(114,118) = JacC(114,118)+ 0.5000000000000000D+00*dw(284,118)
      JacC(118, 88) = JacC(118, 88) - dw(284, 88)
      JacC(118,118) = JacC(118,118) - dw(284,118)
      JacC(119, 88) = JacC(119, 88)+ 0.3000000000000000D-01*dw(284, 88)
      JacC(119,118) = JacC(119,118)+ 0.3000000000000000D-01*dw(284,118)
      JacC(123, 88) = JacC(123, 88)+ 0.5000000000000000D+00*dw(284, 88)
      JacC(123,118) = JacC(123,118)+ 0.5000000000000000D+00*dw(284,118)
      JacC( 74, 74) = JacC( 74, 74) - dw(285, 74)
      JacC( 74,118) = JacC( 74,118) - dw(285,118)
      JacC(106, 74) = JacC(106, 74) + dw(285, 74)
      JacC(106,118) = JacC(106,118) + dw(285,118)
      JacC(109, 74) = JacC(109, 74) + dw(285, 74)
      JacC(109,118) = JacC(109,118) + dw(285,118)
      JacC(112, 74) = JacC(112, 74) + dw(285, 74)
      JacC(112,118) = JacC(112,118) + dw(285,118)
      JacC(114, 74) = JacC(114, 74)+ 0.5000000000000000D+00*dw(285, 74)
      JacC(114,118) = JacC(114,118)+ 0.5000000000000000D+00*dw(285,118)
      JacC(118, 74) = JacC(118, 74) - dw(285, 74)
      JacC(118,118) = JacC(118,118) - dw(285,118)
      JacC(123, 74) = JacC(123, 74)+ 0.5000000000000000D+00*dw(285, 74)
      JacC(123,118) = JacC(123,118)+ 0.5000000000000000D+00*dw(285,118)
      JacC( 79, 79) = JacC( 79, 79) - dw(286, 79)
      JacC( 79,118) = JacC( 79,118) - dw(286,118)
      JacC( 84, 79) = JacC( 84, 79)+ 0.3080000000000000D+00*dw(286, 79)
      JacC( 84,118) = JacC( 84,118)+ 0.3080000000000000D+00*dw(286,118)
      JacC( 89, 79) = JacC( 89, 79)+ 0.1920000000000000D+00*dw(286, 79)
      JacC( 89,118) = JacC( 89,118)+ 0.1920000000000000D+00*dw(286,118)
      JacC(106, 79) = JacC(106, 79)+ 0.5000000000000000D+00*dw(286, 79)
      JacC(106,118) = JacC(106,118)+ 0.5000000000000000D+00*dw(286,118)
      JacC(114, 79) = JacC(114, 79)+ 0.5000000000000000D+00*dw(286, 79)
      JacC(114,118) = JacC(114,118)+ 0.5000000000000000D+00*dw(286,118)
      JacC(118, 79) = JacC(118, 79) - dw(286, 79)
      JacC(118,118) = JacC(118,118) - dw(286,118)
      JacC(119, 79) = JacC(119, 79)+ 0.3850000000000000D+00*dw(286, 79)
      JacC(119,118) = JacC(119,118)+ 0.3850000000000000D+00*dw(286,118)
      JacC(123, 79) = JacC(123, 79)+ 0.5000000000000000D+00*dw(286, 79)
      JacC(123,118) = JacC(123,118)+ 0.5000000000000000D+00*dw(286,118)
      JacC( 86, 86) = JacC( 86, 86) - dw(287, 86)
      JacC( 86,118) = JacC( 86,118) - dw(287,118)
      JacC( 87, 86) = JacC( 87, 86)+ 0.7000000000000000D+00*dw(287, 86)
      JacC( 87,118) = JacC( 87,118)+ 0.7000000000000000D+00*dw(287,118)
      JacC( 89, 86) = JacC( 89, 86)+ 0.3000000000000000D+00*dw(287, 86)
      JacC( 89,118) = JacC( 89,118)+ 0.3000000000000000D+00*dw(287,118)
      JacC(104, 86) = JacC(104, 86)+ 0.6000000000000000D+00*dw(287, 86)
      JacC(104,118) = JacC(104,118)+ 0.6000000000000000D+00*dw(287,118)
      JacC(114, 86) = JacC(114, 86) + dw(287, 86)
      JacC(114,118) = JacC(114,118) + dw(287,118)
      JacC(118, 86) = JacC(118, 86) - dw(287, 86)
      JacC(118,118) = JacC(118,118) - dw(287,118)
      JacC(123, 86) = JacC(123, 86)+ 0.6000000000000000D+00*dw(287, 86)
      JacC(123,118) = JacC(123,118)+ 0.6000000000000000D+00*dw(287,118)
      JacC( 54, 54) = JacC( 54, 54) - dw(288, 54)
      JacC( 54,118) = JacC( 54,118) - dw(288,118)
      JacC( 57, 54) = JacC( 57, 54)+ 0.7800000000000000D+00*dw(288, 54)
      JacC( 57,118) = JacC( 57,118)+ 0.7800000000000000D+00*dw(288,118)
      JacC( 65, 54) = JacC( 65, 54) + dw(288, 54)
      JacC( 65,118) = JacC( 65,118) + dw(288,118)
      JacC(114, 54) = JacC(114, 54) + dw(288, 54)
      JacC(114,118) = JacC(114,118) + dw(288,118)
      JacC(118, 54) = JacC(118, 54) - dw(288, 54)
      JacC(118,118) = JacC(118,118) - dw(288,118)
      JacC(123, 54) = JacC(123, 54) + dw(288, 54)
      JacC(123,118) = JacC(123,118) + dw(288,118)
      JacC( 53, 53) = JacC( 53, 53) - dw(289, 53)
      JacC( 53,118) = JacC( 53,118) - dw(289,118)
      JacC( 63, 53) = JacC( 63, 53) + dw(289, 53)
      JacC( 63,118) = JacC( 63,118) + dw(289,118)
      JacC(114, 53) = JacC(114, 53) + dw(289, 53)
      JacC(114,118) = JacC(114,118) + dw(289,118)
      JacC(118, 53) = JacC(118, 53) - dw(289, 53)
      JacC(118,118) = JacC(118,118) - dw(289,118)
      JacC( 52, 52) = JacC( 52, 52) - dw(290, 52)
      JacC( 52,118) = JacC( 52,118) - dw(290,118)
      JacC( 69, 52) = JacC( 69, 52) + dw(290, 52)
      JacC( 69,118) = JacC( 69,118) + dw(290,118)
      JacC(102, 52) = JacC(102, 52) + dw(290, 52)
      JacC(102,118) = JacC(102,118) + dw(290,118)
      JacC(114, 52) = JacC(114, 52) + dw(290, 52)
      JacC(114,118) = JacC(114,118) + dw(290,118)
      JacC(118, 52) = JacC(118, 52) - dw(290, 52)
      JacC(118,118) = JacC(118,118) - dw(290,118)
      JacC(123, 52) = JacC(123, 52) + dw(290, 52)
      JacC(123,118) = JacC(123,118) + dw(290,118)
      JacC( 62, 62) = JacC( 62, 62) - dw(291, 62)
      JacC( 62,118) = JacC( 62,118) - dw(291,118)
      JacC( 69, 62) = JacC( 69, 62) + dw(291, 62)
      JacC( 69,118) = JacC( 69,118) + dw(291,118)
      JacC( 91, 62) = JacC( 91, 62)+ 0.2050000000000000D+01*dw(291, 62)
      JacC( 91,118) = JacC( 91,118)+ 0.2050000000000000D+01*dw(291,118)
      JacC(102, 62) = JacC(102, 62) + dw(291, 62)
      JacC(102,118) = JacC(102,118) + dw(291,118)
      JacC(114, 62) = JacC(114, 62) + dw(291, 62)
      JacC(114,118) = JacC(114,118) + dw(291,118)
      JacC(118, 62) = JacC(118, 62) - dw(291, 62)
      JacC(118,118) = JacC(118,118) - dw(291,118)
      JacC(123, 62) = JacC(123, 62) + dw(291, 62)
      JacC(123,118) = JacC(123,118) + dw(291,118)
      JacC( 50, 67) = JacC( 50, 67) + dw(292, 67)
      JacC( 50,118) = JacC( 50,118) + dw(292,118)
      JacC( 67, 67) = JacC( 67, 67) - dw(292, 67)
      JacC( 67,118) = JacC( 67,118) - dw(292,118)
      JacC(114, 67) = JacC(114, 67) + dw(292, 67)
      JacC(114,118) = JacC(114,118) + dw(292,118)
      JacC(118, 67) = JacC(118, 67) - dw(292, 67)
      JacC(118,118) = JacC(118,118) - dw(292,118)
      JacC( 50, 50) = JacC( 50, 50) - dw(293, 50)
      JacC( 50,118) = JacC( 50,118) - dw(293,118)
      JacC( 51, 50) = JacC( 51, 50) + dw(293, 50)
      JacC( 51,118) = JacC( 51,118) + dw(293,118)
      JacC(114, 50) = JacC(114, 50) + dw(293, 50)
      JacC(114,118) = JacC(114,118) + dw(293,118)
      JacC(118, 50) = JacC(118, 50) - dw(293, 50)
      JacC(118,118) = JacC(118,118) - dw(293,118)
      JacC( 57, 64) = JacC( 57, 64)+ 0.7100000000000000D+00*dw(294, 64)
      JacC( 57,118) = JacC( 57,118)+ 0.7100000000000000D+00*dw(294,118)
      JacC( 64, 64) = JacC( 64, 64) - dw(294, 64)
      JacC( 64,118) = JacC( 64,118) - dw(294,118)
      JacC( 65, 64) = JacC( 65, 64)+ 0.7700000000000000D-01*dw(294, 64)
      JacC( 65,118) = JacC( 65,118)+ 0.7700000000000000D-01*dw(294,118)
      JacC( 69, 64) = JacC( 69, 64)+ 0.7370000000000000D+00*dw(294, 64)
      JacC( 69,118) = JacC( 69,118)+ 0.7370000000000000D+00*dw(294,118)
      JacC( 91, 64) = JacC( 91, 64)+ 0.1860000000000000D+00*dw(294, 64)
      JacC( 91,118) = JacC( 91,118)+ 0.1860000000000000D+00*dw(294,118)
      JacC(102, 64) = JacC(102, 64)+ 0.6320000000000000D+00*dw(294, 64)
      JacC(102,118) = JacC(102,118)+ 0.6320000000000000D+00*dw(294,118)
      JacC(104, 64) = JacC(104, 64)+ 0.3680000000000000D+00*dw(294, 64)
      JacC(104,118) = JacC(104,118)+ 0.3680000000000000D+00*dw(294,118)
      JacC(114, 64) = JacC(114, 64) + dw(294, 64)
      JacC(114,118) = JacC(114,118) + dw(294,118)
      JacC(118, 64) = JacC(118, 64) - dw(294, 64)
      JacC(118,118) = JacC(118,118) - dw(294,118)
      JacC(123, 64) = JacC(123, 64) + dw(294, 64)
      JacC(123,118) = JacC(123,118) + dw(294,118)
      JacC( 55, 55) = JacC( 55, 55) - dw(295, 55)
      JacC( 55,118) = JacC( 55,118) - dw(295,118)
      JacC( 63, 55) = JacC( 63, 55) + dw(295, 55)
      JacC( 63,118) = JacC( 63,118) + dw(295,118)
      JacC(114, 55) = JacC(114, 55) + dw(295, 55)
      JacC(114,118) = JacC(114,118) + dw(295,118)
      JacC(118, 55) = JacC(118, 55) - dw(295, 55)
      JacC(118,118) = JacC(118,118) - dw(295,118)
      JacC( 56, 56) = JacC( 56, 56) - dw(296, 56)
      JacC( 56,118) = JacC( 56,118) - dw(296,118)
      JacC( 57, 56) = JacC( 57, 56)+ 0.7100000000000000D+00*dw(296, 56)
      JacC( 57,118) = JacC( 57,118)+ 0.7100000000000000D+00*dw(296,118)
      JacC( 65, 56) = JacC( 65, 56) + dw(296, 56)
      JacC( 65,118) = JacC( 65,118) + dw(296,118)
      JacC(114, 56) = JacC(114, 56) + dw(296, 56)
      JacC(114,118) = JacC(114,118) + dw(296,118)
      JacC(118, 56) = JacC(118, 56) - dw(296, 56)
      JacC(118,118) = JacC(118,118) - dw(296,118)
      JacC(123, 56) = JacC(123, 56) + dw(296, 56)
      JacC(123,118) = JacC(123,118) + dw(296,118)
      JacC( 77, 78) = JacC( 77, 78)+ 0.3200000000000000D+00*dw(297, 78)
      JacC( 77,118) = JacC( 77,118)+ 0.3200000000000000D+00*dw(297,118)
      JacC( 78, 78) = JacC( 78, 78) - dw(297, 78)
      JacC( 78,118) = JacC( 78,118) - dw(297,118)
      JacC(104, 78) = JacC(104, 78)+ 0.6800000000000000D+00*dw(297, 78)
      JacC(104,118) = JacC(104,118)+ 0.6800000000000000D+00*dw(297,118)
      JacC(114, 78) = JacC(114, 78) + dw(297, 78)
      JacC(114,118) = JacC(114,118) + dw(297,118)
      JacC(115, 78) = JacC(115, 78)+ 0.6800000000000000D+00*dw(297, 78)
      JacC(115,118) = JacC(115,118)+ 0.6800000000000000D+00*dw(297,118)
      JacC(118, 78) = JacC(118, 78) - dw(297, 78)
      JacC(118,118) = JacC(118,118) - dw(297,118)
      JacC(123, 78) = JacC(123, 78)+ 0.2000000000000000D+01*dw(297, 78)
      JacC(123,118) = JacC(123,118)+ 0.2000000000000000D+01*dw(297,118)
      JacC(114,118) = JacC(114,118)+ 0.2000000000000000D+01*dw(298,118)
      JacC(114,118) = JacC(114,118)+ 0.2000000000000000D+01*dw(298,118)
      JacC(118,118) = JacC(118,118)- 0.2000000000000000D+01*dw(298,118)
      JacC(118,118) = JacC(118,118)- 0.2000000000000000D+01*dw(298,118)
      JacC(113,122) = JacC(113,122)+ 0.2000000000000000D+01*dw(299,122)
      JacC(113,122) = JacC(113,122)+ 0.2000000000000000D+01*dw(299,122)
      JacC(122,122) = JacC(122,122)- 0.2000000000000000D+01*dw(299,122)
      JacC(122,122) = JacC(122,122)- 0.2000000000000000D+01*dw(299,122)
      JacC( 69,101) = JacC( 69,101)+ 0.5000000000000000D+00*dw(300,101)
      JacC( 69,118) = JacC( 69,118)+ 0.5000000000000000D+00*dw(300,118)
      JacC(101,101) = JacC(101,101) - dw(300,101)
      JacC(101,118) = JacC(101,118) - dw(300,118)
      JacC(106,101) = JacC(106,101)+ 0.5000000000000000D+00*dw(300,101)
      JacC(106,118) = JacC(106,118)+ 0.5000000000000000D+00*dw(300,118)
      JacC(114,101) = JacC(114,101)+ 0.5000000000000000D+00*dw(300,101)
      JacC(114,118) = JacC(114,118)+ 0.5000000000000000D+00*dw(300,118)
      JacC(118,101) = JacC(118,101) - dw(300,101)
      JacC(118,118) = JacC(118,118) - dw(300,118)
      JacC(123,101) = JacC(123,101)+ 0.5000000000000000D+00*dw(300,101)
      JacC(123,118) = JacC(123,118)+ 0.5000000000000000D+00*dw(300,118)
      JacC( 98, 98) = JacC( 98, 98) - dw(301, 98)
      JacC( 98,118) = JacC( 98,118) - dw(301,118)
      JacC(106, 98) = JacC(106, 98)+ 0.7500000000000000D+00*dw(301, 98)
      JacC(106,118) = JacC(106,118)+ 0.7500000000000000D+00*dw(301,118)
      JacC(114, 98) = JacC(114, 98)+ 0.5000000000000000D+00*dw(301, 98)
      JacC(114,118) = JacC(114,118)+ 0.5000000000000000D+00*dw(301,118)
      JacC(118, 98) = JacC(118, 98)- 0.5000000000000000D+00*dw(301, 98)
      JacC(118,118) = JacC(118,118)- 0.5000000000000000D+00*dw(301,118)
      JacC(119, 98) = JacC(119, 98) + dw(301, 98)
      JacC(119,118) = JacC(119,118) + dw(301,118)
      JacC( 68, 68) = JacC( 68, 68) - dw(302, 68)
      JacC( 68,118) = JacC( 68,118) - dw(302,118)
      JacC( 69, 68) = JacC( 69, 68)+ 0.3340000000000000D+00*dw(302, 68)
      JacC( 69,118) = JacC( 69,118)+ 0.3340000000000000D+00*dw(302,118)
      JacC(106, 68) = JacC(106, 68)+ 0.5000000000000000D+00*dw(302, 68)
      JacC(106,118) = JacC(106,118)+ 0.5000000000000000D+00*dw(302,118)
      JacC(114, 68) = JacC(114, 68)+ 0.5000000000000000D+00*dw(302, 68)
      JacC(114,118) = JacC(114,118)+ 0.5000000000000000D+00*dw(302,118)
      JacC(118, 68) = JacC(118, 68) - dw(302, 68)
      JacC(118,118) = JacC(118,118) - dw(302,118)
      JacC(119, 68) = JacC(119, 68)+ 0.3300000000000000D+00*dw(302, 68)
      JacC(119,118) = JacC(119,118)+ 0.3300000000000000D+00*dw(302,118)
      JacC(123, 68) = JacC(123, 68)+ 0.3300000000000000D+00*dw(302, 68)
      JacC(123,118) = JacC(123,118)+ 0.3300000000000000D+00*dw(302,118)
      JacC( 93, 93) = JacC( 93, 93) - dw(303, 93)
      JacC( 93,118) = JacC( 93,118) - dw(303,118)
      JacC(111, 93) = JacC(111, 93) + dw(303, 93)
      JacC(111,118) = JacC(111,118) + dw(303,118)
      JacC(114, 93) = JacC(114, 93) + dw(303, 93)
      JacC(114,118) = JacC(114,118) + dw(303,118)
      JacC(118, 93) = JacC(118, 93) - dw(303, 93)
      JacC(118,118) = JacC(118,118) - dw(303,118)
      JacC(123, 93) = JacC(123, 93) + dw(303, 93)
      JacC(123,118) = JacC(123,118) + dw(303,118)
      JacC( 94, 94) = JacC( 94, 94) - dw(304, 94)
      JacC( 94,118) = JacC( 94,118) - dw(304,118)
      JacC(106, 94) = JacC(106, 94)+ 0.5000000000000000D+00*dw(304, 94)
      JacC(106,118) = JacC(106,118)+ 0.5000000000000000D+00*dw(304,118)
      JacC(109, 94) = JacC(109, 94)+ 0.4640000000000000D+00*dw(304, 94)
      JacC(109,118) = JacC(109,118)+ 0.4640000000000000D+00*dw(304,118)
      JacC(112, 94) = JacC(112, 94)+ 0.1240000000000000D+01*dw(304, 94)
      JacC(112,118) = JacC(112,118)+ 0.1240000000000000D+01*dw(304,118)
      JacC(114, 94) = JacC(114, 94)+ 0.5000000000000000D+00*dw(304, 94)
      JacC(114,118) = JacC(114,118)+ 0.5000000000000000D+00*dw(304,118)
      JacC(118, 94) = JacC(118, 94) - dw(304, 94)
      JacC(118,118) = JacC(118,118) - dw(304,118)
      JacC(119, 94) = JacC(119, 94)+ 0.2870000000000000D+00*dw(304, 94)
      JacC(119,118) = JacC(119,118)+ 0.2870000000000000D+00*dw(304,118)
      JacC(124, 94) = JacC(124, 94) + dw(304, 94)
      JacC(124,118) = JacC(124,118) + dw(304,118)
      JacC( 93, 93) = JacC( 93, 93)- 0.2000000000000000D+01*dw(305, 93)
      JacC( 93, 93) = JacC( 93, 93)- 0.2000000000000000D+01*dw(305, 93)
      JacC(111, 93) = JacC(111, 93)+ 0.2000000000000000D+01*dw(305, 93)
      JacC(111, 93) = JacC(111, 93)+ 0.2000000000000000D+01*dw(305, 93)
      JacC(123, 93) = JacC(123, 93) + dw(305, 93)
      JacC(123, 93) = JacC(123, 93) + dw(305, 93)
      JacC( 93, 93) = JacC( 93, 93) - dw(306, 93)
      JacC( 93, 94) = JacC( 93, 94) - dw(306, 94)
      JacC( 94, 93) = JacC( 94, 93) - dw(306, 93)
      JacC( 94, 94) = JacC( 94, 94) - dw(306, 94)
      JacC(109, 93) = JacC(109, 93)+ 0.1490000000000000D+00*dw(306, 93)
      JacC(109, 94) = JacC(109, 94)+ 0.1490000000000000D+00*dw(306, 94)
      JacC(111, 93) = JacC(111, 93)+ 0.1500000000000000D+01*dw(306, 93)
      JacC(111, 94) = JacC(111, 94)+ 0.1500000000000000D+01*dw(306, 94)
      JacC(112, 93) = JacC(112, 93)+ 0.6400000000000000D+00*dw(306, 93)
      JacC(112, 94) = JacC(112, 94)+ 0.6400000000000000D+00*dw(306, 94)
      JacC(119, 93) = JacC(119, 93)+ 0.2020000000000000D+00*dw(306, 93)
      JacC(119, 94) = JacC(119, 94)+ 0.2020000000000000D+00*dw(306, 94)
      JacC(123, 93) = JacC(123, 93)+ 0.5000000000000000D+00*dw(306, 93)
      JacC(123, 94) = JacC(123, 94)+ 0.5000000000000000D+00*dw(306, 94)
      JacC(124, 93) = JacC(124, 93)+ 0.5000000000000000D+00*dw(306, 93)
      JacC(124, 94) = JacC(124, 94)+ 0.5000000000000000D+00*dw(306, 94)
      JacC( 94, 94) = JacC( 94, 94)- 0.2000000000000000D+01*dw(307, 94)
      JacC( 94, 94) = JacC( 94, 94)- 0.2000000000000000D+01*dw(307, 94)
      JacC(109, 94) = JacC(109, 94)+ 0.2850000000000000D+00*dw(307, 94)
      JacC(109, 94) = JacC(109, 94)+ 0.2850000000000000D+00*dw(307, 94)
      JacC(111, 94) = JacC(111, 94) + dw(307, 94)
      JacC(111, 94) = JacC(111, 94) + dw(307, 94)
      JacC(112, 94) = JacC(112, 94)+ 0.1210000000000000D+01*dw(307, 94)
      JacC(112, 94) = JacC(112, 94)+ 0.1210000000000000D+01*dw(307, 94)
      JacC(119, 94) = JacC(119, 94)+ 0.5040000000000000D+00*dw(307, 94)
      JacC(119, 94) = JacC(119, 94)+ 0.5040000000000000D+00*dw(307, 94)
      JacC(124, 94) = JacC(124, 94) + dw(307, 94)
      JacC(124, 94) = JacC(124, 94) + dw(307, 94)
      JacC(114,114) = JacC(114,114) - dw(308,114)
      JacC(114,121) = JacC(114,121) - dw(308,121)
      JacC(119,114) = JacC(119,114) + dw(308,114)
      JacC(119,121) = JacC(119,121) + dw(308,121)
      JacC(121,114) = JacC(121,114) - dw(308,114)
      JacC(121,121) = JacC(121,121) - dw(308,121)
      JacC(123,114) = JacC(123,114) + dw(308,114)
      JacC(123,121) = JacC(123,121) + dw(308,121)
      JacC(124,114) = JacC(124,114) + dw(308,114)
      JacC(124,121) = JacC(124,121) + dw(308,121)
      JacC(100,113) = JacC(100,113) + dw(309,113)
      JacC(100,121) = JacC(100,121) + dw(309,121)
      JacC(113,113) = JacC(113,113) - dw(309,113)
      JacC(113,121) = JacC(113,121) - dw(309,121)
      JacC(121,113) = JacC(121,113) - dw(309,113)
      JacC(121,121) = JacC(121,121) - dw(309,121)
      JacC(123,113) = JacC(123,113) + dw(309,113)
      JacC(123,121) = JacC(123,121) + dw(309,121)
      JacC(124,113) = JacC(124,113) + dw(309,113)
      JacC(124,121) = JacC(124,121) + dw(309,121)
      JacC(104,110) = JacC(104,110)+ 0.6700000000000000D-01*dw(310,110)
      JacC(104,121) = JacC(104,121)+ 0.6700000000000000D-01*dw(310,121)
      JacC(109,110) = JacC(109,110)+ 0.6620000000000000D+00*dw(310,110)
      JacC(109,121) = JacC(109,121)+ 0.6620000000000000D+00*dw(310,121)
      JacC(110,110) = JacC(110,110) - dw(310,110)
      JacC(110,121) = JacC(110,121) - dw(310,121)
      JacC(112,110) = JacC(112,110)+ 0.2480000000000000D+00*dw(310,110)
      JacC(112,121) = JacC(112,121)+ 0.2480000000000000D+00*dw(310,121)
      JacC(113,110) = JacC(113,110)+ 0.5100000000000000D-01*dw(310,110)
      JacC(113,121) = JacC(113,121)+ 0.5100000000000000D-01*dw(310,121)
      JacC(114,110) = JacC(114,110)+ 0.1590000000000000D+00*dw(310,110)
      JacC(114,121) = JacC(114,121)+ 0.1590000000000000D+00*dw(310,121)
      JacC(116,110) = JacC(116,110)+ 0.5100000000000000D-01*dw(310,110)
      JacC(116,121) = JacC(116,121)+ 0.5100000000000000D-01*dw(310,121)
      JacC(119,110) = JacC(119,110)+ 0.5000000000000000D-01*dw(310,110)
      JacC(119,121) = JacC(119,121)+ 0.5000000000000000D-01*dw(310,121)
      JacC(121,110) = JacC(121,110) - dw(310,110)
      JacC(121,121) = JacC(121,121) - dw(310,121)
      JacC(123,110) = JacC(123,110)+ 0.7890000000000000D+00*dw(310,110)
      JacC(123,121) = JacC(123,121)+ 0.7890000000000000D+00*dw(310,121)
      JacC(124,110) = JacC(124,110) + dw(310,110)
      JacC(124,121) = JacC(124,121) + dw(310,121)
      JacC( 72, 72) = JacC( 72, 72) - dw(311, 72)
      JacC( 72,121) = JacC( 72,121) - dw(311,121)
      JacC(109, 72) = JacC(109, 72)+ 0.8240000000000000D+00*dw(311, 72)
      JacC(109,121) = JacC(109,121)+ 0.8240000000000000D+00*dw(311,121)
      JacC(112, 72) = JacC(112, 72)+ 0.2410000000000000D+00*dw(311, 72)
      JacC(112,121) = JacC(112,121)+ 0.2410000000000000D+00*dw(311,121)
      JacC(113, 72) = JacC(113, 72)+ 0.2800000000000000D+00*dw(311, 72)
      JacC(113,121) = JacC(113,121)+ 0.2800000000000000D+00*dw(311,121)
      JacC(114, 72) = JacC(114, 72)+ 0.3500000000000000D-01*dw(311, 72)
      JacC(114,121) = JacC(114,121)+ 0.3500000000000000D-01*dw(311,121)
      JacC(116, 72) = JacC(116, 72)+ 0.3810000000000000D+00*dw(311, 72)
      JacC(116,121) = JacC(116,121)+ 0.3810000000000000D+00*dw(311,121)
      JacC(119, 72) = JacC(119, 72)+ 0.2400000000000000D-01*dw(311, 72)
      JacC(119,121) = JacC(119,121)+ 0.2400000000000000D-01*dw(311,121)
      JacC(121, 72) = JacC(121, 72) - dw(311, 72)
      JacC(121,121) = JacC(121,121) - dw(311,121)
      JacC(123, 72) = JacC(123, 72)+ 0.6840000000000001D+00*dw(311, 72)
      JacC(123,121) = JacC(123,121)+ 0.6840000000000001D+00*dw(311,121)
      JacC(124, 72) = JacC(124, 72) + dw(311, 72)
      JacC(124,121) = JacC(124,121) + dw(311,121)
      JacC( 75, 75) = JacC( 75, 75) - dw(312, 75)
      JacC( 75,121) = JacC( 75,121) - dw(312,121)
      JacC(109, 75) = JacC(109, 75)+ 0.8690000000000000D+00*dw(312, 75)
      JacC(109,121) = JacC(109,121)+ 0.8690000000000000D+00*dw(312,121)
      JacC(112, 75) = JacC(112, 75)+ 0.2030000000000000D+00*dw(312, 75)
      JacC(112,121) = JacC(112,121)+ 0.2030000000000000D+00*dw(312,121)
      JacC(113, 75) = JacC(113, 75)+ 0.1800000000000000D+00*dw(312, 75)
      JacC(113,121) = JacC(113,121)+ 0.1800000000000000D+00*dw(312,121)
      JacC(116, 75) = JacC(116, 75)+ 0.5629999999999999D+00*dw(312, 75)
      JacC(116,121) = JacC(116,121)+ 0.5629999999999999D+00*dw(312,121)
      JacC(121, 75) = JacC(121, 75) - dw(312, 75)
      JacC(121,121) = JacC(121,121) - dw(312,121)
      JacC(123, 75) = JacC(123, 75)+ 0.8200000000000000D+00*dw(312, 75)
      JacC(123,121) = JacC(123,121)+ 0.8200000000000000D+00*dw(312,121)
      JacC(124, 75) = JacC(124, 75) + dw(312, 75)
      JacC(124,121) = JacC(124,121) + dw(312,121)
      JacC( 85, 85) = JacC( 85, 85) - dw(313, 85)
      JacC( 85,121) = JacC( 85,121) - dw(313,121)
      JacC(112, 85) = JacC(112, 85)+ 0.2000000000000000D+00*dw(313, 85)
      JacC(112,121) = JacC(112,121)+ 0.2000000000000000D+00*dw(313,121)
      JacC(119, 85) = JacC(119, 85)+ 0.1600000000000000D+01*dw(313, 85)
      JacC(119,121) = JacC(119,121)+ 0.1600000000000000D+01*dw(313,121)
      JacC(121, 85) = JacC(121, 85) - dw(313, 85)
      JacC(121,121) = JacC(121,121) - dw(313,121)
      JacC(123, 85) = JacC(123, 85) + dw(313, 85)
      JacC(123,121) = JacC(123,121) + dw(313,121)
      JacC(124, 85) = JacC(124, 85) + dw(313, 85)
      JacC(124,121) = JacC(124,121) + dw(313,121)
      JacC( 70, 70) = JacC( 70, 70) - dw(314, 70)
      JacC( 70,121) = JacC( 70,121) - dw(314,121)
      JacC(109, 70) = JacC(109, 70)+ 0.6000000000000000D-01*dw(314, 70)
      JacC(109,121) = JacC(109,121)+ 0.6000000000000000D-01*dw(314,121)
      JacC(112, 70) = JacC(112, 70)+ 0.9399999999999999D+00*dw(314, 70)
      JacC(112,121) = JacC(112,121)+ 0.9399999999999999D+00*dw(314,121)
      JacC(119, 70) = JacC(119, 70) + dw(314, 70)
      JacC(119,121) = JacC(119,121) + dw(314,121)
      JacC(121, 70) = JacC(121, 70) - dw(314, 70)
      JacC(121,121) = JacC(121,121) - dw(314,121)
      JacC(123, 70) = JacC(123, 70) + dw(314, 70)
      JacC(123,121) = JacC(123,121) + dw(314,121)
      JacC(124, 70) = JacC(124, 70) + dw(314, 70)
      JacC(124,121) = JacC(124,121) + dw(314,121)
      JacC( 92, 92) = JacC( 92, 92) - dw(315, 92)
      JacC( 92,121) = JacC( 92,121) - dw(315,121)
      JacC(109, 92) = JacC(109, 92)+ 0.2900000000000000D+00*dw(315, 92)
      JacC(109,121) = JacC(109,121)+ 0.2900000000000000D+00*dw(315,121)
      JacC(112, 92) = JacC(112, 92)+ 0.1710000000000000D+01*dw(315, 92)
      JacC(112,121) = JacC(112,121)+ 0.1710000000000000D+01*dw(315,121)
      JacC(121, 92) = JacC(121, 92) - dw(315, 92)
      JacC(121,121) = JacC(121,121) - dw(315,121)
      JacC(123, 92) = JacC(123, 92) + dw(315, 92)
      JacC(123,121) = JacC(123,121) + dw(315,121)
      JacC(124, 92) = JacC(124, 92) + dw(315, 92)
      JacC(124,121) = JacC(124,121) + dw(315,121)
      JacC( 80, 80) = JacC( 80, 80) - dw(316, 80)
      JacC( 80,121) = JacC( 80,121) - dw(316,121)
      JacC( 81, 80) = JacC( 81, 80)+ 0.6100000000000000D+00*dw(316, 80)
      JacC( 81,121) = JacC( 81,121)+ 0.6100000000000000D+00*dw(316,121)
      JacC( 84, 80) = JacC( 84, 80)+ 0.4380000000000000D+00*dw(316, 80)
      JacC( 84,121) = JacC( 84,121)+ 0.4380000000000000D+00*dw(316,121)
      JacC(119, 80) = JacC(119, 80)+ 0.1050000000000000D+01*dw(316, 80)
      JacC(119,121) = JacC(119,121)+ 0.1050000000000000D+01*dw(316,121)
      JacC(121, 80) = JacC(121, 80) - dw(316, 80)
      JacC(121,121) = JacC(121,121) - dw(316,121)
      JacC(123, 80) = JacC(123, 80) + dw(316, 80)
      JacC(123,121) = JacC(123,121) + dw(316,121)
      JacC(124, 80) = JacC(124, 80) + dw(316, 80)
      JacC(124,121) = JacC(124,121) + dw(316,121)
      JacC( 74, 74) = JacC( 74, 74) - dw(317, 74)
      JacC( 74,121) = JacC( 74,121) - dw(317,121)
      JacC(109, 74) = JacC(109, 74) + dw(317, 74)
      JacC(109,121) = JacC(109,121) + dw(317,121)
      JacC(112, 74) = JacC(112, 74) + dw(317, 74)
      JacC(112,121) = JacC(112,121) + dw(317,121)
      JacC(121, 74) = JacC(121, 74) - dw(317, 74)
      JacC(121,121) = JacC(121,121) - dw(317,121)
      JacC(123, 74) = JacC(123, 74) + dw(317, 74)
      JacC(123,121) = JacC(123,121) + dw(317,121)
      JacC(124, 74) = JacC(124, 74) + dw(317, 74)
      JacC(124,121) = JacC(124,121) + dw(317,121)
      JacC( 79, 79) = JacC( 79, 79) - dw(318, 79)
      JacC( 79,121) = JacC( 79,121) - dw(318,121)
      JacC( 84, 79) = JacC( 84, 79)+ 0.6150000000000000D+00*dw(318, 79)
      JacC( 84,121) = JacC( 84,121)+ 0.6150000000000000D+00*dw(318,121)
      JacC( 89, 79) = JacC( 89, 79)+ 0.3850000000000000D+00*dw(318, 79)
      JacC( 89,121) = JacC( 89,121)+ 0.3850000000000000D+00*dw(318,121)
      JacC(119, 79) = JacC(119, 79)+ 0.3850000000000000D+00*dw(318, 79)
      JacC(119,121) = JacC(119,121)+ 0.3850000000000000D+00*dw(318,121)
      JacC(121, 79) = JacC(121, 79) - dw(318, 79)
      JacC(121,121) = JacC(121,121) - dw(318,121)
      JacC(123, 79) = JacC(123, 79) + dw(318, 79)
      JacC(123,121) = JacC(123,121) + dw(318,121)
      JacC(124, 79) = JacC(124, 79) + dw(318, 79)
      JacC(124,121) = JacC(124,121) + dw(318,121)
      JacC( 86, 86) = JacC( 86, 86) - dw(319, 86)
      JacC( 86,121) = JacC( 86,121) - dw(319,121)
      JacC( 87, 86) = JacC( 87, 86)+ 0.5000000000000000D+00*dw(319, 86)
      JacC( 87,121) = JacC( 87,121)+ 0.5000000000000000D+00*dw(319,121)
      JacC( 89, 86) = JacC( 89, 86)+ 0.5000000000000000D+00*dw(319, 86)
      JacC( 89,121) = JacC( 89,121)+ 0.5000000000000000D+00*dw(319,121)
      JacC(104, 86) = JacC(104, 86) + dw(319, 86)
      JacC(104,121) = JacC(104,121) + dw(319,121)
      JacC(121, 86) = JacC(121, 86) - dw(319, 86)
      JacC(121,121) = JacC(121,121) - dw(319,121)
      JacC(123, 86) = JacC(123, 86) + dw(319, 86)
      JacC(123,121) = JacC(123,121) + dw(319,121)
      JacC(124, 86) = JacC(124, 86) + dw(319, 86)
      JacC(124,121) = JacC(124,121) + dw(319,121)
      JacC( 59, 64) = JacC( 59, 64)+ 0.3200000000000000D+00*dw(320, 64)
      JacC( 59,121) = JacC( 59,121)+ 0.3200000000000000D+00*dw(320,121)
      JacC( 64, 64) = JacC( 64, 64) - dw(320, 64)
      JacC( 64,121) = JacC( 64,121) - dw(320,121)
      JacC( 65, 64) = JacC( 65, 64)+ 0.7700000000000000D-01*dw(320, 64)
      JacC( 65,121) = JacC( 65,121)+ 0.7700000000000000D-01*dw(320,121)
      JacC( 66, 64) = JacC( 66, 64)+ 0.2300000000000000D-01*dw(320, 64)
      JacC( 66,121) = JacC( 66,121)+ 0.2300000000000000D-01*dw(320,121)
      JacC( 69, 64) = JacC( 69, 64)+ 0.7370000000000000D+00*dw(320, 64)
      JacC( 69,121) = JacC( 69,121)+ 0.7370000000000000D+00*dw(320,121)
      JacC( 91, 64) = JacC( 91, 64)+ 0.1860000000000000D+00*dw(320, 64)
      JacC( 91,121) = JacC( 91,121)+ 0.1860000000000000D+00*dw(320,121)
      JacC(102, 64) = JacC(102, 64)+ 0.6320000000000000D+00*dw(320, 64)
      JacC(102,121) = JacC(102,121)+ 0.6320000000000000D+00*dw(320,121)
      JacC(104, 64) = JacC(104, 64)+ 0.3680000000000000D+00*dw(320, 64)
      JacC(104,121) = JacC(104,121)+ 0.3680000000000000D+00*dw(320,121)
      JacC(121, 64) = JacC(121, 64) - dw(320, 64)
      JacC(121,121) = JacC(121,121) - dw(320,121)
      JacC(123, 64) = JacC(123, 64) + dw(320, 64)
      JacC(123,121) = JacC(123,121) + dw(320,121)
      JacC(124, 64) = JacC(124, 64) + dw(320, 64)
      JacC(124,121) = JacC(124,121) + dw(320,121)
      JacC( 77, 78) = JacC( 77, 78)+ 0.3200000000000000D+00*dw(321, 78)
      JacC( 77,121) = JacC( 77,121)+ 0.3200000000000000D+00*dw(321,121)
      JacC( 78, 78) = JacC( 78, 78) - dw(321, 78)
      JacC( 78,121) = JacC( 78,121) - dw(321,121)
      JacC(104, 78) = JacC(104, 78)+ 0.6800000000000000D+00*dw(321, 78)
      JacC(104,121) = JacC(104,121)+ 0.6800000000000000D+00*dw(321,121)
      JacC(115, 78) = JacC(115, 78)+ 0.6800000000000000D+00*dw(321, 78)
      JacC(115,121) = JacC(115,121)+ 0.6800000000000000D+00*dw(321,121)
      JacC(121, 78) = JacC(121, 78) - dw(321, 78)
      JacC(121,121) = JacC(121,121) - dw(321,121)
      JacC(123, 78) = JacC(123, 78) + dw(321, 78)
      JacC(123,121) = JacC(123,121) + dw(321,121)
      JacC(124, 78) = JacC(124, 78) + dw(321, 78)
      JacC(124,121) = JacC(124,121) + dw(321,121)
      JacC(114,118) = JacC(114,118) + dw(322,118)
      JacC(114,121) = JacC(114,121) + dw(322,121)
      JacC(118,118) = JacC(118,118) - dw(322,118)
      JacC(118,121) = JacC(118,121) - dw(322,121)
      JacC(121,118) = JacC(121,118) - dw(322,118)
      JacC(121,121) = JacC(121,121) - dw(322,121)
      JacC(124,118) = JacC(124,118) + dw(322,118)
      JacC(124,121) = JacC(124,121) + dw(322,121)
      JacC(113,122) = JacC(113,122) + dw(323,122)
      JacC(113,121) = JacC(113,121) + dw(323,121)
      JacC(121,122) = JacC(121,122) - dw(323,122)
      JacC(121,121) = JacC(121,121) - dw(323,121)
      JacC(122,122) = JacC(122,122) - dw(323,122)
      JacC(122,121) = JacC(122,121) - dw(323,121)
      JacC(124,122) = JacC(124,122) + dw(323,122)
      JacC(124,121) = JacC(124,121) + dw(323,121)
      JacC( 68, 68) = JacC( 68, 68) - dw(324, 68)
      JacC( 68,121) = JacC( 68,121) - dw(324,121)
      JacC( 69, 68) = JacC( 69, 68)+ 0.6700000000000000D+00*dw(324, 68)
      JacC( 69,121) = JacC( 69,121)+ 0.6700000000000000D+00*dw(324,121)
      JacC(119, 68) = JacC(119, 68)+ 0.3300000000000000D+00*dw(324, 68)
      JacC(119,121) = JacC(119,121)+ 0.3300000000000000D+00*dw(324,121)
      JacC(121, 68) = JacC(121, 68) - dw(324, 68)
      JacC(121,121) = JacC(121,121) - dw(324,121)
      JacC(123, 68) = JacC(123, 68)+ 0.6700000000000000D+00*dw(324, 68)
      JacC(123,121) = JacC(123,121)+ 0.6700000000000000D+00*dw(324,121)
      JacC(124, 68) = JacC(124, 68) + dw(324, 68)
      JacC(124,121) = JacC(124,121) + dw(324,121)
      JacC( 69,101) = JacC( 69,101) + dw(325,101)
      JacC( 69,121) = JacC( 69,121) + dw(325,121)
      JacC(101,101) = JacC(101,101) - dw(325,101)
      JacC(101,121) = JacC(101,121) - dw(325,121)
      JacC(121,101) = JacC(121,101) - dw(325,101)
      JacC(121,121) = JacC(121,121) - dw(325,121)
      JacC(123,101) = JacC(123,101) + dw(325,101)
      JacC(123,121) = JacC(123,121) + dw(325,121)
      JacC(124,101) = JacC(124,101) + dw(325,101)
      JacC(124,121) = JacC(124,121) + dw(325,121)
      JacC( 98, 98) = JacC( 98, 98) - dw(326, 98)
      JacC( 98,121) = JacC( 98,121) - dw(326,121)
      JacC(118, 98) = JacC(118, 98) + dw(326, 98)
      JacC(118,121) = JacC(118,121) + dw(326,121)
      JacC(119, 98) = JacC(119, 98) + dw(326, 98)
      JacC(119,121) = JacC(119,121) + dw(326,121)
      JacC(121, 98) = JacC(121, 98) - dw(326, 98)
      JacC(121,121) = JacC(121,121) - dw(326,121)
      JacC(124, 98) = JacC(124, 98) + dw(326, 98)
      JacC(124,121) = JacC(124,121) + dw(326,121)
      JacC( 93, 93) = JacC( 93, 93) - dw(327, 93)
      JacC( 93,121) = JacC( 93,121) - dw(327,121)
      JacC(111, 93) = JacC(111, 93) + dw(327, 93)
      JacC(111,121) = JacC(111,121) + dw(327,121)
      JacC(121, 93) = JacC(121, 93) - dw(327, 93)
      JacC(121,121) = JacC(121,121) - dw(327,121)
      JacC(123, 93) = JacC(123, 93) + dw(327, 93)
      JacC(123,121) = JacC(123,121) + dw(327,121)
      JacC(124, 93) = JacC(124, 93) + dw(327, 93)
      JacC(124,121) = JacC(124,121) + dw(327,121)
      JacC( 94, 94) = JacC( 94, 94) - dw(328, 94)
      JacC( 94,121) = JacC( 94,121) - dw(328,121)
      JacC(109, 94) = JacC(109, 94)+ 0.4640000000000000D+00*dw(328, 94)
      JacC(109,121) = JacC(109,121)+ 0.4640000000000000D+00*dw(328,121)
      JacC(112, 94) = JacC(112, 94)+ 0.1240000000000000D+01*dw(328, 94)
      JacC(112,121) = JacC(112,121)+ 0.1240000000000000D+01*dw(328,121)
      JacC(119, 94) = JacC(119, 94)+ 0.2870000000000000D+00*dw(328, 94)
      JacC(119,121) = JacC(119,121)+ 0.2870000000000000D+00*dw(328,121)
      JacC(121, 94) = JacC(121, 94) - dw(328, 94)
      JacC(121,121) = JacC(121,121) - dw(328,121)
      JacC(124, 94) = JacC(124, 94)+ 0.2000000000000000D+01*dw(328, 94)
      JacC(124,121) = JacC(124,121)+ 0.2000000000000000D+01*dw(328,121)
      JacC( 83, 83) = JacC( 83, 83) - dw(329, 83)
      JacC( 83,121) = JacC( 83,121) - dw(329,121)
      JacC(102, 83) = JacC(102, 83) + dw(329, 83)
      JacC(102,121) = JacC(102,121) + dw(329,121)
      JacC(112, 83) = JacC(112, 83)+ 0.7000000000000000D+00*dw(329, 83)
      JacC(112,121) = JacC(112,121)+ 0.7000000000000000D+00*dw(329,121)
      JacC(116, 83) = JacC(116, 83)+ 0.2300000000000000D+01*dw(329, 83)
      JacC(116,121) = JacC(116,121)+ 0.2300000000000000D+01*dw(329,121)
      JacC(118, 83) = JacC(118, 83)+ 0.2300000000000000D+01*dw(329, 83)
      JacC(118,121) = JacC(118,121)+ 0.2300000000000000D+01*dw(329,121)
      JacC(119, 83) = JacC(119, 83)+ 0.3000000000000000D+00*dw(329, 83)
      JacC(119,121) = JacC(119,121)+ 0.3000000000000000D+00*dw(329,121)
      JacC(121, 83) = JacC(121, 83) - dw(329, 83)
      JacC(121,121) = JacC(121,121) - dw(329,121)
      JacC(123, 83) = JacC(123, 83) + dw(329, 83)
      JacC(123,121) = JacC(123,121) + dw(329,121)
      JacC(124, 83) = JacC(124, 83) + dw(329, 83)
      JacC(124,121) = JacC(124,121) + dw(329,121)
      JacC( 76,105) = JacC( 76,105)+ 0.3300000000000000D+00*dw(330,105)
      JacC( 76,121) = JacC( 76,121)+ 0.3300000000000000D+00*dw(330,121)
      JacC(102,105) = JacC(102,105)+ 0.6670000000000000D+00*dw(330,105)
      JacC(102,121) = JacC(102,121)+ 0.6670000000000000D+00*dw(330,121)
      JacC(105,105) = JacC(105,105) - dw(330,105)
      JacC(105,121) = JacC(105,121) - dw(330,121)
      JacC(108,105) = JacC(108,105)+ 0.3300000000000000D+00*dw(330,105)
      JacC(108,121) = JacC(108,121)+ 0.3300000000000000D+00*dw(330,121)
      JacC(118,105) = JacC(118,105)+ 0.3300000000000000D+00*dw(330,105)
      JacC(118,121) = JacC(118,121)+ 0.3300000000000000D+00*dw(330,121)
      JacC(119,105) = JacC(119,105) + dw(330,105)
      JacC(119,121) = JacC(119,121) + dw(330,121)
      JacC(121,105) = JacC(121,105) - dw(330,105)
      JacC(121,121) = JacC(121,121) - dw(330,121)
      JacC(123,105) = JacC(123,105) + dw(330,105)
      JacC(123,121) = JacC(123,121) + dw(330,121)
      JacC(124,105) = JacC(124,105) + dw(330,105)
      JacC(124,121) = JacC(124,121) + dw(330,121)
      JacC( 53, 53) = JacC( 53, 53) - dw(331, 53)
      JacC( 53,121) = JacC( 53,121) - dw(331,121)
      JacC( 63, 53) = JacC( 63, 53) + dw(331, 53)
      JacC( 63,121) = JacC( 63,121) + dw(331,121)
      JacC(121, 53) = JacC(121, 53) - dw(331, 53)
      JacC(121,121) = JacC(121,121) - dw(331,121)
      JacC(124, 53) = JacC(124, 53) + dw(331, 53)
      JacC(124,121) = JacC(124,121) + dw(331,121)
      JacC( 54, 54) = JacC( 54, 54) - dw(332, 54)
      JacC( 54,121) = JacC( 54,121) - dw(332,121)
      JacC( 59, 54) = JacC( 59, 54)+ 0.3360000000000000D+00*dw(332, 54)
      JacC( 59,121) = JacC( 59,121)+ 0.3360000000000000D+00*dw(332,121)
      JacC( 65, 54) = JacC( 65, 54) + dw(332, 54)
      JacC( 65,121) = JacC( 65,121) + dw(332,121)
      JacC( 66, 54) = JacC( 66, 54)+ 0.5300000000000000D-01*dw(332, 54)
      JacC( 66,121) = JacC( 66,121)+ 0.5300000000000000D-01*dw(332,121)
      JacC(121, 54) = JacC(121, 54) - dw(332, 54)
      JacC(121,121) = JacC(121,121) - dw(332,121)
      JacC(123, 54) = JacC(123, 54) + dw(332, 54)
      JacC(123,121) = JacC(123,121) + dw(332,121)
      JacC(124, 54) = JacC(124, 54) + dw(332, 54)
      JacC(124,121) = JacC(124,121) + dw(332,121)
      JacC( 52, 52) = JacC( 52, 52) - dw(333, 52)
      JacC( 52,121) = JacC( 52,121) - dw(333,121)
      JacC( 69, 52) = JacC( 69, 52) + dw(333, 52)
      JacC( 69,121) = JacC( 69,121) + dw(333,121)
      JacC(102, 52) = JacC(102, 52) + dw(333, 52)
      JacC(102,121) = JacC(102,121) + dw(333,121)
      JacC(121, 52) = JacC(121, 52) - dw(333, 52)
      JacC(121,121) = JacC(121,121) - dw(333,121)
      JacC(123, 52) = JacC(123, 52) + dw(333, 52)
      JacC(123,121) = JacC(123,121) + dw(333,121)
      JacC(124, 52) = JacC(124, 52) + dw(333, 52)
      JacC(124,121) = JacC(124,121) + dw(333,121)
      JacC( 55, 55) = JacC( 55, 55) - dw(334, 55)
      JacC( 55,121) = JacC( 55,121) - dw(334,121)
      JacC( 63, 55) = JacC( 63, 55) + dw(334, 55)
      JacC( 63,121) = JacC( 63,121) + dw(334,121)
      JacC(121, 55) = JacC(121, 55) - dw(334, 55)
      JacC(121,121) = JacC(121,121) - dw(334,121)
      JacC(124, 55) = JacC(124, 55) + dw(334, 55)
      JacC(124,121) = JacC(124,121) + dw(334,121)
      JacC( 56, 56) = JacC( 56, 56) - dw(335, 56)
      JacC( 56,121) = JacC( 56,121) - dw(335,121)
      JacC( 59, 56) = JacC( 59, 56)+ 0.3200000000000000D+00*dw(335, 56)
      JacC( 59,121) = JacC( 59,121)+ 0.3200000000000000D+00*dw(335,121)
      JacC( 65, 56) = JacC( 65, 56) + dw(335, 56)
      JacC( 65,121) = JacC( 65,121) + dw(335,121)
      JacC( 66, 56) = JacC( 66, 56)+ 0.2300000000000000D-01*dw(335, 56)
      JacC( 66,121) = JacC( 66,121)+ 0.2300000000000000D-01*dw(335,121)
      JacC(121, 56) = JacC(121, 56) - dw(335, 56)
      JacC(121,121) = JacC(121,121) - dw(335,121)
      JacC(123, 56) = JacC(123, 56) + dw(335, 56)
      JacC(123,121) = JacC(123,121) + dw(335,121)
      JacC(124, 56) = JacC(124, 56) + dw(335, 56)
      JacC(124,121) = JacC(124,121) + dw(335,121)
      JacC( 62, 62) = JacC( 62, 62) - dw(336, 62)
      JacC( 62,121) = JacC( 62,121) - dw(336,121)
      JacC( 69, 62) = JacC( 69, 62) + dw(336, 62)
      JacC( 69,121) = JacC( 69,121) + dw(336,121)
      JacC( 91, 62) = JacC( 91, 62)+ 0.2050000000000000D+01*dw(336, 62)
      JacC( 91,121) = JacC( 91,121)+ 0.2050000000000000D+01*dw(336,121)
      JacC(102, 62) = JacC(102, 62) + dw(336, 62)
      JacC(102,121) = JacC(102,121) + dw(336,121)
      JacC(121, 62) = JacC(121, 62) - dw(336, 62)
      JacC(121,121) = JacC(121,121) - dw(336,121)
      JacC(123, 62) = JacC(123, 62) + dw(336, 62)
      JacC(123,121) = JacC(123,121) + dw(336,121)
      JacC(124, 62) = JacC(124, 62) + dw(336, 62)
      JacC(124,121) = JacC(124,121) + dw(336,121)
      JacC( 50, 67) = JacC( 50, 67) + dw(337, 67)
      JacC( 50,121) = JacC( 50,121) + dw(337,121)
      JacC( 67, 67) = JacC( 67, 67) - dw(337, 67)
      JacC( 67,121) = JacC( 67,121) - dw(337,121)
      JacC(121, 67) = JacC(121, 67) - dw(337, 67)
      JacC(121,121) = JacC(121,121) - dw(337,121)
      JacC(124, 67) = JacC(124, 67) + dw(337, 67)
      JacC(124,121) = JacC(124,121) + dw(337,121)
      JacC( 50, 50) = JacC( 50, 50) - dw(338, 50)
      JacC( 50,121) = JacC( 50,121) - dw(338,121)
      JacC( 51, 50) = JacC( 51, 50) + dw(338, 50)
      JacC( 51,121) = JacC( 51,121) + dw(338,121)
      JacC(121, 50) = JacC(121, 50) - dw(338, 50)
      JacC(121,121) = JacC(121,121) - dw(338,121)
      JacC(124, 50) = JacC(124, 50) + dw(338, 50)
      JacC(124,121) = JacC(124,121) + dw(338,121)
      JacC( 88, 88) = JacC( 88, 88) - dw(339, 88)
      JacC( 88,121) = JacC( 88,121) - dw(339,121)
      JacC(102, 88) = JacC(102, 88)+ 0.2100000000000000D+00*dw(339, 88)
      JacC(102,121) = JacC(102,121)+ 0.2100000000000000D+00*dw(339,121)
      JacC(104, 88) = JacC(104, 88)+ 0.1800000000000000D+00*dw(339, 88)
      JacC(104,121) = JacC(104,121)+ 0.1800000000000000D+00*dw(339,121)
      JacC(108, 88) = JacC(108, 88)+ 0.6100000000000000D+00*dw(339, 88)
      JacC(108,121) = JacC(108,121)+ 0.6100000000000000D+00*dw(339,121)
      JacC(109, 88) = JacC(109, 88)+ 0.7000000000000000D+00*dw(339, 88)
      JacC(109,121) = JacC(109,121)+ 0.7000000000000000D+00*dw(339,121)
      JacC(112, 88) = JacC(112, 88)+ 0.2700000000000000D+00*dw(339, 88)
      JacC(112,121) = JacC(112,121)+ 0.2700000000000000D+00*dw(339,121)
      JacC(119, 88) = JacC(119, 88)+ 0.3000000000000000D-01*dw(339, 88)
      JacC(119,121) = JacC(119,121)+ 0.3000000000000000D-01*dw(339,121)
      JacC(121, 88) = JacC(121, 88) - dw(339, 88)
      JacC(121,121) = JacC(121,121) - dw(339,121)
      JacC(123, 88) = JacC(123, 88) + dw(339, 88)
      JacC(123,121) = JacC(123,121) + dw(339,121)
      JacC(124, 88) = JacC(124, 88) + dw(339, 88)
      JacC(124,121) = JacC(124,121) + dw(339,121)
      JacC(115,116) = JacC(115,116) + dw(340,116)
      JacC(115,123) = JacC(115,123) + dw(340,123)
      JacC(116,116) = JacC(116,116) - dw(340,116)
      JacC(116,123) = JacC(116,123) - dw(340,123)
      JacC(123,116) = JacC(123,116) - dw(340,116)
      JacC(123,123) = JacC(123,123) - dw(340,123)
      JacC(114,116) = JacC(114,116) - dw(341,116)
      JacC(114,114) = JacC(114,114) - dw(341,114)
      JacC(116,116) = JacC(116,116) - dw(341,116)
      JacC(116,114) = JacC(116,114) - dw(341,114)
      JacC(119,116) = JacC(119,116) + dw(341,116)
      JacC(119,114) = JacC(119,114) + dw(341,114)
      JacC(123,116) = JacC(123,116) + dw(341,116)
      JacC(123,114) = JacC(123,114) + dw(341,114)
      JacC(114,116) = JacC(114,116) + dw(342,116)
      JacC(114,118) = JacC(114,118) + dw(342,118)
      JacC(116,116) = JacC(116,116) - dw(342,116)
      JacC(116,118) = JacC(116,118) - dw(342,118)
      JacC(118,116) = JacC(118,116) - dw(342,116)
      JacC(118,118) = JacC(118,118) - dw(342,118)
      JacC(116,116) = JacC(116,116)- 0.2000000000000000D+01*dw(343,116)
      JacC(116,116) = JacC(116,116)- 0.2000000000000000D+01*dw(343,116)
      JacC(116,116) = JacC(116,116) - dw(344,116)
      JacC(116,117) = JacC(116,117) - dw(344,117)
      JacC(117,116) = JacC(117,116) - dw(344,116)
      JacC(117,117) = JacC(117,117) - dw(344,117)
      JacC(124,116) = JacC(124,116) + dw(344,116)
      JacC(124,117) = JacC(124,117) + dw(344,117)
      JacC(116,116) = JacC(116,116) - dw(345,116)
      JacC(116,121) = JacC(116,121) - dw(345,121)
      JacC(121,116) = JacC(121,116) - dw(345,116)
      JacC(121,121) = JacC(121,121) - dw(345,121)
      JacC(124,116) = JacC(124,116) + dw(345,116)
      JacC(124,121) = JacC(124,121) + dw(345,121)
      JacC(104,107) = JacC(104,107) + dw(346,107)
      JacC(104,117) = JacC(104,117) + dw(346,117)
      JacC(107,107) = JacC(107,107) - dw(346,107)
      JacC(107,117) = JacC(107,117) - dw(346,117)
      JacC(117,107) = JacC(117,107) - dw(346,107)
      JacC(117,117) = JacC(117,117) - dw(346,117)
      JacC(123,107) = JacC(123,107) + dw(346,107)
      JacC(123,117) = JacC(123,117) + dw(346,117)
      JacC(124,107) = JacC(124,107) + dw(346,107)
      JacC(124,117) = JacC(124,117) + dw(346,117)
      JacC(107,107) = JacC(107,107) - dw(347,107)
      JacC(107,123) = JacC(107,123) - dw(347,123)
      JacC(115,107) = JacC(115,107) + dw(347,107)
      JacC(115,123) = JacC(115,123) + dw(347,123)
      JacC(123,107) = JacC(123,107) - dw(347,107)
      JacC(123,123) = JacC(123,123) - dw(347,123)
      JacC(104,107) = JacC(104,107) + dw(348,107)
      JacC(104,114) = JacC(104,114) + dw(348,114)
      JacC(107,107) = JacC(107,107) - dw(348,107)
      JacC(107,114) = JacC(107,114) - dw(348,114)
      JacC(114,107) = JacC(114,107) - dw(348,107)
      JacC(114,114) = JacC(114,114) - dw(348,114)
      JacC(119,107) = JacC(119,107) + dw(348,107)
      JacC(119,114) = JacC(119,114) + dw(348,114)
      JacC(123,107) = JacC(123,107) + dw(348,107)
      JacC(123,114) = JacC(123,114) + dw(348,114)
      JacC(104,107) = JacC(104,107) + dw(349,107)
      JacC(104,118) = JacC(104,118) + dw(349,118)
      JacC(107,107) = JacC(107,107) - dw(349,107)
      JacC(107,118) = JacC(107,118) - dw(349,118)
      JacC(114,107) = JacC(114,107) + dw(349,107)
      JacC(114,118) = JacC(114,118) + dw(349,118)
      JacC(118,107) = JacC(118,107) - dw(349,107)
      JacC(118,118) = JacC(118,118) - dw(349,118)
      JacC(104,107) = JacC(104,107) + dw(350,107)
      JacC(104,121) = JacC(104,121) + dw(350,121)
      JacC(107,107) = JacC(107,107) - dw(350,107)
      JacC(107,121) = JacC(107,121) - dw(350,121)
      JacC(121,107) = JacC(121,107) - dw(350,107)
      JacC(121,121) = JacC(121,121) - dw(350,121)
      JacC(123,107) = JacC(123,107) + dw(350,107)
      JacC(123,121) = JacC(123,121) + dw(350,121)
      JacC(124,107) = JacC(124,107) + dw(350,107)
      JacC(124,121) = JacC(124,121) + dw(350,121)
      JacC(113,122) = JacC(113,122) + dw(351,122)
      JacC(113,118) = JacC(113,118) + dw(351,118)
      JacC(114,122) = JacC(114,122) + dw(351,122)
      JacC(114,118) = JacC(114,118) + dw(351,118)
      JacC(118,122) = JacC(118,122) - dw(351,122)
      JacC(118,118) = JacC(118,118) - dw(351,118)
      JacC(122,122) = JacC(122,122) - dw(351,122)
      JacC(122,118) = JacC(122,118) - dw(351,118)
      JacC( 49,123) = JacC( 49,123)+ 0.5000000000000000D+00*dw(352,123)
      JacC(123,123) = JacC(123,123) - dw(352,123)
      JacC( 23,124) = JacC( 23,124)+ 0.5000000000000000D+00*dw(353,124)
      JacC(103,124) = JacC(103,124)+ 0.5000000000000000D+00*dw(353,124)
      JacC(124,124) = JacC(124,124) - dw(353,124)
      JacC(103,121) = JacC(103,121) + dw(354,121)
      JacC(121,121) = JacC(121,121) - dw(354,121)
      JacC( 17, 17) = JacC( 17, 17) - dw(355, 17)
      JacC(103, 17) = JacC(103, 17)+ 0.2000000000000000D+01*dw(355, 17)
 
      do j = 1, ns
         do i = 1, ns
            JacC(i,j) = JacC(i,j) * convers_factor_jac(i,j)
         enddo
      enddo
 
 
      RETURN
      END
 
